/*
 * 
 * @author Manuel Parras  
 */
package proyecto.arbol;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;
import java.awt.event.MouseEvent;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Enumeration;
import java.util.EventObject;
import java.util.Iterator;
import java.util.Vector;
import javax.swing.BoxLayout;
import javax.swing.CellEditor;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextField;
import javax.swing.JTree;
import javax.swing.event.CellEditorListener;
import javax.swing.event.ChangeEvent;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.text.BadLocationException;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.DefaultTreeSelectionModel;
import javax.swing.tree.TreeCellEditor;
import javax.swing.tree.TreeCellRenderer;
import javax.swing.tree.TreePath;
import org.apache.log4j.Logger;

import proyecto.editor.Editor;
import proyecto.editor.PanelEdicion;
import proyecto.imagenes.IconFactory;
import proyecto.paneles.VentanaEliminarProyecto;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.OperacionesFicheros;

/**
 * ArbolFicheros <br>
 * 
 * La clase hereda de Jpanel a cual le hemos introducido un JTree con unos nodos (ObjetoNodo) <br>
 * con ciertas caractersticas especiales para tener una objetividad mayor de
 * los ficheros de nuestro espacio de trabajo. Se le aade al rbol la
 * posibilidad de tener un men contextual con las cualidades
 * (MenuPopupArbol)tipicas de un browser.<br>
 * 
 * Dicha clase contiene el control del rbol de ficheros de nuestra aplicacin,
 * cuando se instancia por primera vez ella recibe una ruta fsica de nuestro
 * disco duro(workSpace) y se encarga de cargar los fichero con la extensin que
 * indican nuestro filtro (iAExtensiones), este proceso se realiza de forma
 * recursiva por su optimizacin. En proceso de carga tenemos acceso a nuestro
 * panel principal (PanelEdicion) esa relacin es necesaria para cuando nos
 * pulsan en un nodo de nuestro rbol, debemos cargar el fichero con el cdigo
 * fuente que contiene en nuestra aplicacin, es decir, nuestro clase
 * rbolficheros es la encargada de notificar que fichero cargar en cada
 * momento.<br>
 * 
 * @see proyecto.arbol.Nodo  ObjetoNodo
 * @see proyecto.arbol.MenuPopupArbol MenuPopupArbol
 * @see proyecto.editor.PanelEdicion PanelEdicion
 * 
 */
/**
 * @author Parras
 *
 */
public class ArbolFicheros extends JPanel implements KeyListener{

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;
	
	public static final String EXTENSION_JAVA ="java";
	public static final String EXTENSION_JAVACC ="jj";

	/** The Constant objLogger. */
	private static final Logger objLogger = Logger
			.getLogger(ArbolFicheros.class);

	/**
	 * Extensiones que va a reconocer nuestro arbol, si deceamos ver otro tipo
	 * de extensin solo tendramos que aadirla a este array.
	 */
	private static String[] iAExtensiones = {EXTENSION_JAVA, EXTENSION_JAVACC}; // extensiones

	

	/** The ruta fichero. */
	//private File rutaFichero = null;

	/** The arbol que contendra toda las estructura de nodos de nuestra aplicacin. */
	private JTree tree;

	/** Comunicacin con nuestro panel central
	 * @see proyecto.editor.PanelEdicion
	 */
	private PanelEdicion iPanel;

	/**Tiene el directorio origen desde donde vamos a cargar nuestro proyecto. */
	private File workSpace;

	/** The fichero que tendremos en memoria para la copia. */
	private File ficheroCopia = null;

	/** The carpeta que tenderemos en memoria para la copia. */
	private File carpetaCopia = null;

	// private Nodo nodoCortar=null;
	/** The variable que nos indica si vamos a cortar o a copiar. */
	private boolean cortar = false;

	/** Nodo de nuestro rbol que vamos a borrar */
	DefaultMutableTreeNode nodoEliminar = null;

	/** The lista paquetes Activos .
	 * @see proyecto.arbol.PaqueteActivos	PaqueteActivos
	 * 
	 */
	private ArrayList<PaqueteActivos> listaPaquetes = new ArrayList<PaqueteActivos>();
	
	/**
	 * Scroll de rbol 
	 */
	JScrollPane iScrollpaneArbol;

	// private ImageIcon ledVerde = new
	// ImageIcon("proyecto/imagenes/arbol.png");

	/**
	 * Constructor arbol ficheros.
	 * 
	 * Crea los paneles y llama al mtodo  de aadir nodos
	 * 
	 * Creado : Parras, 18-abr-2009
	 * 
	 * @param dir directorio que vamos a cargar
	 *            
	 * @param aPanel PanelEdicin al que vamos a referenciar
	 *            
	 */
	public ArbolFicheros(File dir, PanelEdicion aPanel) {

		if (dir != null && dir.exists()) {
			setLayout(new BorderLayout());
			// Crear el arbol y contruir
			tree = new JTree(addNodes(null, dir));
			DefaultTreeSelectionModel ldModelo = new DefaultTreeSelectionModel();
			ldModelo.setSelectionMode(DefaultTreeSelectionModel.SINGLE_TREE_SELECTION);
			tree.setSelectionModel(ldModelo);
			// tree.setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);
			iPanel = aPanel;
			workSpace = dir;

			tree.addMouseListener(new MenuPopupArbol(this));
			tree.addKeyListener(this);

			tree.setShowsRootHandles(true);
//			PonIcono iconosArbol = new PonIcono();
//			tree.setCellRenderer(iconosArbol);			
//			EditorListener editorListener = new EditorListener();
//			DefaultTreeCellRenderer renderer = (DefaultTreeCellRenderer) tree.getCellRenderer();
//			DefaultTreeCellEditor editor = new DefaultTreeCellEditor(tree,renderer, editorListener);			
//			tree.setCellEditor(editor);
//			tree.setEditable(true);
			tree.setCellRenderer(new PonIcono());
			tree.setCellEditor(new EditorListener());
			tree.setEditable(true);
			// listener
			tree.addTreeSelectionListener(new TreeSelectionListener() {
				public void valueChanged(TreeSelectionEvent e) {
					/*
					 * //DefaultMutableTreeNode nodo = (DefaultMutableTreeNode)
					 * e.getPath().getLastPathComponent();
					 * DefaultMutableTreeNode nodo= nodoSeleccionado();
					 * System.out.println(nodo); if (nodo !=null && !((Nodo)
					 * nodo.getUserObject()).getDirectorioOk ()){
					 * 
					 * rutaFichero =((Nodo)
					 * nodo.getUserObject()).getDirectorio(); try {
					 * abrirFichero(rutaFichero,((Nodo)
					 * nodo.getUserObject()).getNombreDirectorio()); } catch
					 * (BadLocationException e1) { e1.printStackTrace(); }
					 * System.out.println("Nodo Seleccionado " + nodo+ "
					 * ESDirectorio " + ((Nodo)
					 * nodo.getUserObject()).getDirectorioOk () + " Ruta " +
					 * ((Nodo) nodo.getUserObject()).getDirectorio()+ " Tiene
					 * Extension: " + ((Nodo)
					 * nodo.getUserObject()).getExtension()); }else{
					 * rutaFichero=null; } System.out.println(nodo);
					 * 
					 */
				}
			});

			// Lastly, put the JTree into a JScrollPane.
			iScrollpaneArbol = new JScrollPane();
			iScrollpaneArbol.getViewport().add(tree);
			add(BorderLayout.CENTER, iScrollpaneArbol);
		} else {// Devolvemos un panel vacio

			add(new JPanel());
		}
	}

	/* ordenar */
	/*
	 * DefaultMutableTreeNode oldNodes =
	 * (DefaultMutableTreeNode)tree.getModel().getRoot(); DefaultMutableTreeNode
	 * newNodes = new DefaultMutableTreeNode(oldNodes.getUserObject());
	 * 
	 * void visitNodes(DefaultMutableTreeNode oldNodes,DefaultMutableTreeNode
	 * newNodes ){
	 * 
	 * Vector sorted = sort(oldNodes.children());
	 * 
	 * for (int i = 0; i < sorted.size(); i++) { DefaultMutableTreeNode chNode =
	 * new DefaultMutableTreeNode(sorted.get(i)); newNodes.add(chNode);
	 * visitNodes((DefaultMutableTreeNode)sorted.get(i),chNode); } }
	 * 
	 * tree = new Tree(newNodes);
	 */

	/**
	 * Constructor arbol ficheros.
	 * Para usuarlo como depurador de la aplicacin
	 * Creado : Parras, 18-abr-2009
	 * 
	 * @param dir
	 *            the dir
	 */
	public ArbolFicheros(File dir) {
		setLayout(new BorderLayout());
		if (dir != null && dir.exists()) {
			// Crear el arbol y contruir
			JTree tree = new JTree(addNodes(null, dir));
			tree.addMouseListener(new MenuPopupArbol(this));
			tree.setCellRenderer(new PonIcono());
			tree.setCellEditor(new EditorListener());
			// listener
			tree.addTreeSelectionListener(new TreeSelectionListener() {
				public void valueChanged(TreeSelectionEvent e) {
					DefaultMutableTreeNode nodo = (DefaultMutableTreeNode) e
					.getPath().getLastPathComponent();
					if (nodo != null
							&& !((Nodo) nodo.getUserObject()).getDirectorioOk()) {

						System.out.println("Nodo Seleccionado "+((Nodo) nodo.getUserObject())
						.getDirectorio());

					} 

					//  + nodo+ "
					// ESDirectorio "
					// + ((Nodo) nodo.getUserObject()).getDirectorioOk () + "
					// Ruta " +
					// ((Nodo) nodo.getUserObject()).getDirectorio() );
				}
			});

			// Lastly, put the JTree into a JScrollPane.
			JScrollPane scrollpane = new JScrollPane();
			scrollpane.getViewport().add(tree);
			add(BorderLayout.CENTER, scrollpane);
		}
	}


	/**
	 * Mtodo que nos monta el arbol a traves de la ruta pasada como directorio.
	 * Estre mtodo es recursivo para el tratamiento de directorio.
	 * 
	 * @param nodo Nodo a tratar
	 * @param dir Directorio a tratar
	 * @return DefaultMutableTreeNode el nodo pasado como parametro fomrmado con su hijos.
	 */
	public DefaultMutableTreeNode addNodes(DefaultMutableTreeNode nodo, File dir) {

		String curPath = dir.getPath();
		DefaultMutableTreeNode curDir = new DefaultMutableTreeNode(new Nodo(
				dir, nodo));
		// Guardar una lista de paquetes de para nuestro jlist
		listaPaquetes.add(new PaqueteActivos(curDir, dir));
		if (nodo != null) { // Si el directorio raiz es nulo
			nodo.add(curDir);
		}
		Vector<String> ol = new Vector<String>();
		String[] tmp = dir.list();

		for (int i = 0; i < tmp.length; i++)
			ol.addElement(tmp[i]);
		Collections.sort(ol, String.CASE_INSENSITIVE_ORDER);
		File f;
		Vector<Nodo> files = new Vector<Nodo>();
		// Miramos si es carpeta o fichero
		for (int i = 0; i < ol.size(); i++) {
			String thisObject = ol.elementAt(i);
			String newPath;
			if (curPath.equals("."))
				newPath = thisObject;
			else
				newPath = curPath + File.separator + thisObject;
			if ((f = new File(newPath)).isDirectory())
				addNodes(curDir, f);
			else {
				if (acceptarExt(new File(thisObject))) {
					files.addElement(new Nodo(new File(curPath + File.separator
							+ thisObject), false, nodo));
					// System.out.println ("<******** "+curPath + File.separator
					// + thisObject );
				}
			}

		}
		// Los ficheros que nos quedan
		for (int fnum = 0; fnum < files.size(); fnum++) {
			curDir.add(new DefaultMutableTreeNode(new Nodo(new File(curPath
					+ File.separator + files.elementAt(fnum)), false, nodo)));
			// System.out.println ("---> "+curPath + File.separator
			// +files.elementAt(fnum) );
		}
		return curDir;
	}

	/* (non-Javadoc)
	 * @see javax.swing.JComponent#getMinimumSize()
	 */
	public Dimension getMinimumSize() {
		return new Dimension(200, 400);
	}

	/* (non-Javadoc)
	 * @see javax.swing.JComponent#getPreferredSize()
	 */
	public Dimension getPreferredSize() {
		return new Dimension(200, 400);
	}

	/**
	 * Acceptar ext.
	 * 
	 * @param file
	 *            the file
	 * 
	 * @return true, si es correcto Creado : Parras, 18-abr-2009
	 */
	public static boolean acceptarExt(File file) {
		if (file.isDirectory()) {
			return false;
		}
		String ext = getExtension(file);
		for (int j = 0; j < iAExtensiones.length; j++) {
			if (iAExtensiones[j].equalsIgnoreCase(ext)) {
				return true;
			}
		}
		return false;
	}

	/**
	 * Devuelve la extension de un fichero dado.
	 * 
	 * @param f
	 *            the f
	 * 
	 * @return the extension
	 */
	private static String getExtension(File f) {
		if (f != null) {
			String filename = f.getName();
			int i = filename.lastIndexOf('.');
			if (i > 0 && i < filename.length() - 1) {
				return filename.substring(i + 1);
			}
			;
		}
		return null;
	}

	// Kage Metodos

	/**
	 * Refrescar arbol. 
	 * No guarda el estado anterior del rbol.
	 * Creado : Parras, 18-abr-2009
	 */
	public void refrescarArbol() {
		tree.setModel(null);
		JTree aux = new JTree(addNodes(null, workSpace));
		tree.setModel(aux.getModel());
		tree.updateUI();

	}



	/**
	 * Copiar fichero. Creado : Parras, 18-abr-2009
	 */
	public void copiarFichero() {
		DefaultMutableTreeNode padreNodo = null;
		TreePath parentPath = getTree().getSelectionPath();

		if (parentPath != null) {
			// System.out.print("No Hay un nodo seleccionado");
			// } else {
			padreNodo = nodoSeleccionado(); // Aqui tengo donde quiero crear la
			// carpeta
			Nodo nodo = (Nodo) padreNodo.getUserObject();
			if (!nodo.getDirectorioOk()) {
				ficheroCopia = nodo.getDirectorio();

				if ( objLogger.isDebugEnabled() )
		            objLogger.debug("Copiar Fichero ");
			}

		}

	}

	/**
	 * Copiar carpeta. Creado : Parras, 18-abr-2009
	 */
	public void copiarCarpeta() {
		DefaultMutableTreeNode padreNodo = null;
		TreePath parentPath = getTree().getSelectionPath();

		if (parentPath != null) {
			// System.out.print("No Hay un nodo seleccionado");
			// } else {
			padreNodo = nodoSeleccionado(); // Aqui tengo donde quiero crear la
			// carpeta
			Nodo nodo = (Nodo) padreNodo.getUserObject();
			if (nodo.getDirectorioOk()) {
				carpetaCopia = nodo.getDirectorio();

			}

		}
		if ( objLogger.isDebugEnabled() )
            objLogger.debug("Copiar Carpeta ");

	}

	/**
	 * Cortar fcihero. Creado : Parras, 18-abr-2009
	 */
	void cortarFcihero() {
		DefaultMutableTreeNode padreNodo = null;
		TreePath parentPath = getTree().getSelectionPath();

		if (parentPath != null) {
			// System.out.print("No Hay un nodo seleccionado");
			// } else {
			padreNodo = nodoSeleccionado(); // Aqui tengo donde quiero crear la
			// carpeta
			Nodo nodo = (Nodo) padreNodo.getUserObject();
			if (!nodo.getDirectorioOk()) {
				ficheroCopia = nodo.getDirectorio();// Ruta que queremos copiar
				nodoEliminar = padreNodo;// Nodo despues de cortar que vamos
				// a elimianar
				cortar = true;
			}

		}
	}

	/**
	 * Renombrar path del arbol.
	 * 
	 *  Llamado por la acciones de rbol.
	 * Creado : Parras, 18-abr-2009
	 */
	void renombrarPath() {
		DefaultMutableTreeNode padreNodo = null;
		TreePath parentPath = getTree().getSelectionPath();
		String nombre = null;

		if (parentPath != null) {
			// System.out.print("No Hay un nodo seleccionado");
			// } else {
			padreNodo = nodoSeleccionado(); // Aqui tengo donde quiero crear la
			// carpeta
			Nodo nodo = (Nodo) padreNodo.getUserObject();			
			Nodo nodoOld = new Nodo (nodo.getDirectorio(),padreNodo);



			// && OperacionesFicheros.validadorFileName(nombre)
			//if (OperacionesFicheros.validadorFileName(nombre)) {

			if (nodo.getDirectorioOk()) {
				nombre = JOptionPane.showInputDialog(null, "Renombrar Carpeta: ",
						nodo.getNombreFicheroSinExtension());
				if (nombre != null && OperacionesFicheros.validadorFileName(nombre)) {

					if (nodo.getDirectorio().renameTo(
							new File(nodo.getDirectorio().getParent()
									.toString()
									+ File.separator + nombre))) {
						
						nodo.setFileyNombre(new File(nodo
								.getDirectorio().getParent().toString()
								+ File.separator + nombre));
						// Indica que hay cambios en el en el Nodo
						((DefaultTreeModel) tree.getModel())
						.nodeChanged(padreNodo);
						Editor.get().getPanel().actualizarFilesTabsConSusRutasDirectirio(nodoOld, nodo);
						renombrarArbol(padreNodo,nodoOld, nodo);
						if (padreNodo.isRoot()){ //es nuestro proyecto tenemos que actualizarlo
							Editor.get().setBorrarProyecto(nodoOld.getDirectorio());
							Editor.get().addProyecto(nodo.getDirectorio());
						}
					} else
						// System.out.println("ERROR AL RENOMBRAR CARPETA");
						iPanel
						.setTextoBarraEstado("ERROR AL RENOMBRAR CARPETA");
				}else{
					//verifico de que ha sido por el string del nombre no por cancelar
					if (OperacionesFicheros.validadorFileName(nombre))
						Mensajes.mensajeAtencion("Nombre introducido no vlido");
				}
			} else {// Es un fichero
				String extension = getExtension(nodo.getDirectorio());
				nombre = JOptionPane.showInputDialog(null,
						"Renombrar Fichero: ", nodo
						.getNombreFicheroSinExtension());
				if (nombre != null && OperacionesFicheros.validadorFileName(nombre)) {
					if (nodo.getDirectorio().renameTo(
							new File(nodo.getDirectorio().getParent()
									.toString()
									+ File.separator
									+ nombre
									+ "."
									+ extension))) {
						nodo
						.setFileyNombre(new File(nodo
								.getDirectorio().getParent()
								.toString()
								+ File.separator
								+ nombre
								+ "."
								+ extension));
						// Indica que hay cambios en el en el Nodo
						((DefaultTreeModel) tree.getModel()).nodeChanged(padreNodo);
						Editor.get().getPanel().actualizarFileTabConSuRutaArchivo(nodoOld, nodo);
					} else
						iPanel
						.setTextoBarraEstado("ERROR AL RENOMBRAR FICHERO");
				}else
					//verifico de que ha sido por el string del nombre no por cancelar
					if (OperacionesFicheros.validadorFileName(nombre))
						Mensajes.mensajeAtencion("Nombre introducido no vlido");
			}

			tree.updateUI();
		}

	}

	/**
	 * Ventana opcion borrar.
	 * 
	 * @param fichero
	 *            the fichero
	 * 
	 * @return true, si es correcto Creado : Parras, 18-abr-2009
	 */
	public boolean ventanaOpcionBorrar(String fichero) {

		int valor = JOptionPane.showConfirmDialog(null,
				"Estas Seguro de Eliminar " + fichero + "?", "Confirmacin",
				JOptionPane.YES_NO_OPTION);

		switch (valor) {
		case JOptionPane.YES_OPTION:
			// SI,Borrar Fichero
			return true;
		case JOptionPane.NO_OPTION:
			// No, Borramos el fichero
			return false;

		}

		return false;
	}

	/**
	 * Pegar fichero. Creado : Parras, 18-abr-2009
	 * 
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public void pegarFichero() throws IOException {
		DefaultMutableTreeNode padreNodo = null;
		DefaultTreeModel model = null;
		TreePath parentPath = getTree().getSelectionPath();
		File ficheroActual = null;

		

		if (parentPath != null) {
			// System.out.print("No Hay un nodo seleccionado");
			// } else {
			padreNodo = nodoSeleccionado(); // Aqui tengo donde quiero crear la
			// carpeta
			Nodo nodo = (Nodo) padreNodo.getUserObject();

			if (nodo != null) {
				// System.out.println(carpetaCopia);
				// De aqui tenemos que obterner la ruta del de la carpeta
				File auxfichero = nodo.getDirectorio();
				if (ficheroCopia != null) {
					// Aadimos el nombre del fichero
					// System.out.println("Mi Fichero a
					// copiar"+auxfichero.toString()+File.separator+ficheroCopia.getName());
					ficheroActual = new File(auxfichero.toString()
							+ File.separator + ficheroCopia.getName());
				}
				if (carpetaCopia != null) {
					// Aadimos el nombre del fichero
					// System.out.println("Mi Fichero a
					// copiar"+auxfichero.toString()+File.separator+carpetaCopia.getName());
					ficheroActual = new File(auxfichero.toString()
							+ File.separator + carpetaCopia.getName());
				}
				// Entramos en un fichero
				if (ficheroActual != null && !ficheroActual.exists()) {
					//System.out.println("Mi Fichero a copiar" + ficheroActual);
					if (carpetaCopia != null) {
						OperacionesFicheros.copyDirectorio(carpetaCopia,
								ficheroActual);
						// Insertamos su nod con sus hijos
						// public DefaultMutableTreeNode
						// addNodes(DefaultMutableTreeNode nodo, File dir)
						if (ficheroActual != null && ficheroActual.exists() ){				
							//DefaultMutableTreeNode lhijo  = addNodes(padreNodo, ficheroActual);
							//lModeloArbol.insertNodeInto(lhijo, padreNodo, posicionArbol(padreNodo, (Nodo) lhijo.getUserObject()));
							padreNodo.add(addNodes(padreNodo, ficheroActual));
							ordenarHijos(padreNodo);
						}
						
					}
					if (ficheroCopia != null) {
						OperacionesFicheros.copy(ficheroCopia, ficheroActual);
						// Solo tenemos que insertar un nodo
						padreNodo.add(new DefaultMutableTreeNode(new Nodo(
								ficheroActual, false, padreNodo)));
						ordenarHijos(padreNodo);
					}

					if (cortar) {
						model = (DefaultTreeModel) tree.getModel();
						// Debemos eliminar el File y eliminar del arbol
						if (!ficheroCopia.delete()) {// si no falla a copiar
							// debemos eliminar la
							// copia
							// System.out.println("ERROR AL CORTAR FICHERO");
							ficheroActual.delete();
							model.removeNodeFromParent(padreNodo);
						} else {
							model.removeNodeFromParent(nodoEliminar);

						}
						cortar = false;
					}
					tree.updateUI();
					// Borramos nuestro posibles fichero
					ficheroCopia = null;
					carpetaCopia = null;
				} else
					// System.out.println("El Fichero Existe en el directorio "+
					// auxfichero.toString());
					iPanel
					.setTextoBarraEstado("El Fichero Existe en el directorio "
							+ auxfichero.toString());

			}

		}
	}
	
	/**
	 * Ordena los hijos de un DefaultMutableTreeNode
	 * 
	 * @param aPadre
	 */
	@SuppressWarnings("unchecked")
	public void ordenarHijos(Object parent) {
		if (parent == null)
			return;

		if (parent instanceof DefaultMutableTreeNode) {
			DefaultMutableTreeNode node = (DefaultMutableTreeNode) parent;
			ArrayList children = Collections.list(node.children());
			Collections.sort(children,new ComparadorNodos());
			node.removeAllChildren();
			Iterator childrenIterator = children.iterator();
			while (childrenIterator.hasNext()) {
				node.add((DefaultMutableTreeNode) childrenIterator.next());
			}
		}
	}

	
	


	/**
	 * Abre crea un fichero o carpeta asociado.
	 * 
	 * @param nuevoPaquete
	 *            the nuevo paquete
	 * 
	 * @return true, if modifica la propiedad nuevo elemento
	 */

	public boolean setNuevoElemento(PaqueteActivos nuevoPaquete) {
		Nodo nuevo;
		DefaultMutableTreeNode padreNodo = nuevoPaquete.getNodo();

		// padreNodo = nodoSeleccionado(); //Aqui tengo donde quiero crear la
		// carpeta
		// Nodo nodo = (Nodo)padreNodo.getUserObject();
		File nuevoFile = nuevoPaquete.getficheroPadre();

		if (!nuevoFile.exists()) {
			if (getExtension(nuevoFile) == null) {
				if (nuevoFile.mkdir()) {
					nuevo = new Nodo(nuevoFile, padreNodo);
					// Al ser carpeta tenemos contancia de ella por si nos
					// quieren guardar mas datos en ella
					listaPaquetes.add(nuevoPaquete);
					DefaultTreeModel  lModeloArbol  = (DefaultTreeModel) tree.getModel();
					lModeloArbol.insertNodeInto(new DefaultMutableTreeNode(nuevo), padreNodo, posicionArbol(padreNodo, nuevo));
					//padreNodo.add(new DefaultMutableTreeNode(nuevo));
					tree.expandRow(padreNodo.getLevel());

					// expandJTree(tree,10);
				}
			}

			else {
				try {
					if (nuevoFile.createNewFile()) {
						nuevo = new Nodo(nuevoFile, false, padreNodo);
						DefaultTreeModel  lModeloArbol  = (DefaultTreeModel) tree.getModel();
						lModeloArbol.insertNodeInto(new DefaultMutableTreeNode(nuevo), padreNodo, posicionArbol(padreNodo, nuevo));
						//padreNodo.add(new DefaultMutableTreeNode(nuevo));
						try {
							abrirFichero(nuevoFile, nuevo);
						} catch (BadLocationException e) {
							// Error al Abrir fichero
							Mensajes
							.mensajeDetalles(
									"Se ha producido un error al leer el fichero",
									e);

						}
					}

				} catch (IOException e1) {
					Mensajes.mensajeDetalles(
							"Se ha producido un error al leer el fichero", e1);

				}

				// Aado al arbol

			}
			tree.updateUI();
			return true;
		} else
			return false;

	}

	/**
	 * Despliega arbol. Creado : Parras, 18-abr-2009
	 */
	public void despliegaArbol() {
		for (int i = 0; i < tree.getRowCount(); i++) {

			tree.expandRow(i);

		}

	}

	/**
	 * Expands all nodes in a JTree.
	 * 
	 * @param tree
	 *            The JTree to expand.
	 * @param depth
	 *            The depth to which the tree should be expanded. Zero will just
	 *            expand the root node, a negative value will fully expand the
	 *            tree, and a positive value will recursively expand the tree to
	 *            that depth.
	 */
	public static void expandJTree(javax.swing.JTree tree, int depth) {
		javax.swing.tree.TreeModel model = tree.getModel();
		expandJTreeNode(tree, model, model.getRoot(), 0, depth);
	} // expandJTree()

	/**
	 * Expands a given node in a JTree.
	 * 
	 * @param tree
	 *            The JTree to expand.
	 * @param model
	 *            The TreeModel for tree.
	 * @param node
	 *            The node within tree to expand.
	 * @param row
	 *            The displayed row in tree that represents node.
	 * @param depth
	 *            The depth to which the tree should be expanded. Zero will just
	 *            expand node, a negative value will fully expand the tree, and
	 *            a positive value will recursively expand the tree to that
	 *            depth relative to node.
	 * 
	 * @return the int
	 */
	public static int expandJTreeNode(javax.swing.JTree tree,
			javax.swing.tree.TreeModel model, Object node, int row, int depth) {
		if (node != null && !model.isLeaf(node)) {
			tree.expandRow(row);
			if (depth != 0) {
				for (int index = 0; row + 1 < tree.getRowCount()
				&& index < model.getChildCount(node); index++) {
					row++;
					Object child = model.getChild(node, index);
					if (child == null)
						break;
					javax.swing.tree.TreePath path;
					while ((path = tree.getPathForRow(row)) != null
							&& path.getLastPathComponent() != child)
						row++;
					if (path == null)
						break;
					row = expandJTreeNode(tree, model, child, row, depth - 1);
				}
			}
		}
		return row;
	} // expandJTreeNode()

	/**
	 * Modificar la propiedad carpeta.
	 * 
	 * @param nombre
	 *            La propiedad carpeta
	 */
	public void setCarpeta(String nombre) {
		DefaultMutableTreeNode padreNodo = null;
		TreePath parentPath = getTree().getSelectionPath();

		if (parentPath != null) {
			// System.out.print("No Hay un nodo seleccionado");
			// } else {
			padreNodo = nodoSeleccionado(); // Aqui tengo donde quiero crear la
			// carpeta
			Nodo nodo = (Nodo) padreNodo.getUserObject();
			File nuevaCarpeta = new File(nodo.getDirectorio().toString()
					+ File.separator + nombre);
			if (!nuevaCarpeta.exists() && nuevaCarpeta.mkdir()) {
				// System.out.println("CARPETA BIEN CREADA
				// "+nuevaCarpeta.toString());
				Nodo nuevo = new Nodo(nuevaCarpeta, padreNodo);
				// Aado al arbol
				DefaultTreeModel  lModeloArbol  = (DefaultTreeModel) tree.getModel();
				lModeloArbol.insertNodeInto(new DefaultMutableTreeNode(nuevo), padreNodo, posicionArbol(padreNodo, nuevo));
				//padreNodo.add(new DefaultMutableTreeNode(nuevo));
				tree.updateUI();
			} else
				// System.out.println("No Se Creo la Carpeta");
				iPanel.setTextoBarraEstado("No Se Creo la Carpeta");

		}

	}

	/**
	 * Modificar la propiedad fichero.
	 * 
	 * @param nombre
	 *            La propiedad fichero
	 */
	public void setFichero(String nombre) {
		DefaultMutableTreeNode padreNodo = null;
		TreePath parentPath = getTree().getSelectionPath();

		if (parentPath != null) {
			// System.out.print("NO Hay un nodo seleccionado");
			// } else {
			padreNodo = nodoSeleccionado(); // Aqui tengo donde quiero crear el
			// fichero
			Nodo nodo = (Nodo) padreNodo.getUserObject();
			File nuevoFichero = new File(nodo.getDirectorio().toString()
					+ File.separator + nombre);
			try {

				if (!nuevoFichero.exists() && nuevoFichero.createNewFile()) {
					// System.out.println("FICHERO BIEN CREADA
					// "+nuevoFichero.toString());
					Nodo nuevo = new Nodo(nuevoFichero, false, padreNodo);
					// Aado al arbol
					DefaultTreeModel  lModeloArbol  = (DefaultTreeModel) tree.getModel();
					lModeloArbol.insertNodeInto(new DefaultMutableTreeNode(nuevo), padreNodo, posicionArbol(padreNodo, nuevo));
					//padreNodo.add(new DefaultMutableTreeNode(nuevo));
					tree.updateUI();
				}// else
				// System.out.println("No Se Creo la FICHERO");
			} catch (IOException ex) {
				Mensajes.mensajeDetalles(
						"Se ha producido un error al leer el fichero", ex);
			}

		}

	}

	/**
	 * Nodo seleccionado.
	 * 
	 * @return the default mutable tree node Creado : Parras, 18-abr-2009
	 */
	public DefaultMutableTreeNode nodoSeleccionado() {
		TreePath ltselPath = null;
		DefaultMutableTreeNode nodo = null;
		//int selRow = getTree().getLeadSelectionRow();
		// System.out.println("Sel ROWWWWW "+ selRow);
		// if (selRow != -1 && selRow > 0){
		ltselPath = getTree().getSelectionPath();
		
		if (ltselPath != null)
			nodo = (DefaultMutableTreeNode) ltselPath.getLastPathComponent();				
		// }

		return nodo;
	}
	public Nodo getObjetoNodo (){
		Nodo lNodo = null;
		
		return lNodo;
	}
		

	/**
	 * Elimina el nodo actual.
	 */
	public void eliminarNodoActual() {
		TreePath selecciionActual = tree.getSelectionPath();
		if (selecciionActual != null) {
			DefaultMutableTreeNode nodoActual = (DefaultMutableTreeNode) (selecciionActual
					.getLastPathComponent());

			// Tiene padre
			DefaultMutableTreeNode padre = (DefaultMutableTreeNode) (nodoActual
					.getParent());
			if (padre != null) {
				DefaultTreeModel model = (DefaultTreeModel) tree.getModel();
				model.removeNodeFromParent(nodoActual);

				return;
			}
		}

	}

	/**
	 * Eliminar path seleccionado
	 * 
	 * Creado : Parras, 18-abr-2009
	 */
	void eliminarPath() {
		DefaultMutableTreeNode padreNodo = null;
		TreePath parentPath = getTree().getSelectionPath();

		if (parentPath == null) {
			// System.out.print("NO Hay un nodo seleccionado");
		} else {
			padreNodo = nodoSeleccionado(); // Aqui tengo donde quiero crear el
			if (!padreNodo.isRoot()) {
				// fichero
				Nodo nodo = (Nodo) padreNodo.getUserObject();
				if (ventanaOpcionBorrar(nodo.toString())) {
					if (OperacionesFicheros.deleteDirectorio(nodo
							.getDirectorio())) {
						eliminarNodoActual();
						// System.out.println("Se ha eliminado Correctamente");
						// Borramos el carpeta de nuestra lista de paquetes
						if (nodo.iBDirectorioOk)
							listaPaquetes.remove(new PaqueteActivos(null, nodo
									.getDirectorio()));

						Editor.get().getPanel().borrarTabsElimindasArbol(nodo);

					} else {
						// System.out.println("Error, al Elimirar
						// "+nodo.getDirectorio().setReadOnly());
						Mensajes.mensajeError("Error, al Elimirar "
								+ nodo.getDirectorio());

					}

				}
			} else {
				VentanaEliminarProyecto ventanaElimina = new VentanaEliminarProyecto(
						Editor.get(), true);
				ventanaElimina.setVisible(true);

			}
		}

	}

	/**
	 * Abrir fichero el fichero seleccionada en un tab.
	 * 
	 * Creado : Parras, 18-abr-2009
	 */
    public void abrirFichero (){
    	File rutaFichero; 
    	DefaultMutableTreeNode nodo= nodoSeleccionado();
    	
    	
			
    	 	//System.out.println(nodo);
			if (nodo !=null && !nodo.isRoot() && ((DefaultMutableTreeNode)nodo.getParent()).getUserObject() instanceof Nodo) {
				//para ajustar el scroll respecto el nodo visualizado
				iScrollpaneArbol.getHorizontalScrollBar().setValue(tree.getRowBounds(tree.getLeadSelectionRow()).x);
				Nodo nodoActual = ((Nodo) nodo.getUserObject());
				
				//System.out.print("abrirFichero MenuPopup " +((DefaultMutableTreeNode)nodo.getParent()).getUserObject());				
				Nodo nodoPadre = (Nodo)((DefaultMutableTreeNode)nodo.getParent()).getUserObject();
				
				verificarRaizPadreHijo(nodoPadre,nodoActual);
				//System.out.print("abrirFichero MenuPopup " +nodoActual.getDirectorio());
				nodoActual.setNodoPadre((DefaultMutableTreeNode) nodo.getParent());
				if (!((Nodo) nodo.getUserObject()).getDirectorioOk ()){
				 rutaFichero =nodoActual.getDirectorio();
				try {
					abrirFichero(rutaFichero,nodoActual);
					
				} catch (BadLocationException e1) {
					e1.printStackTrace();
				}
				}
//				System.out.println("Nodo Seleccionado " + nodo+ " ESDirectorio  "
//						+ ((Nodo) nodo.getUserObject()).getDirectorioOk () + "  Ruta " +
//						((Nodo) nodo.getUserObject()).getDirectorio()+ " Tiene Extension: " + ((Nodo) nodo.getUserObject()).getExtension());
			}else{
				rutaFichero=null;
			}
			//System.out.println(nodo);
    }      
        
        /**
		 * verificarRaizPadreHijo Verifica si tiene la misma raiz el padre que
		 * el hijo, si no es asi es porque se ha renombrado el nodo y debemos
		 * renombrarlo a l.
		 * 
		 * @param nodoPadre Nodo padre
		 *            
		 * @param nodoActual Nodo actual
		 *           
		 */
        private void verificarRaizPadreHijo(Nodo nodoPadre, Nodo nodoActual) {
        	
        	//System.out.println("\n"+nodoPadre.getDirectorio()+"=="+nodoActual.getDirectorio().getParent());
        	String padrePath=nodoPadre.getDirectorio().toString();
        	String hijoPath =nodoActual.getDirectorio().getParent().toString();
        	
        	if (!padrePath.equals(hijoPath)){
        		nodoActual.setFileyNombre(new File( padrePath+ File.separator + nodoActual.getNombreDirectorio()));					
        		// Indica que hay cambios en el en el Nodo
				//((DefaultTreeModel) tree.getModel()).nodeChanged(nodoPadre);
        	}
		
	}
	// Fin Kage Metodos

	/**
	 * Abrir fichero. Creado : Parras, 18-abr-2009
	 * 
	 * @param nombreArchivo
	 *            the nombre archivo
	 * @param nombreFichero
	 *            the nombre fichero
	 * 
	 * @throws BadLocationException
	 *             the bad location exception
	 */
	public void abrirFichero(File nombreArchivo, Nodo nombreFichero)
			throws BadLocationException {
		if (nombreArchivo.exists()) {
			try {
				// nos proporciona informacin acerca de los archivos, de sus
				// atributos, de los directorios

				// Obtenemos el tamao del fichero
				int tamanno = (int) nombreArchivo.length();

				// Caracteres a leer
				int car_Leer = 0;

				// Creamos el descriptor para leer el fichero
				FileReader in = new FileReader(nombreArchivo);

				// No creamos el array del tamao de fichero
				char[] data = new char[tamanno];

				// Empezamos a recorer el fichero miestras este preparado
				while (in.ready()) {

					car_Leer += in.read(data, car_Leer, tamanno - car_Leer);
				}
				in.close();

				// Guardamos todo lo leido de en nuestro panel

				iPanel.guardarTexto(new String(data, 0, car_Leer),
						nombreFichero);

				// Escribimos en nuestro estatuBar que se abierto el fichero.

			} catch (IOException e) {
				iPanel.setTextoBarraEstado("Error Abriendo " + nombreArchivo);
			}
			
		}else{
			iPanel
			.setTextoBarraEstado("Fichero no encontrado "
					+ nombreArchivo);
		}

	}

	/**
	 * Clase interna encargada de introduccir el Renderizado de nuestro rbol
	 * <br> si deseamos introducir un nuevo tipo de fichero  aqu introduciremos<br>
	 * su tipo de fichero.
	 */
	class PonIcono extends JPanel implements TreeCellRenderer {

		/** The Constant serialVersionUID. */
		private static final long serialVersionUID = -1441147641767333618L;

		/** The etiqueta. */
		JLabel etiqueta = new JLabel();

		/** The imagen. */
		JLabel imagen = new JLabel();

		/**
		 * Constructor pon icono.
		 * 
		 * Creado : Parras, 18-abr-2009
		 */
		public PonIcono() {
			super(new BorderLayout());
			add(imagen, BorderLayout.WEST);
			add(etiqueta, BorderLayout.CENTER);

			setOpaque(false);
		}

		/* (non-Javadoc)
		 * @see javax.swing.tree.TreeCellRenderer#getTreeCellRendererComponent(javax.swing.JTree, java.lang.Object, boolean, boolean, boolean, int, boolean)
		 */
		public java.awt.Component getTreeCellRendererComponent(JTree tree,
				Object value, boolean sel, boolean expanded, boolean leaf,
				int row, boolean hasFocus) {
			// http://www.chuidiang.com/java/JTree/ejemplo-simple-jtree.php
			DefaultMutableTreeNode raiz = (DefaultMutableTreeNode) value;
			Nodo nodo = (Nodo) raiz.getUserObject();
			etiqueta.setText(" " + raiz.getUserObject().toString());
			// Mirar la raiz
			// if (raiz.isRoot())

			// System.out.print("\n"+getClass().getResource(""));
			if (!nodo.getDirectorioOk()) {// aqui tenemos un fichero
				if (nodo.getExtension() != null
						&& nodo.getExtension().equals("java"))
					this.imagen.setIcon(IconFactory
							.getImage("arbolficherojava.png"));

				else if (nodo.getExtension() != null
						&& nodo.getExtension().equals("jj"))
					this.imagen.setIcon(IconFactory
							.getImage("arbolficherojj.png"));

			} else
				// Es un directorio
				this.imagen.setIcon(IconFactory.getImage("arbolcarpeta.png"));
			// this.imagen.setIcon(new
			// ImageIcon("proyecto/imagenes/led-verde"));

			// this.imagen.setIcon(new
			// ImageIcon("proyecto/imagenes/arbolfichero.png"));

			return this;
		}

	}

	// class EditorListener implements TreeCellEditor {
	//
	// public Component getTreeCellEditorComponent(JTree tree, Object value,
	// boolean isSelected, boolean expanded, boolean leaf, int row) {
	// // TreePath ltselPath = null;
	// // DefaultMutableTreeNode padreNodo = null;
	// // int selRow =getTree().getLeadSelectionRow();
	// // //System.out.println("Sel ROWWWWW "+ selRow);
	// // //if (selRow != -1 && selRow > 0){
	// // ltselPath = getTree().getSelectionPath();
	// // Nodo nodo=null;
	// //
	// // if (ltselPath!=null){
	// // padreNodo = (DefaultMutableTreeNode)ltselPath.getLastPathComponent();
	// // nodo= (Nodo)padreNodo.getUserObject();
	// // }
	// // if (nodo!=null){
	// //
	// // if (nodo.getDirectorioOk()){
	// //
	// // if (value!=null){
	// //
	// // if (nodo.getDirectorio().renameTo(new File
	// (nodo.getDirectorio().getParent().toString()+File.separator+value))){
	// // nodo.setNombreDirectorio(new File
	// (nodo.getDirectorio().getParent().toString()+File.separator+value));
	// // //Indica que hay cambios en el en el Nodo
	// // ((DefaultTreeModel)tree.getModel()).nodeChanged(padreNodo);
	// // }else
	// // //System.out.println("ERROR AL RENOMBRAR CARPETA");
	// // iPanel.setTextoBarraEstado("ERROR AL RENOMBRAR CARPETA");
	// // }
	// // }else{//Es un fichero
	// // String extension = getExtension(nodo.getDirectorio());
	// // if (value!=null){
	// // if(nodo.getDirectorio().renameTo(new File
	// (nodo.getDirectorio().getParent().toString()+File.separator+value+"."+extension))){
	// // nodo.setNombreDirectorio(new File
	// (nodo.getDirectorio().getParent().toString()+File.separator+value+"."+extension));
	// // //Indica que hay cambios en el en el Nodo
	// // ((DefaultTreeModel)tree.getModel()).nodeChanged(padreNodo);
	// // }else
	// // iPanel.setTextoBarraEstado("ERROR AL RENOMBRAR FICHERO");
	// // }
	// // }
	// // }
	// // return null;
	// return new JTextField("PEPE");
	// }
	//
	// public void addCellEditorListener(CellEditorListener arg0) {
	// // 
	//		
	// }
	//
	// public void cancelCellEditing() {
	// // 
	//		
	// }
	//
	// public Object getCellEditorValue() {
	// // 
	// return null;
	// }
	//
	// public boolean isCellEditable(EventObject arg0) {
	// // 
	// return false;
	// }
	//
	// public void removeCellEditorListener(CellEditorListener arg0) {
	// // 
	//		
	// }
	//
	// public boolean shouldSelectCell(EventObject arg0) {
	// // 
	// return false;
	// }
	//
	// public boolean stopCellEditing() {
	// 
	// return false;
	// }
	//	  
	// }
	
	
	/**
	 * 
	 * The listener interface for receiving editor events. The class that is
	 * interested in processing a editor event implements this interface, and
	 * the object created with that class is registered with a component using
	 * the component's <code>addEditorListener<code> method. When
	 * the editor event occurs, that object's appropriate
	 * method is invoked.
	 *
	 * @author Parras
	 *
	 */
	class EditorListener implements TreeCellEditor {

		/** The text editor. */
		TextFielEditor textEditor;
		
		/** The i default nodo. */
		DefaultMutableTreeNode iDefaultNodo;
		
		/** The valor anterior. */
		String valorAnterior="";

		/**
		 * Constructor editor listener.
		 * 
		 * Creado : Parras, 18-abr-2009
		 */
		public EditorListener() {
			TextFielEditor tE = new TextFielEditor();
			textEditor = tE;
		}
		
		/**
		 * Devuelve el Component que se usar para editar el dato.
		 * 
		 * @param tree
		 *            JTree en el que est el dato que se va a editar
		 * @param value
		 *            El dato a editar. Este valor debe meterse en el Component
		 *            que se usa para editar, de forma que sea el que se
		 *            muestre.
		 * @param isSelected
		 *            Si el dato est seleccionado en el JTree
		 * @param expanded
		 *            Si el nodo del dato est expandido
		 * @param leaf
		 *            Si el nodo del dato es hoja (no tiene hijos)
		 * @param row
		 *            Fila del JTree en el que est el dato.
		 * 
		 * @return El Component que hace de editor, mostrando value.
		 */

		public Component getTreeCellEditorComponent(JTree tree, Object value,
				boolean isSelected, boolean expanded, boolean leaf, int row) {
			DefaultMutableTreeNode nodoTree = (DefaultMutableTreeNode)value;
			Nodo nodo = (Nodo) nodoTree.getUserObject();

			iDefaultNodo=nodoTree;
			//System.out.print("Editor Arbol Nodo "+ nodo.getNombreFicheroSinExtension());
			valorAnterior=nodo.getNombreDirectorio();
			textEditor.setText(nodo.getNombreFicheroSinExtension());
			return textEditor;
		}

		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#addCellEditorListener(javax.swing.event.CellEditorListener)
		 */
		public void addCellEditorListener(CellEditorListener l) {
			textEditor.addCellEditorListener(l);

		}
		
		/**
		 * Debemos devolver el dato que ha recogido el editor.
		 * 
		 * @return El dato.
		 */
		public Object getCellEditorValue() {
			Nodo nodo = (Nodo) iDefaultNodo.getUserObject();
			Nodo nodoOld = new Nodo (nodo.getDirectorio(),iDefaultNodo);
			String lnombre =(String)textEditor.getCellEditorValue();			
			//boolean tratamientoTab=false;
			if (!lnombre.equals("")){
				if (nodo.getDirectorioOk()){//Directorio
					nodo.setNombreDirectorio(lnombre);
					if (nodo.getDirectorio().renameTo(
							new File(nodo.getDirectorio().getParent().toString()+ File.separator + lnombre))) {
						nodo.setFileyNombre(new File(nodo.getDirectorio().getParent().toString()+ File.separator + lnombre));					
						//este tratamiento se debe hacer cuando es una carpeta ya que esta cambia de ubicacin
						// y debemos informar al los tab operativos para su funcionamiento
						Editor.get().getPanel().actualizarFilesTabsConSusRutasDirectirio(nodoOld, nodo);
						
						renombrarArbol(iDefaultNodo,nodoOld, nodo);
						if (iDefaultNodo.isRoot()){ //es nuestro proyecto tenemos que actualizarlo
							Editor.get().setBorrarProyecto(nodoOld.getDirectorio());
							Editor.get().addProyecto(nodo.getDirectorio());
						}
						

					} 
				}else{//Fichero
					nodo.setNombreDirectorio((String)textEditor.getCellEditorValue()+"."+nodo.getExtension());
					if (nodo.getDirectorio().renameTo(new File(nodo.getDirectorio().getParent().toString()
							+ File.separator+lnombre+ "."+ nodo.getExtension()))) {
						nodo.setFileyNombre(new File(nodo.getDirectorio().getParent().toString()+ File.separator+
								lnombre+ "."+nodo.getExtension()));

						// Indica que hay cambios en el en el Nodo
						((DefaultTreeModel) tree.getModel()).nodeChanged(iDefaultNodo);
						Editor.get().getPanel().actualizarFileTabConSuRutaArchivo(nodoOld, nodo);
					}					
				}

			}else{
				nodo.setNombreDirectorio(valorAnterior);

			}





			return nodo;
		}

		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#removeCellEditorListener(javax.swing.event.CellEditorListener)
		 */
		public void removeCellEditorListener(CellEditorListener l) {
			textEditor.removeCellEditorListener(l);

		}

		/**
		 * Nos pasan el evento que ha sucedido sobre el nodo y debemos decidir
		 * si es un evento para empezar a editar o no. En este ejemplo se
		 * comprobar si es un triple click de ratn. El doble click ya lo tiene
		 * reservado el JTree para expandir/contraer nodos.
		 * 
		 * @param anEvent
		 *            Evento.
		 * 
		 * @return true si se debe empezar a editar el nodo.
		 */
		public boolean isCellEditable(EventObject anEvent)
		{
			// Se comprueba si el evento es un evento de ratn
			if (anEvent instanceof MouseEvent)
			{
				// Y si es tripe click
				if (((MouseEvent) anEvent).getClickCount() == 3)
				{
					return true;
				}
			}

			// En caso contrario no hay que editar.
			return false;
		}
		
		/**
		 * Para decidir si cuando se edita una celda, debe a su vez
		 * seleccionarse. Habitualmente se devuelve true, ya que al editar se
		 * suele querer que se seleccione. Se pude devolver false si se quiere
		 * editar una celda sin que se deseleccionen otras posibles celdas del
		 * JTree que estuvieran seleccionadas y sin que se seleccione la celda
		 * que estamos editando.
		 * 
		 * @param event
		 *            Evento que ha ocurrido sobre la celda.
		 * 
		 * @return true si queremos que se seleccione.
		 */
		public boolean shouldSelectCell(EventObject event) {
			return textEditor.shouldSelectCell(event);
		}
		
		/**
		 * Nos avisan que debemos detener la edicin y aceptar el valor que haya
		 * en el editor. Debemos devolver true si el valor del editor es valido
		 * y lo aceptamos. false en caso de que ese valor no sea correcto y no
		 * debamos aceptar la edicion.
		 * 
		 * @return true
		 */
		public boolean stopCellEditing() {


			return textEditor.stopCellEditing();
		}
		
		/**
		 * El JTree nos avisa de que se ha cancelado la edicin, por ejemplo, el
		 * usuario ha pinchado con el ratn en otro nodo sin terminar de editar
		 * el nuestro.
		 */
		public void cancelCellEditing() {
			textEditor.cancelCellEditing();
		}

	}

	/**
	 * The Class TextFielEditor.
	 */
	class TextFielEditor extends JTextField implements CellEditor {
		
		/** The Constant serialVersionUID. */
		private static final long serialVersionUID = 6030643053244310822L;
		
		/** The value. */
		String value = "";		
		
		/** The listeners. */
		Vector<CellEditorListener> listeners = new Vector<CellEditorListener>();

		/**
		 * Constructor text fiel editor.
		 * 
		 * Creado : Parras, 18-abr-2009
		 */
		public TextFielEditor() {
			addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent ae) {
					if (stopCellEditing()) {
						fireEditingStopped();
					}
				}
			});
		}

		/**
		 * Constructor text fiel editor.
		 * 
		 * Creado : Parras, 18-abr-2009
		 * 
		 * @param s
		 *            the s
		 */
		public TextFielEditor(String s) {
			super(s);
			// Listen to our own action events so that we know when to stop
			// editing.
			addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent ae) {
					if (stopCellEditing()) {
						fireEditingStopped();
					}
				}
			});
		}

		// Implement the CellEditor methods.
		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#cancelCellEditing()
		 */
		public void cancelCellEditing() {
			setText("");
		}

		// Stop editing only if the user entered a valid value.
		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#stopCellEditing()
		 */
		public boolean stopCellEditing() {
			try {
				String tmp = getText();
				value=getText();

				return OperacionesFicheros.validadorFileName(tmp);

			} catch (Exception e) {
				// Something went wrong (most likely we don't have a valid
				// integer).
				return false;
			}
		}

		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#getCellEditorValue()
		 */
		public Object getCellEditorValue() {
			return value;
		}

		// Start editing when the right mouse button is clicked.
		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#isCellEditable(java.util.EventObject)
		 */
		public boolean isCellEditable(EventObject eo) {
			if ((eo == null)
					|| ((eo instanceof MouseEvent) && (((MouseEvent) eo)
							.isMetaDown()))) {

				return true;
			}
			return false;
		}

		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#shouldSelectCell(java.util.EventObject)
		 */
		public boolean shouldSelectCell(EventObject eo) {
			return true;
		}

		// Add support for listeners.
		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#addCellEditorListener(javax.swing.event.CellEditorListener)
		 */
		public void addCellEditorListener(CellEditorListener cel) {
			listeners.addElement(cel);
		}

		/* (non-Javadoc)
		 * @see javax.swing.CellEditor#removeCellEditorListener(javax.swing.event.CellEditorListener)
		 */
		public void removeCellEditorListener(CellEditorListener cel) {
			listeners.removeElement(cel);
		}

		/**
		 * Fire editing stopped.<br> Creado : Parras, 18-abr-2009
		 */
		protected void fireEditingStopped() {
			if (listeners.size() > 0) {
				ChangeEvent ce = new ChangeEvent(this);
				for (int i = listeners.size() - 1; i >= 0; i--) {
					listeners.elementAt(i)
					.editingStopped(ce);
				}
			}
		}

	}

	/**
	 * Obtener el tree.
	 * 
	 * @return el tree<br> Creado : Parras, 18-abr-2009
	 */
	public JTree getTree() {
		return tree;
	}

	
	
	/**
	 * Posicion arbol.
	 * Inserta ordenado el nodo
	 * 
	 * @param editNodo
	 *            the edit nodo
	 * @param nodoNew
	 *            the nodo new
	 * 
	 * @return the int <br>Creado : Parras, 18-abr-2009
	 */
	public static int posicionArbol(DefaultMutableTreeNode editNodo,Nodo nodoNew) {

		//DefaultMutableTreeNode node = (DefaultMutableTreeNode)editPath.getParentPath().getLastPathComponent();

		Enumeration children = editNodo.children();
		int posicion =0;//si no encuentra inserta e la cero
		boolean lbOk=false;
		if ( objLogger.isDebugEnabled() )
            objLogger.debug("Fichero a insertar :" +nodoNew);

		while( children.hasMoreElements() && !lbOk ) {

			DefaultMutableTreeNode child =(DefaultMutableTreeNode) children.nextElement() ;
			
			//Debo Mirar si es carpeta o fichero para saber si es meno o mayor
			
			//System.out.print(" nodoNew.compareTo((Nodo)child.getUserObject() "+nodoNew.compareTo((Nodo)child.getUserObject()));
			if (nodoNew.compareTo((Nodo)child.getUserObject())==0)
				lbOk=true;
			else
				posicion ++;
			

		}
		//No hemos encontrado nuestro elemento y devolcemos posicin
	
		
		return posicion;
	}
	
	/**
	 * Nodo arbol encontrado.
	 * 
	 * @param editNodo
	 *            the edit nodo
	 * @param nodoNew
	 *            the nodo new
	 * 
	 * @return the default mutable tree node <br> Creado : Parras, 18-abr-2009
	 */
	public static DefaultMutableTreeNode nodoArbolEncontrado (DefaultMutableTreeNode editNodo,Nodo nodoNew) {

		
		Enumeration children = editNodo.children();		
		boolean lbOk=false;
		DefaultMutableTreeNode child=null;

		while( children.hasMoreElements() && !lbOk ) {

			 child =(DefaultMutableTreeNode) children.nextElement() ;
			
			//Debo Mirar si es carpeta o fichero para saber si es meno o mayor
			if (nodoNew.compareTo((Nodo)child.getUserObject())==0)
				lbOk=true;
			else//Nuestro hijo a nulo porque no lo hemos encontrado
				child=null;	

		}
	
		
		return child;
	}
	
	/**
	 * Método main.
	 * 
	 * @param av
	 *            the arguments
	 * 
	 *            <br>Creado : Parras, 18-abr-2009
	 */
	public static void main(String[] av) {

		JFrame frame = new JFrame("Arbol");
		frame.setForeground(Color.black);
		frame.setBackground(Color.lightGray);
		Container cp = frame.getContentPane();

		if (av.length == 0) {
			cp.add(new ArbolFicheros(new File(".")));
			// cp.add(new ArbolFicheros(new File("E:\\util")));
		} else {
			cp.setLayout(new BoxLayout(cp, BoxLayout.X_AXIS));
			// for (int i = 0; i < av.length; i++)
			// cp.add(new ArbolFicheros(new File(av[i])));
		}

		frame.pack();
		frame.setVisible(true);
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	// Para nuestra ventana de nuevo fichero
	/**
	 * Obtener la lista paquetes.<br>
	 * Para nuestra ventana de nuevo fichero
	 * @return el lista paquetes <br> Creado : Parras, 18-abr-2009
	 */
	public ArrayList<PaqueteActivos> getListaPaquetes() {
		return listaPaquetes;
	}

	/**
	 * Obtener la lista paquetes. Actualizada (por si existiera alguna renombrado)<br>
	 * Para nuestra ventana de nuevo fichero
	 * @return el lista paquetes <br> Creado : Parras, 18-abr-2009
	 */
	public ArrayList<PaqueteActivos> getListaPaquetesActualizada() {
		listaPaquetes = actualizarListaPaqueteActivos((DefaultMutableTreeNode) tree.getModel().getRoot());
		return listaPaquetes;
	}
	
	
	public ArrayList<PaqueteActivos> actualizarListaPaqueteActivos(DefaultMutableTreeNode aNodoRaiz)
	    {
	        DefaultMutableTreeNode node = null;
	        ArrayList<PaqueteActivos> listaPaquetes = new ArrayList<PaqueteActivos>();
	        
	        Enumeration enumeration = aNodoRaiz.breadthFirstEnumeration();
	        
	        //iterate through the enumeration
	        while(enumeration.hasMoreElements())
	        {
	            //get the node
	            node = (DefaultMutableTreeNode)enumeration.nextElement();
	            Nodo lNodo = (Nodo) node.getUserObject();
	            //match the string with the user-object of the node
	            if(lNodo.getDirectorioOk())
	            {
	            	listaPaquetes.add(new PaqueteActivos(node,lNodo.getDirectorio()));                      
	            }
	        }
	        //oredenamos para no tener la lista de fichero ordenados en amplitud.
	        Collections.sort(listaPaquetes);
	        //tree node with string node found return null
	        return listaPaquetes;
	    } 
	
	/**
	 * Modificar la propiedad lista paquetes.
	 * 
	 * @param listaPaquetes
	 *            La propiedad de  lista paquetes
	 */
	public void setListaPaquetes(ArrayList<PaqueteActivos> listaPaquetes) {
		this.listaPaquetes = listaPaquetes;
	}

	/**
	 * Eliminar un paquete.
	 * 
	 * @param aPaquete
	 *            the a paquete
	 * 
	 * @return true, si es correcto <br> Creado : Parras, 18-abr-2009
	 */
	
	class ComparadorNodos implements Comparator<DefaultMutableTreeNode> {

		@Override
		public int compare(DefaultMutableTreeNode o1, DefaultMutableTreeNode o2) {
			Nodo aNodo = (Nodo) o2.getUserObject();
			Nodo aNodo2 = (Nodo) o1.getUserObject();
			int lValor = -1;
			if (aNodo2.getDirectorioOk() && aNodo.getDirectorioOk()) {
				if (aNodo2.getNombreDirectorio().compareToIgnoreCase(aNodo
						.getNombreDirectorio()) > 0)
					lValor = 1;
				else
					lValor = 0;
				// directorio Fichero
			} else if (!aNodo2.getDirectorioOk() && aNodo.getDirectorioOk())
				lValor = 1;
			else if (aNodo2.getDirectorioOk() && !aNodo.getDirectorioOk())
				lValor = 0;
			else if (!aNodo2.getDirectorioOk() && !aNodo.getDirectorioOk()) {
				// Fichero Fichero
				if (aNodo2.getNombreDirectorio().compareToIgnoreCase(aNodo
						.getNombreDirectorio()) > 0)
					lValor = 1;
				else
					lValor = 0;

			} else
				// No hay nada en el arbol as que lo colocamos en cualquier sitio
				lValor = 0;

			return lValor;
		}	
		
	}
	
//	public boolean eliminarUnPaquete (PaqueteActivos aPaquete){
//		return listaPaquetes.remove(aPaquete);
//	}
//	
//	class ComparadorNodos implements Comparator<DefaultMutableTreeNode> {
//
//		@Override
//		public int compare(DefaultMutableTreeNode o1, DefaultMutableTreeNode o2) {
//			Nodo aNodo = (Nodo) o2.getUserObject();
//			Nodo aNodo2 = (Nodo) o1.getUserObject();
//			
//			
//			if (aNodo == null || aNodo.getDirectorio() == null)
//				return -1;
//			if (aNodo2 == null || aNodo2.getDirectorio() == null)
//				return  1;
//			System.out.print(aNodo.getDirectorio().getName() + " " + aNodo2.getDirectorio().getName() + " = "+  aNodo.getDirectorio().compareTo(aNodo2.getDirectorio())+ "\n");
//			
//			return aNodo.getDirectorio().compareTo(aNodo2.getDirectorio());
//			
//		}	
//	
//	}

	/* (non-Javadoc)
	 * @see java.awt.event.KeyListener#keyPressed(java.awt.event.KeyEvent)
	 */
	@Override
	public void keyPressed(KeyEvent e) {
		if (e.getSource() == tree){	
			//para ajustar el scroll respecto el nodo visualizado
			if (iScrollpaneArbol.getHorizontalScrollBar() !=null &&  tree.getRowBounds(tree.getLeadSelectionRow())!= null)
				iScrollpaneArbol.getHorizontalScrollBar().setValue(tree.getRowBounds(tree.getLeadSelectionRow()).x);
			
			if (e.getKeyCode() == KeyEvent.VK_DELETE)
				eliminarPath();
			
			if (e.getKeyCode() == KeyEvent.VK_ENTER)
				abrirFichero();			
			
			if (e.getKeyCode() == KeyEvent.VK_F5)
				refrescarArbol();
		
				
		}
		
	}

	/* (non-Javadoc)
	 * @see java.awt.event.KeyListener#keyReleased(java.awt.event.KeyEvent)
	 */
	@Override
	public void keyReleased(KeyEvent e) {
		
		
	}

	/* (non-Javadoc)
	 * @see java.awt.event.KeyListener#keyTyped(java.awt.event.KeyEvent)
	 */
	@Override
	public void keyTyped(KeyEvent e) {
		
		
	}
	/**
	 * Dado un  DefaultMutableTreeNode nos devuelve el objeto asociado en el arbol.
	 * Si es distinto de la clase Nodo nos devuelve un Null.
	 * @param aNodo
	 * @return
	 */
	private Nodo getObjetoArbol(DefaultMutableTreeNode aNodo){
		if (aNodo != null && aNodo.getUserObject() instanceof Nodo){
			return (Nodo) aNodo.getUserObject();
		}
		return null;
	}
	


    /**
     * Repara los nodos que estan situados en rbol.
     * Ejmeplo de renombrar: c:\javac\          	 ==> c:\javaCC
     * 								|c:\javac\|hola				|c:\javaCC\|hola
     * 
     * 
     * @param aNodoPadre DefaultMutableTreeNode
     * @param aNodoOld Nodo
     * @param aNodonNew
     * @return Nodo
     */
    public DefaultMutableTreeNode renombrarArbol(DefaultMutableTreeNode aNodoPadre,Nodo aNodoOld,Nodo aNodonNew)
    {
        DefaultMutableTreeNode node = null;
        //Ruta Antigua que deseamos renombrar
        String lRutaOld = aNodoOld.getDirectorio().toString();
        //Get the enumeration
         Enumeration enumeration = aNodoPadre.breadthFirstEnumeration();
        
        //iterate through the enumeration
        while(enumeration.hasMoreElements())
        {
            //get the node
            node = (DefaultMutableTreeNode)enumeration.nextElement();
           // System.out.print("\nNodo Recorrido "+node);            
            Nodo lNodoActual = getObjetoArbol(node);
            if (lNodoActual != null){
            	if (lNodoActual.getDirectorio() != null && !lNodoActual.getDirectorio().exists()
            			&& aNodonNew != null && aNodonNew.getDirectorio().exists()){
            		lNodoActual.setFileyNombre(parsearFile(lRutaOld,lNodoActual.getDirectorio().toString(),aNodonNew.getDirectorio().toString()));
            	}
            }
            //lNodoActual.setNombreDirectorio(lNodoActual.getNombreDirectorio)
            //match the string with the user-object of the node
//            if(nodeStr.equals(node.getUserObject().toString()))
//            {
//                //tree node with string found
//                return node;                         
//            }
        }
        
        //tree node with string node found return null
        return null;
    }
   
    /**
     * Repara el path erroneo en el rbol, esto sucede porque no renombran una carpeta.
     * 
     * @param aCadenaBuscar
     * @param aPathErroneo
     * @param aPathPdre
     * @return
     */
    public File parsearFile (String aCadenaBuscar, String aPathErroneo,String aPathPdre){
    	File lRutaPathReparada = null;
    	
    	//lugar donde tenemos que cortar
    	if ( aPathErroneo.startsWith(aCadenaBuscar)){
    		
    		lRutaPathReparada = new File (aPathPdre + File.separator +aPathErroneo.substring(aCadenaBuscar.length() +1, aPathErroneo.length()));
    	 if ( objLogger.isDebugEnabled() && !lRutaPathReparada.exists() )
        	objLogger.debug("Ruta No reparada :" +lRutaPathReparada);
    	}
    	return lRutaPathReparada;
    }

    /**
     * Busca un objeto Nodo en nuestro rbol. 
     * 
     * La busqueda se realiza en anchura.
     * @param aNodoRaiz
     * @param aNodoObjeto
     * @return
     */
    public DefaultMutableTreeNode buscarNodo(DefaultMutableTreeNode aNodoRaiz,Nodo aNodoObjeto)
    {
        DefaultMutableTreeNode node = null;
        
        
        Enumeration enumeration = aNodoRaiz.breadthFirstEnumeration();
        
        //iterate through the enumeration
        while(enumeration.hasMoreElements())
        {
            //get the node
            node = (DefaultMutableTreeNode)enumeration.nextElement();
            
            //match the string with the user-object of the node
            if(aNodoObjeto.compareTo((Nodo) node.getUserObject()) == 0)
            {
                //tree node with string found
                return node;                         
            }
        }
        
        //tree node with string node found return null
        return null;
    } 

}
