/*
 * 
 * @author Manuel Parras  
 */
package proyecto.arbol;

import java.io.File;

import javax.swing.tree.DefaultMutableTreeNode;

/**
 * Clase Nodo.<br>
 * Esta clase es la encargada de manejar la estructura que contiene un nodo de
 * nuestro rbol. Esta estructura extiende el interfaz comparable porque
 * necesitamos comparar un nodo con otro para su ordenacin en el rbol.<br>
 * La estructura formada por los siguientes atributos:
 * <ul>
 * <li>iFDirectorio variable encargada de saber la ruta fsica (disco duro) en
 * de nuestro fichero o directorio.
 * <li>iSNombreDirectorio contine el nombre que se mostrar en el nodo del
 * rbol.
 * <li>iBDirectorioOk incdica si es directorio o fichero (java o JavaCC).
 * <li>iExtension indica la extensin del fichero cargado en nuestro rbol
 * .java y .jj
 * <li>iNodoPadre esta variable nos referencia a padre de nodo tratado as
 * teniendo referencia a todos los nodos del rbol (estructura recuersiva).
 * </ul>
 * 
 * 
 * @author Manuel Parras
 */
public class Nodo implements Comparable<Nodo> {

	/** ifdirectorio ruta de nuestro directorio o fichero. */
	private File iFDirectorio;

	/** iSnombre nombre del fichero. */
	private String iSNombreDirectorio;

	/** iBdirectoriook indica si es directorio o no. */
	boolean iBDirectorioOk;

	/** iExtension extension */
	private String iExtension;

	/** iNodoPadre. referncia al padre de nuestro Nodo */
	private DefaultMutableTreeNode iNodoPadre;

	/**
	 * Constructor nodo.
	 * 
	 * Creado : Parras, 18-abr-2009
	 */
	public Nodo() {

	}

	/**
	 * Constructor nodo.
	 * 
	 * Creado : Parras, 18-abr-2009
	 * 
	 * @param aFDirectorio
	 *            the a f directorio
	 * @param aNodoPadre
	 *            the a nodo padre
	 */
	public Nodo(File aFDirectorio, DefaultMutableTreeNode aNodoPadre) {
		iFDirectorio = aFDirectorio;
		iSNombreDirectorio = aFDirectorio.getName();
		this.iBDirectorioOk = true;
		// iNodoPadre=aNodoPadre;
		// System.out.print("\nConstrucor 1 "+ aNodoPadre);
	}

	// NodoDirectorio si es false es un archivo

	/**
	 * Constructor nodo.
	 * 
	 * Creado : Parras, 18-abr-2009
	 * 
	 * @param aFDirectorio
	 *            the a f directorio
	 * @param nodirectorio
	 *            the nodirectorio
	 * @param aNodoPadre
	 *            the a nodo padre
	 */
	public Nodo(File aFDirectorio, boolean nodirectorio,
			DefaultMutableTreeNode aNodoPadre) {
		iFDirectorio = aFDirectorio;
		iSNombreDirectorio = aFDirectorio.getName();
		this.iBDirectorioOk = nodirectorio;
		if (!iBDirectorioOk)
			iExtension = getExtension(iFDirectorio);

		// iNodoPadre=aNodoPadre;
		// System.out.print("\nConstrucor 2 "+ aNodoPadre );
	}

	/**
	 * Obtener la extension de un fichero pasado por parametro.
	 * 
	 * @param f
	 *            fichero para quitar al extension
	 * 
	 * @return el extension <br>
	 *         Creado : Parras, 18-abr-2009
	 */
	private String getExtension(File f) {

		if (f != null) {
			String filename = f.getName();
			int i = filename.lastIndexOf('.');
			if (i > 0 && i < filename.length() - 1) {
				return filename.substring(i + 1);
			}
			;
		}
		return "";
	}

	/**
	 * Obtener el directorio.
	 * 
	 * @return el directorio <br>
	 *         Creado : Parras, 18-abr-2009
	 */
	public File getDirectorio() {
		return iFDirectorio;
	}

	/**
	 * Obtener el directorio ok.
	 * 
	 * @return el directorio ok <br>
	 *         Creado : Parras, 18-abr-2009
	 */
	public boolean getDirectorioOk() {
		return iBDirectorioOk;
	}

	/**
	 * Obtener el nombre directorio.
	 * 
	 * @return el nombre directorio <br>
	 *         Creado : Parras, 18-abr-2009
	 */
	public String getNombreDirectorio() {
		return iSNombreDirectorio;
	}

	/**
	 * setFileyNombre <br>
	 * Este metodo no actuliza nuestra ruta del directorio y el nombre que
	 * tendra nuesrta carpeta o fichero.
	 * 
	 * @param file
	 *            the file
	 */
	public void setFileyNombre(File file) {
		iFDirectorio = file;
		iSNombreDirectorio = file.getName();
	}

	/**
	 * Obtener el nombre fichero sin extension.
	 * 
	 * @return el nombre fichero sin extension <br>
	 *         Creado : Parras, 18-abr-2009
	 */
	public String getNombreFicheroSinExtension() {

		if (!iBDirectorioOk && iSNombreDirectorio != null) {
			int i = iSNombreDirectorio.lastIndexOf('.');
			if (i > 0 && i < iSNombreDirectorio.length() - 1) {
				return iSNombreDirectorio.substring(0, i);
			}
			;
		}

		// en otro caso devolvemos los que tengamos almazenado aqui ya que
		// posiblemente
		// sera una carpeta sin extensin
		return iSNombreDirectorio;
	}

	/**
	 * Hace una copia de nuestro objeto Nodo.
	 * 
	 * @param aCopia
	 *            Copia de nuesrto objeto
	 * 
	 */
	public void copia(Nodo aCopia) {
		aCopia.setExtension(this.iExtension);
		aCopia.setFileyNombre(this.iFDirectorio);
		aCopia.setNodoPadre(this.iNodoPadre);
		aCopia.setNombreDirectorio(this.iSNombreDirectorio);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return iSNombreDirectorio;
	}

	/**
	 * Obtener el extension.
	 * 
	 * @return el extension
	 * 
	 * <br>
	 *         Creado : Parras, 18-abr-2009
	 */
	public String getExtension() {
		return iExtension;
	}

	/**
	 * Modificar la propiedad extension.
	 * 
	 * @param extension
	 *            Asignar extension
	 */
	public void setExtension(String extension) {
		iExtension = extension;
	}

	/**
	 * Modificar la propiedad nombre directorio.
	 * 
	 * @param nombreDirectorio
	 *            Asigna la propiedad del nombre directorio
	 */
	public void setNombreDirectorio(String nombreDirectorio) {
		iSNombreDirectorio = nombreDirectorio;
	}

	
	
	
	
	
	
	
	/**
	 * Compara Nuestro Objeto nodo con otro, para tratar su ordenacin en rbol
	 * 
	 * <ul>
	 * <li>  >0 Indica que el directorio/fichero es mayor que el comparado
	 * <li>  =0 Mismo directorio/fichero comparado
	 * <li>  <0 Indica que el directorio/fichero es menor que el comparado
	 * </ul>
	 * @param aNodo
	 *            Nodo.
	 * @return int	 
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	public int compareTo(Nodo aNodo) {
		// System.out.print("\n"+iSNombreDirectorio+" = "+aNodo.getNombreDirectorio()+" "+
		// this.iSNombreDirectorio.compareTo(aNodo.getNombreDirectorio()));
		// directorio directorio
		
		if (aNodo == null || aNodo.getDirectorio() == null)
			return -1;
		if (getDirectorio() == null)
			return  1;
		
		return getDirectorio().compareTo(aNodo.getDirectorio());

	}

	/**
	 * Obtener el nodo padre.
	 * 
	 * @return iNodoPadre DefaultMutableTreeNode <br>Creado : Parras, 18-abr-2009
	 */
	public DefaultMutableTreeNode getNodoPadre() {

		return iNodoPadre;
	}

	/**
	 * Modificar la propiedad nodo padre.
	 * 
	 * @param aNodoPadre Asigna Nuestro nodo padre
	 *            
	 */
	public void setNodoPadre(DefaultMutableTreeNode aNodoPadre) {
		iNodoPadre = aNodoPadre;
	}

}
