/*
 * 
 * @author Manuel Parras  
 */
package proyecto.arbol;

import java.io.File;

import javax.swing.tree.DefaultMutableTreeNode;

/**
 * PaqueteActivos<br>
 *<p> Este es el objeto encargado de saber los paquetes (carpetas) que estn
 * activos en el proyecto. Cuando vamos a insertar un nuevo fichero o carpeta 
 * por el botn de nuevo tenemos una lista de paquetes haciendo as ms
 * eficiente la aplicacin, y no teniendo que recorrer el rbol para insertar un
 * nuevo fichero.</p> <p>Solo guardamos la referencia a Nodo que pertenece y el fichero
 * donde se crear.</p><br>
 * <p>Si se hace alguna modificacin en la alguna paquete del rbol debemos
 * actualizar nuestro objeto al estado correspondiente.<br></p>
 * <br>
 * Creado : Parras, 19-abr-2009
 */
public class PaqueteActivos implements Comparable<PaqueteActivos>{

	/** Nodo de arbol donde vamos a insertar. */
	DefaultMutableTreeNode nodo; // Nodo de arbol donde vamos a insertar

	/** ficheroPadre el que tenemos que formatear para nuestra ventana de nuevo. */
	File ficheroPadre; // ficheroPadre en que tenemos que hacer formatear para
						// nuestra ventana de nuevo

	// File ficherNuevo;

	/**
	 * Constructor paquete activos.
	 * 
	 * Creado : Parras, 19-abr-2009
	 * 
	 * @param aNodo
	 *            DefaultMutableTreeNode
	 * 
	 * @param aficheroPadre
	 *            File
	 * 
	 */
	public PaqueteActivos(DefaultMutableTreeNode aNodo, File aficheroPadre) {

		nodo = aNodo;
		ficheroPadre = aficheroPadre;
	}

	/**
	 * Obtener el fichero padre.
	 * 
	 * @return el fichero padre <br>
	 *         Creado : Parras, 19-abr-2009
	 */
	public File getficheroPadre() {
		return ficheroPadre;
	}

	/**
	 * Modificar la propiedad fichero padre.
	 * 
	 * @param ficheroPadre
	 *            El fichero padre
	 * 
	 */
	public void setficheroPadre(File ficheroPadre) {
		this.ficheroPadre = ficheroPadre;
	}

	public DefaultMutableTreeNode getNodo() {
		return nodo;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#hashCode()
	 */
	@Override
	public int hashCode() {
		final int PRIME = 31;
		int result = 1;
		result = PRIME * result
				+ ((ficheroPadre == null) ? 0 : ficheroPadre.hashCode());
		return result;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		final PaqueteActivos other = (PaqueteActivos) obj;
		if (ficheroPadre == null) {
			if (other.ficheroPadre != null)
				return false;
		} else if (!ficheroPadre.equals(other.ficheroPadre))
			return false;
		return true;
	}

	/**
	 * Modificar la propiedad nodo.
	 * 
	 * @param nodo
	 *            La propiedad nodo
	 */
	public void setNodo(DefaultMutableTreeNode nodo) {
		this.nodo = nodo;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	public String toString() {
		return ficheroPadre.toString();
	}

	/* (non-Javadoc) Usamose el comparador de File.
	 * @see java.lang.Comparable#compareTo(java.lang.Object)
	 */
	@Override
	public int compareTo(PaqueteActivos aPaquete) {

		// ... Sort primerio los directorio
		// Otro caso alfabetico
				return ficheroPadre.compareTo(aPaquete.getficheroPadre());
		
	}

	// public File getFicherNuevo() {
	// return ficherNuevo;
	// }
	//
	// public void setFicherNuevo(File ficherNuevo) {
	// this.ficherNuevo = ficherNuevo;
	// }
}
