/*
 * 
 * @author Manuel Parras  
 */
package proyecto.consola;

import proyecto.arbol.Nodo;

/**
 * CompilacionDatos <br>
 * Es un objeto bsico que no sirve para referenciar un fichero compilado con
 * errores. Este objeto contendr la referencia a su fila y a su columna. 
 * <br>
 * <p>Este
 * objeto se montar cuando no encontremos un error y su link asociado llevara
 * insertado este tipo de objeto </p>
 * 
 * @see proyecto.consola.ConsolaOutStream#getLineaYColumna
 **/
public class CompilacionDatos {
	
	/** Fila en la que se encuentra nuestro error. */
	private int fila=-1;
	
	/** The Columna en la que se encuentra nuestro error. */
	private int columna;
	
	/**Referencia al fichero que hemos compilado */
	private Nodo ficheroCompiladoDatos;
	/** Indica la posicin de array en la que esta la compilacin*/
	private int posicion;
	
	/**
	 * Constructor compilacion datos.
	 * 
	 * Creado : Parras, 22-jun-2009
	 */
	public CompilacionDatos(){
		
	}
	
	/**
	 * Constructor compilacion datos.
	 * 
	 * Creado : Parras, 22-jun-2009
	 * 
	 * @param aFila
	 *            fila
	 * @param aColumna
	 *            columna
	 * @param aficheroCompiladoDatos
	 *             afichero compilado con datos
	 */
	public CompilacionDatos(int aFila,int aColumna,Nodo aficheroCompiladoDatos){
		fila=aFila;
		columna=aColumna;
		ficheroCompiladoDatos=aficheroCompiladoDatos;
		crearCopia (aficheroCompiladoDatos);
	}
	
	/**
	 * crearCopia<br>
	 *  Se creara una copia para guardar nuestro nodo y tener una
	 * referencia a l por si nos cierra nuestro tab.
	 * 
	 * @param aficheroCompiladoDatos
	 *            the afichero compilado datos
	 */
	private void crearCopia (Nodo aficheroCompiladoDatos){
		ficheroCompiladoDatos = new Nodo();
		aficheroCompiladoDatos.copia(ficheroCompiladoDatos);
	}
	
	/**
	 * Obtener el columna.
	 * 
	 * @return el columna 
	 * <br>Creado : Parras, 22-jun-2009
	 */
	public int getColumna() {
		return columna;
	}
	
	/**
	 * Modificar la propiedad columna.
	 * 
	 * @param columna
	 *            La propiedad columna
	 */
	public void setColumna(int columna) {
		this.columna = columna;
	}
	
	/**
	 * Obtener el fichero compilado datos.
	 * 
	 * @return el fichero compilado datos 
	 * <br>Creado : Parras, 22-jun-2009
	 */
	public Nodo getficheroCompiladoDatos() {
		return ficheroCompiladoDatos;
	}
	
	/**
	 * Modificar la propiedad fichero compilado datos.
	 * 
	 * @param ficheroCompiladoDatos
	 *            La propiedad fichero compilado datos
	 */
	public void setficheroCompiladoDatos(Nodo ficheroCompiladoDatos) {
		this.ficheroCompiladoDatos = ficheroCompiladoDatos;
	}
	
	/**
	 * Obtener el fila.
	 * 
	 * @return el fila Creado : Parras, 22-jun-2009
	 */
	public int getFila() {
		return fila;
	}
	
	/**
	 * Modificar la propiedad fila.
	 * 
	 * @param fila
	 *            La propiedad fila
	 */
	public void setFila(int fila) {
		this.fila = fila;
	}
	
	/**
	 * esValido
	 * <br> Esta funcin nos devuelve cierto si los datos son suficientes
	 * para el tratamiento del los datos, tales como que exista el fichero y un tipo de error.
	 * 
	 * @return boolean
	 */
	public boolean esValido(){
		return (ficheroCompiladoDatos!=null && ficheroCompiladoDatos.getDirectorio()!=null 
				&& ficheroCompiladoDatos.getDirectorio().exists() &&  fila !=-1 );
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString (){
		if (!this.esValido())
			return  "";
		else
			return ficheroCompiladoDatos.getDirectorio().toString();
	}

	/**
	 * Obtener el posicion.
	 * 
	 * @return el posicion Creado : Parras, 14-feb-2010
	 */
	public int getPosicion() {
		return posicion;
	}

	/**
	 * Modificar la propiedad posicion.
	 * 
	 * @param posicion
	 *            La propiedad posicion
	 */
	public void setPosicion(int posicion) {
		this.posicion = posicion;
	}
}
