/*
 * 
 * @author Manuel Parras  
 */
package proyecto.consola;

import java.awt.Color;
import java.io.ByteArrayOutputStream;

import javax.swing.text.BadLocationException;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.StyleConstants;
import javax.swing.text.html.HTMLDocument;

import org.apache.log4j.Logger;

import proyecto.arbol.Nodo;

/**
 * <p>
 * ConsolaOutStream
 * </p>
 * 
 * 
 * Clase encargada de generar un documento HTML vlido, dicho texto HTML
 * contiene la informacin recogida del compilador. La informacin del
 * compilador ha sido parseada para el reconocimiento del error, si existiere.
 * <p>
 * El error es parseado para convertirlo en un link, para cuando este sea
 * pulsado nos lleve a la altura en la que se encuentra nuestro error en el
 * documento.
 * </p>
 * <p>
 * Todo compilacin que reciba un fichero ser derivada hacia nuestra salida de
 * la consola, para realizar esta operacin cambiamos el flujo de nuestra salida
 * estndar de java.
 * </p>
 * @see proyecto.consola.ConsolaTextPane
 */
public class ConsolaOutStream extends ByteArrayOutputStream {

	/** objLogger. */
	private static final Logger objLogger = Logger.getLogger(ConsolaOutStream.class);

	/**@see proyecto.consola.ConsolaTextPane */
	private ConsolaTextPane textPane;
	// private Color textColor;
	// private StyledDocument document;
	/**@see javax.swing.text.html.HTMLDocument */
	private HTMLDocument document;

	/**
	 * <p>Atributos que contiene todo lo necesario para al el color y tipo de letra</p> 
	 * @see javax.swing.text.SimpleAttributeSet */
	private SimpleAttributeSet attributos;

	/**<p>Fichero que vamos a a compilar</p>
	 * 
	 *  @see proyecto.arbol.Nodo
	 **/
	private Nodo iFileFicheroACompilar;

	/** @see java.awt.Color */
	private Color iColor;

	/**
	 * Constructor consola out stream.
	 * 
	 * Creado : Parras, 24-jun-2009
	 * 
	 * @param textPane
	 *            ConsolaTextPane
	 * @param aFicheroaCompilacion
	 *            Fichero que vamos a compilar
	 *            
	 */
	public ConsolaOutStream(ConsolaTextPane textPane, Nodo aFicheroaCompilacion) {
		this(textPane, textPane.getForeground(), aFicheroaCompilacion);

	}

	/**
	 * Constructor consola out stream.
	 * 
	 * Creado : Parras, 24-jun-2009
	 * 
	 * @param textPane
	 *            the text pane
	 * @param textoColor
	 *            the texto color
	 * @param aFicheroaCompilacion
	 *            the a ficheroa compilacion
	 *            
	 * 
	 * @see proyecto.consola.ConsolaTextPane
	 */
	public ConsolaOutStream(ConsolaTextPane textPane, Color textoColor,
			Nodo aFicheroaCompilacion) {
		this.textPane = textPane;
		// this.document = textPane.getStyledDocument();
		this.document = (HTMLDocument) textPane.getDocument();
		iFileFicheroACompilar = aFicheroaCompilacion;
		iColor = textoColor;
		attributos = new SimpleAttributeSet();
		StyleConstants.setForeground(attributos, textoColor);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.io.OutputStream#flush()
	 */
	synchronized public void flush() {
		// StringBuffer lValor =new StringBuffer(toString());

		if (!toString().equals("")) {
			StringBuffer lValor;
			if (iColor.equals(Color.RED))
				lValor = new StringBuffer(
						"<div style=\"color: red;\" align=\"left\">"
								+ toString().replaceAll("\n", "<br>")
								+ "</div>");
			else
				lValor = new StringBuffer(toString().replaceAll("\n", "<br>"));

			// Encountered "public" at line 1, column 1.
			// if ( objLogger.isDebugEnabled() ){
			// objLogger.debug("\nTexto Consola :  "+toString().trim());
			// }
			lValor.indexOf("line");
			lValor.indexOf("column");
			int atLine = lValor.indexOf("at line");// principio donde nos
													// podemosencontrar el error
			int atLine2 = lValor.indexOf("Line");// principio donde nos
													// podemosencontrar el error
			if (atLine > 0) {
				int fin = atLine + lValor.substring(atLine).indexOf(".");
				lValor.insert(fin + 1,
						"<div style=\"color: red;\" align=\"left\">");
			

				String valores[] = lValor.substring(atLine, fin).split(
						"[^0-9]+");
				// Generar Link de enlace
				// ("<html><A HREF>Texto de enlace. Indice</A>")
				// lValor.split("[^0-9]+")
				lValor.replace(atLine + 1, fin, "<A HREF=\" "+textPane.addCompilacion(getLineaYColumna(valores))+"\">" + " "
						+ lValor.substring(atLine, fin) + "</A>");
				
				
				
				lValor.append("</div>");
				// segundo tipo

			} else if (atLine2 > 0) {
				// Line 70, Column 3
				int fin = atLine2 + lValor.substring(atLine2).indexOf(":");
				lValor.insert(fin + 1,
						"<div style=\"color: red;\" align=\"left\">");
				// Generar Link de enlace
				// ("<html><A HREF>Texto de enlace. Indice</A>")
				lValor.replace(atLine2, fin, "<A HREF>" + " "
						+ lValor.substring(atLine2, fin) + "</A>");

				String valores[] = lValor.substring(atLine2, fin).split(
						"[^0-9]+");
				// lValor.split("[^0-9]+")
				textPane.addCompilacion(getLineaYColumna(valores));
				lValor.append("</div>");
			}

			// String htmlText ="<head><base href=\"file:d:/\"></head>"+
			// "<b>hola</b><br>" + "<i>adios</i><br>" +
			// "<font face=\"arial\">fuente arial</font><br>" +
			// "<font face=\"courier\">fuente courier</font><br>" +
			// "<font size=\"24\">fuente grande</font><br>" +
			// "<font color=\"red\">color rojo</font><br>" +
			// "<img src=\"viejo.gif\"></img>";

			// limpiamos todo lo que hay en nuestro documento, por que lo
			// tenemos insertado en nustro
			// Buffer
			// document.replace(0, document.getLength(), "", null);

			// document.insertBeforeEnd(document.getDefaultRootElement(),"<div style=\"color: black;\" align=\"left\">"+
			// lValor.toString()+"</div>");
			// document.insertBeforeEnd(document.getDefaultRootElement(),htmlText);

			try {
				document.insertString(document.getLength(), lValor.toString(),
						attributos);
			} catch (BadLocationException e) {
				
				if (objLogger.isDebugEnabled()) 
					objLogger.debug(" flush-->ConsolaOut "+e);
			}

			// if ( objLogger.isDebugEnabled() ){
			// objLogger.debug("\nTexto Consola :  "+"<div style=\"color: black;\" align=\"left\">"+
			// lValor.toString()+"</div>");
			// }

			textPane.getCaret().setDot(Integer.MAX_VALUE);
			// Se ha comentado esto para que vaya acumulando en el buffer y as
			// sacar una salida limpia
			reset();

		}
	}

	/**
	 * getLineaYColumna<br>
	 * Este mtodo nos montar nuestro Objeto compilacionDatos para el uso de la
	 * ubicacin en nuestro fichero.<br>
	 * 
	 * En el caso de existir algn problema en la bsqueda se iniciar en la
	 * posicin (0,0). <br>
	 * 
	 * @param aValor
	 *            valor
	 * 
	 * @return CompilacionDatos la linea y columna
	 * 
	 * @see proyecto.consola.CompilacionDatos
	 */
	public CompilacionDatos getLineaYColumna(String[] aValor) {
		boolean lbOk;
		CompilacionDatos compilacionDatos = null;
		int fila = -1;
		int columna = 0;// este simpre lo ponemos a 0 por si existen problemas a
						// la hora de buscar los datos
		if (aValor != null) {
			lbOk = false;
			int i = 0;
			String lvalor;
			while (i < aValor.length && !lbOk) {
				lvalor = aValor[i];
				if (lvalor.matches("[0-9]+") && Integer.valueOf(lvalor) > 0) {
					if (fila == -1)
						fila = Integer.parseInt(lvalor);

					else {
						columna = Integer.parseInt(lvalor);
						lbOk = true;
					}
				}
				i++;
			}
		}
		if (fila != -1) {
			compilacionDatos = new CompilacionDatos(fila, columna,
					iFileFicheroACompilar);
		} else {
			compilacionDatos = new CompilacionDatos(0, 0, iFileFicheroACompilar);
		}
		return compilacionDatos;
	}

}