/*
 * 
 * @author Manuel Parras  
 */
package proyecto.editor;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.JTextPane;
import proyecto.utilidades.OperacionesVentanas;


/**
 * BuscarYRemplazar
 * 
 * <p>
 * Ventana que implementa en patrn singleton sincronizado (para solo uso de una
 * sola instancia)para que solo la tengamos que crearla una sola vez y poder
 * hacer uso de la ventana en cualquier momento
 * </p>
 * <p>
 * En la clase tenemos la instancia del editor, con la cual podemos monopolizar
 * cualquier cosa de la ventana, esto es til para marcar el texto de la
 * bsqueda en los tab (siempre buscamos en la ventana Activa)
 * </p>
 * <p>
 * El uso para buscar la palabras en el Tab activo lo hacemos mediante
 * expresiones regulares (Clase Pattern y Matcher)
 * </p>
 * 
 * <p>
 * La explicacin del uso de la ventana:
 * </p>
 * 
 * <p>
 * Mediante el comando Buscar podemos buscar texto en el tab activo. Podemos
 * ejecutarlo desde el men Editar, Buscar o con la combinacin de teclas Ctrl +
 * B.
 * </p>
 * <p>
 * Si antes de llamar a este comando, seleccionamos la palabra o frase a buscar,
 * esta aparecer en el campo Buscar, si no lo hacemos tendremos que teclearla.
 * Pulsar el botn Buscar siguiente y cuando EpSilon encuentre la palabra, nos
 * llevar a esa. Si queremos buscar otra ocurrencia de la palabra pulsar de
 * nuevo el botn Buscar siguiente o fuera de la ventana F3.
 * </p>
 * Cuando EpSilon llegue al final del volvera principio del texto tab activo. Si
 * necesitamos refinar nuestra bsqueda tenemos ms opciones disponibles.
 * <p>
 * <b>Opciones</b>
 * </p>
 * <ul>
 * <li>Sensible May/min: Podemos hacer que la bsqueda diferencie o no entre
 * maysculas y minsculas.</li>
 * <li>Palabra completa: Se puede especificar que busque texto que contenga la
 * palabra buscada o que busque exactamente la palabra completa.</li>
 * </ul>
 * <p>
 * <b>Usos:</b>
 * </p>
 * <ul>
 * <li>Literal: Palabra completa como esta en el panel de texto.
 * <li>Comodn :Para ver qu smbolos se pueden usar como comodn sobrepasamos
 * el ratn para ver su tooltiptext, activar esa casilla y hacer clic en el
 * botn Especial. Por ejemplo, el comodn ? sustituye a cualquier carcter; el
 * comodn * sustituye a cualquier conjunto de caracteres</li>
 * <li>Expresiones regulares: Podemos buscar y sustituir expresiones regulares.
 * Un resumen de expresiones regulares: <tbody>
 * <TABLE cellspacing="10" cellpadding="10" border="3">
 * <tr>
 * <td>.</td>
 * <td>Concuerda con cualquier carcter.</td>
 * </tr>
 * <tr>
 * <td>(</td>
 * <td>Seala el inicio de una regin para marcar una concordancia; as, lo que
 * est agrupado entre ( ) puede utilizarse en "Reemplazar con" usando \1, \2,
 * etc.</td>
 * </tr>
 * <tr>
 * <td>)</td>
 * <td>Seala el final de una regin agrupada.</td>
 * </tr>
 * <tr>
 * <td>\n</td>
 * <td>Donde n el un entero del 1 al 9 que hace referencia de la primera a la
 * novena regiones agrupadas para reemplazarlas. Por ejemplo, si la cadena de
 * bsqueda fuera Fred([1-9])XXX y la cadena de reemplazo fuera Sam\1YYY, al
 * aplicarlas a Fred2XXX generara Sam2YYY.</td>
 * </tr>
 * <tr>
 * <td>\<</td>
 * <td>Concuerda con el principio de una palabra.</td>
 * </tr>
 * <tr>
 * <td>\></td>
 * <td>Concuerda con el final de una palabra.</td>
 * </tr>
 * <tr>
 * <td>\x</td>
 * <td>Le permite utilizar un carcter x que, de otra forma, tendra un
 * significado especial. Por ejemplo, \[ se interpretara como [, y no como el
 * inico de un conjunto de caracteres.</td>
 * </tr>
 * <tr>
 * <td>[...]</td>
 * <td>Indica un conjunto de caracteres; por ejemplo, [abc] concuerda con
 * cualquiera de los caracteres a, b  c. Tambin puede utilizar rangos, por
 * ejemplo, [a-z] para cualquier carcter en minscula.</td>
 * </tr>
 * <tr>
 * <td>[^...]</td>
 * <td>El complementario de los caracteres del conjunto. Por ejemplo, [^A-Za-z]
 * concuerda con cualquier carcter excepto los alfabticos.</td>
 * </tr>
 * <tr>
 * <td>^</td>
 * <td>Concuerda con el principio de una lnea (excepto cuando se utiliza dentro
 * de un conjunto, ver arriba).</td>
 * </tr>
 * <tr>
 * </tr>
 * <tr>
 * </tr>
 * <tr>
 * </tr>
 * </tbody>
 * </table>
 * </li>
 * </ul>
 * 
 * @author Parras
 * @see java.util.regex.Matcher
 * @see java.util.regex.Pattern
 */
public class BuscarYRemplazar extends JDialog implements ActionListener {

	/** Constant serialVersionUID. */
	private static final long serialVersionUID = -4418954002712814766L;

	/** buscar. Creado : Parras, 19-oct-2009 */
	 JTextField fBuscar;

	/** remplazar. Creado : Parras, 19-oct-2009 */
	private JTextField fRemplazar;

	/** boton buscar sig. */
	private JButton bBuscarSig;

	/** boton remplazar. */
	private JButton bRemplazar;

	/** boton remplazar todo. */
	private JButton bRemplazarTodo;

	/** boton activar remplazar. */
	private JButton bActivarRemplazar;

	/** boton cerrar. */
	private JButton bCerrar;

	/** cbox sensitivo min may. */
	private JCheckBox cboxSensitivoMinMay;

	/** cbox palabra entera. */
	private JCheckBox cboxPalabraEntera;

	/** boton expr regular. */
	private JRadioButton bExprRegular;

	/** boton comodines. */
	private JRadioButton bComodines;

	/** radio boton literal. */
	private JRadioButton rBLiteral;

	/** label buscar. */
	private JLabel lBuscar;

	/** label lremplazar. */
	private JLabel lremplazar;

	/** localizar. */
	private boolean localizar;

	/** The i editor. */
	private Editor iEditor;

	/* Instacia para patrón singlton ventbus. */
	/** The vent bus. */
	private static BuscarYRemplazar ventBus;

	/**
	 * Constructor buscar y remplazar.
	 * <p>
	 * Crea el panel de la ventana
	 * </p>
	 * Creado : Parras, 19-oct-2009
	 * 
	 * @param ventanEditor
	 *            the ventan editor
	 */
	public BuscarYRemplazar(Editor ventanEditor) {
		super(ventanEditor, false);
		iEditor = ventanEditor;
		JPanel panelGrande = new JPanel();

		panelGrande.setLayout(new BoxLayout(panelGrande, BoxLayout.X_AXIS));
		JPanel panelIzquierda = new JPanel();

		panelIzquierda
				.setLayout(new BoxLayout(panelIzquierda, BoxLayout.Y_AXIS));
		JPanel panelBuscarYRemplazar = new JPanel();

		panelBuscarYRemplazar.setLayout(new BoxLayout(panelBuscarYRemplazar,
				BoxLayout.X_AXIS));
		JPanel panelEtiqueta = new JPanel();

		panelEtiqueta.setLayout(new BoxLayout(panelEtiqueta, BoxLayout.Y_AXIS));
		panelEtiqueta.add(getLBuscar());
		panelEtiqueta.add(getLRemplazar());
		panelBuscarYRemplazar.add(panelEtiqueta);
		JPanel panelTextField = new JPanel();

		panelTextField
				.setLayout(new BoxLayout(panelTextField, BoxLayout.Y_AXIS));
		panelTextField.add(getFieldBuscar());
		panelTextField.add(getFieldRemplazar());
		panelBuscarYRemplazar.add(panelTextField);
		panelIzquierda.add(panelBuscarYRemplazar);
		JPanel panelOpciones = new JPanel();

		panelOpciones.setLayout(new BoxLayout(panelOpciones, BoxLayout.X_AXIS));
		JPanel panelChexBox = new JPanel();

		panelChexBox.setLayout(new BoxLayout(panelChexBox, BoxLayout.Y_AXIS));
		panelChexBox.setBorder(BorderFactory.createTitledBorder(BorderFactory
				.createEtchedBorder(), "Opciones:"));
		panelChexBox.add(getCaseSensitiveCheckBox());
		panelChexBox.add(getWholeWordCheckBox());
		panelChexBox.setAlignmentY(TOP_ALIGNMENT);
		panelOpciones.add(panelChexBox);
		JPanel panelRadioButton = new JPanel();

		panelRadioButton.setLayout(new BoxLayout(panelRadioButton,
				BoxLayout.Y_AXIS));
		panelRadioButton.setBorder(BorderFactory.createTitledBorder(
				BorderFactory.createEtchedBorder(), "Usos:"));
		panelRadioButton.add(getLiteralButton());
		panelRadioButton.add(getBComodines());
		panelRadioButton.add(getBExpresionRegular());
		panelRadioButton.setAlignmentY(TOP_ALIGNMENT);
		ButtonGroup buttonGroup = new ButtonGroup();

		buttonGroup.add(getLiteralButton());
		buttonGroup.add(getBComodines());
		buttonGroup.add(getBExpresionRegular());
		panelOpciones.add(panelRadioButton);
		panelIzquierda.add(panelOpciones);
		panelIzquierda.setAlignmentY(TOP_ALIGNMENT);
		panelGrande.add(panelIzquierda);
		JPanel panelBotonenes = new JPanel();

		panelBotonenes
				.setLayout(new BoxLayout(panelBotonenes, BoxLayout.Y_AXIS));
		panelBotonenes.add(getBuscarSiguiente());
		panelBotonenes.add(getBActivarRemplazar());
		panelBotonenes.add(getBRemplazar());
		panelBotonenes.add(getBRemplazarTodo());
		panelBotonenes.add(getCloseButton());
		panelBotonenes.setAlignmentY(TOP_ALIGNMENT);
		panelGrande.add(panelBotonenes);
		setContentPane(panelGrande);
		// introducimos texto seleccionado si existe
		fBuscar.setText(ventanEditor.getPanel().getETexto().getSelectedText());
	}

	// Patron Singleton
	/**
	 * Obtener.
	 * 
	 * @param ventanEditor
	 *            the ventan editor
	 * 
	 * @return the buscar y remplazar Creado : Parras, 19-oct-2009
	 */
	public static BuscarYRemplazar get(Editor ventanEditor) {
		if (ventBus == null) {
			synchronized (BuscarYRemplazar.class) {
				ventBus = new BuscarYRemplazar(ventanEditor);
				ventanEditor.getPanel().getETexto().requestFocus();
			}
		} else {
			// introducimos texto seleccionado si existe
			ventBus.fBuscar.setText(ventanEditor.getPanel().getETexto()
					.getSelectedText());
		}
		return (BuscarYRemplazar) ventBus;

	}

	/**
	 * Show dialog. Creado : Parras, 19-oct-2009
	 * 
	 * @param mostrarRemplazar
	 *            the mostrar remplazar
	 */
	public void showDialog(boolean mostrarRemplazar) {
		getLRemplazar().setVisible(mostrarRemplazar);
		getFieldRemplazar().setVisible(mostrarRemplazar);
		getBRemplazar().setVisible(mostrarRemplazar);
		getBRemplazarTodo().setVisible(mostrarRemplazar);
		if (mostrarRemplazar) {
			setTitle("Remplazar");
			getRootPane().setDefaultButton(getBRemplazar());
			getBActivarRemplazar().setText("Buscar...");
			getBActivarRemplazar().setMnemonic('r');
			getBActivarRemplazar().setDisplayedMnemonicIndex(3);
		} else {
			setTitle("Buscar");
			getRootPane().setDefaultButton(getBuscarSiguiente());
			getBActivarRemplazar().setText("Remplazar...");
			getBActivarRemplazar().setMnemonic('R');
			getBActivarRemplazar().setDisplayedMnemonicIndex(0);
		}
		this.pack();
		if (!localizar) {
			// Rectangle bounds = iEditor.getBounds();
			// Dimension size = getSize();

			// setLocation((int) (bounds.getX() + (bounds.getWidth() -
			// size.getWidth()) / 2),
			// (int) (bounds.getY() + (bounds.getHeight() - size.getHeight()) /
			// 2));
			OperacionesVentanas.centraVentana(this);
			localizar = true;
		}
		this.setVisible(true);
		this.setResizable(false);
	}

	/**
	 * Crea o obtiene la etiqueta Buscador.
	 * 
	 * @return label Creado : Parras, 19-oct-2009
	 */
	public JLabel getLBuscar() {
		if (lBuscar == null) {
			lBuscar = new JLabel();
			lBuscar.setText(" Buscar:");
			lBuscar.setDisplayedMnemonicIndex(3);
		}
		return lBuscar;
	}

	/**
	 * Crea o obtiene la etiqueta Remplazar.
	 * 
	 * @return label Creado : Parras, 19-oct-2009
	 */
	public JLabel getLRemplazar() {
		if (lremplazar == null) {
			lremplazar = new JLabel();
			lremplazar.setText(" Remplazar:");
			lremplazar.setDisplayedMnemonicIndex(3);
		}
		return lremplazar;
	}

	/**
	 * Crea o obtiene la Field a Buscador..
	 * 
	 * @return el field Creado : Parras, 19-oct-2009
	 */
	public JTextField getFieldBuscar() {
		if (fBuscar == null) {
			fBuscar = new JTextField();
			fBuscar.setFocusAccelerator('n');
			fBuscar.addActionListener(this);
		}
		return fBuscar;
	}

	/**
	 * Crea o obtiene la Field remplazar.
	 * 
	 * @return el field remplazar Creado : Parras, 19-oct-2009
	 */
	public JTextField getFieldRemplazar() {
		if (fRemplazar == null) {
			fRemplazar = new JTextField();
			fRemplazar.setFocusAccelerator('p');
			fRemplazar.addActionListener(this);
		}
		return fRemplazar;
	}

	/**
	 * Crea o Obteniene el buscar siguiente.
	 * 
	 * @return buscar siguiente Creado : Parras, 19-oct-2009
	 */
	public JButton getBuscarSiguiente() {
		if (bBuscarSig == null) {
			bBuscarSig = new JButton();
			bBuscarSig.setText("Buscar Siguiente");
			bBuscarSig.setMnemonic('S');
			bBuscarSig.setDisplayedMnemonicIndex(0);
			bBuscarSig.setDefaultCapable(true);
			bBuscarSig.addActionListener(this);
		}
		return bBuscarSig;
	}

	/**
	 * Crea o Obteniene el buscar siguiente.
	 * 
	 * @return botn remplazar Creado : Parras, 19-oct-2009
	 */
	public JButton getBRemplazar() {
		if (bRemplazar == null) {
			bRemplazar = new JButton();
			bRemplazar.setText("Remplazar");
			bRemplazar.setMnemonic('R');
			bRemplazar.setDisplayedMnemonicIndex(0);
			bRemplazar.setDefaultCapable(true);
			bRemplazar.addActionListener(this);
		}
		return bRemplazar;
	}

	/**
	 * Crea o Obteniene el buscar siguiente. remplazar todo.
	 * 
	 * @return el b remplazar todo Creado : Parras, 19-oct-2009
	 */
	public JButton getBRemplazarTodo() {
		if (bRemplazarTodo == null) {
			bRemplazarTodo = new JButton();
			bRemplazarTodo.setText("Remplazar Todo");
			bRemplazarTodo.setMnemonic('T');
			bRemplazarTodo.setDisplayedMnemonicIndex(8);
			bRemplazarTodo.addActionListener(this);
		}
		return bRemplazarTodo;
	}

	/**
	 * Crea o Obteniene el botn remplazar.
	 * 
	 * @return boton remplazar Creado : Parras, 19-oct-2009
	 */
	public JButton getBActivarRemplazar() {
		if (bActivarRemplazar == null) {
			bActivarRemplazar = new JButton();
			bActivarRemplazar.addActionListener(this);
		}
		return bActivarRemplazar;
	}

	/**
	 * Crea o Obteniene el botn de salir.
	 * 
	 * @return Botn de salir
	 * 
	 *         Creado : Parras, 19-oct-2009
	 */
	public JButton getCloseButton() {
		if (bCerrar == null) {
			bCerrar = new JButton();
			bCerrar.setText("Cerrar");
			bCerrar.setMnemonic('c');
			bCerrar.setDisplayedMnemonicIndex(4);
			bCerrar.addActionListener(this);
		}
		return bCerrar;
	}

	/**
	 * Crea o Obteniene el case sensitive check box.
	 * 
	 * @return el case sensitive check box Creado : Parras, 19-oct-2009
	 */
	public JCheckBox getCaseSensitiveCheckBox() {
		if (cboxSensitivoMinMay == null) {
			cboxSensitivoMinMay = new JCheckBox();
			cboxSensitivoMinMay.setText("Sensible May/Min");
			cboxSensitivoMinMay.setMnemonic('C');
			cboxSensitivoMinMay.setDisplayedMnemonicIndex(0);
			cboxSensitivoMinMay.addActionListener(this);
		}
		return cboxSensitivoMinMay;
	}

	/**
	 * Crea o Obteniene el check de palabras completas.
	 * 
	 * @return el whole word check box Creado : Parras, 19-oct-2009
	 */
	public JCheckBox getWholeWordCheckBox() {
		if (cboxPalabraEntera == null) {
			cboxPalabraEntera = new JCheckBox();
			cboxPalabraEntera.setText("Palabra Enteras");
			cboxPalabraEntera.setMnemonic('P');
			cboxPalabraEntera.setDisplayedMnemonicIndex(0);
			cboxPalabraEntera.addActionListener(this);
		}
		return cboxPalabraEntera;
	}

	/**
	 * Crea o Obteniene elliteral button.
	 * 
	 * @return el literal button Creado : Parras, 19-oct-2009
	 */
	public JRadioButton getLiteralButton() {
		if (rBLiteral == null) {
			rBLiteral = new JRadioButton();
			rBLiteral.setText("Literal");
			rBLiteral.setMnemonic('L');
			rBLiteral.setSelected(true);
			rBLiteral.setDisplayedMnemonicIndex(0);
			rBLiteral.addActionListener(this);
		}
		return rBLiteral;
	}

	/**
	 * Crea o Obteniene el botn de los comodines.
	 * 
	 * @return el b comodines Creado : Parras, 19-oct-2009
	 */
	public JRadioButton getBComodines() {
		if (bComodines == null) {
			bComodines = new JRadioButton();
			bComodines.setText("Comodines");
			bComodines
					.setToolTipText("<html>Los comodines son <br>?: Sustituye a un carcter cualquiera"
							+ "<br>*: Repeticin de un caracter 0 o ms veces</html>.");
			bComodines.setMnemonic('i');
			bComodines.setDisplayedMnemonicIndex(5);
			bComodines.addActionListener(this);
		}
		return bComodines;
	}

	/**
	 * Crea o Obteniene el botn de la expresiones regulares.
	 * 
	 * @return el b expresion regular Creado : Parras, 19-oct-2009
	 */
	public JRadioButton getBExpresionRegular() {
		if (bExprRegular == null) {
			bExprRegular = new JRadioButton();
			bExprRegular.setText("Expresion Regular");
			bExprRegular.setMnemonic('x');
			bExprRegular.setDisplayedMnemonicIndex(1);
			bExprRegular.addActionListener(this);
		}
		return bExprRegular;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent e) {
		Object source = e.getSource();

		if (source == getBuscarSiguiente()) {
			iEditor.getPanel().getETexto().requestFocus();
			buscarSig();
		} else if (source == getBRemplazar()) {
			iEditor.getPanel().getETexto().requestFocus();
			remplazar();
			buscarSig();

		} else if (source == getBRemplazarTodo()) {
			iEditor.getPanel().getETexto().requestFocus();
			remplazarTodo();
		} else if (source == getCloseButton()) {
			iEditor.getPanel().getETexto().requestFocus();
			setVisible(false);
		} else if (source == getBActivarRemplazar()) {
			iEditor.getPanel().getETexto().requestFocus();
			showDialog(!getBRemplazar().isVisible());
		} else if (source instanceof JTextField) {
			iEditor.getPanel().getETexto().requestFocus();
			getRootPane().getDefaultButton().doClick();
		}
	}

	// Metodo Para Expresiones Regulara
	/**
	 * Obtener el patron.
	 * 
	 * @return el patron Creado : Parras, 19-oct-2009
	 */
	private Pattern getPatron() {
		String pattern = getFieldBuscar().getText();
		int flags = Pattern.DOTALL;

		if (!getBExpresionRegular().isSelected()) {
			String newpattern = "";

			for (int i = 0; i < pattern.length(); i++) {
				if ("\\[]^$&|().*+?{}".indexOf(pattern.charAt(i)) >= 0) {
					newpattern += '\\';
				}
				newpattern += pattern.charAt(i);
			}
			// "*" .* "?" .
			if (getBComodines().isSelected()) {
				newpattern = newpattern.replaceAll("\\\\\\*", ".+?");
				newpattern = newpattern.replaceAll("\\\\\\?", ".");
			}
			pattern = newpattern;
		}
		if (!getCaseSensitiveCheckBox().isSelected()) {
			flags |= Pattern.CASE_INSENSITIVE;
		}
		if (getWholeWordCheckBox().isSelected()) {
			pattern = "\\b" + pattern + "\\b";
		}
		return Pattern.compile(pattern, flags);
	}

	/**
	 * Buscar sig. Creado : Parras, 19-oct-2009
	 */
	public void buscarSig() {
		if ((iEditor.getPanel().ventanaActiva() < 0)
				|| getFieldBuscar().getText().length() == 0) {
			iEditor.getPanel().setTextoBarraEstado(
					"Introduzca un texto a buscar");
			return;
		}
		Pattern p = getPatron();
		JTextPane textPane = iEditor.getPanel().getETexto();

		String text = textPane.getText().replaceAll("\\r", "");
		Matcher m = p.matcher(text);
		int index = textPane.getSelectionEnd();

		if (!m.find(index)) {
			if (!m.find()) {
				iEditor.getPanel().setTextoBarraEstado("Palabra no encotrada");
				return;

			}
		}
		textPane.setSelectionStart(m.start());
		textPane.setSelectionEnd(m.end());
	}
	
	
	
	
	
	/**
	 * Buscar cadena en un jtextpane si la encuentra la devuelve, en otro caso devuelve vacio.
	 * 
	 * @param aTextPane
	 *            textpane
	 * @param aRegex
	 *             Expresion regular
	 * 
	 * @return Cadena encontrada 
	 * Creado : Parras, 10-ene-2010
	 */
	public static String buscarCadena(JTextPane aTextPane, String aRegex) {
		String lCadena = "";
		Pattern p = Pattern.compile(aRegex, Pattern.DOTALL);
		

		String text = aTextPane.getText().replaceAll("\\r", "");
		Matcher m = p.matcher(text);
		int index = aTextPane.getSelectionEnd();

		if (!m.find(index)) {
			if (!m.find()) {
				lCadena = "";

			}
		}else{
			lCadena = text.substring(m.start(),m.end());
		}
		
		return lCadena;
	}

	/**
	 * Remplazar. Creado : Parras, 19-oct-2009
	 */
	public void remplazar() {

		if ((iEditor.getPanel().ventanaActiva() < 0)
				|| getFieldBuscar().getText().length() == 0) {
			// Error al cargar dialogo
			iEditor.getPanel().setTextoBarraEstado(
					"Introduzca un texto a buscar");
			return;
		}
		Pattern p = getPatron();
		JTextPane textPane = iEditor.getPanel().getETexto();
		String text = textPane.getSelectedText();

		if (text == null) {
			// no Seleccioon
			// iEditor.getPanel().setTextoBarraEstado
			// ("No existe texto a buscar");
			return;
		}
		Matcher m = p.matcher(text);

		if (m.matches()) {
			if (getBExpresionRegular().isSelected()) {

				textPane.replaceSelection(m.replaceFirst(getFieldRemplazar()
						.getText()));
			} else {
				textPane.replaceSelection(getFieldRemplazar().getText());
			}
		}
	}

	/**
	 * Remplazar todo. Creado : Parras, 19-oct-2009
	 */
	public void remplazarTodo() {
		if ((iEditor.getPanel().ventanaActiva() < 0)
				|| getFieldBuscar().getText().length() == 0) {
			iEditor.getPanel().setTextoBarraEstado(
					"Introduzca un texto a buscar");
			return;
		}
		Pattern p = getPatron();
		JTextPane textPane = iEditor.getPanel().getETexto();
		String text = textPane.getText();
		Matcher m = p.matcher(text);
		String replacement = getFieldRemplazar().getText();

		if (!getBExpresionRegular().isSelected()) {
			String newreplacement = "";

			for (int i = 0; i < replacement.length(); i++) {
				if (replacement.charAt(i) == '$'
						|| replacement.charAt(i) == '\\') {
					newreplacement += "\\" + replacement.charAt(i);
				}
				newreplacement += replacement.charAt(i);
			}
			replacement = newreplacement;
		}
		textPane.setText(m.replaceAll(replacement));
	}
}
