/*
 * 
 * @author Manuel Parras  
 */
package proyecto.editor;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.FileFilter;
import java.io.IOException;

import javax.swing.JCheckBox;
import proyecto.acercade.AcercaDeVentana;
import proyecto.herramientas.OpcionesCompilacion;
import proyecto.paneles.DatosExportar;
import proyecto.paneles.ExportacionesPanel;
import proyecto.paneles.SeleccionPaqueteDialogo;
import proyecto.preferencias.VentanaPreferencias;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.OperacionesFicheros;

/**
 * 
 * ControlVentEditor
 * 
 * <p>
 * La aplicacin ha de responder a las acciones que realiza el usuario en la clase Editor, por
 * ejemplo: abrir las preferencias del editor. Es necesario poder detectar las
 * acciones de usuario y convertirlas en acciones de programa.
 * </p>
 * 
 * <p>
 * Los distintos elementos de la parte de la JMenuBar del editor estn vigilados
 * por Listeners que detectan las acciones que tienen lugar sobre el elemento
 * vigilado. Cuando ActionListener detecta una accin se genera un evento de
 * accin (ActionEvent) en el elemento (JMenuItem). Los ActionEvent invocan el
 * mtodo actionPerformed (ActionEvent e) que realiza las acciones programadas
 * ante ese evento.
 * </p>
 * <p>
 * Los elementos que estn definidos mediante ActionCommand en nuestra clase Editor son 
 * la	s siguientes:
 * </p>
 * <ul>
 * <li>SALIR: Abandona la aplicacin</li>
 * <li>NUEVO : Abre la ventana que gestiona nuevo elementos en nuestra
 * aplicacin</li>
 * <li>PROYECTO: Crear un proyecto</li>
 * <li>ABRIR_PROYECTO: Abrir un proyecto existente</li>
 * <li>ABRIR: Abre un fichero en modo texto</li>
 * <li>CERRAR: Cierra la ventana activa, gestionado su estado de modificado</li>
 * <li>CERRARTODO: Cierra todas las ventanas, gestionado su estado de modificado
 * </li>
 * <li>GUARDAR: Guarda un fichero abierto en un tab</li>
 * <li>GUARDAR_C: Guarda todos los ficheros que tengamos con modificaciones en
 * los tab.</li>
 * <li>BUSCAR: Abre la ventana buscar en nuestro cdigo fuente, siempre lo
 * realiza en el tab que est activo</li>
 * <li>BUSCARSIG: Busca la siguiente cadena de texto, sin tener la ventana de
 * bsqueda abierta</li>
 * <li>IR_A: Abre la ventana de ir a una lnea del source determinada</li>
 * <li>IMPRIMIR: imprime nuestro tab activo mediante ireport.</li>
 * <li>EXPORTAR: Abre la ventana de exportar</li>
 * <li>DESHACER: Deshace la modificaciones que se han realizado en nuestro tab
 * activo</li>
 * <li>REHACER: Rehace la modificaciones que se han realizado en nuestro tab
 * activo</li>
 * <li>COPIAR: Copia texto al portapapeles del texto seleccionado en nuestro tab
 * </li>
 * <li>PEGAR: Pega el texto del portapapeles de la maquina donde este situado el
 * cursor</li>
 * <li>CORTAR: Corta texto de nuestro tab y lo copia al portapapeles del texto</li>
 * <li>SELECIONARTODO: Selecciona todo el texto de nuestro tab activo</li>
 * <li>SUPR: Elimina el texto seleccionado de nuestro tab</li>
 * <li>PERSONALIZAR: Abre la ventana personalizar colores y tipo de letra</li>
 * <li>OPCIONES: Abre la ventana de opciones de compilacin</li>
 * <li>SALIR_SIN_PREGUNTAR: Salir sin preguntar de nuestro sistema</li>
 * <li>COMPILAR_Y_GUARDAR: Compila y guarda el tab activo</li>
 * </ul>
 * @see proyecto.editor.Editor
 * @see proyecto.paneles.DatosExportar
 * @see proyecto.paneles.ExportacionesPanel
 * @see proyecto.paneles.SeleccionPaqueteDialogo
 * @see proyecto.preferencias.VentanaPreferencias
 * @see proyecto.paneles.SeleccionPaqueteDialogo
 * 
 * @author Parras
 */
public class ControlVentEditor implements ActionListener {

	/**@see proyecto.editor.Editor*/
	private Editor gui;

	/**
	 * Constructor control vent editor.
	 * 
	 * Creado : Parras, 27-sep-2009
	 * 
	 * @param vent
	 *            the vent
	 */
	public ControlVentEditor (Editor vent){
		gui=vent;
	}

	/* (non-Javadoc)
	 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed  (ActionEvent event) {
		String comando = event.getActionCommand();

		if (comando.equals("SALIR")){

			gui.tratarCancelar();

			//gui.salir();

		}else if (comando.equals("NUEVO")){			
			gui.getPanel().abritVentanaNuevo();			
		}else if (comando.equals("ABRIR_PROYECTO")){
			
			//si solo queremos la carpetas que tenemos en nuestro fichero xml
			
//			File [] fileProyectos = (gui.getProyectos() == null) ? null:(File[])
//					gui.getProyectos().toArray(new File[gui.getProyectos().size()]);
			
			//aqui obtenemos todas las carpetas que existen en nuestra ruta de workspace.
			//SeleccionPaqueteDialogo proyecto = new SeleccionPaqueteDialogo(gui,true,gui.getWorkspace().listFiles(new MiFiltroCarpetas()));
			//aqui obtenemos todas las carpetas que existen en nuestra fichero de XML., es decir que puden
			//existir carpetas en el workspace que no sean proyecto.
			SeleccionPaqueteDialogo proyecto = new SeleccionPaqueteDialogo(gui,true,gui.getProyectosActivos());
			proyecto.setVisible(true);
			
			//cambiamos de proyecto
			if (proyecto.getProyectoSelecionado()!=null) //por si nos pulsa el botnde aceptar
				gui.addProyectosNoActivo(proyecto.getProyectoSelecionado());
				gui.getPanel().cargarProyectoArbol(proyecto.getProyectoSelecionado());

		}else if (comando.equals("ABRIR")){
			try {

				gui.buscarFichero();
			} catch (IOException e) {
				e.printStackTrace();
			}
		}else if (comando.equals("PROYECTO")){
			String lsProjecto=Mensajes.entradaMensaje("Nuevo Proyecto","Nombre del projecto:",Mensajes.PREGUNTA);
			if (lsProjecto!=null){
				if ( OperacionesFicheros.validadorFileName(lsProjecto)){
					File lFmyprojecto = new File (gui.getWorkspace()+File.separator+lsProjecto);

					if (!lFmyprojecto.exists()){
						if (lFmyprojecto.mkdir()){
							gui.addProyecto(lFmyprojecto);
							gui.getPanel().nuevoProyecto(lFmyprojecto);
						}else
							Mensajes.mensajeAtencion("No ha sido Posible crear directorio");
					}else
						Mensajes.mensajeAtencion("Projecto definido en el workspace");
				}else
					Mensajes.mensajeAtencion("Nombre del fichero no valido");
			}


		}else if (comando.equals("CERRAR")){
			if (gui.getPanel().ventanaActiva()>=0){ 
				try {
					gui.getPanel().cerrarVentanas(true);
				} catch (EpSilonExcepciones e1) {
					gui.getPanel().setTextoBarraEstado("Error, al Cerrar la pestaa");
				} catch (IOException e1) {

					gui.getPanel().setTextoBarraEstado("Error, al Cerrar la pestaa");
				}
			}
		}else if (comando.equals("CERRARTODO")){
			if (gui.getPanel().ventanaActiva()>=0){ 
				try {
					gui.getPanel().cerrarVentanas(false);
				} catch (EpSilonExcepciones e1) {
					gui.getPanel().setTextoBarraEstado("Error, al Cerrar la pestaa");
				} catch (IOException e1) {
					// TODO Bloque catch generado autom�ticamente
					gui.getPanel().setTextoBarraEstado("Error, al Cerrar la pestaa");
				}
			}
		}else if (comando.equals("GUARDAR")){
			if (gui.getPanel().ventanaActiva()>=0){ 
				try {
					File fichero =gui.getPanel().getFicheroTabRun();
					//System.out.print(fichero);
					if (fichero==null)
						gui.guardarEnFichero();
					else 
						gui.guardarComo(fichero);
					gui.getPanel().setOKTextPane(true);
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
		}else if (comando.equals("GUARDAR_C")){
			if (gui.getPanel().ventanaActiva()>=0){ 

				try {
					gui.guardarEnFichero();
				} catch (IOException e) {
					
					e.printStackTrace();
				}

			}
		}else if (comando.equals("IMPRIMIR")){
			if (gui.getPanel().ventanaActiva()>=0){
				gui.getPanel().imprimir();
			}
		}else if (comando.equals("EXPORTAR")){
			if (gui.getPanel().ventanaActiva()>=0){
				ExportacionesPanel exportarPanel = new ExportacionesPanel (gui,true);
				exportarPanel.setVisible(true);
				DatosExportar datosExportar =exportarPanel.getDatosExportar();
                                if (datosExportar!=null && datosExportar.isValido() ){
                                	datosExportar.setNombreExportar(OperacionesFicheros.getNombreSinExtension(gui.getPanel().getFicheroTabRun()));
                                    gui.getPanel().exportar(exportarPanel.getDatosExportar());
                                }
                                exportarPanel.dispose();
			}

		}else if (comando.equals("BUSCAR")){
			if (gui.getPanel().ventanaActiva()>=0){
				BuscarYRemplazar busqueda =BuscarYRemplazar.get(gui);
				busqueda.showDialog(false);
			}
		}else if (comando.equals("BUSCARSIG")){
			if (gui.getPanel().ventanaActiva()>=0){
				BuscarYRemplazar busqueda =BuscarYRemplazar.get(gui);
				busqueda.buscarSig();
			}	


		}else if (comando.equals("IR_A")){ 	 
			if (gui.getPanel().ventanaActiva()>=0){
				gui.getPanel().getVentanaIrA();
			}

			//Debemos comprar que es un numero y despues situar el caret en su linea   
		}else if (comando.equals("DESHACER")){
			if (gui.getPanel().ventanaActiva()>=0)    	 
				gui.getPanel().getETexto().deshacer();
		}else if (comando.equals("REHACER")){
			if (gui.getPanel().ventanaActiva()>=0)
				gui.getPanel().getETexto().rehacer();
		} else if (comando.equals("COPIAR")){

			if (gui.getPanel().ventanaActiva()>=0)   
				gui.getPanel().getETexto().copiar();
		}else if (comando.equals("PEGAR")){
			if (gui.getPanel().ventanaActiva()>=0)
				gui.getPanel().getETexto().pegar();
		}else if (comando.equals("CORTAR")){
			if (gui.getPanel().ventanaActiva()>=0)
				gui.getPanel().getETexto().cortar();
		}else if (comando.equals("SELECIONARTODO")){
			if (gui.getPanel().ventanaActiva()>=0) 
				gui.getPanel().getETexto().selecionarTodo();
		}else if (comando.equals("SUPR")){
			if (gui.getPanel().ventanaActiva()>=0) 
				gui.getPanel().getETexto().suprimir();
		}else if (comando.equals("PERSONALIZAR")){
			VentanaPreferencias ventana = new VentanaPreferencias (gui,true,gui.getPanel().getImapa());
			ventana.setVisible(true);
			gui.getPanel().setImapa(ventana.getImapa());



		}
		else if (comando.equals("OPCIONES")){
			OpcionesCompilacion ventana = new OpcionesCompilacion (gui,true);
			if (gui.getPreferenciasCompilacion()!=null)
				ventana.cargarDatos(gui.getPreferenciasCompilacion());

			ventana.setVisible(true);	




		}
		else if (comando.equals("SALIR_SIN_PREGUNTAR")){
			gui.getPreferenciasUsuario().setSalirConfirmar(((JCheckBox)event.getSource()).isSelected());

		}
		else if (comando.equals("COMPILAR_Y_GUARDAR")){
			gui.getPreferenciasUsuario().setGuardarAlCompilar(((JCheckBox)event.getSource()).isSelected());

		}

		
		else if (comando.equals("ACERCA")){
			
			 new AcercaDeVentana (gui, true).abreVentana();        ;

		}	

	}  
	
	
	

}//FIN DE IF DE todo LO ALTO



