/*
 * 
 * @author Manuel Parras  
 */
package proyecto.editor;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;
import proyecto.utilidades.Mensajes;


/**
 * 
 * ControlVentPanel.
 * 
 * <p>
 * La aplicacin ha de responder a las acciones que realiza el usuario en nustro
 * panel de ediccin, por ejemplo barra de herramientas, por ejemplo: imprimir
 * un tab .Es necesario poder detectar las acciones de usuario y convertirlas en
 * acciones de programa.
 * </p>
 * 
 * <p>
 * Los distintos elementos de la parte de la JMenuBar del editor estn vigilados
 * por Listeners que detectan las acciones que tienen lugar sobre el elemento
 * vigilado. Cuando ActionListener detecta una accin se genera un evento de
 * accin (ActionEvent) en el elemento (JMenuItem). Los ActionEvent invocan el
 * mtodo actionPerformed (ActionEvent e) que realiza las acciones programadas
 * ante ese evento.
 * </p>
 * <p>
 * Los elementos que estn definidos mediante ActionCommand en nuestra clase
 * PanelEdicion son las siguientes:
 * </p>
 * <ul>
 * <ul>
 * <li>NUEVO : Abre la ventana que gestiona nuevo elementos en nuestra
 * aplicacin</li>
 * <li>ABRIRBOTON: Abre un fichero en modo texto</li>
 * <li>BUSCAR: Abre la ventana buscar en nuestro cdigo fuente, siempre lo
 * realiza en el tab que est activo</li>
 * <li>GUARDARBOTON: Guarda un fichero abierto en un tab</li>
 * <li>GUARDARBOTONTODO: Guarda todos los ficheros que tengamos con
 * modificaciones en los tab.</li>
 * <li>COMPILAR: Compilacin + Ejecucin si todo ha ido correcto. Verifica el
 * tipo de fichero que tengamos en el tab, para compilar mediante JavaCC o Java</li>
 * <li>COMPILAR_SIMPLE: Compilacin. Verifica el tipo de fichero que tengamos en
 * el tab, para compilar mediante JavaCC o Java</li>
 * <li>IMPRIMIR: imprime nuestro tab activo mediante ireport.</li>
 * </ul>
 * 
 * @see proyecto.arbol.ArbolFicheros
 * @see proyecto.arbol.Nodo
 * @author Parras
 * 
 */
public class ControlVentPanel implements ActionListener {

	/** The gui. */
	//private Editor gui ;
	
	private PanelEdicion ipPanelEdicion;

	/** The carpeta generados. */
	

	/**
	 * Constructor control ventana panel.
	 * 
	 * Creado : Parras, 25-oct-2009
	 * 
	 * @param vent
	 *            the vent
	 */
	public ControlVentPanel(PanelEdicion aPanel) {
		ipPanelEdicion = aPanel;
		
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void actionPerformed(ActionEvent event) {
		String comando = event.getActionCommand();
		if (comando.equals("GUARDARBOTON")) {
			ipPanelEdicion.guardarTabActivo ();
		}// GUARDARBOTON
		else if (comando.equals("GUARDARBOTONTODO")) {
			System.out.print(ipPanelEdicion.ventanaActiva());
			if (ipPanelEdicion.ventanaActiva() >= 0) {
				ipPanelEdicion.guardarTodo();
			}
		} else if (comando.equals("ABRIRBOTON")) {
			try {
				Editor.get().buscarFichero();
			} catch (IOException e) {
				Mensajes.mensajeDetalles("Error al abrir el fichero", e);
			}
		} else if (comando.equals("IMPRIMIR")) {
			if (ipPanelEdicion.ventanaActiva() >= 0) {
				ipPanelEdicion.imprimir();
			}

		} else if (comando.equals("BUSCAR")) {
			if (ipPanelEdicion.ventanaActiva() >= 0) {
				BuscarYRemplazar vent = BuscarYRemplazar.get(Editor.get());
				vent.showDialog(false);
			}

		} else if (comando.equals("NUEVO")) {
			// ipPanelEdicion.pestaaNueva(null);
			// ipPanelEdicion.getConVentanas();
			ipPanelEdicion.abritVentanaNuevo();
			// NuevoVentana ventana =new NuevoVentana(gui,true,null);
			// ventana.setVisible(true);

		} else if (comando.equals("COMPILAR")) {
			if (ipPanelEdicion.ventanaActiva() >= 0) {
				ipPanelEdicion.compilarFichero(true);
			}

		} else if (comando.equals("COMPILAR_SIMPLE")) {
			ipPanelEdicion.compilarFichero(false);

		}

	}

	
}
