/*
 * 
 * @author Manuel Parras  
 */
package proyecto.editor;


import java.awt.Event;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.WindowEvent;
import java.beans.XMLDecoder;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JCheckBox;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.KeyStroke;
import javax.swing.UIManager;
import javax.swing.UnsupportedLookAndFeelException;
import javax.swing.WindowConstants;
import javax.swing.text.BadLocationException;

import org.apache.log4j.Logger;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.jvnet.substance.SubstanceLookAndFeel;

import proyecto.arbol.Nodo;
import proyecto.configuracion.ConstantesEpSilon;
import proyecto.herramientas.PreferenciasCompilacion;
import proyecto.herramientas.PreferenciasUsuario;
import proyecto.imagenes.IconFactory;
import proyecto.paneles.SeleccionarWorkSpace;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.OperacionesFicheros;
import proyecto.utilidades.OperacionesVentanas;
import proyecto.utilidades.SplashPrincipal;

/**
 *Class Editor.
 */
/**
 * 
 * <p>
 * Es nuestro frame principal, la encargada de diversas actividades sobre la
 * aplicacin. Las actividades de nuestra aplicacin las vamos a separar en dos
 * grupos: Acciones sobre el editor y creacin de elementos.
 * </p>
 * 
 * <ol>
 * <li><b>
 * Creacin de elementos:</b>
 * </li>
 * <ul>
 * <li>Barra de Men (barraMenu): Esta situada en la parte superior de la
 * ventana, en posicin horizontal los mens de la aplicacin se centra
 * actualmente en: Archivo, Edicin, Propiedades, Ayuda. Los eventos y acciones
 * de los mens estn gestionados por nuestro control de esta
 * clase(ControlVentEditor).</li>
 * <li>Creacin del Splah(SplashPrincipal): Mientras se inicia la aplicacin nos
 * aparece el Splash</li>
 * <li>Creacin del Panel Principal (PanelEdicion): Inicializa el panel central,
 * si se cre algn proyecto en nuestro workSpace en otro acceso a la
 * aplicacin, entonces el ltimo que se utiliz se iniciar la carga
 * directamente su rbol.</li>
 * </ul>
 * <li><b>Acciones sobre el editor:</b>
 * </li>
 * <ul>
 * <li>Acceder al workSpace</li>
 * <li>Cargar los 3 ltimos proyectos y Acceder al proyecto Activo</li>
 * <li>Cargar Propiedades de compilacin, si no existe carga las de defecto.</li>
 * <li>Guardar la salida estndar para cuando compilemos en nuestro editor.</li>
 * </ul>
 * </ol>
 * 
 * @see proyecto.editor.PanelEdicion
 * @see javax.swing.JMenuBar
 * @see javax.swing.JFrame
 * 
 * @author Parras
 * 
 */
public class Editor extends JFrame implements InterfazVentEditor {

	/** Constant objLogger. */
	private static final Logger objLogger = Logger.getLogger(Editor.class);

	/** barra menu. */
	private JMenuBar barraMenu; // Barra Men para opciones

	/** menu ayuda. */
	private JMenu menuArchivo, menuEditar, menuOpciones, menuAyuda; // Subdivisiones
	// en la
	// barra
	// Menu

	/** Item Para Archivo */
	private JMenuItem itemMenuArchivo_Nuevo, itemMenuArchivo_NuevoProejecto,
			itemMenuArchivo_Abrir, itemMenuArchivo_AbrirProyecto,
			itemMenuArchivo_Cerrar, itemMenuArchivo_GuardarComo,
			itemMenuArchivo_GuardarTodo;

	/** item menu archivo. */
	private JMenuItem itemMenuArchivo_Imprimir, itemMenuArchivo_Exportar,
			itemMenuArchivo_Guardar, itemMenuArchivo_Salir,
			itemMenuArchivo_CerrarTodo;

	/** Item Para Editar */
	private JMenuItem itemMenuEditar_Deshacer, itemMenuEditar_Rehacer,
			itemMenuEditar_Copiar, itemMenuEditar_Pegar;

	/** Item Para Editar */
	private JMenuItem itemMenuEditar_Cortar, itemMenuEditar_Todo,
			itemMenuEditar_Supr;

	/** Item Para Editar */
	private JMenuItem itemMenuEditar_Buscar, itemMenuEditar_BuscarSig,
			itemMenuEditar_IrA;
	// Item Para Herramientas
	/** item menu herramientas */
	private JMenuItem itemMenuHerramientas_Personalizar,
			itemMenuHerramientas_Opciones;
	
	private JMenu  itemMenuHerramientas_SubMenu; 
	/**Menu de herrmaientas opciones sobre el IDE	 */
	private JCheckBox ijCheckSalirSinPreguntar, ijCheckCOmpilarYGuardar;
	// Item Para Ayuda
	/** item menu ayuda */
	private JMenuItem itemMenuAyuda_Acerca; // Valores introducidos en los barra
	// menus

	/** @see proyecto.editor.PanelEdicion */
	private PanelEdicion panel;

	// Utilidades FileChooser
	/** ruta archivo. */
	private String rutaArchivo = null;

	/** variable boolena que controla la salida. */
	private boolean ok = false;
	// private Vector <Boolean> oks = new Vector <Boolean> ();
	// Para el Listener
	/** control de la clase. */
	private ControlVentEditor crt;

	/** ruta donde esta nuestro workspace */
	private File iFWorkspace;

	/** lista de proyecto activos. */
	private ArrayList<File> ilproyectos;
	// Mantener un patrn singleton de nuestra clase
	/**
	 * Mantener un patrn singleton de nuestra clase Editor. Es esencial para
	 * acceso a toda la aplicacin
	 */
	private static Editor ventanaprincipal;

	/** salida standar out. */
	public static PrintStream iSalidaStandarOut = System.out;

	/** salida standar err. */
	public static PrintStream iSalidaStandarErr = System.err;

	// Propiedades de Compilacin
	/** @see proyecto.herramientas.PreferenciasCompilacion */
	private PreferenciasCompilacion prefCompilacion;
	/** @see proyecto.herramientas.PreferenciasUsuario */
	private PreferenciasUsuario prefUsuario;
	// Imagenes para las pestaas
	/** Imagenes para las pestaas. */
	// ImageIcon ledverde = new
	// ImageIcon(getClass().getResource("../imagenes/led-verde.png"));
	/** Imagenes para las pestaas. Ok */
	Icon ledverde = IconFactory.getImage("led-verde.png");

	/** Imagenes para las pestaas. No Ok */
	Icon ledrojo = IconFactory.getImage("led-rojo.png");

	/** Ruta del proyecto0. */
	private File ifProyecto0;

	/** Ruta del proyecto1. */
	private File ifProyecto1;

	/** Ruta del proyecto2. */
	private File ifProyecto2;

	/** Constant serialVersionUID. */
	private static final long serialVersionUID = 4023146312037519916L;

	/*
	 * (non-Javadoc)
	 * 
	 * @see proyecto.InterfazVentEditor#salir()
	 */
	public void salir() {

		this.dispose();
	}

	/**
	 * Constructor editor.
	 * 
	 * Creado : Parras, 07-jun-2009
	 */
	public Editor() {
		super();

		inicializaAplicacion();
		ventanaprincipal = this;
		if (objLogger.isDebugEnabled())
			objLogger.debug("Inicializada la Aplicacin Editor ");

	}

	// Patrn singleton
	/**
	 * <p>
	 * Obtenemos nuestra ventana principal, para tener acceso a caulquier
	 * propiedad creada.
	 * <p>
	 * <p>
	 * Patrn singleton.
	 * </p>
	 * 
	 * @return editor Creado : Parras, 07-jun-2009
	 */
	public static Editor get() {
		if (ventanaprincipal == null) {
			synchronized (Editor.class) {
				ventanaprincipal = new Editor();
			}
		}
		return (Editor) ventanaprincipal;

	}

	/**
	 * lookAndFeel
	 * <p>
	 * carga nuestro look and fell de substance.
	 * </p>
	 */
	private void lookAndFeel() {
		try {
			UIManager.setLookAndFeel(new SubstanceLookAndFeel());

		} catch (UnsupportedLookAndFeelException e) {

			Mensajes.mensajeDetalles("No se ha podido cargar el Look And Feel",
					e);
		}
		try {
			UIManager
					.setLookAndFeel("org.jvnet.substance.SubstanceLookAndFeel");
		} catch (ClassNotFoundException e) {
			Mensajes.mensajeDetalles("No se encuentra la clase", e);
		} catch (InstantiationException e) {
			Mensajes.mensajeDetalles("No se ha podido instanciar", e);
		} catch (IllegalAccessException e) {
			e.printStackTrace();
		} catch (UnsupportedLookAndFeelException e) {
			Mensajes.mensajeDetalles("No se ha podido cargar el Look And Feel",
					e);
		}
	}

	/**
	 * Inicializa nuestro Splash y aplicacin. Creado : Parras, 07-jun-2009
	 */
	private void inicializaAplicacion() {

		// Creacin de La ventana.
		SplashPrincipal splash = new SplashPrincipal(IconFactory
				.getImage("splash.png"), this, 3500);
		splash.setProgressBarMaximum(6);
		splash.setSize(510, 330);
		splash.setProgressBarValue(0);
		//splash.setProgressBarBounds(29, 86, 10, 4);
		//splash.setProgressBarColor(Color.ORANGE);
		//splash.setProgressBarVisible(true);
		//splash.setProgressTextBounds(29, 86, 10, 4);
		//splash.setProgressTextColor(Color.BLUE);
		splash.setProgressTextVisible(true);
		splash.setProgressText("Inicializando");

		// preparar el lookAndFeel
		lookAndFeel();
		this.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE); // Pulsar y		
		
		// cerrar
		// this.setPreferredSize(new Dimension (800,600) );
		// this.setSize(new Dimension(412, 183));
		this.setTitle("EpSilon"); // Nombre del IDE
		// Aumentamos Splash
		splash.setProgressBarValue(1);
		splash.setProgressText("Generando Entorno de  GUI");
		this.addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				tratarCancelar();
			}
		});
		// Posibles nombre GraVity
		//

		this.setIconImage(((ImageIcon) IconFactory.getImage("logo.png"))
				.getImage());
		this.pack();
		// Para que se Maximice la pantalla
		this.setSize(600, 400);
		OperacionesVentanas.centraVentana(this);
		this.setExtendedState(JFrame.MAXIMIZED_BOTH);

		// Aumentamos Splash
		splash.setProgressBarValue(3);
		splash.setProgressText("Cargando Configuraciones XML");

		
		// Cargamos nuestros proyectos ante de inicializar nuestro panel.
		getProyectoXML(splash);
		// Aumentamos Splash
		splash.setProgressBarValue(4);
		splash.setProgressText("Cargando Layout");

		// Aadimos la BarraMenu A la Ventana
		this.setContentPane(getPanel());

		splash.setProgressBarValue(5);
		splash.setProgressText("Generando Barras");
		this.setJMenuBar(getBarraMenu());
		
		//Cargando Preferencias del usuario
		splash.setProgressBarValue(6);
		splash.setProgressText("Generando Preferencias Usuario");
		getPreferecuasUsuarioXML();
		
		this.setVisible(true); // Ver la ventana
		splash.killSplash();
		
		// Aumentamos Splash

		// Controles Sobre el documento

		// updateCaption();

	}
	
	/**
	 * getPreferecuasUsuario
	 * <p>
	 * Mtodo que obtine la preferencias del Usuario
	 * </p>
	 * 
	 * 
	 */
	public void getPreferecuasUsuarioXML() {
		XMLDecoder d;
		try {
			File urlPrefUsu = new File (this.getPrefUsuerXML());
			// Mensajes.mensajeAtencion(urlCompilacion.toString());
			
			if (urlPrefUsu != null && urlPrefUsu.exists()){
			d = new XMLDecoder(new BufferedInputStream(new FileInputStream(urlPrefUsu)));

			setPreferenciasUsuario((PreferenciasUsuario) d.readObject());
			d.close();
			}
		} catch (FileNotFoundException e1) {
			// Cargamos los valores con lo de defecto
			setPreferenciasUsuario(new PreferenciasUsuario());
			if (objLogger.isDebugEnabled())
				objLogger.debug("No se encuentra el fichero de prefUsu.xml ");
		}finally{
			if (getPreferenciasUsuario() ==null)
				setPreferenciasUsuario(new PreferenciasUsuario());			
			
				ijCheckSalirSinPreguntar.setSelected(getPreferenciasUsuario().isSalirConfirmar()); 
				ijCheckCOmpilarYGuardar.setSelected(getPreferenciasUsuario().isGuardarAlCompilar());
			
		}
	}

	/**
	 * getProyectosXML
	 * <p>
	 * Mtodo que obtine el workspace y sus proyectos.
	 * </p>
	 * <p>Pasamas el spash como argumento por si lo tenemos que cerrar para la definicin del workSpace</p>
	 * 
	 * @param splash
	 *            splash
	 */

	public void getProyectoXML(SplashPrincipal splash) {
		SAXBuilder builder = new SAXBuilder(false);
		// usar el parser Xerces y no queremos
		// que valide el documento

		
		org.jdom.Document doc;	
		

		XMLDecoder d;
		
		String lfWorkspace = getWorkSpaceXML();
		
		if (objLogger.isDebugEnabled())
			objLogger.debug("Resorce Workspace: " + lfWorkspace);
		
				//)+File.separator+ConstantesEpSilon.CONFIGURACION_WORKSPACE;
		File url = new File(lfWorkspace);
		
		try {
			if (url != null && url.exists()){
				

			doc = builder.build(url);
			// construyo el arbol en memoria desde el fichero
			// que se lo pasarn por parametro.
			Element raiz = doc.getRootElement();
			// cojo el elemento raiz el cual tiene nuestra direccion workSpace
			// System.out.println(raiz.getAttributeValue ("tipo"));
			iFWorkspace = new File(raiz.getAttributeValue("ruta"));
			// System.out.print("iFWorkspace"+ iFWorkspace +
			// iFWorkspace.exists());
			if (iFWorkspace.exists()) {
				List proyectos = raiz.getChildren("proyecto");
				// System.out.println("Formada por:"+opciones.size()+" opciones");
				Iterator iter = proyectos.iterator();
				ilproyectos = new ArrayList<File>();
				while (iter.hasNext()) {
					Element e = (Element) iter.next();

					// Montados Todos los proyectos
					File lFile = new File(iFWorkspace + File.separator
							+ e.getText());
					if (lFile.exists())
						ilproyectos.add(lFile);
				}
				// System.out.print("Lista de Proyectos"+ilproyectos);

			} else {
				splash.killSplash();
				crearWorkSpace();
			}
			// SeleccionarWorkspcae ventanaWorkSpace = new SeleccionarWorkspcae
			// (this,true);
			// ventanaWorkSpace.setVisible(true);
			}else{
				splash.killSplash();
				crearWorkSpace();
			}

		} catch (MalformedURLException e) {
			// URL
			Mensajes.mensajeDetalles(
					"URL del fichero workspace.xml no encontrada", e);
		} catch (JDOMException e) {
			// Excepcion
			// Mensajes.mensajeDetalles("Fichero mal construido workspace.xml ",
			// e);
			splash.killSplash();
			crearWorkSpace();

		} catch (IOException e) {

			Mensajes.mensajeDetalles(
					"No se puede leer el fichero workspace.xml ", e);
		}finally{
			//creamos el directorio de .metadata donde tendremos todos nuestro ficheros de configuracion
			if (objLogger.isDebugEnabled())
				objLogger.debug("Creamos o verificamos "+ ConstantesEpSilon.DIRECTORIO_METADATOS);
			
			new File(this.getWorkspace().toString()+File.separator+ConstantesEpSilon.DIRECTORIO_METADATOS).mkdir();
			try {
				
				
				File urlCompilacion = new File( this.getCompilacionXML());
				
				//no encontramos el fichero de la propiedades de compilacin del usuario.
				if (urlCompilacion == null || !urlCompilacion.exists() ){
					prefCompilacion = new PreferenciasCompilacion(true);
					if (objLogger.isDebugEnabled())
						objLogger.debug("No se encuentra el fichero de compilacion.xml ");
				}else{
				d = new XMLDecoder(new BufferedInputStream(
				// new
						// FileInputStream("E:/Util/workspace/PFC/proyecto/configuracion/compilacion.xml")));
						new FileInputStream(urlCompilacion)));

				prefCompilacion = (PreferenciasCompilacion) d.readObject();
				d.close();
				}
			} catch (FileNotFoundException e1) {
				// Cargamos los valores con lo de defecto
				prefCompilacion = new PreferenciasCompilacion(true);
				if (objLogger.isDebugEnabled())
					objLogger.debug("No se encuentra el fichero de compilacion.xml ");
			}
		}

	}

	// Guarda el espacio de trabajo que tenemos en nuestro fichero de trabajo
	/**
	 *<p>
	 * Guarda el espacio de trabajo que lo tenemos en nuestro fichero en una
	 * estructura XML.
	 * </p>
	 * <p>Tambin guardamos las preferencias de usuario</p>
	 *<p>
	 * La ruta donde podemos encontrar el fichero XML es Ruta:
	 * /PFC/workspace.xml
	 * </p>
	 */
	public void guardarWorkSpaceXML() {
		StringBuffer ltexto = new StringBuffer();
		
		//guardamos las preferencias del usuario
		getPreferenciasUsuario().guardarObjetoAFichero();
		
		if (iFWorkspace != null && iFWorkspace.exists()) {
			ltexto.append("<workspace ruta=\"" + iFWorkspace + "\">");
			if (ilproyectos != null) {
				for (Iterator iter = ilproyectos.iterator(); iter.hasNext();) {
					File lfProyecto = (File) iter.next();
					ltexto.append("\n\t" + "<proyecto>" + lfProyecto.getName()
							+ "</proyecto>");

				}
			}
			ltexto.append("\n</workspace>");

		}
		try {
			//url.getFile()
			File url = new File( this.getWorkSpaceXML());
			
			if (objLogger.isDebugEnabled())
				objLogger.debug("Creamos el Fichero workspace.xml en la ruta: " + url);
			
			OperacionesFicheros.guardarFichero(url, ltexto.toString());
		} catch (EpSilonExcepciones e) {
			Mensajes.mensajeDetalles(
					"No se ha podido guardar las opciones del WorkSpace ", e);
		} catch (IOException e) {
			Mensajes.mensajeDetalles(
					"No se ha podido guardar las opciones del WorkSpace ", e);
		}

	}

	/**
	 * Crea el workSpace, es decir la carpeta de trabajo donde iremos guardando
	 * nuestro proyectos.
	 */
	public void crearWorkSpace() {

		// abriremos nuestra ventana
		SeleccionarWorkSpace ventanaWorkSpace = new SeleccionarWorkSpace(this,
				true);
		ventanaWorkSpace.setVisible(true);
		iFWorkspace = ventanaWorkSpace.getWorkSpace();
	}

	/**
	 * Tratar cancelar. Creado : Parras, 07-jun-2009
	 */
	public void tratarCancelar() {

		if (getPanel() != null && getPanel().hayDatosAGuardar()) {
			GuardadoFinalPanel guardarFinal = new GuardadoFinalPanel(this,
					false, GuardadoFinalPanel.GUARDAR_MODO_SALIR);
			guardarFinal.setVisible(true);
			if (guardarFinal.isSalirAplicacion()) {
				guardarWorkSpaceXML();
				System.exit(0);
			}

		} else {

			if (!ijCheckSalirSinPreguntar.isSelected()){
			int valor = JOptionPane.showConfirmDialog(this,
					"Desea Salir de EpSilon?", "Confirmar Salida ",
					JOptionPane.YES_NO_OPTION, JOptionPane.QUESTION_MESSAGE,
					null);
			if (valor == JOptionPane.YES_OPTION) {
				guardarWorkSpaceXML();
				System.exit(0);
			} else if (valor == JOptionPane.NO_OPTION) {
				this.setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE); // Pulsar
				// y
				// cerrar
			}
			// case JOptionPane.NO_OPTION:
			// // No, Abandonar cambios
			// this.requestFocus();
			}else{
				guardarWorkSpaceXML();
				System.exit(0);
			}

		}
	}

	// Inicializacion del Panel
	/**
	 * Inicializacion de nuestro panel
	 * 
	 * @see proyecto.editor.PanelEdicion
	 **/
	public PanelEdicion getPanel() {
		if (panel == null) {
			panel = new PanelEdicion(this);
			// Controlador para el panel
			panel.setControlador(new ControlVentPanel(panel));
		}
		return panel;

	}

	// ITEM PARA LA EL MENU DE ARVHICO
	/**
	 * ITEM PARA LA EL MENU DE ARCHIVO
	 * 
	 * Creado : Parras, 07-jun-2009
	 */
	private void itemArchivo() {

		// ITEM Nuevo ctrl+N
		itemMenuArchivo_Nuevo = new JMenuItem("Nuevo Elemento", IconFactory
				.getImage("nuevo.png"));
		itemMenuArchivo_Nuevo.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_N, Event.CTRL_MASK));
		menuArchivo.add(itemMenuArchivo_Nuevo);

		itemMenuArchivo_NuevoProejecto = new JMenuItem("Nuevo Proyecto",
				IconFactory.getImage("proyecto_nuevo.png"));
		itemMenuArchivo_NuevoProejecto.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_N, Event.CTRL_MASK | Event.SHIFT_MASK));
		menuArchivo.add(itemMenuArchivo_NuevoProejecto);

		// ITEM Abrir Projecto ctrl+B
		itemMenuArchivo_AbrirProyecto = new JMenuItem("Abrir Proyecto",
				IconFactory.getImage("projecto_open.png"));
		// itemMenuArchivo_Abrir.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_A,
		// ActionEvent.CTRL_MASK));

		menuArchivo.add(itemMenuArchivo_AbrirProyecto);

		// ITEM Abrir ctrl+B
		itemMenuArchivo_Abrir = new JMenuItem("Abrir");
		itemMenuArchivo_Abrir.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_A, ActionEvent.CTRL_MASK));

		menuArchivo.add(itemMenuArchivo_Abrir);

		menuArchivo.addSeparator();

		// ITEM Cerar Archivos ctrl+W
		itemMenuArchivo_Cerrar = new JMenuItem("Cerrar");
		itemMenuArchivo_Cerrar.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_W, ActionEvent.CTRL_MASK));

		menuArchivo.add(itemMenuArchivo_Cerrar);

		// ITEM Cerar Todo Archivos ctrl+shift+W
		itemMenuArchivo_CerrarTodo = new JMenuItem("Cerrar Todo");
		itemMenuArchivo_CerrarTodo.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_W, Event.CTRL_MASK | Event.SHIFT_MASK));

		menuArchivo.add(itemMenuArchivo_CerrarTodo);
		// Separador Archivo
		menuArchivo.addSeparator();

		// ITEM Guardar Archivos ctrl+S

		itemMenuArchivo_Guardar = new JMenuItem("Guardar", IconFactory
				.getImage("guardar.gif"));
		itemMenuArchivo_Guardar.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_S, ActionEvent.CTRL_MASK));

		menuArchivo.add(itemMenuArchivo_Guardar);

		// ITEM Guardar_Como Archivos ctrl+S

		itemMenuArchivo_GuardarComo = new JMenuItem("Guardar Como", IconFactory
				.getImage("guardarcomo.gif"));
		// itemMenuArchivo_GuardarComo.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_S,
		// Event.CTRL_MASK | Event.SHIFT_MASK));

		menuArchivo.add(itemMenuArchivo_GuardarComo);

		itemMenuArchivo_GuardarTodo = new JMenuItem("Guardar Todo", IconFactory
				.getImage("guardartodo.gif"));
		itemMenuArchivo_GuardarTodo.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_S, Event.CTRL_MASK | Event.SHIFT_MASK));

		menuArchivo.add(itemMenuArchivo_GuardarTodo);

		// Separador Archivo
		menuArchivo.addSeparator();
		// ITEM Imprimir Archivos ctrl+P

		itemMenuArchivo_Exportar = new JMenuItem("Exportar", IconFactory
				.getImage("exportar.png"));
		itemMenuArchivo_Exportar.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_P, ActionEvent.CTRL_MASK));

		menuArchivo.add(itemMenuArchivo_Exportar);

		itemMenuArchivo_Imprimir = new JMenuItem("Imprimir", IconFactory
				.getImage("impresora.gif"));
		itemMenuArchivo_Imprimir.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_P, ActionEvent.CTRL_MASK));

		menuArchivo.add(itemMenuArchivo_Imprimir);
		// Separador Archivo
		menuArchivo.addSeparator();

		// Aadimos nuestro proyectos si nuestro array es distinto de null
		if (ilproyectos != null) {
			menuArchivo.add(subMenuProyectosRecientes());
			menuArchivo.addSeparator();

		}

		// ITEM Salir ctrl+x
		itemMenuArchivo_Salir = new JMenuItem("Salir", IconFactory
				.getImage("exit.gif"));
		itemMenuArchivo_Salir.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_X, ActionEvent.CTRL_MASK));

		menuArchivo.add(itemMenuArchivo_Salir);

	}

	/**
	 * Sub menu proyectos recientes.
	 * 
	 * @return jmenu Creado : Parras, 07-jun-2009
	 */
	public JMenu subMenuProyectosRecientes() {
		JMenu subMenu = new JMenu("Proyectos Recientes");
		// submenu.setMnemonic(KeyEvent.VK_S);

		if (ilproyectos.size() >= 1) {
			JMenuItem proyecto1 = new JMenuItem(ilproyectos.get(0).getName());
			ifProyecto0 = ilproyectos.get(0);
			proyecto1.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					if (ifProyecto0 != null)
						getPanel().cargarProyectoArbol(ifProyecto0);
				}

			});
			subMenu.add(proyecto1);
			if (ilproyectos.size() >= 2) {
				subMenu.addSeparator();
				JMenuItem proyecto2 = new JMenuItem(ilproyectos.get(1)
						.getName());
				ifProyecto1 = ilproyectos.get(1);
				proyecto2.addActionListener(new ActionListener() {
					public void actionPerformed(ActionEvent e) {
						if (ifProyecto1 != null)
							getPanel().cargarProyectoArbol(ifProyecto1);

					}

				});
				subMenu.add(proyecto2);

				subMenu.addSeparator();
				if (ilproyectos.size() >= 3) {
					JMenuItem proyecto3 = new JMenuItem(ilproyectos.get(2)
							.getName());
					ifProyecto2 = ilproyectos.get(2);
					proyecto3.addActionListener(new ActionListener() {
						public void actionPerformed(ActionEvent e) {
							if (ifProyecto2 != null)
								getPanel().cargarProyectoArbol(ifProyecto2);
						}

					});
					subMenu.add(proyecto3);
				}
			}
		} else {
			JMenuItem vacio = new JMenuItem("Vacio...");
			subMenu.add(vacio);
		}
		return subMenu;
	}

	// ITEM PARA LA EL MENU DE Editar
	/**
	 * Item editar. Creado : Parras, 07-jun-2009
	 */
	private void itemEditar() {

		// ITEM Deshacer ctrl+Z
		itemMenuEditar_Deshacer = new JMenuItem("Deshacer Teclado", IconFactory
				.getImage("deshacer.gif"));
		itemMenuEditar_Deshacer.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_Z, ActionEvent.CTRL_MASK));

		menuEditar.add(itemMenuEditar_Deshacer);
		// ITEM Reshacer ctrl+Y
		itemMenuEditar_Rehacer = new JMenuItem("Rehacer", IconFactory
				.getImage("rehacer.gif"));
		itemMenuEditar_Rehacer.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_Y, ActionEvent.CTRL_MASK));

		menuEditar.add(itemMenuEditar_Rehacer);

		menuEditar.addSeparator();

		// ITEM COPIAR ctrl+C
		itemMenuEditar_Copiar = new JMenuItem("Copiar", IconFactory
				.getImage("copiar.gif"));
		itemMenuEditar_Copiar.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_C, ActionEvent.CTRL_MASK));
		menuEditar.add(itemMenuEditar_Copiar);

		// ITEM Pegar ctrl+V
		itemMenuEditar_Pegar = new JMenuItem("Pegar", IconFactory
				.getImage("pegar.gif"));
		itemMenuEditar_Pegar.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_P, ActionEvent.CTRL_MASK));

		menuEditar.add(itemMenuEditar_Pegar);

		// ITEM Cortar ctrl+x
		itemMenuEditar_Cortar = new JMenuItem("Cortar", IconFactory
				.getImage("cortar.gif"));
		itemMenuEditar_Cortar.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_X, ActionEvent.CTRL_MASK));

		menuEditar.add(itemMenuEditar_Cortar);

		menuEditar.addSeparator();

		// ITEM Suprimir SUPR
		itemMenuEditar_Supr = new JMenuItem("Suprimir", IconFactory
				.getImage("suprimir.gif"));
		itemMenuEditar_Supr.setMnemonic('l');
		itemMenuEditar_Supr.setDisplayedMnemonicIndex(2);
		itemMenuEditar_Supr.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_DELETE, 0));

		menuEditar.add(itemMenuEditar_Supr);

		// ITEM Seleciona Todo ctr+A
		itemMenuEditar_Todo = new JMenuItem("Selecionar todo ");
		itemMenuEditar_Todo.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_A, ActionEvent.CTRL_MASK));
		// itemMenuEditar_Todo.setAction(panel.seleccionarTodo());
		menuEditar.add(itemMenuEditar_Todo);

		// ITEM BUSCAR ctrl+B
		itemMenuEditar_Buscar = new JMenuItem("Buscar", IconFactory
				.getImage("buscar.png"));
		itemMenuEditar_Buscar.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_B, ActionEvent.CTRL_MASK));
		menuEditar.add(itemMenuEditar_Buscar);

		itemMenuEditar_BuscarSig = new JMenuItem("Buscar Siguiente",
				IconFactory.getImage("buscar_sig.png"));
		// itemMenuEditar_BuscarSig.setText("Buscar Siguiente");
		itemMenuEditar_BuscarSig.setMnemonic('S');
		itemMenuEditar_BuscarSig.setDisplayedMnemonicIndex(7);
		itemMenuEditar_BuscarSig.setAccelerator(KeyStroke.getKeyStroke(
				KeyEvent.VK_F3, 0));
		menuEditar.add(itemMenuEditar_BuscarSig);

		// ITEM Remplazar ctrl+R
		itemMenuEditar_IrA = new JMenuItem("       Ir A...");
		itemMenuEditar_IrA.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_R,
				ActionEvent.CTRL_MASK));
		menuEditar.add(itemMenuEditar_IrA);

	}

	// ITEM PARA LA EL MENU DE Opciones
	/**
	 * Item opciones. Creado : Parras, 07-jun-2009
	 */
	private void itemOpciones() {
		// ItemMenuHerramientas
		// Intem Personalizar el IDE alt+p
		itemMenuHerramientas_Personalizar = new JMenuItem("Personalizar...",
				IconFactory.getImage("preferencias.gif"));
		itemMenuHerramientas_Personalizar.setMnemonic(KeyEvent.VK_P);
		menuOpciones.add(itemMenuHerramientas_Personalizar);

		// Intem Opciones del Compilador alt+E
		itemMenuHerramientas_Opciones = new JMenuItem("Opciones JavaCC...",
				IconFactory.getImage("opciones.gif"));
		itemMenuHerramientas_Opciones.setMnemonic(KeyEvent.VK_E);
		menuOpciones.add(itemMenuHerramientas_Opciones);
		
		itemMenuHerramientas_SubMenu = new JMenu ("Preferencias");		
		ijCheckSalirSinPreguntar = new JCheckBox ("Salir Sin Confirmacin");
		ijCheckSalirSinPreguntar.setToolTipText("No pide confirmacin al salir de la plataforma, si esta no tiene cambios");
		itemMenuHerramientas_SubMenu.add(ijCheckSalirSinPreguntar);
		ijCheckCOmpilarYGuardar = new JCheckBox ("Guardar al Compilar    ");
		ijCheckCOmpilarYGuardar.setToolTipText("Guarda la pestaa al activa cuando pulsemos compilar");
		itemMenuHerramientas_SubMenu.add(ijCheckCOmpilarYGuardar);
		
		menuOpciones.add(itemMenuHerramientas_SubMenu);
	}

	// ITEM PARA LA EL MENU DE Ayuda
	/**
	 * ITEM PARA LA EL MENU DE Ayuda. Creado : Parras, 07-jun-2009
	 */
	private void itemAyuda() {
		// Intem Personalizar el IDE alt+p
		itemMenuAyuda_Acerca = new JMenuItem("Acerca de EpSilon...",
				IconFactory.getImage("help.gif"));
		itemMenuAyuda_Acerca.setMnemonic(KeyEvent.VK_P);
		menuAyuda.add(itemMenuAyuda_Acerca);
		menuAyuda.add(itemMenuAyuda_Acerca);
	}

	/**
	 * Barra menu.
	 * 
	 * @return JMenuBar Creado : Parras, 07-jun-2009
	 */
	private JMenuBar getBarraMenu() {
		// Definniciones de la Barra de menu
		if (barraMenu == null) {
			// Creacion Barra Menu
			barraMenu = new JMenuBar();
			// Archivo y su tecla Asociada alt+ A
			menuArchivo = new JMenu("Archivo");
			menuArchivo.setMnemonic(KeyEvent.VK_A);
			// MenuArchivo.getAccessibleContext().setAccessibleDescription("The only menu in this program that has menu items");
			barraMenu.add(menuArchivo);
			// Item para menu Archivo
			itemArchivo();

			// Editar y su tecla Asociada alt+e
			menuEditar = new JMenu("Editar");
			menuEditar.setMnemonic(KeyEvent.VK_E);
			barraMenu.add(menuEditar);
			// Grupo de JMenuItems de Editar
			itemEditar();

			// Opciones y su tecla Asociada alt+O
			menuOpciones = new JMenu("Herramientas");
			menuOpciones.setMnemonic(KeyEvent.VK_H);
			barraMenu.add(menuOpciones);
			// Grupo de JMenuItems de Opciones
			itemOpciones();

			// Ayuda y su tecla Asociada alt+y
			menuAyuda = new JMenu("Ayuda");
			menuAyuda.setMnemonic(KeyEvent.VK_Y);
			barraMenu.add(menuAyuda);
			// Grupo de JMenuItems de Ayuda
			itemAyuda();
		}
		return barraMenu;
	}

	/**
	 * 
	 * <p>
	 * Los elementos que estn definidos mediante ActionCommand para los
	 * JMenuItem son:
	 * </p>
	 * <ul>
	 * <li>SALIR: Abandona la aplicacin</li>
	 * <li>NUEVO : Abre la ventana que gestiona nuevo elementos en nuestra
	 * aplicacin</li>
	 * <li>PROYECTO: Crear un proyecto</li>
	 * <li>ABRIR_PROYECTO: Abrir un proyecto existente</li>
	 * <li>ABRIR: Abre un fichero en modo texto</li>
	 * <li>CERRAR: Cierra la ventana activa, gestionado su estado de modificado</li>
	 * <li>CERRARTODO: Cierra todas las ventanas, gestionado su estado de
	 * modificado</li>
	 * <li>GUARDAR: Guarda un fichero abierto en un tab</li>
	 * <li>GUARDAR_C: Guarda todos los ficheros que tengamos con modificaciones
	 * en los tab.</li>
	 * <li>BUSCAR: Abre la ventana buscar en nuestro cdigo fuente, siempre lo
	 * realiza en el tab que est activo</li>
	 * <li>BUSCARSIG: Busca la siguiente cadena de texto, sin tener la ventana
	 * de bsqueda abierta</li>
	 * <li>IR_A: Abre la ventana de ir a una lnea del source determinada</li>
	 * <li>IMPRIMIR: imprime nuestro tab activo mediante ireport.</li>
	 * <li>EXPORTAR: Abre la ventana de exportar</li>
	 * <li>DESHACER: Deshace la modificaciones que se han realizado en nuestro
	 * tab activo</li>
	 * <li>REHACER: Rehace la modificaciones que se han realizado en nuestro tab
	 * activo</li>
	 * <li>COPIAR: Copia texto al portapapeles del texto seleccionado en nuestro
	 * tab</li>
	 * <li>PEGAR: Pega el texto del portapapeles de la maquina donde este
	 * situado el cursor</li>
	 * <li>CORTAR: Corta texto de nuestro tab y lo copia al portapapeles del
	 * texto</li>
	 * <li>SELECIONARTODO: Selecciona todo el texto de nuestro tab activo</li>
	 * <li>SUPR: Elimina el texto seleccionado de nuestro tab</li>
	 * <li>PERSONALIZAR: Abre la ventana personalizar colores y tipo de letra</li>
	 * <li>OPCIONES: Abre la ventana de opciones de compilacin</li>
	 * <li>SALIR_SIN_PREGUNTAR: Salir sin preguntar de nuestro sistema</li>
	 * <li>COMPILAR_Y_GUARDAR: Compila y guarda el tab activo</li>
	 * </ul>
	 * <p>
	 * Sern implementados en la clase ControlVentEditor.
	 * </p>
	 * 
	 * @see proyecto.editor.ControlVentEditor#actionPerformed(java.awt.event.ActionEvent)
	 */
	public void setControlador(ControlVentEditor c) {
		crt = c;
		// Para los Item de Archivo su correspondiente listenar
		
		
		itemMenuArchivo_Salir.setActionCommand("SALIR");
		itemMenuArchivo_Salir.addActionListener(crt);

		itemMenuArchivo_Nuevo.setActionCommand("NUEVO");
		itemMenuArchivo_Nuevo.addActionListener(crt);

		itemMenuArchivo_NuevoProejecto.setActionCommand("PROYECTO");
		itemMenuArchivo_NuevoProejecto.addActionListener(crt);

		itemMenuArchivo_AbrirProyecto.setActionCommand("ABRIR_PROYECTO");
		itemMenuArchivo_AbrirProyecto.addActionListener(crt);

		itemMenuArchivo_Abrir.setActionCommand("ABRIR");
		itemMenuArchivo_Abrir.addActionListener(crt);

		itemMenuArchivo_Cerrar.setActionCommand("CERRAR");
		itemMenuArchivo_Cerrar.addActionListener(crt);

		itemMenuArchivo_CerrarTodo.setActionCommand("CERRARTODO");
		itemMenuArchivo_CerrarTodo.addActionListener(crt);

		itemMenuArchivo_Guardar.setActionCommand("GUARDAR");
		itemMenuArchivo_Guardar.addActionListener(crt);

		itemMenuArchivo_GuardarComo.setActionCommand("GUARDAR_C");
		itemMenuArchivo_GuardarComo.addActionListener(crt);

		itemMenuEditar_Buscar.setActionCommand("BUSCAR");
		itemMenuEditar_Buscar.addActionListener(crt);
		itemMenuEditar_BuscarSig.setActionCommand("BUSCARSIG");
		itemMenuEditar_BuscarSig.addActionListener(crt);

		itemMenuEditar_IrA.setActionCommand("IR_A");
		itemMenuEditar_IrA.addActionListener(crt);

		itemMenuArchivo_Imprimir.setActionCommand("IMPRIMIR");
		itemMenuArchivo_Imprimir.addActionListener(crt);

		itemMenuArchivo_Exportar.setActionCommand("EXPORTAR");
		itemMenuArchivo_Exportar.addActionListener(crt);

		itemMenuEditar_Deshacer.setActionCommand("DESHACER");
		itemMenuEditar_Deshacer.addActionListener(crt);

		itemMenuEditar_Rehacer.setActionCommand("REHACER");
		itemMenuEditar_Rehacer.addActionListener(crt);

		itemMenuEditar_Copiar.setActionCommand("COPIAR");
		itemMenuEditar_Copiar.addActionListener(crt);

		itemMenuEditar_Pegar.setActionCommand("PEGAR");
		itemMenuEditar_Pegar.addActionListener(crt);

		itemMenuEditar_Cortar.setActionCommand("CORTAR");
		itemMenuEditar_Cortar.addActionListener(crt);
		itemMenuEditar_Todo.setActionCommand("SELECIONARTODO");
		itemMenuEditar_Todo.addActionListener(crt);

		itemMenuEditar_Supr.setActionCommand("SUPR");
		itemMenuEditar_Supr.addActionListener(crt);

		itemMenuHerramientas_Personalizar.setActionCommand("PERSONALIZAR");
		itemMenuHerramientas_Personalizar.addActionListener(crt);

		itemMenuHerramientas_Opciones.setActionCommand("OPCIONES");
		itemMenuHerramientas_Opciones.addActionListener(crt);

		itemMenuAyuda_Acerca.setActionCommand("ACERCA");
		itemMenuAyuda_Acerca.addActionListener(crt);
		
		ijCheckSalirSinPreguntar.setActionCommand("SALIR_SIN_PREGUNTAR");
		ijCheckSalirSinPreguntar.addActionListener(crt);
		
		ijCheckCOmpilarYGuardar.setActionCommand("COMPILAR_Y_GUARDAR");
		ijCheckCOmpilarYGuardar.addActionListener(crt);
		

	}

	/**
	 * ******************************Manejos de Fichero Para el JTextPane
	 * ************INICIO*****************.
	 * 
	 * @throws BadLocationException  *
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	// Para Seleccionar el archivo abrir
	public void buscarFichero() throws IOException {
		if (!okAbandonar()) {
			return;
		}
		// para elegir el archivo
		/** para elgir archivo. */
		JFileChooser elgirArchivo = new JFileChooser();
		if (JFileChooser.APPROVE_OPTION == elgirArchivo.showOpenDialog(this)) {
			try {
				abrirFichero(elgirArchivo.getSelectedFile().getPath());
			} catch (BadLocationException e) {
				Mensajes.mensajeDetalles("Error al abrir el fichero", e);
			}
		}
		this.repaint();
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see proyecto.editor.InterfazVentEditor#AbrirFichero(java.lang.String)
	 */
	public void abrirFichero(String nombreArchivo) throws BadLocationException {
		try {
			// nos proporciona informaci�n acerca de los archivos, de sus
			// atributos, de los directorios
			File file = new File(nombreArchivo);

			// Obtenemos el tama�o del fichero
			int tamanno = (int) file.length();

			// Caracteres a leer
			int car_Leer = 0;

			// Creamos el descriptor para leer el fichero
			FileReader in = new FileReader(file);

			// No creamos el array del tama�o de fichero
			char[] data = new char[tamanno];

			// Empezamos a recorer el fichero miestras este preparado
			while (in.ready()) {

				car_Leer += in.read(data, car_Leer, tamanno - car_Leer);
			}
			in.close();

			// Guardamos todo lo leido de en nuestro panel

			panel.guardarTexto(new String(data, 0, car_Leer), new Nodo(file,
					false, null));

			// Tener costancia del fichero que estamos leuendo
			this.rutaArchivo = nombreArchivo;
			// ...Marca de que esta leido
			ok = false;

			// Escribimos en nuestro estatuBar que se abierto el fichero.
			panel.setTextoBarraEstado("Abierto " + nombreArchivo);
			updateCaption(nombreArchivo);
			panel.cambiarTabbImag(ledverde);

		} catch (IOException e) {
			panel.setTextoBarraEstado("Error Abriendo " + nombreArchivo);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see proyecto.InterfazVentEditor#guardarComo()
	 */
	public boolean guardarComo() throws EpSilonExcepciones, IOException {

		if (rutaArchivo == null) {
			return guardarEnFichero();
		}

		try {
			// Abrimos el Archivo
			File file = new File(rutaArchivo);

			// Nos Abrimos el descriptor
			FileWriter out = new FileWriter(file);
			String texto = panel.devolverTexto();
			out.write(texto);
			out.close();

			panel.setTextoBarraEstado("Guardado " + rutaArchivo);

			panel.cambiarTabbImag(ledverde);
			rutaArchivo = null;// ya tenmos la file guardada no tenemos que
			// tener costancia de ella

			return true;
		} catch (EpSilonExcepciones e) {
			panel.setTextoBarraEstado("Error Guardando " + rutaArchivo);
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see proyecto.InterfazVentEditor#guardarComo(java.io.File)
	 */
	public boolean guardarComo(File archivo) throws EpSilonExcepciones, IOException {

		try {
			// Abrimos el Archivo

			// Nos Abrimos el descriptor
			FileWriter out = new FileWriter(archivo);
			String texto = panel.devolverTexto(archivo.toString());
			if (texto != null )
				out.write(texto);
		
			out.close();

			panel.setTextoBarraEstado("Guardado " + archivo);
			panel.cambiarTabbImag(ledverde);

			return true;
		} catch (EpSilonExcepciones e) {
			panel.setTextoBarraEstado("Error Guardando " + archivo);
		}
		return false;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see proyecto.InterfazVentEditor#guardarEnFichero()
	 */
	public boolean guardarEnFichero() throws IOException {
		this.repaint();
		// para elegir el archivo
		/** para elgir archivo. */
		JFileChooser elgirArchivo = new JFileChooser();
		// Abrir el chooser para salvar
		if (JFileChooser.APPROVE_OPTION == elgirArchivo.showSaveDialog(this)) {
			// Mandar el path al fichero
			rutaArchivo = elgirArchivo.getSelectedFile().getPath();
			this.repaint();
			panel.cambiarTabbImag(ledverde);
			return guardarComo();
		} else {
			this.repaint();
			return false;
		}
	}

	/**
	 * Obtener el ruta archivo.
	 * 
	 * @return el ruta archivo Creado : Parras, 07-jun-2009
	 */
	public String getRutaArchivo() {
		return rutaArchivo;
	}

	// Cambiar el Camption en la parte de arriba de la ventana con el nombre de
	// la ruta
	/**
	 * Cambiar el Camption en la parte de arriba de la ventana con el nombre de
	 * la ruta.
	 * 
	 * @param texto
	 *            texto
	 */
	public void updateCaption(String texto) {
		String caption;

		caption = "EpSilon - " + texto;
		this.setTitle(caption);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see proyecto.InterfazVentEditor#okAbandonar()
	 */
	public boolean okAbandonar() throws EpSilonExcepciones, IOException {
		if (!ok) {
			return true;
		}
		int valor = JOptionPane.showConfirmDialog(this,
				"�Guardar Los Cambios?", "Texto",
				JOptionPane.YES_NO_CANCEL_OPTION);

		switch (valor) {
		case JOptionPane.YES_OPTION:
			// SI,Aceptar los Cambios
			return guardarComo();
		case JOptionPane.NO_OPTION:
			// No Abandonar cambios
			return true;
		case JOptionPane.CANCEL_OPTION:
		default:
			// cancelar
			return false;
		}
	}

	// la carpeta de nuestro workSpace, la cual contredr� nuestro proyectos
	/**
	 * Obtener el workspace.
	 * 
	 * @return el workspace Creado : Parras, 07-jun-2009
	 */
	public File getWorkspace() {
		if (iFWorkspace == null)
			Mensajes.mensajeError("Error Grave , debe definir el workSpace");
		return iFWorkspace;
	}

	/**
	 * Modificar la propiedad workspace.
	 * 
	 * @param aWorkspace
	 *            La propiedad workspace
	 */
	public void setWorkspace(File aWorkspace) {
		this.iFWorkspace = aWorkspace;
	}

	// Devolvemos el proyecto pasado una posicin

	/**
	 * Obtener proyecto.
	 * 
	 * @param aPosicion
	 *            a posicion
	 * 
	 * @return File proyecto
	 */
	public File getProyecto(int aPosicion) {
		File lFile = null;
		if (ilproyectos != null && ilproyectos.size() <= aPosicion)
			lFile = ilproyectos.get(aPosicion);
		return lFile;
	}

	/**
	 * Obtener el primer proyecto.
	 * 
	 * @return el primer proyecto Creado : Parras, 07-jun-2009
	 */
	public File getPrimerProyecto() {
		File lFile = null;
		if (ilproyectos != null && ilproyectos.size() > 0)
			lFile = ilproyectos.get(0);

		return lFile;

	}

	/**
	 * borrar un proyecto pasado como paramentro proyecto, solo el nombre.
	 * 
	 * @param proyecto
	 *            String
	 * 
	 * @return true, si es correcto Creado : Parras, 07-jun-2009
	 */
	public boolean setBorrarProyecto(String proyecto) {

		return ilproyectos.remove(new File(iFWorkspace + File.separator
				+ proyecto));
	}
	
	/**
	 * borrar un proyecto pasado como paramentro proyecto. Pasamos toda la ruta
	 * 
	 * @param proyecto
	 *            File
	 * 
	 * @return true, si es correcto Creado : Parras, 07-jun-2009
	 */
	public boolean setBorrarProyecto(File proyecto) {

		return ilproyectos.remove(proyecto);
	}

	/**
	 * addProyecto aade nuestro proyecto a nuestro array si no lo contiene.
	 * 
	 * @param aFileProyecto
	 *            a file proyecto
	 */
	public void addProyecto(File aFileProyecto) {
		if (ilproyectos == null)
			ilproyectos = new ArrayList<File>();
		// se inserta en la primera en la primera posicin
		if (!ilproyectos.contains(aFileProyecto))
			ilproyectos.add(0, aFileProyecto);
		else {// Se elimina porque ya existe y se inserta en la primera
			// posicin
			ilproyectos.remove(aFileProyecto);
			ilproyectos.add(0, aFileProyecto);
		}
	}

	/**
	 * Devolvemos el array de proyectos.
	 * 
	 * @return ArrayList<File>
	 */
	public ArrayList<File> getProyectos() {
		return ilproyectos;
	}

	/**
	 * Obtener el preferencias compilacion.
	 * 
	 * @return el preferencias compilacion Creado : Parras, 07-jun-2009
	 */
	public PreferenciasCompilacion getPreferenciasCompilacion() {
		return prefCompilacion;
	}

	/**
	 * Modificar la propiedad preferencias compilacion.
	 * 
	 * @param prefCompilacion
	 *            La propiedad preferencias compilacion
	 */
	public void setPreferenciasCompilacion(
			PreferenciasCompilacion prefCompilacion) {
		this.prefCompilacion = prefCompilacion;
	}

	
	/**
	 * Modificar la propiedad preferencias usuario.
	 * 
	 * @param prefUsuario
	 *            La propiedad preferencias usuario
	 */
	public void setPreferenciasUsuario(PreferenciasUsuario prefUsuario) {
		this.prefUsuario = prefUsuario;
	}

	/**
	 * Obtener las  preferencias usuario.
	 * 
	 * @return el preferencias usuario Creado : Parras, 25-nov-2009
	 */
	public PreferenciasUsuario getPreferenciasUsuario() {
		return prefUsuario;
	}

	/**
	 * Proyectos cargados en nuestro Fichero WorkSpace.xml
	 * 
	 * @see proyecto.editor.InterfazVentEditor#getProyectosActivos()
	 */
	public File[] getProyectosActivos() {

		if (ilproyectos == null) //nunca se ha creado un proyecto
			ilproyectos = new ArrayList<File> ();
		
		return (ilproyectos == null) ? null : (File[]) ilproyectos
				.toArray(new File[ilproyectos.size()]);
	}

	/**
	 * Devuelve Proyectos cargados en nuestro Fichero WorkSpace
	 * 
	 * @param ilproyectos
	 */
	public void setProyectosActivas(ArrayList<File> ilproyectos) {
		this.ilproyectos = ilproyectos;
	}
	
	/**
	 * Inserta un nuevo proyecto que proviene de nuestro workSpace. Si existe 
	 * devuelve falso.
	 * 
	 * @param ilproyectos
	 */
	public boolean addProyectosNoActivo(File ilproyectoWorkSpace) {
		boolean lbInserta = false;
		if (ilproyectos == null)
			ilproyectos = new ArrayList<File>();
			
		if (!ilproyectos.contains(ilproyectoWorkSpace)){
			
			lbInserta = ilproyectos.add(ilproyectoWorkSpace);
		}
		return lbInserta;
	}

	/**
	 * Devuelve la situacion del fichero workSpace.xml
	 * @return String ruta completa con el nombre del fichero.
	 */
	public  String getWorkSpaceXML(){
		return getClass().getResource(ConstantesEpSilon.DIRECTORIO_CLASSPATH).getFile()+ConstantesEpSilon.CONFIGURACION_WORKSPACE;
	}
	
	/**
	 * Devuelve la situacion del fichero configColores.xml
	 * @return String ruta completa con el nombre del fichero.
	 */
	public  String getPrefColoresXML(){
		
		return getWorkspace().toString()+File.separator+ConstantesEpSilon.CONFIGURACION_COLORES;
	}
	
	/**
	 * Devuelve la situacion del fichero compilacion.xml
	 * @return String ruta completa con el nombre del fichero.
	 */
	public  String getCompilacionXML(){
		
		return getWorkspace().toString()+File.separator+ConstantesEpSilon.CONFIGURACION_COMPILACION;
	}
	 
	/** Devuelve la situacion del fichero prefUsu.xml
	 * @return String ruta completa con el nombre del fichero.
	 */
	public  String getPrefUsuerXML(){
		
		return getWorkspace().toString()+File.separator+ConstantesEpSilon.CONFIGURACION_PREF_USU;
	}
	
	/********************************
	 * Manejos de Fichero Para el JTexTPane INICIO
	 */
} // @jve:decl-index=0:visual-constraint="162,46"

