/*
 * 
 * @author Manuel Parras  
 */

package proyecto.editor;

import java.awt.Component;
import java.io.IOException;

import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;
import javax.swing.WindowConstants;

import proyecto.arbol.Nodo;
import proyecto.imagenes.IconFactory;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.OperacionesVentanas;

/**
 * GuardadoFinalPanel.
 * 
 * 
 * 
 * GuardadoFinalPanel
 * <p>
 * Ventana que corresponde al panel de salir de la aplicacin. Esta ventana
 * guarda los ficheros que tienen cambios.
 * </p>
 * <p>
 * El panel est divido en dos secciones :
 * </p>
 * <ul>
 * <li>Apartado de tem/s a guardar: corresponde a los fichero/s que se han
 * modificado en nuestro editor y estn pendientes de cambios</li>.
 * <li>Botonera: Contempla las siguientes opciones:
 * <ul>
 * <li>Guardar: Solo guardamos los tem/s seleccionado, el resto sern omitidos,
 * seguidamente abandonamos la aplicacin</li>
 * <li>Guardar Todo: Guarda todos los tem de la aplicacin y salimos</li>
 * <li>Cancelar: Cancelamos la salida de la aplicacin, por consiguiente
 * volvemos a la aplicacin en el mismo estado que lo dejamos.</li>
 * <li>Salir: Abandonamos la aplicacin omitiendo los cambios realizados en los
 * tem/s mostrados</li>
 * </ul>
 * </li>
 * 
 * </ul>
 * 
 * @see proyecto.arbol.Nodo 
 * @author Parras
 */
public class GuardadoFinalPanel extends javax.swing.JDialog {
	
	/** Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;
	
	/** Constant GUARDAR_MODO_SALIR. */
	public static final int GUARDAR_MODO_SALIR = 0;
	
	/** Constant GUARDAR_MODO_PROYECTO. */
	public static final int GUARDAR_MODO_PROYECTO = 1;
	
	

	/**  @see proyecto.editor.Editor  */
	private Editor iGuiPrinc;
	
	/** @see proyecto.arbol.Nodo */
	private Nodo [] iasNoGuardados;
	
	/** Modo como va a funcionar nuesrto panel. */
	private int iModoPanel;
	
	/** ibsaliraplicacion. */
	private boolean ibSalirAplicacion=true;
	
	
	/**
	 * Constructor guardado final panel.
	 * 
	 * Creado : Parras, 21-oct-2009
	 * 
	 * @param aguiEditor
	 *            agui editor 
	 * @param modal ventana permante
	 *            
	 * @param aModo Constantes de clase para usar la ventana
	 *
	 * @see proyecto.editor.PanelEdicion#getNombreTabSinGuardar()
	 */
	public GuardadoFinalPanel(Editor aguiEditor, boolean modal,int aModo) {
		super(aguiEditor, true);
		iGuiPrinc=aguiEditor;
		iasNoGuardados=iGuiPrinc.getPanel().getNombreTabSinGuardar();	

		//Si no tenemos datos que guardar la aplicacion debe 
		//cerrarse al completo
		
		iModoPanel=aModo;
		initComponents();
		accesoRapido();		
		this.pack();
		this.setSize(420, 200);
		this.setTitle("Guardar");
//		Rectangle bounds = iGuiPrinc.getBounds();
//		Dimension size = getSize();
		OperacionesVentanas.centraVentana(this);
		if (aModo==GUARDAR_MODO_PROYECTO)
			bSalir.setVisible(false);




	}
	
  /**
	 * Acceso rapido a los botones
	 * 
	 * reado : Parras, 21-oct-2009
	 */
  public void  accesoRapido(){
	  bGuardar.setMnemonic('G');
	  bGuardarTodo.setMnemonic('T');
	  bCancelar.setMnemonic('C');
	  bSalir.setMnemonic('S');
  }

	/**
	 * Inits components. Creado : Parras, 21-oct-2009
	 */
	@SuppressWarnings("serial")
	private void initComponents() {
		java.awt.GridBagConstraints gridBagConstraints;

		panelListaItem = new javax.swing.JPanel();
		jScrollPane1 = new javax.swing.JScrollPane();
		jList1 = new javax.swing.JList();
		panelBotones = new javax.swing.JPanel();
		bGuardar = new javax.swing.JButton();
		bGuardarTodo = new javax.swing.JButton();
		bCancelar = new javax.swing.JButton();
		bSalir= new javax.swing.JButton();

		getContentPane().setLayout(new java.awt.GridBagLayout());

		setDefaultCloseOperation(WindowConstants.DO_NOTHING_ON_CLOSE);
		panelListaItem.setLayout(new java.awt.GridBagLayout());

		panelListaItem.setBorder(javax.swing.BorderFactory.createTitledBorder("Item"));
		jList1.setModel(new javax.swing.AbstractListModel() {
			Nodo[] nodoTab = iasNoGuardados;
			public int getSize() { return nodoTab.length; }
			public Object getElementAt(int i) { return nodoTab[i]; }
		});
		jList1.setCellRenderer(new RendereJlist());
		jScrollPane1.setViewportView(jList1);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.weightx = 1.0;
		gridBagConstraints.weighty = 1.0;
		panelListaItem.add(jScrollPane1, gridBagConstraints);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.weightx = 1.0;
		gridBagConstraints.weighty = 1.0;
		gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
		getContentPane().add(panelListaItem, gridBagConstraints);

		panelBotones.setLayout(new java.awt.GridBagLayout());

		panelBotones.setBorder(javax.swing.BorderFactory.createTitledBorder(javax.swing.BorderFactory.createTitledBorder("Opciones")));
		bGuardar.setText("Guardar");
		bGuardar.setToolTipText("<html>Guarda los Ficheros Seleccionados<br> Seleccionar varios pulsando Ctrl</html>");

		bGuardar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				bGuardarActionPerformed(evt);
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(5, 3, 10, 8);
		panelBotones.add(bGuardar, gridBagConstraints);

		bGuardarTodo.setText("Guardar Todo");
		bGuardarTodo.setToolTipText("<html>Guarda todos los Ficheros</html>");
		bGuardarTodo.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				bGuardarTodoActionPerformed(evt);
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(5, 3, 10, 8);
		panelBotones.add(bGuardarTodo, gridBagConstraints);

		bCancelar.setText("Cancelar");
		if (iModoPanel==GUARDAR_MODO_SALIR)
			bCancelar.setToolTipText("Cancelar");
		if (iModoPanel==GUARDAR_MODO_PROYECTO)
			bCancelar.setToolTipText("Se perder los cambios realizados");
		
		bCancelar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				bCancelarActionPerformed(evt);
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(5, 3, 10, 8);
		panelBotones.add(bCancelar, gridBagConstraints);

		bSalir.setText("Salir");
		bSalir.setToolTipText("<html>Salir de la aplicacin</html>");
		bSalir.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				bSalirActionPerformed(evt);
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 3;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(0, 3, 0, 8);
		panelBotones.add(bSalir, gridBagConstraints);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.VERTICAL;
		gridBagConstraints.weighty = 1.0;
		gridBagConstraints.insets = new java.awt.Insets(4, 4, 4, 4);
		getContentPane().add(panelBotones, gridBagConstraints);

		pack();
	}

	/**
	 *  cancelar action performed. 
	 * 
	 * @param evt
	 *            evt
	 *            Creado : Parras, 21-oct-2009
	 */
	private void bCancelarActionPerformed(java.awt.event.ActionEvent evt) {
		//Boton Cancelar
		ibSalirAplicacion=false;
		this.dispose();
		
	}
	
	/**
	 * Salir de la ventana, si destruir la aplicacin
	 * 
	 * @param evt
	 *            evt
	 *            Creado : Parras, 21-oct-2009
	 */
	private void bSalirActionPerformed(java.awt.event.ActionEvent evt) {
		//System.exit(0);
		this.dispose();
	}

	/**
	 *Guarda todos los item de la lista  
	 * 
	 * @param evt
	 *            evt
	 *            Creado : Parras, 21-oct-2009
	 */
	private void bGuardarTodoActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_bGuardarTodoActionPerformed
		//Boton De Seleccionar
		if (iasNoGuardados!=null){
			for (int i = 0; i < iasNoGuardados.length; i++) {
				try {
					iGuiPrinc.guardarComo(iasNoGuardados[i].getDirectorio());
				} catch (EpSilonExcepciones e) {

					Mensajes.mensajeDetalles("Error al guardar el fichero", e);
				} catch (IOException e) {

					Mensajes.mensajeDetalles("Error al guardar el fichero", e);
				}

			}
//			if (iModoPanel==GUARDAR_MODO_SALIR)	
//				System.exit(0);
//			if (iModoPanel==GUARDAR_MODO_PROYECTO)
				this.dispose();
		}

	}//GEN-LAST:event_bGuardarTodoActionPerformed

	/**
	 *  Guarda los ficheros seleccionados en la JList.
	 * 
	 * @param evt
	 *            evt
	 *            Creado : Parras, 21-oct-2009
	 */
	private void bGuardarActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_bGuardarActionPerformed
		//Boton Seleccionar Todo

		if (!jList1.isSelectionEmpty()){

			//Aqui tenemos las posiciones que queremos guardar, es decir lo que hemos seleccionado
			//Para que se guardado
			int[] auxSelecionados = jList1.getSelectedIndices();
			if (auxSelecionados!=null){
				for (int i = 0; i < auxSelecionados.length; i++) {
					try {
						//System.out.print("\n"+auxSelecionados[i]+"  "+iasNoGuardados[auxSelecionados[i]].getDirectorio());
						//auxSelecionados[i] tenemos los elementos seleccionado para que sean guardados
						iGuiPrinc.guardarComo(iasNoGuardados[auxSelecionados[i]].getDirectorio());
					} catch (EpSilonExcepciones e) {

						Mensajes.mensajeDetalles("Error al guardar el fichero", e);
					} catch (IOException e) {

						Mensajes.mensajeDetalles("Error al guardar el fichero", e);
					}

				}		

//				if (iModoPanel==GUARDAR_MODO_SALIR)	
//					System.exit(0);
//				if (iModoPanel==GUARDAR_MODO_PROYECTO)
					this.dispose();
			}
		}else
			Mensajes.mensajeInfo("Debe seleccionar algn elemento a guardar");


	}//GEN-LAST:event_bGuardarActionPerformed
	
	/**
	 * Class RendereJlist.
	 * Renderes con un icono para la lista 
	 */
	private class RendereJlist extends JLabel implements ListCellRenderer {

		/** Constant serialVersionUID. */
		private static final long serialVersionUID = 1L;
		
		/* (non-Javadoc)
		 * @see javax.swing.ListCellRenderer#getListCellRendererComponent(javax.swing.JList, java.lang.Object, int, boolean, boolean)
		 */
		public Component getListCellRendererComponent(JList arg0, Object arg1, int arg2, boolean arg3, boolean arg4) {
			// TODO Apndice de mtodo generado automticamente
			//System.out.print(arg1);
			if (getExtension(arg1.toString()).equals("java")){
				this.setIcon(IconFactory.getImage("arbolFicherojava.png"));	
				this.setText(arg1.toString());


			}else if (getExtension(arg1.toString()).equals("jj")){
				this.setIcon(IconFactory.getImage("arbolFicherojj.png"));
				this.setText(arg1.toString());
			}



			return this;
		}
		
		/**
		 * Obtener el extension.
		 * 
		 * @param filename
		 *            filename
		 * 
		 * @return el extension Creado : Parras, 21-oct-2009
		 */
		private  String getExtension(String filename) {
			if(filename != null) {

				int i = filename.lastIndexOf('.');
				if(i>0 && i<filename.length()-1) {
					return filename.substring(i+1);
				};
			}
			return null;
		}

	}


	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** JButtoncancelar. */
	private javax.swing.JButton bCancelar;
	
	/** JButtonguardar. */
	private javax.swing.JButton bGuardar;
	
	/** JButton guardar todo. */
	private javax.swing.JButton bGuardarTodo;
	
	/** JButton salir. */
	private javax.swing.JButton bSalir;
	
	/** JList list1. */
	private javax.swing.JList jList1;
	
	/**  scroll pane1. */
	private javax.swing.JScrollPane jScrollPane1;
	
	/** panel botones. */
	private javax.swing.JPanel panelBotones;
	
	/** panel lista item. */
	private javax.swing.JPanel panelListaItem;
	// End of variables declaration//GEN-END:variables

	/**
	 * Verificamos si vamos a  salir aplicacion.
	 * 
	 * @return true, Si es salir aplicacion Creado : Parras, 21-oct-2009
	 */
	public boolean isSalirAplicacion() {
		return ibSalirAplicacion;
	}

	/**
	 * Modificar la propiedad salir aplicacion.
	 * 
	 * @param abSalirAplicacion
	 *            La propiedad salir aplicacion
	 */
	public void setSalirAplicacion(boolean abSalirAplicacion) {
		this.ibSalirAplicacion = abSalirAplicacion;
	}

}
