/*
 * 
 * @author Manuel Parras  
 */
package proyecto.editor;

import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;

import javax.swing.text.BadLocationException;

/**
 * 
 * 
 * Clase InterfazVentEditor
 * <p>
 * Describe una lista de mtodos y acciones que debe implementar nuestra clase
 * Editor.
 * </p>
 * 
 * @see proyecto.editor.Editor
 */
interface InterfazVentEditor {

	// *******************METODOS UTILIZADOS ***********
	/**
	 * Crea La ventana Principal.
	 */
	public void salir();

	/*-----------------------------------------------*/
	/**
	 * Asigna al Oyente que estar pendiente de los eventos de los botones.
	 * 
	 * @param c
	 *            Sera el oyente
	 */
	public void setControlador(ControlVentEditor c);

	/*-----------------------------------------------*/

	/**
	 * Guarda el fichero asignando un direccion.
	 * 
	 * @return true, if guardar como
	 * 
	 * @throws EpSilonExcepciones
	 *             the excepciones
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public boolean guardarComo() throws EpSilonExcepciones, IOException;

	/**
	 * Para Saber si ha salido el programador.
	 * 
	 * @return true, if ok abandonar
	 * 
	 * @throws EpSilonExcepciones
	 *             the excepciones
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public boolean okAbandonar() throws EpSilonExcepciones, IOException;

	/**
	 * Para Abrir el fichero.
	 * 
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public void buscarFichero() throws IOException;

	/**
	 * Guardar los datos en un fichero.
	 * 
	 * @return true, if guardar en fichero
	 * 
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public boolean guardarEnFichero() throws IOException;

	/**
	 * Cuando Modificamos o Borramos algo en nuestro fichero.
	 * 
	 * @return the panel
	 */
	public PanelEdicion getPanel();

	/**
	 * Update caption. Creado : Parras, 13-oct-2009
	 * 
	 * @param texto
	 *            the texto
	 */
	public void updateCaption(String texto);

	/**
	 * Abrir fichero. 
	 * 
	 * @param nombreArchivo
	 *            the nombre archivo
	 * 
	 * @throws BadLocationException
	 *             the bad location exception
	 *             Creado : Parras, 13-oct-2009
	 */
	public void abrirFichero(String nombreArchivo) throws BadLocationException;

	/**
	 * Guardar como.
	 * 
	 * @param archivo
	 *            the archivo
	 * 
	 * @return true, si es correcto Creado : Parras, 13-oct-2009
	 * 
	 * @throws EpSilonExcepciones
	 *             the excepciones
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public boolean guardarComo(File archivo) throws EpSilonExcepciones, IOException;

	/**
	 * Proyectos cargados en nuestro Fichero WorkSpace.xml
	 * 
	 * @return the proyectos activos
	 */
	public File[] getProyectosActivos();

}
