/*
 * 
 * @author Manuel Parras  
 */
package proyecto.editor;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Font;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import java.io.PrintStream;
import java.net.URL;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Vector;

import javax.swing.Icon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTabbedPane;
import javax.swing.JToolBar;
import javax.swing.JTree;
import javax.swing.ScrollPaneConstants;
import javax.swing.SwingConstants;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.Style;
import javax.swing.text.StyleConstants;
import javax.swing.text.StyleContext;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import org.apache.log4j.Logger;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.jvnet.substance.SubstanceLookAndFeel;
import org.jvnet.substance.tabbed.VetoableTabCloseListener;

import proyecto.arbol.ArbolFicheros;
import proyecto.arbol.Nodo;
import proyecto.consola.CompilacionDatos;
import proyecto.consola.ConsolaOutStream;
import proyecto.consola.ConsolaTextPane;
import proyecto.consola.TabbInformacion;
import proyecto.imagenes.IconFactory;
import proyecto.impresion.ImprimirEpsilon;
import proyecto.paneles.DatosExportar;
import proyecto.paneles.NuevoVentana;
import proyecto.preferencias.AtributosPreferenicas;
import proyecto.preferencias.ItemDeLista;
import proyecto.utilidades.BarraEstado;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.MenuPopupTab;
import proyecto.utilidades.NumeroLinea;
import proyecto.utilidades.OperacionesFicheros;
import proyecto.utilidades.OperacionesTextPane;
import proyecto.utilidades.UtilidadesEpsilon;

/**
 * PanelEdicin:
 * 
 * <p>
 * Clase contenedora de todos los elementos ms importantes de nuestro editor,
 * la clase hereda de JPanel. Nuestro panel esta ordenado mediante un
 * BorderLayout , dicho layout es propicio para montar todos los elementos. Los
 * Elementos que pose nuestro panel son:
 * </p>
 * <ol>
 * <li><b>Barra de botones (barraBotones) :</b> Incluye todos los botones que
 * deseamos tenerlos como acceso rpido. Est situada al norte del panel
 * (aadido al panel directamente).</li>
 * <li><b>Panel Parte Consola (splitPaneConsola): </b>Este elemento es un
 * splitPane que a su vez de subdivide en dos lados con ms elementos. La
 * definicin por ubicacin es:
 * <ul>
 * <li><i>Lado derecho (splitPaneConsola.Right): </i>Contiene otro splitPane
 * (splitPanelArbol). Dicho splitPane contiene en su lado derecho el rbol de
 * ficheros (arbolDirectorio) y en el lado izquierdo contiene un panel
 * (panelAuxiliar) con un bordeLayout. En el panelAuxiliar aadimos al centro
 * los JTabbedPane (contenedorTab) y al sur aadimos nuestra barra de estado del
 * editor (barraEstado).</li>
 * <li>Lado Izquierdo (splitPaneConsola.Izquierdo): Contiene un JTabbedPane
 * (tabbInformacion), el cual lleva toda la informacin de la consola a la hora
 * de compilar elementos.</li>
 * </ul>
 * </li>
 * </o>
 * <p>
 * En cada tab (contenedorTab) contiene un Objeto JavaTextPane que es el
 * encargado de pintar las palabras de nuestro editor y llevar el numero de
 * lnea (el mtodo encargado es pestanaNueva(x,y)).
 * </p>
 * 
 * Esta clase contiene mtodos para aadir texto a lo JTextPane, colores,
 * elementos pendientes, verificaciones de lo tabs al cerrarse...etc...
 * 
 * @see javax.swing.JSplitPane
 * @see proyecto.arbol.Nodo
 * @see proyecto.consola.CompilacionDatos
 * @see proyecto.arbol.ArbolFicheros
 * @see proyecto.editor.Editor
 * @author Parras
 */
public class PanelEdicion extends JPanel {

	/** Constant objLogger. */
	private static final Logger objLogger = Logger
			.getLogger(PanelEdicion.class);
	public static final String NOMBRE_PARSE_JAVACC = "PARSER_BEGIN[^\\(]*\\([^\\)]*\\)";
	public static final String CARPETA_GENERADOS = "generados";
	public static final int SPLIT_ARBOL_TAMANO = 240;
	public static final int SPLIT_CONSOLA_TAMANO = 640;

	/** barra botones. */
	private JToolBar barraBotones;// ,barraInformacion; //Barra de Botonones
	// de acceso rapido

	/** mi layout. */
	private BorderLayout miLayout;

	/** split pane consola. */
	private JSplitPane splitPanelArbol, splitPaneConsola;

	// private JTabbedPaneWithCloseIcons contenedorTab;
	/** contenedor tab. */
	private JTabbedPane contenedorTab;

	/** boton compilar simple. */
	private JButton botonGuardar, botonGuardarTodo, botonNuevo, botonAbrir,
			botonImprimir, botonBuscar, botonCompilar, botonCompilarSimple;

	/** arbol directorio. */
	private ArbolFicheros arbolDirectorio;// = new ArbolFicheros (new File
	// ("e:\\Util\\workspace\\prueba"),this);

	// private ArbolFicheros arbolDirectorio = new ArbolFicheros (new File
	// (""),this);
	// private JLabel label;
	/** e texto. */
	private Vector<JavaTextPane> eTexto = new Vector<JavaTextPane>();

	/** scroll barra. */
	private Vector<JScrollPane> scrollBarra = new Vector<JScrollPane>();

	/** icont ventanas. */
	private int icontVentanas = 0;

	/** sin nombre tab. */
	private String sinNombreTab = "Sin Nombre";

	/** panel auxiliar. */
	private JPanel panelAuxiliar;

	/** led verde. */
	private Icon ledVerde = IconFactory.getImage("led-verde.png");

	/** barra estado. */
	private BarraEstado barraEstado;

	/** ficheros abiertos en el tab. */
	private ArrayList<Nodo> iAFicherosAbiertos; // aqui controlamos todas las
	// rutas de nuestro ficheros que tenemos abiertas

	/** style context. */
	private static StyleContext styleContext = new StyleContext();
	// Para los colores
	/** imapa. */
	private Map<ItemDeLista, AtributosPreferenicas> imapa;

	/**  proyecto activo. */
	private String iSProyectoActivo;

	/** ruta proyecto activo. */
	private File rutaProyectoActivo;

	// guardo mi salida estandar
	/**  salida standar out. */
	private PrintStream iSalidaStandarOut;

	/**  salida standar Error. */
	private PrintStream iSalidaStandarErr;

	// private JTextArea miConsola=new JTextArea();
	/** tabb informacion. */
	private TabbInformacion tabbInformacion = new TabbInformacion();

	/** panel consola informacion. */
	private JPanel panelConsolaInformacion = new JPanel();

	/** text pane auxiliar. */
	private ConsolaTextPane textPaneAuxiliar = new ConsolaTextPane();

	// Recogiada de Acciones en el Documento de Texto
	// private HashMap<Object, Action> accion;

	// Para Listener
	/** controlador. */
	private ActionListener controlador;

	/**@see proyecto.editor.Editor  */
	private Editor guiPrinc;

	/** Constant serialVersionUID. */
	private static final long serialVersionUID = 9192161222612632271L;

	// Metodo Para activar el panel

	/**
	 * Constructor panel edicion.
	 * 
	 * Creado : Parras, 12-oct-2009
	 * 
	 * @param princ
	 *            princ
	 */
	public PanelEdicion(Editor princ) {
		super();
		guiPrinc = princ;
		inicializaPanel();
	}

	/**
	 * Obtener la ventana de Editor.
	 * 
	 * @return el principal Creado : Parras, 12-oct-2009
	 */
	public InterfazVentEditor getPrincipal() {
		return guiPrinc;
	}

	/**
	 * Inicializa arbol. Creado : Parras, 12-oct-2009
	 * 
	 * @param aRuta
	 *            ruta a la que pertenece nuestro proyecto
	 */
	public void inicializaArbol(File aRuta) {
		arbolDirectorio = new ArbolFicheros(aRuta, this);
		if (aRuta != null) {
			iSProyectoActivo = aRuta.getName();
			rutaProyectoActivo = aRuta;

		}
	}

	/**
	 * getArbolFichero.
	 * 
	 * @return devuelve nuestro tree Arbol de Fichero
	 */
	public JTree getArbolFichero() {
		return arbolDirectorio.getTree();
	}

	/**
	 * Deja a nuestro arbol vacio si nada en la memoria.
	 */
	public void anularArbol() {
		cerrarProyecto();
		inicializaArbol(null);
		splitPanelArbol.updateUI();
		splitPanelArbol.setLeftComponent(arbolDirectorio);

	}

	// 
	/**
	 * Nuevo projecto.
	 * 
	 * <p>
	 * Nos genera un nuevo projecto, y verifica que no existe ninguno abierto
	 * </p>
	 * 
	 * @param aRuta
	 *            ruta del proyecto a tratar
	 * 
	 *            Creado : Parras, 12-oct-2009
	 */
	public void nuevoProyecto(File aRuta) {
		// Hay poyecto abierto
		if (guiPrinc.getProyectos() != null
				&& guiPrinc.getProyectos().size() != 0) {
			arbolDirectorio = new ArbolFicheros(aRuta, this);
			splitPanelArbol.setLeftComponent(arbolDirectorio);
			splitPanelArbol.setLeftComponent(arbolDirectorio);
			iSProyectoActivo = aRuta.getName();
			rutaProyectoActivo = aRuta;
		} else
			// Tenemos un projecto debemos cerrarlo
			cargarProyectoArbol(aRuta);
	}

	/**
	 * Abre un proyecto y lo carga en el arbol.
	 * 
	 * @param aRuta
	 *            a ruta
	 */
	public void cargarProyectoArbol(File aRuta) {

		if (aRuta != null) {
			if (iSProyectoActivo != null) {
				int valor = JOptionPane.showConfirmDialog(this,
						"Desea cerrar el proyecto " + iSProyectoActivo + "?",
						"Texto", JOptionPane.YES_OPTION);

				switch (valor) {
				case JOptionPane.YES_OPTION:
					// al cargar un proyecto no debe de existir ninguna
					// compilacin
					// anteriorg
					if (tabbInformacion != null)
						tabbInformacion.removeAll();

					if (hayDatosAGuardar()) {
						GuardadoFinalPanel guardarFinal = new GuardadoFinalPanel(
								guiPrinc, false,
								GuardadoFinalPanel.GUARDAR_MODO_PROYECTO);
						guardarFinal.setVisible(true);
					}
					// Cierra nuestro proyecto y deja nuestra variables vacias.
					cerrarProyecto();

					arbolDirectorio = new ArbolFicheros(aRuta, this);
					splitPanelArbol.setLeftComponent(arbolDirectorio);
					iSProyectoActivo = aRuta.getName();
					rutaProyectoActivo = aRuta;
					// apuntamos nuestro proyecto para tenerlo como reciente
					guiPrinc.addProyecto(aRuta);

					// case JOptionPane.NO_OPTION:

				}
			}else{//precargamos un proyecto no existente de nuestro WorkSpace 
				arbolDirectorio = new ArbolFicheros(aRuta, this);
				splitPanelArbol.setLeftComponent(arbolDirectorio);
				iSProyectoActivo = aRuta.getName();
				rutaProyectoActivo = aRuta;
				// apuntamos nuestro proyecto para tenerlo como reciente
				guiPrinc.addProyecto(aRuta);
			}
		}

	}

	// Inicializacion de JPanel
	/**
	 * Inicializa panel. Creado : Parras, 12-oct-2009
	 */
	private void inicializaPanel() {
		this.setOpaque(false);
		miLayout = new BorderLayout();
		this.setLayout(miLayout);
		this.add(barraDeBotones(), BorderLayout.PAGE_START);
		inicializaArbol(guiPrinc.getPrimerProyecto());
		// Inicializacion del Scroll
		// this.add(PanelDivisor(),BorderLayout.CENTER);
		this.add(panelDivisorConsola(), BorderLayout.CENTER);
		// Inicializacion del Splitpane

		// this.add(barraDeInformacion (),miLayout.PAGE_END);
		// this.add(new BarraEstado (),miLayout.PAGE_END);

		// Colores, aqui inicializamos el syler con nuestros colores
		initStyles();
		lookAndFeellTabs();

	}

	// Para creas pestaas

	/**
	 * Look and feell tabs. Creacin aadimos las propiedas que necesitamos para
	 * los tabs (Botn de cerrar)
	 * 
	 * Creado : Parras, 12-oct-2009
	 */
	private void lookAndFeellTabs() {
		contenedorTab = new JTabbedPane();
		contenedorTab.addMouseListener(new MenuPopupTab(this));
		iAFicherosAbiertos = new ArrayList<Nodo>();

		panelAuxiliar.add(contenedorTab);
		panelAuxiliar.add(getbarraEstado(), BorderLayout.PAGE_END);// Inicilizo
		getbarraEstado().setVisible(false);
		// la
		// Barra
		// de
		// Estado

		contenedorTab.putClientProperty(
				SubstanceLookAndFeel.TABBED_PANE_CLOSE_BUTTONS_PROPERTY,
				Boolean.TRUE);
		// contenedorTab.putClientProperty(SubstanceLookAndFeel.TABBED_PANE_CLOSE_BUTTONS_MODIFIED_ANIMATION,
		// Boolean.TRUE);
		// contenedorTab.putClientProperty(SubstanceLookAndFeel.TABBED_PANE_CLOSE_BUTTONS_SIZE,Boolean.TRUE);
		contenedorTab.putClientProperty(
				SubstanceLookAndFeel.TABBED_PANE_CLOSE_CALLBACK, contenedorTab);

		SubstanceLookAndFeel.registerTabCloseChangeListener(contenedorTab,
				new VetoableTabCloseListener() {

					public boolean vetoTabClosing(JTabbedPane arg0,
							Component arg1) {
						// Si es False, cierra la ventana en otro caso la
						// deja abierta

						// System.out.println("VetoTabClosing"+contenedorTab.getSelectedIndex());

						boolean lbOk = false;
						try {
							lbOk = guardarTab();

						} catch (EpSilonExcepciones e) {
							Mensajes.mensajeDetalles("Error", e);
						} catch (IOException e) {
							Mensajes.mensajeDetalles(
									"Error, al cerrar el documento", e);
						}
						return !lbOk;
					}

					public void tabClosed(JTabbedPane arg0, Component arg1) {
						// System.out.println("tabClosed"+contenedorTab.getSelectedIndex());
						// System.out.println(contVentanas);
						// Pone no visible al barra del cursor xq no tenemos
						// pestaas
						// Aqui se necesita limpiar Ventana.
						if (icontVentanas == 0)
							getbarraEstado().setVisible(false);

					}

					public void tabClosing(JTabbedPane arg0, Component arg1) {
						// System.out.println("tabClosing"+contenedorTab.getSelectedIndex());

					}
				});
		if (objLogger.isDebugEnabled())
			objLogger.debug("Generado Nuestro Tab con layout de Substance");
	}

	/**
	 * Pestana nueva.
	 * 
	 * <p>
	 * Para la creacin de una nueva pestaa con reconocedor de texto los pasos
	 * a seguir son:
	 * </p>
	 * <ol>
	 * <li>Crear un JavaTextPane con el estilo que va a reconocer (en nuestro
	 * caso JavaCC) . Lo incluimos es su vector (eTexto) para tenerlo
	 * referenciado en cualquier momento.</li>
	 * <li>Crear un JSrollPane para la variable JavaTextPane. Le aadamos al
	 * scroll un contador de lneas, el cual aparecer a su izquierdo.
	 * Seguidamente lo aadimos a su vector (scrollBarra)</li>
	 * <li>Le aadimos un tootipText al tab con la ruta del fichero</li>
	 * <li>Le insertamos el foco a nuestro tab. Para que pueda escribir
	 * directamente en l</li>
	 * <li>Aadimos nuestro fichero y los guardamos en la variable que controla
	 * los ficheros abiertos (iAFicherosAbiertos).</li>
	 * <li>Incrementamos el numero de tab</li>
	 * </ol>
	 * 
	 * 
	 * @param nombreTabb
	 *            nombre tabb
	 * @param textoFile
	 *            texto file
	 * 
	 *            Creado : Parras, 12-oct-2009
	 */
	public void pestanaNueva(Nodo nombreTabb, String textoFile) {
		if (nombreTabb == null) {
			nombreTabb = new Nodo(new File("."), null);
			nombreTabb.setNombreDirectorio(sinNombreTab + icontVentanas);
		}

		if (contenedorTab == null) {
			lookAndFeellTabs();

			eTexto.add(icontVentanas, new JavaTextPane(this, styleContext,
					textoFile));
			JScrollPane jsp = new JScrollPane(eTexto.get(icontVentanas),
					ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED,
					ScrollPaneConstants.HORIZONTAL_SCROLLBAR_AS_NEEDED);
			scrollBarra.add(icontVentanas, jsp);
			// scrollBarra.get(contVentanas).setRowHeaderView(
			// new NumeroLineas(eTexto.get(contVentanas)));

			scrollBarra.get(icontVentanas).setRowHeaderView(
					new NumeroLinea(eTexto.get(icontVentanas)));
			contenedorTab.addTab(nombreTabb.toString(), ledVerde, scrollBarra
					.get(icontVentanas));
			// le ponemos de tootip a cada tab su directorio asociado
			contenedorTab.setToolTipTextAt(icontVentanas, nombreTabb
					.getDirectorio().toString());

		} else {
			// nuestro contador de ventanas nunca puede estar por debajo de
			// cero, por si hemos
			// realizado algn decremento con el tab0.
			if (icontVentanas < 0)
				icontVentanas = 0;

			eTexto.add(icontVentanas, new JavaTextPane(this, styleContext,
					textoFile));
			// scrollBarra.add(contVentanas,new JScrollPane (getETexto()));

			// eTexto.add(contVentanas,new TextoPanel (this)) ;
			scrollBarra.add(icontVentanas, new JScrollPane(eTexto
					.get(icontVentanas)));
			// scrollBarra.get(contVentanas).setRowHeaderView(
			// new NumeroLineas(eTexto.get(contVentanas)));

			scrollBarra.get(icontVentanas).setRowHeaderView(
					new NumeroLinea(eTexto.get(icontVentanas)));
			contenedorTab.addTab(nombreTabb.toString(), ledVerde, scrollBarra
					.get(icontVentanas));
			// le ponemos de tootip a cada tab su directorio asociado
			contenedorTab.setToolTipTextAt(icontVentanas, nombreTabb
					.getDirectorio().toString());

			// Pone visible al barra del cursor xq tenemos pestaas

			if (icontVentanas == 0)
				getbarraEstado().setVisible(true);

		}

		// Guardamos nuestro fichero para asi poder tener su ruta
		contenedorTab.setFocusable(true);
		contenedorTab.setSelectedIndex(icontVentanas);
		iAFicherosAbiertos.add(nombreTabb);
		this.setIncrementarNumTabs(); // Ventana ++
		if (objLogger.isDebugEnabled())
			objLogger.debug("Ficheros Abiertos en el Tab: "
					+ iAFicherosAbiertos);

	}

	/**
	 * setValoresTexto establece en nuesro tab los valores por defecto.
	 */
	public void setValoresTexto() {
		guiPrinc.updateCaption(getTextoTabActivo());
		getETexto().setCaretPosition(0);
		getETexto().requestFocus(true);
		getETexto().setCambios(true);
		// eTexto.get(icontVentanas).setUndoManager();
		cambiarTabbImag(ledVerde);
		// System.out.print("CAMBIO DE TODAS LAS PROPIEDAS");
	}

	/**
	 * Guardar tab.
	 * 
	 * @return true, si es correcto Creado : Parras, 12-oct-2009
	 * 
	 * @throws EpSilonExcepciones
	 *             excepciones
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public boolean guardarTab() throws EpSilonExcepciones, IOException {

		if (ventanaActiva() >= 0 && (eTexto.get(ventanaActiva())).getCambios()) {
			if (iAFicherosAbiertos.size() >= icontVentanas) {
				iAFicherosAbiertos.remove(ventanaActiva());
				eTexto.remove(ventanaActiva());
				scrollBarra.remove(ventanaActiva());
				icontVentanas--;
			}
			return true;
		}
		int valor = JOptionPane.showConfirmDialog(this, "Guardar Los Cambios "
				+ iAFicherosAbiertos.get(ventanaActiva()) + "?", "Texto",
				JOptionPane.YES_NO_CANCEL_OPTION);

		switch (valor) {
		case JOptionPane.YES_OPTION:
			// SI,Aceptar los Cambios
			boolean lbOk = false;
			// Observamos si tien lo mismo elementos o mas
			if (iAFicherosAbiertos.size() >= icontVentanas)
				lbOk = guiPrinc.guardarComo(iAFicherosAbiertos.get(
						ventanaActiva()).getDirectorio());

			if (lbOk) {
				iAFicherosAbiertos.remove(ventanaActiva());
				eTexto.remove(ventanaActiva());
				scrollBarra.remove(ventanaActiva());
				icontVentanas--;

			}

			return lbOk;
		case JOptionPane.NO_OPTION:
			// No, Abandonar cambios
			if (ventanaActiva() > -1) {
				eTexto.remove(ventanaActiva());
				scrollBarra.remove(ventanaActiva());
				iAFicherosAbiertos.remove(ventanaActiva());
				icontVentanas--;
			}

			return true;
		case JOptionPane.CANCEL_OPTION:
		default:
			// cancelar
			return false;
		}
	}

	/**
	 * Ventana cerrar.
	 * 
	 * @return true, si es correcto Creado : Parras, 12-oct-2009
	 * 
	 * @throws EpSilonExcepciones
	 *             excepciones
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public boolean ventanaCerrar() throws EpSilonExcepciones, IOException {
		int valor = JOptionPane.showConfirmDialog(this, "Guardar Los Cambios "
				+ iAFicherosAbiertos.get(ventanaActiva()) + "?", "Texto",
				JOptionPane.YES_NO_CANCEL_OPTION);

		switch (valor) {
		case JOptionPane.YES_OPTION:
			// SI,Aceptar los Cambios
			boolean lbOk = false;
			// Observamos si tien lo mismo elementos o mas

			if (iAFicherosAbiertos.size() >= icontVentanas)
				lbOk = guiPrinc.guardarComo(iAFicherosAbiertos.get(
						ventanaActiva()).getDirectorio());

			if (lbOk) {
				iAFicherosAbiertos.remove(ventanaActiva());
				eTexto.remove(ventanaActiva());
				scrollBarra.remove(ventanaActiva());
				contenedorTab.removeTabAt(ventanaActiva());
				icontVentanas--;
			}

			return lbOk;
		case JOptionPane.NO_OPTION:
			// No, Abandonar cambios
			if (ventanaActiva() > -1) {
				eTexto.remove(ventanaActiva());
				scrollBarra.remove(ventanaActiva());
				iAFicherosAbiertos.remove(ventanaActiva());
				icontVentanas--;
				contenedorTab.removeTabAt(ventanaActiva());
			}
			return true;
		case JOptionPane.CANCEL_OPTION:
		default:
			// cancelar
			return false;
		}
	}

	/**
	 * El booleano es para tratar la ventana con una tab individual, O cerrala
	 * todas. Verifica si existen cambios en el tab a cerrar.
	 * 
	 * @param soloUna
	 *            solo una
	 * 
	 * @throws EpSilonExcepciones
	 *             excepciones
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 */
	public void cerrarVentanas(boolean soloUna) throws EpSilonExcepciones, IOException {
		if (soloUna) {
			if (ventanaActiva() >= 0
					&& (eTexto.get(contenedorTab.getSelectedIndex()))
							.getCambios()) {
				if (iAFicherosAbiertos.size() >= icontVentanas) {
					iAFicherosAbiertos.remove(ventanaActiva());
					eTexto.remove(ventanaActiva());
					scrollBarra.remove(ventanaActiva());
					contenedorTab.removeTabAt(ventanaActiva());
					icontVentanas--;
					if (icontVentanas == 0)
						getbarraEstado().setVisible(false);

				}

			} else if (ventanaActiva() >= 0
					&& !(eTexto.get(contenedorTab.getSelectedIndex()))
							.getCambios()) {
				ventanaCerrar();

				if (icontVentanas == 0)
					getbarraEstado().setVisible(false);

			}
		} else {
			if (ventanaActiva() >= 0) {
				int cont = icontVentanas;
				contenedorTab.setSelectedIndex(0);
				for (int i = 0; i < cont; i++) {
					if (ventanaActiva() >= 0
							&& (eTexto.get(ventanaActiva()).getCambios())) {
						if (iAFicherosAbiertos.size() >= icontVentanas) {
							iAFicherosAbiertos.remove(ventanaActiva());
							// System.out.print("\ncerrarVentanas Sin
							// Modi"+iAFicherosAbiertos.toString());
							eTexto.remove(ventanaActiva());
							scrollBarra.remove(ventanaActiva());
							contenedorTab.removeTabAt(ventanaActiva());
							icontVentanas--;
							if (icontVentanas == 0)
								getbarraEstado().setVisible(false);

						}

					} else if (ventanaActiva() >= 0
							&& !(eTexto.get(ventanaActiva())).getCambios()) {
						ventanaCerrar();
						// System.out.print("\ncerrarVentanas Con
						// Modi"+iAFicherosAbiertos.toString());
						// System.out.print("\nven"+contVentanas);
					}

				}
				if (icontVentanas == 0)
					getbarraEstado().setVisible(false);
			}
		}
	}

	/**
	 * Cerrar ventana sin confirmacion.
	 * 
	 * @param posicionVentana
	 *            posicion ventana
	 * 
	 * @return true si se ha borrado el tab en perfecta condiciones
	 */
	public boolean cerrarVentanaSinConfirmacion(int posicionVentana) {

		boolean retorno = false;

		if (this.getVentana() >= posicionVentana) {

			eTexto.remove(posicionVentana);
			scrollBarra.remove(posicionVentana);
			contenedorTab.removeTabAt(posicionVentana);
			icontVentanas--;
			if (icontVentanas == 0)
				getbarraEstado().setVisible(false);

			retorno = true;

		}

		return retorno;

	}

	// Cierra nuestro proyecto y deja nuestra variables vacias.
	/**
	 * Cerrar proyecto. Creado : Parras, 12-oct-2009
	 */
	public void cerrarProyecto() {
		int cont = icontVentanas;
		if (ventanaActiva() != -1) {
			contenedorTab.setSelectedIndex(0);
			for (int i = 0; i < cont; i++) {
				if (ventanaActiva() >= 0) {
					if (iAFicherosAbiertos.size() >= icontVentanas) {
						iAFicherosAbiertos.remove(ventanaActiva());
						// System.out.print("\ncerrarVentanas Sin
						// Modi"+iAFicherosAbiertos.toString());
						eTexto.remove(ventanaActiva());
						scrollBarra.remove(ventanaActiva());
						contenedorTab.removeTabAt(ventanaActiva());
						icontVentanas--;
						if (icontVentanas == 0)
							getbarraEstado().setVisible(false);

					}

				}
			}
		}

		System.out.print("Textos size " + eTexto.size() + " ScrollBarras "
				+ scrollBarra.size());
	}

	/**
	 * Cambiar tabb imag. Creado : Parras, 12-oct-2009
	 * 
	 * @param aicono
	 *            aicono
	 */
	public void cambiarTabbImag(Icon aicono) {
		// Primera componete es para indicar la pestaa a la que nos referimos
		if (aicono != null)
			contenedorTab.setIconAt(ventanaActiva(), aicono);
		else
			contenedorTab.setIconAt(ventanaActiva(), ledVerde);
	}

	/**
	 * Cambiar tabb imag. Creado : Parras, 12-oct-2009
	 * 
	 * @param aicono
	 *            aicono
	 * @param numeroTab
	 *            numero tab
	 */
	public void cambiarTabbImag(Icon aicono, int numeroTab) {
		// Primera componete es para indicar la pestaa a la que nos referimos
		if (aicono != null)
			contenedorTab.setIconAt(numeroTab, aicono);
		else
			contenedorTab.setIconAt(numeroTab, ledVerde);
	}

	/**
	 * getFicheroTabRun Devuelve la ventanaActiva su ruta de directorio.
	 * 
	 * @return File
	 */
	public File getFicheroTabRun() {
		if (objLogger.isDebugEnabled())
			objLogger.debug("Fichero Seleccionado: "
					+ iAFicherosAbiertos.get(ventanaActiva()).getDirectorio());

		return iAFicherosAbiertos.get(ventanaActiva()).getDirectorio();
	}

	/**
	 * getNodoArbolTabRub Devuelve el nodo del arbol de tab que esta siendo
	 * activo en nuestra aplicacin.
	 * 
	 * @return nodo arbol tab rub
	 */
	public Nodo getNodoArbolTabRub() {
		return iAFicherosAbiertos.get(ventanaActiva());
	}

	/*
	 * public JTextPane getETexto(){ Font fuenteTexto= new Font ("fuente",
	 * Font.ROMAN_BASELINE, 12); eTexto.add(contVentanas,new JTextPane ()) ;
	 * tablaAcciones (eTexto.get(contVentanas) );
	 * eTexto.get(contVentanas).setCaretPosition(0);
	 * eTexto.get(contVentanas).setMargin(new Insets(5,5,5,5));
	 * eTexto.get(contVentanas).setFont(fuenteTexto);
	 * eTexto.get(contVentanas).setForeground(Color.black);
	 * //documentos.add(contVentanas, eTexto.get(contVentanas).getDocument());
	 * //documentos.get(contVentanas).addDocumentListener(new
	 * ControlDocumento(guiPrinc));
	 * //eTexto.get(contVentanas).getDocument().addDocumentListener(new
	 * ControlDocumento(guiPrinc));
	 * 
	 * 
	 * return eTexto.get(contVentanas); }
	 */

	// Funciones para guardar texto y leer texto
	/**
	 * Obtener el texto del tab activo.
	 * 
	 * @return el JtextPane Asocioado al tab activo Creado : Parras, 12-oct-2009
	 */
	public JavaTextPane getETexto() {

		return eTexto.get(ventanaActiva());

	}

	/**
	 * Devolver texto del tab activo.
	 * 
	 * @return string 
	 * Creado : Parras, 12-oct-2009
	 */
	public String devolverTexto() {

		return eTexto.get(ventanaActiva()).getText();
	}
	
	/**
	 * Nombre fichero parse.
	 * 
	 * @return the string Creado : Parras, 10-ene-2010
	 */
	public String nombreFicheroParse(){
		String lsValor ="";
		// Nos devuelve esta cadena ==>PARSER_BEGIN(JavaParser)
		//Nos interesa ==>JavaParser
		lsValor = BuscarYRemplazar.buscarCadena(getETexto(),PanelEdicion.NOMBRE_PARSE_JAVACC);
		//si no lo encontramos devolvemos el nombre del fichero
		if (lsValor == null || lsValor.equals("")) //devolvemos el nombre fichero java
			lsValor = getNodoArbolTabRub().getNombreFicheroSinExtension();
		else
			lsValor = lsValor.substring(lsValor.indexOf("(")+1,lsValor.length()-1);
		
		return lsValor;
	}

	/**
	 * Devolver texto impresion.
	 * 
	 * @return string 
	 * Creado : Parras, 12-oct-2009
	 */
	public String devolverTextoImpresion() {

		return eTexto.get(ventanaActiva()).getTextoFormateadoImprir()
				.toString();
	}

	
	/**
	 * compilarFichero
	 * 
	 * Compilar el fichero del tab activo en ese momento (JavaCC ".jj" y Java ".java").
	 * 
	 * @parama Ejecutar si deseamos compilar y ejuctar en el caso de todo Ok.
	 * 
	 *  Creado : Parras, 10-ene-2010
	 */
	public void compilarFichero(boolean aEjecutar){
		if (ventanaActiva() >= 0) {
			//verificamos nuestra propiedad
			if (Editor.get().getPreferenciasUsuario().isGuardarAlCompilar())
				guardarTabActivo ();
			
			try {
				DefaultTreeModel lModeloArbol = (DefaultTreeModel) getArbolFichero().getModel();
				
				// Iniciamos

				// para el directorio de salida
				// javacc -OUTPUT_DIRECTORY:E:\Util\javacc-4.0\bin\prueba
				// CalcInput.jj
				// String
				// dirDestino=getRutaProyectoActivo().toString()+File.separator+"generados"+File.separator+OperacionesFicheros.getNombreSinExtension(getFicheroTabRun());

				// System.out.print("Directorio destiono"+dirDestino);
				// getMiConsola().setText("");
				// Establecemos a nuestra salida standar de nuetro texto
				// ConsolePane.getInstance().setModificarSalidaConsola();
				// ConsolePane.getInstance().setModificarSalidaConsola();
				// ConsolePane.getInstance().limpiarTextPane();
				long t0 = System.currentTimeMillis();
				setModificarSalidaConsola();
				//compilacin fichero JavaCC
				if (getNodoArbolTabRub() != null
						&& getNodoArbolTabRub()
								.getExtension().equalsIgnoreCase(ArbolFicheros.EXTENSION_JAVACC)) {

					String dirDestino = getFicheroTabRun()
							.getParent()
							+ File.separator
							+ PanelEdicion.CARPETA_GENERADOS
							+ OperacionesFicheros.getNombreSinExtension(getFicheroTabRun());
					
					if (new File (dirDestino).exists()){ // borramos los y .java .class
						OperacionesFicheros.deleteFilesPorJavaCC(dirDestino, nombreFicheroParse());
						OperacionesFicheros.deleteFiles(dirDestino, "class");
						//Borramos el nodo por si esta insertado y as lo tenemos actualizado
						DefaultMutableTreeNode nodoABorrar = ArbolFicheros.nodoArbolEncontrado(getNodoArbolTabRub().getNodoPadre(),
								new Nodo(new File(dirDestino), true, null));
						if (nodoABorrar != null)
							lModeloArbol.removeNodeFromParent(nodoABorrar);
						
						DefaultMutableTreeNode compilacionHijo= UtilidadesEpsilon.addNodos(null,new File(dirDestino));
						DefaultMutableTreeNode padreNodo =getNodoArbolTabRub().getNodoPadre();					
						lModeloArbol.insertNodeInto(compilacionHijo, padreNodo,padreNodo.getChildCount());
						arbolDirectorio.ordenarHijos(padreNodo);	
					}
				

					proyecto.utilidades.ThreadCompilacionJavaCC hebra = null;
					if (Editor.get().getPreferenciasCompilacion() == null)
						// org.javacc.parser.Main.main(new
						// String[]{"-OUTPUT_DIRECTORY:"+dirDestino,getFicheroTabRun().toString()});
						hebra = new proyecto.utilidades.ThreadCompilacionJavaCC(new String[] {
								"-OUTPUT_DIRECTORY:" + dirDestino,
								getFicheroTabRun()
										.toString() });
					else {
						ArrayList<String> propiedadCompilacion = Editor.get()
								.getPreferenciasCompilacion()
								.getPropiedadesCompilacion();
						propiedadCompilacion.add("-OUTPUT_DIRECTORY:"
								+ dirDestino);
						propiedadCompilacion.add(getFicheroTabRun().toString());
						// Mensajes.mensajeAtencion(propiedadCompilacion.toString());
						String[] argumentos = (propiedadCompilacion == null) ? null
								: (String[]) propiedadCompilacion
										.toArray(new String[propiedadCompilacion
												.size()]);
						System.err.print("\n Compilacin JavaCC: \n");
						hebra = new proyecto.utilidades.ThreadCompilacionJavaCC(argumentos);

						// org.javacc.parser.Main.main(argumentos);

						// Si el argumento es bueno debemos aadir nuestra
						// carpeta generada con sus correpondientes ficheros

					}
					// Espera el fin de nuestra hebra
					hebra.start();
					hebra.join();
					
					if (new File(dirDestino).exists()){
								
					//Borramos el nodo por si esta insertado y as lo tenemos actualizado
					DefaultMutableTreeNode nodoABorrar = ArbolFicheros.nodoArbolEncontrado(getNodoArbolTabRub().getNodoPadre(),
							new Nodo(new File(dirDestino), true, null));
					if (nodoABorrar != null)
						lModeloArbol.removeNodeFromParent(nodoABorrar);

					DefaultMutableTreeNode compilacionHijo= UtilidadesEpsilon.addNodos(null,new File(dirDestino));
					DefaultMutableTreeNode padreNodo =getNodoArbolTabRub().getNodoPadre();
					
					
					
					lModeloArbol.insertNodeInto(compilacionHijo, padreNodo,padreNodo.getChildCount());
					arbolDirectorio.ordenarHijos(padreNodo);		
					
					getArbolFichero().validate();
					getArbolFichero().updateUI();
					}
					

					if (aEjecutar && new File(dirDestino).exists()) {
						System.err.print("\n Compilacin Java: " +  nombreFicheroParse());
						UtilidadesEpsilon.compilarJava(new File(dirDestino),nombreFicheroParse() );
								//getNodoArbolTabRub().getNombreFicheroSinExtension());
						// getNodoArbolTabRub().getNodoPadre().remove(
						// ArbolFicheros.posicionArbol(getNodoArbolTabRub().getNodoPadre(),
						// new Nodo(new File(dirDestino),true,null)));

						// Buscamos el nodo por si existe y si existe lo
						// borramos para que nos de el nuevo resutlado de la
						// compilacin
						
					}
				} else if (getNodoArbolTabRub() != null
						&&getNodoArbolTabRub()
								.getExtension().equalsIgnoreCase("java")) {
					UtilidadesEpsilon.compilarJava(getNodoArbolTabRub().getDirectorio(), aEjecutar);
				}

				// fin del tiempo
				long t1 = System.currentTimeMillis();
				long total = (t1 - t0) / 1000;
				System.err.println(" \n Tiempo total de Compilacin: "
						+ total + " s.");
				setEstablecerSalidaEstandar();

				// Vector vectorError=
				// org.javacc.parser.JavaCCErrors.getVectorErrores();

				// Iterator iter =vectorError.iterator();
				// while (iter.hasNext()) {
				// MiError element = (MiError) iter.next();
				// System.out.print(" "+element.toString()+"\n");
				// }

			} catch (Exception e) {
				Mensajes.mensajeDetalles("Problemas en la compilacin", e);
				// e.printStackTrace();
			}
		}

	}
	
	/**
	 * Devolver texto.
	 * Si 
	 * @param aNombreFichero
	 *            a nombre fichero
	 * 
	 * @return String Creado : Parras, 12-oct-2009
	 */
	public String devolverTexto(String aNombreFichero) {
		// Comparacion por toolTip de los tab para
		// Verificar que el fichero que guardamos es el mismo que el del tab
		boolean lbOk = false;
		String lsTexto = null;
		int i = 0;
		int cont = icontVentanas;
		while (i < cont && !lbOk) {
			if (contenedorTab.getToolTipTextAt(i).compareTo(aNombreFichero) == 0) {
				lbOk = true;
			} else
				i++;
		}
		if (objLogger.isDebugEnabled())
			objLogger.debug(" Textos Cargados:"	+ " i: " +i+ " Tamao: "+ eTexto.size());
		
		if (i <= eTexto.size())
			lsTexto = eTexto.get(i).getText(); 
		else
			throw new EpSilonExcepciones("Error, al encontrar el tab con el contenido");
			

		return lsTexto;
	}

	/**
	 * actualizarTabsConSusRutas
	 * 
	 * Actualiza la referencia pasada como new en nuestro tab pane. Por si se ha
	 * cambiado alguna etiqueta de nombre, este problema viene referenciado por
	 * la carpetas.
	 * 
	 * @param nodoOld
	 *            Vieja referencia en ubicacin
	 * @param nodoNew
	 *            Nueva referencia en la ubicacin
	 * 
	 * @return devuelve el nmero total de tab actualizados
	 */
	public int actualizarFilesTabsConSusRutasDirectirio(Nodo nodoOld,
			Nodo nodoNew) {

		int liActualizaciones = 0;
		int i = 0;
		int cont = icontVentanas;
		while (i < cont) {

			File fileTab = new File(contenedorTab.getToolTipTextAt(i));
			// Recorrido completo, hacer la busqueda por ruta de path
			//incidencia, es posible que no hallan renombrando mayusculas y minusculas
			//if (!fileTab.exists()) {// no existe la
				int tamFileOld = nodoOld.getDirectorio().toString().length();

				if (fileTab.toString().substring(0, tamFileOld).equals(
						nodoOld.getDirectorio().toString())) {
					String rutaFinal = nodoNew.getDirectorio().toString()
							+ fileTab.toString().substring(tamFileOld);
					System.out.print("\nLa ruta Actualizada es : " + rutaFinal);
					contenedorTab.setToolTipTextAt(i, rutaFinal);
					iAFicherosAbiertos.get(i).setFileyNombre(
							new File(rutaFinal));
					liActualizaciones++;
				}

			//}
			i++;
		}

		return liActualizaciones;
	}

	/**
	 * borrarTabsElimindasArbol
	 * 
	 * Actualiza la referencia pasada como new en nuestro tab pane. Por si se ha
	 * cambiado alguna etiqueta de nombre, este problema viene referenciado por
	 * la carpetas.
	 * 
	 * @param nodoOld
	 *            Vieja referencia en ubicacin
	 * 
	 * @return int
	 */
	public int borrarTabsElimindasArbol(Nodo nodoOld) {

		int liActualizaciones = 0;
		int i = 0;
		int cont = icontVentanas - 1;

		// ArrayList<Integer> tabABorrar = new ArrayList<Integer>();
		while (cont >= i) {
			// existe un problema no podemos recorer a la vez que borramos
			//

			File fileTab = new File(contenedorTab.getToolTipTextAt(cont));
			// Recorrido completo, hacer la busqueda por ruta de path
			if (!fileTab.exists()) {// no existe la
				int tamFileOld = nodoOld.getDirectorio().toString().length();
				System.out.print("\nCadenas iguales "
						+ fileTab.toString().substring(0, tamFileOld) + " == "
						+ nodoOld.getDirectorio());
				if (fileTab.toString().substring(0, tamFileOld).equals(
						nodoOld.getDirectorio().toString())) {
					cerrarVentanaSinConfirmacion(cont);

					liActualizaciones++;
				}

			}
			cont--;
		}

		return liActualizaciones;
	}

	/**
	 * actualizarFileTabConSuRuta
	 * 
	 * Al modificar el nombre de un tab en el arbol, debemos verificar que no
	 * esta abierta para su actualizacion en la de fichero.
	 * 
	 * @param nodoOld
	 *            Vieja referencia en ubicacin
	 * @param nodoNew
	 *            Nueva referencia en la ubicacin
	 * 
	 * @return devuelve si se ha encontrado el tab
	 */
	public boolean actualizarFileTabConSuRutaArchivo(Nodo nodoOld, Nodo nodoNew) {

		int i = 0;
		boolean lbOk = false;
		int cont = icontVentanas;
		while (i < cont && !lbOk) {

			File fileTab = new File(contenedorTab.getToolTipTextAt(i));
			// Recorrido completo, hacer la busqueda por ruta de path
			//incidencia, es posible que no hallan renombrando mayusculas y minusculas
			//if (!fileTab.exists()) {// no existe la
				if (fileTab.toString().equals(
						nodoOld.getDirectorio().toString())) {
					// System.out.print("\nLa ruta Actualizada es : "+nodoNew.getDirectorio());
					System.out
							.print(" Titulo AT: " + contenedorTab.getTitleAt(i));
					contenedorTab.setTitleAt(i, nodoNew.getNombreDirectorio());
					contenedorTab.setToolTipTextAt(i, nodoNew.getDirectorio()
							.toString());
					iAFicherosAbiertos.get(i).setFileyNombre(
							nodoNew.getDirectorio());
					lbOk = true;

				}

			//}
			i++;
		}

		return lbOk;
	}

	/**
	 * Metodo que nos dice si existe el nombre de un tab en el contendor de Tabs
	 * *.
	 * 
	 * @param aContenedorTab
	 *            JTabbedPane, si esta variables es nula cogemos en que tenemos
	 *            de instancia
	 * @param aNombreTab
	 *            Nombre Tab que vendra dado por la ruta completa, es decir
	 *            patch dondre se encuentra nuestro fichero, que es lo que lo
	 *            hace unico.
	 * 
	 * @return En la posicion que existe para eliminarla, si no la encuentra
	 *         devuelve -1
	 */
	public int isFicheroAbierto(JTabbedPane aContenedorTab, String aNombreTab) {
		int valor = -1;
		int i = 0;
		boolean estaTab = false;
		// Si es nulo hacemos la gestiones con el que tenemos de instancia
		if (aContenedorTab == null)
			aContenedorTab = contenedorTab;

		if (aContenedorTab != null && aNombreTab != null
				&& new File(aNombreTab).exists()) {
			while (i < aContenedorTab.getTabCount() && !estaTab) {
				// System.out.print(aContenedorTab.getToolTipTextAt(i)+"=="+
				// aNombreTab+"\n");
				// Utilizamos el toolTip porque aqui tenemos la ruta completa
				// que es lo que hace a nuestro fichero
				// unico
				if (aContenedorTab.getToolTipTextAt(i).equals(aNombreTab)) {
					valor = i;
					estaTab = true;
				}
				i++;
			}
		}
		return valor;
	}

	/**
	 * GuardarTexto Nos abre una ventana con el texto asociado a su fichero en
	 * nuestro tab.
	 * 
	 * @param nombreDocumento
	 *            nombre documento
	 * @param texto
	 *            texto
	 * 
	 * @throws BadLocationException
	 *             bad location exception
	 */

	public void guardarTexto(String texto, Nodo nombreDocumento)
			throws BadLocationException {
		int numTab = isFicheroAbierto(contenedorTab, nombreDocumento
				.getDirectorio().toString());
		if (numTab == -1) {
			// vamos a incializar nuestro texto
			if (texto.equals("")) {
				StringBuffer textoInicio = new StringBuffer();
				Date date = new Date();
				String user = System.getProperty("user.name");
				
				

				textoInicio.append("/**\n * Creado por : " + date
						+ "\n * Autor : " + user + "\n */\n");
				if (nombreDocumento.getExtension().equals(ArbolFicheros.EXTENSION_JAVACC))
					textoInicio.append( "\n\nPARSER_BEGIN("+ nombreDocumento.getNombreFicheroSinExtension()+")\n");
					
				textoInicio.append( "\npublic class "
						+ nombreDocumento.getNombreFicheroSinExtension()
						+ " {\n" + "\n\tpublic "
						+ nombreDocumento.getNombreFicheroSinExtension()
						+ "() {\n\n\n" + "\t}" + "\n}");
				
				if (nombreDocumento.getExtension().equals(ArbolFicheros.EXTENSION_JAVACC))
					textoInicio.append( "\n\nPARSER_END("+ nombreDocumento.getNombreFicheroSinExtension()+")\n");
				
				texto = textoInicio.toString();
			}

			this.pestanaNueva(nombreDocumento, texto);

			// Aseguramos nuestro booleano a falso despuedes de a ver recuperado
			// el
			// fichero
			// eTexto.get(contVentanas).setText(documento);

			getETexto().requestFocusInWindow();

			this.setTextoBarraEstado("Abierto "
					+ nombreDocumento.getDirectorio().toString());

			setValoresTexto();

		} else {
			contenedorTab.setSelectedIndex(numTab);
		}

	}

	/**
	 * Metodo que nos mueve nuestro cursor a los datos de nuestro fichero.
	 * 
	 * @param aCompilacionDatos
	 *            a compilacion datos
	 */
	public void moverCursorAError(CompilacionDatos aCompilacionDatos) {
		if (aCompilacionDatos.esValido()) {
			int numTab = isFicheroAbierto(contenedorTab, aCompilacionDatos
					.toString());
			if (numTab == -1) {// abri fichero
				// Hay que pasarle l nodo
				try {
					this.pestanaNueva(aCompilacionDatos
							.getficheroCompiladoDatos(),
							OperacionesFicheros
									.cargarFichero(aCompilacionDatos
											.getficheroCompiladoDatos()
											.getDirectorio()));
					// no necesitamos contenedorTab.setSelectedIndex(numTab);
					// porque nuestro metodo de pestanaNueva nos lo hace.
					getETexto().requestFocusInWindow();
					OperacionesTextPane.irALinea(getETexto(), aCompilacionDatos
							.getFila());
				} catch (BadLocationException e) {

					Mensajes.mensajeDetalles("Error, el fichero no Existe ", e);
				}
			} else {
				contenedorTab.setSelectedIndex(numTab);
				getETexto().requestFocusInWindow();
				OperacionesTextPane.irALinea(getETexto(), aCompilacionDatos
						.getFila());
				// getETexto().select(aCompilacionDatos.getFila(),
				// aCompilacionDatos.getFila());
				// getETexto().viewToModel(new Point
				// (aCompilacionDatos.getFila(),aCompilacionDatos.getColumna()));

			}
		}
	}

	/**
	 * Ventana activa.
	 * 
	 * @return int Creado : Parras, 12-oct-2009
	 */
	public int ventanaActiva() {

		if (contenedorTab != null) {
			return contenedorTab.getSelectedIndex();
		} else {
			return -1;
		}
	}

	/**
	 * Devuelve el documento del tab activo
	 * 
	 * @return document Creado : Parras, 12-oct-2009
	 */
	public Document getDocumentoActivo() {
		return eTexto.get(ventanaActiva()).getDocument();
	}

	// 
	/**
	 * Panel divisor.
	 * <p>
	 * Separador de nuestro Panel en el centro
	 * </p>
	 * 
	 * @return jplit pane Creado : Parras, 12-oct-2009
	 */
	private JSplitPane panelDivisor() {
		if (splitPanelArbol == null) {
			splitPanelArbol = new JSplitPane();
			// aadimos A la izquierda y a la derecha
			splitPanelArbol.setLeftComponent(arbolDirectorio);
			// splitPanel.setRightComponent(pestaaNueva ());

			panelAuxiliar = new JPanel();
			BorderLayout layaout = new BorderLayout();
			panelAuxiliar.setLayout(layaout);

			splitPanelArbol.setRightComponent(panelAuxiliar);

			// Propiedades
			splitPanelArbol.setOneTouchExpandable(true); // Se exapande y se
			// cierra
			splitPanelArbol.setDividerLocation(SPLIT_ARBOL_TAMANO); // Tamao  de nuestro rbol.
		}
		return splitPanelArbol;

	}

	// Separador de nuestro Panel de la consola
	/**
	 * 
	 * 
	 * <p>
	 * Separador de nuestro Panel de la consola
	 * </p>
	 * 
	 * @returnj split pane Creado : Parras, 12-oct-2009
	 */
	private JSplitPane panelDivisorConsola() {
		if (splitPaneConsola == null) {
			splitPaneConsola = new JSplitPane(JSplitPane.VERTICAL_SPLIT);
			// aadimos A la izquierda y a la derecha
			splitPaneConsola.setLeftComponent(panelDivisor());

			// Cosola
			// splitPaneConsola.setRightComponent(new JScrollPane(miConsola));
			// Guardamos nuestra salidas estandares
			iSalidaStandarOut = System.out;
			iSalidaStandarErr = System.err;
			panelConsolaInformacion.setLayout(new BorderLayout());
			panelConsolaInformacion.add(tabbInformacion, BorderLayout.CENTER);
			splitPaneConsola.setRightComponent(panelConsolaInformacion);

			// Propiedades
			splitPaneConsola.setOneTouchExpandable(true); // Se exapande y se
			// cierra
			splitPaneConsola.setDividerLocation(SPLIT_CONSOLA_TAMANO); // Tamao a la hora de
			// dividir
		}
		return splitPaneConsola;

	}

	// Barra de Botones en la cual tendremos todos los botones de acceso
	// rpido
	/**
	 * Barra de botones.
	 * 
	 * @returnj tool bar Creado : Parras, 12-oct-2009
	 */
	private JToolBar barraDeBotones() {
		if (barraBotones == null) {

			barraBotones = new JToolBar();
			barraBotones.setOrientation(SwingConstants.HORIZONTAL);

			// Botones de Barra
			barraBotones.addSeparator();
			botonNuevo = new JButton(IconFactory.getImage("nuevo.png"));
			botonNuevo.setToolTipText("Nuevo");
			botonNuevo.setBorderPainted(true);
			barraBotones.add(botonNuevo);

			botonAbrir = new JButton(IconFactory.getImage("abrir.gif"));
			botonAbrir.setToolTipText("Abrir");
			botonAbrir.setBorderPainted(true);
			barraBotones.add(botonAbrir);

			botonGuardar = new JButton(IconFactory.getImage("guardar.gif"));
			botonGuardar.setToolTipText("Guardar");
			botonGuardar.setBorderPainted(true);
			barraBotones.add(botonGuardar);

			botonGuardarTodo = new JButton(IconFactory
					.getImage("guardarTodo.gif"));
			botonGuardarTodo.setToolTipText("Guardar Todo");
			botonGuardarTodo.setBorderPainted(true);
			barraBotones.add(botonGuardarTodo);

			botonImprimir = new JButton(IconFactory.getImage("impresora.gif"));
			botonImprimir.setToolTipText("Imprimir");
			botonImprimir.setBorderPainted(true);
			barraBotones.add(botonImprimir);

			botonBuscar = new JButton(IconFactory.getImage("buscar.png"));
			botonBuscar.setToolTipText("Imprimir");
			botonBuscar.setBorderPainted(true);
			barraBotones.add(botonBuscar);

			botonCompilarSimple = new JButton(IconFactory
					.getImage("compile_simple.png"));
			botonCompilarSimple.setBorderPainted(true);
			barraBotones.add(botonCompilarSimple);

			botonCompilar = new JButton(IconFactory.getImage("compile.png"));
			botonCompilar.setToolTipText("Compilar + Ejecutar");
			botonCompilar.setBorderPainted(true);
			barraBotones.add(botonCompilar);
			// compile_simple.png

		}

		return barraBotones;
	}

	/**
	 * Hay datos a guardar.
	 * 
	 * @return true, si es correcto Creado : Parras, 12-oct-2009
	 */
	public boolean hayDatosAGuardar() {

		boolean lbok = false;
		int i = 0;
		while (i < icontVentanas && !lbok) {
			// System.out.print ("--i--->" + i+"=="+ contVentanas);
			// si OK = true es que no tenemos modificaciones en el texto
			if (!(eTexto.get(i).getCambios())) {
				lbok = true;

			}
			i++;
		}
		return lbok;
	}

	/**
	 *<p>
	 * Recorre los tab que existen en la aplicacin y guarda la informacin de
	 * los que necesitan guardar
	 * </p>
	 * 
	 * @return Nodo[] lista de nodos pendientes de guardar cambios
	 * @see proyecto.arbol.Nodo
	 */
	public Nodo[] getNombreTabSinGuardar() {

		ArrayList<Nodo> lalSinGuardar = new ArrayList<Nodo>();
		// String [] lasSinGuardar=null ;
		// System.out.print ("--contVentanas--->" + contVentanas);
		for (int i = 0; i < icontVentanas; i++) {
			// System.out.print ("\n--OK--->" + eTexto.get(i).getOk()+i);

			// si OK = true es que no tenemos modificaciones en el texto
			if (!(eTexto.get(i).getCambios())
					&& iAFicherosAbiertos.get(i) != null) {
				lalSinGuardar.add(iAFicherosAbiertos.get(i));
				// System.out.print (contenedorTab.getTitleAt(i));
			}
		}
		// String[] ldevolver = null;
		// System.out.print ("--lalSinGuardar.size()--->" +
		// lalSinGuardar.size());
		System.out.print("\n1" + lalSinGuardar);
		Collections.sort(lalSinGuardar);
		System.out.print("\n2" + lalSinGuardar);
		return (lalSinGuardar == null) ? null : (Nodo[]) lalSinGuardar
				.toArray(new Nodo[lalSinGuardar.size()]);

		// System.out.print ("--length--->" + ldevolver.length);
		// return ldevolver;

	}

	// private JToolBar barraDeInformacion(){
	// if (barraInformacion ==null){
	// barraInformacion = new JToolBar ();
	// barraInformacion.setOrientation(barraInformacion.HORIZONTAL);
	// label = new JLabel ("Cargado");
	// barraInformacion.add(label);
	// }
	// return barraInformacion;
	// }
	// Para Escribir En Nuestra etiqueta
	/**
	 * Modifica la propiedad texto barra estado.
	 * 
	 * @param s
	 *            s
	 */
	public void setTextoBarraEstado(String s) {
		// label.setText(s);
		if (barraEstado != null)
			barraEstado.setTextAreaOpciones(s);
	}

	/**
	 * Barra De Estado Para pasarle Informacion.
	 * 
	 * @return barra estado
	 */
	public BarraEstado getbarraEstado() {
		if (barraEstado == null)
			barraEstado = new BarraEstado(this);

		return barraEstado;
	}

	// 
	/**
	 * <p>
	 * Ventana que maneja ir a una posicion determindada de nuestro texto.
	 * Verifica que la posicin sea valida, en el caso de correcto lo situal el
	 * cursor en la posicin de nuestro cdigo, en otro caso muestra un mensaje
	 * sobre el problema ocurrido en nuestra barra de estado.
	 * </p>
	 * 
	 * @see proyecto.utilidades.BarraEstado <p>
	 *      Creado : Parras, 12-oct-2009</p
	 */
	public void getVentanaIrA() {
		JavaTextPane lTextPanel = this.getETexto();
		int liNLineas = OperacionesTextPane.getLineas(lTextPanel);
		String lsAux = "(1.." + String.valueOf(liNLineas) + ")";
		String valor = JOptionPane.showInputDialog(new JFrame(),
				"Nmero de Lnea " + lsAux + ":", "Ir A La linea ",
				JOptionPane.QUESTION_MESSAGE);

		// Mathes le damos una expresion regular y no devuelve si es cierta
		// System.out.println(valor.matches("[0-9]+"));
		if (valor != null && valor.matches("[0-9]+")
				&& Integer.valueOf(valor) > 0
				&& Integer.valueOf(valor) < liNLineas + 1)
			OperacionesTextPane.irALinea(lTextPanel, Integer.valueOf(valor));
		else if (valor != null)
			// valor insertado es un caracter, si es -1 es cancelar y no
			// mostramos ningun error
			this
					.setTextoBarraEstado("Debe introducir un nmero comprendido entre "
							+ lsAux);

		// Devolver os el foco
		this.getETexto().requestFocus();
	}

	/**
	 * Metodo Para Guardar Todos los tabs.
	 */

	public void guardarTodo() {
		ArrayList<Nodo> lalSinGuardar = new ArrayList<Nodo>();
		System.out.print(hayDatosAGuardar());
		if (ventanaActiva() >= 0 && hayDatosAGuardar()) {
			for (int i = 0; i < icontVentanas; i++) {
				System.out.print("\n--OK--->" + eTexto.get(i).getCambios() + i);

				// si OK = true es que no tenemos modificaciones en el texto
				if (!(eTexto.get(i).getCambios())
						&& iAFicherosAbiertos.get(i) != null) {

					lalSinGuardar.add(iAFicherosAbiertos.get(i));
					// System.out.print (contenedorTab.getTitleAt(i));
					eTexto.get(i).setCambios(true);
					cambiarTabbImag(ledVerde, i);
				}
			}
			// System.out.print(lalSinGuardar);

			if (lalSinGuardar.size() >= 0) {
				for (Iterator iter = lalSinGuardar.iterator(); iter.hasNext();) {
					try {
						guiPrinc.guardarComo(((Nodo) iter.next())
								.getDirectorio());
					} catch (EpSilonExcepciones e) {

						e.printStackTrace();
					} catch (IOException e) {

						e.printStackTrace();
					}

				}

			}

		}
		setTextoBarraEstado("Documentos Guardados");

	}

	
	/**
	 * Guardar nuestro fichero del tab activo. 
	 * 
	 * Creado : Parras, 25-nov-2009
	 */
	public void guardarTabActivo (){
		if (ventanaActiva() >= 0) {
		try {
			File fichero = getFicheroTabRun();
			// System.out.print(fichero);
			if (fichero == null && !fichero.exists())
				Editor.get().guardarEnFichero();
			else
				Editor.get().guardarComo(fichero);

			setOKTextPane(true);

		} catch (IOException e) {
			Mensajes.mensajeDetalles("Error al guardar el fichero", e);

		}
		// Tenemos que poner el ok a true para que saber que no hay
		// modificaciones
		// en nuestro fichero

	}
	}
	/**
	 * Modificare el Boolean de nustro textPane desde el arbol.
	 * 
	 * @param guardado
	 *            guardado
	 */
	public void setOKTextPane(boolean guardado) {

		eTexto.get(ventanaActiva()).setCambios(guardado);
		// eTexto.get(contVentanas).setCaretPosition(0);
		eTexto.get(ventanaActiva()).setFocusable(true);

	}

	/**
	 *<p>
	 * Los elementos que estn definidos mediante ActionCommand para los JButton
	 * de la barra de herramientas son:
	 * </p>
	 * *
	 * <ul>
	 * <ul>
	 * <li>NUEVO : Abre la ventana que gestiona nuevo elementos en nuestra
	 * aplicacin</li>
	 * <li>ABRIRBOTON: Abre un fichero en modo texto</li>
	 * <li>BUSCAR: Abre la ventana buscar en nuestro cdigo fuente, siempre lo
	 * realiza en el tab que est activo</li>
	 * <li>GUARDARBOTON: Guarda un fichero abierto en un tab</li>
	 * <li>GUARDARBOTONTODO: Guarda todos los ficheros que tengamos con
	 * modificaciones en los tab.</li>
	 * <li>COMPILAR: Compilacin + Ejecucin si todo ha ido correcto. Verifica
	 * el tipo de fichero que tengamos en el tab, para compilar mediante JavaCC
	 * o Java</li>
	 * <li>COMPILAR_SIMPLE: Compilacin. Verifica el tipo de fichero que
	 * tengamos en el tab, para compilar mediante JavaCC o Java</li>
	 * <li>IMPRIMIR: imprime nuestro tab activo mediante ireport.</li>
	 * </ul>
	 * 
	 * @see proyecto.editor.ControlVentPanel#actionPerformed(java.awt.event.ActionEvent)
	 * 
	 * @param c
	 *            La propiedad controlador
	 */
	public void setControlador(ActionListener c) {
		controlador = c;
		// Para los Item de Archivo su correspondiente listenar
		botonNuevo.setActionCommand("NUEVO");
		botonNuevo.addActionListener(controlador);

		botonAbrir.setActionCommand("ABRIRBOTON");
		botonAbrir.addActionListener(controlador);

		botonBuscar.setActionCommand("BUSCAR");
		botonBuscar.addActionListener(controlador);

		botonGuardar.setActionCommand("GUARDARBOTON");
		botonGuardar.addActionListener(controlador);

		botonGuardarTodo.setActionCommand("GUARDARBOTONTODO");
		botonGuardarTodo.addActionListener(controlador);

		botonCompilar.setActionCommand("COMPILAR");
		botonCompilar.addActionListener(controlador);

		botonCompilarSimple.setActionCommand("COMPILAR_SIMPLE");
		botonCompilarSimple.addActionListener(controlador);

		botonImprimir.setActionCommand("IMPRIMIR");
		botonImprimir.addActionListener(controlador);
	}

	/**
	 * Incrementar Numero de Ventanas icontVentanas++.
	 */
	private void setIncrementarNumTabs() {
		icontVentanas++;

	}

	/**
	 * imprimir Metodo que monta la impresin de nuestro proyecto.
	 */
	public void imprimir() {
		ImprimirEpsilon imprimir = new ImprimirEpsilon();
		imprimir.getControlador().setPathMaestro(
				"proyecto/informe/epsilon.jasper");
		imprimir.getControlador().addParametro("LOGO",
				"proyecto/imagenes/logo.gif");
		imprimir.getControlador().addParametro("RUTA",
				getRutaProyectoActivo().toString());
		imprimir.getControlador().addParametro("FILE", getProyectoActivo());

		System.out.println(getRutaProyectoActivo().toString());

		imprimir.getControlador().addParametro("PRUEBA",
				devolverTextoImpresion());
		// ArrayList<Document> documentos = new ArrayList<Document> ();
		// documentos.add(gui.getPanel().getETexto ().getDocument());
		// imprimir.getControlador().addParametro("documento",gui.getPanel().getETexto
		// ().getDocument());
		imprimir.getControlador().imprimir();
	}

	/**
	 * <p>
	 * Exportar
	 * </p>
	 * 
	 * Prepara los datos para mandarlos a imprimir. Los datos que pintamos en el
	 * report son:
	 * <ul>
	 * <li>LOGO : proyecto/imagenes/logo.gif</li>
	 * <li>RUTA: Ruta donde se encuentra el fichero localmente</li>
	 * <li>FILE: Nombre al proyecto que pertenece.</li>
	 * </ul>
	 * Nota:Estos son los paramentros con lo que se ha compilado el report.
	 * 
	 * <p>
	 * Jasper que utilizamos para la impresin==>proyecto/informe/epsilon.jasper
	 * </p>
	 * 
	 * @param aDatos
	 *            DatosExportar
	 * 
	 * @see proyecto.paneles.DatosExportar
	 * @see proyecto.impresion.ImprimirEpsilon
	 */
	public void exportar(DatosExportar aDatos) {
		ImprimirEpsilon imprimir = new ImprimirEpsilon();
		imprimir.getControlador().setPathMaestro(
				"proyecto/informe/epsilon.jasper");
		imprimir.getControlador().addParametro("LOGO",
				"proyecto/imagenes/logo.gif");
		imprimir.getControlador().addParametro("RUTA",
				getRutaProyectoActivo().toString());
		imprimir.getControlador().addParametro("FILE", getProyectoActivo());

		System.out.println(getRutaProyectoActivo().toString());

		imprimir.getControlador().addParametro("PRUEBA",
				devolverTextoImpresion());
		// ArrayList<Document> documentos = new ArrayList<Document> ();
		// documentos.add(gui.getPanel().getETexto ().getDocument());
		// imprimir.getControlador().addParametro("documento",gui.getPanel().getETexto
		// ().getDocument());
		imprimir.getControlador().imprimir(aDatos);
	}

	/**
	 * getVentana
	 * 
	 * <p>
	 * Devuelve el nmero total de tabs abiertos.
	 * </p>
	 * 
	 * @return int
	 */
	public int getVentana() {
		return icontVentanas;
	}

	// Rediccionar la salida estandar a mi consola
	// public void setModificarSalidaConsola (){
	// // iSalidaStandarOut = System.out;
	// // iSalidaStandarerr = System.err;
	//			
	// // Creamos un nuevo TextAreaOutputStream para escribir en
	// nuestroJTextArea control and wrap a
	// // PrintStream around it to supportprintln/printf methods.
	// PrintStream out = new PrintStream( new Consola( this.getMiConsola()) );
	// // redirect standard output stream toTextAreaOutputStream
	// System.setOut( out );
	// // redirect standard error stream toTextAreaOutputStream
	// System.setErr( out );
	//
	// }
	// //Establecer la salida estanda a la consola de java
	// public void setEstablecerSalidaEstandar (){
	//			
	// // redirect standard output stream toJava
	// System.setOut( iSalidaStandarOut);
	// // redirect standard error stream toJava
	// System.setErr( iSalidaStandarerr );
	// }

	// Rediccionar la salida estandar a mi consola
	/**
	 * Modifica la propiedad modificar salida consola. Creado : Parras,
	 * 12-oct-2009
	 */
	public void setModificarSalidaConsola() {
		textPaneAuxiliar = new ConsolaTextPane();
		// redirect
		System.setErr(new PrintStream(new ConsolaOutStream(textPaneAuxiliar,
				Color.RED, getNodoArbolTabRub()), true));
		System.setOut(new PrintStream(new ConsolaOutStream(textPaneAuxiliar,
				getNodoArbolTabRub()), true));

	}

	/**
	 * Establece nuestra salida estandar.
	 */
	public void setEstablecerSalidaEstandar() {

		System.setOut(this.iSalidaStandarOut);
		System.setErr(this.iSalidaStandarErr);
		ConsolaTextPane textPaneConsolaDatos = new ConsolaTextPane();
		textPaneAuxiliar.copiarConsolaTextPane(textPaneConsolaDatos);
		tabbInformacion.addTabConsola(textPaneConsolaDatos, this
				.getFicheroTabRun());

	}

	/**
	 * Modifica la propiedad de colores de nuestro editor Creado : Parras,
	 * 12-oct-2009
	 * 
	 * @param aMapa
	 *            Nuevas propiedades de modificacin
	 */
	public void setDefectoColores(Map<ItemDeLista, AtributosPreferenicas> aMapa) {

		// { "Texto","Palabras Reservadas", "Identificadores", "Separadores",
		// "Operadores", "Comentarios" };
		// imapa= new HashMap<ItemDeLista,AtributosPreferenicas>() ;

		// Comentarios
		aMapa.put(new ItemDeLista("comment", "Comentario"),
				new AtributosPreferenicas(new Font("Monospaced", 0, 12),
						Color.white, Color.gray.darker()));

		// Palabras Reservadas
		aMapa.put(new ItemDeLista("reservedWord", "Palabras Reservadas"),
				new AtributosPreferenicas(new Font("Monospaced", 0, 12),
						Color.white, Color.blue));
		// Texto normal
		aMapa.put(new ItemDeLista("identifier", "Texto"),
				new AtributosPreferenicas(new Font("Monospaced", 0, 12),
						Color.white, Color.black));

		// Aadir al Mapa
		// Numeros
		aMapa.put(new ItemDeLista("literal", "Literal"),
				new AtributosPreferenicas(new Font("Monospaced", 0, 12),
						Color.white, new Color(0xB03060)/* Color.maroon */));

		// Espacios
		aMapa.put(new ItemDeLista("whitespace", "Espacios"),
				new AtributosPreferenicas(new Font("Monospaced", 0, 12),
						Color.white, Color.black));
		// Operadores + * /
		aMapa.put(new ItemDeLista("operator", "Operadores"),
				new AtributosPreferenicas(new Font("Monospaced", 0, 12),
						Color.white, Color.black));

		// Aadir al Mapa
		// imapa.put( new ItemDeLista("unknown", "unknown"),new
		// AtributosPreferenicas (new Font("Monospaced",0,12),
		// Color.white,Color.black));

		// comment reservedWord identifier literal whitespace operator

	}

	/**
	 * Obtener el imapa.
	 * 
	 * Nuestro Mapa con los colores generados
	 * 
	 * @return el imapa Creado : Parras, 12-oct-2009
	 */
	public Map<ItemDeLista, AtributosPreferenicas> getImapa() {
		return imapa;

	}

	/**
	 * Modifica la propiedad imapa. Creado : Parras, 12-oct-2009
	 * 
	 * @param aMapa
	 *            a mapa
	 */
	public void setImapa(Map<ItemDeLista, AtributosPreferenicas> aMapa) {
		// this.imapa.putAll(aMapa);
		imapa = aMapa;
		// initStyles();//No hace falta que recargemos de nuevo el XML ya que lo
		// tenemos en memoria
		inicializaColores();

		// Recoloreamos todos los texto que tengamos ya que hemos cambiado todos
		// los colores
		if (eTexto != null) {
			Iterator<JavaTextPane> iter;
			iter = eTexto.iterator();
			while (iter.hasNext()) {
				iter.next().colorAll();
			}
		}

	}

	/**
	 * Crea la ventana que gestiona el crear los tipos de ficheros (java o
	 * javaCC) o carpeta.
	 */
	public void abritVentanaNuevo() {
		if (guiPrinc.getPrimerProyecto() != null) {
			NuevoVentana ventana = new NuevoVentana(guiPrinc, true,
					arbolDirectorio.getListaPaquetesActualizada());
			if (objLogger.isDebugEnabled())
				objLogger.debug("Lista paquetes:"
						+ arbolDirectorio.getListaPaquetes());
			
			ventana.setVisible(true);
			if (ventana.getPaqueteNuevo() != null)
				arbolDirectorio.setNuevoElemento(ventana.getPaqueteNuevo());
		}
	}

	/**
	 * <p>
	 * Carga la configuracin de nuestro XML de configuracin
	 * (configColores.xml). Este XML es recorrido mediante JDOOM y lo elementos
	 * obtenido lo introducimos (JDOMException) en un mapa. En el caso que
	 * exista cualquier incidente en el XML, el mtodo mostrar una excepcin
	 * que se cargar los colores por defecto de nuestra aplicacin.
	 * </p>
	 * 
	 * 
	 * 
	 * @throws JDOMException
	 *             JDOM exception
	 * @throws IOException
	 *             Signals that an I/O exception has occurred.
	 * 
	 *             Creado : Parras, 13-oct-2009
	 */
	public void coloresXml() throws JDOMException, IOException {
		SAXBuilder builder = new SAXBuilder(false);
		// usar el parser Xerces y no queremos
		// que valide el documento

		// System.out.print(getClass().getResource("../configuracion/configColores.xml")+"\n");

		org.jdom.Document doc;
		// Inicializamos Nuestro mapa que contine los Item de y los atributos de
		// eso items.
		imapa = new HashMap<ItemDeLista, AtributosPreferenicas>();

		File url = new File (guiPrinc.getPrefColoresXML());

		if (url != null && url.exists()){
			
		doc = builder.build(url);
		// construyo el arbol en memoria desde el fichero
		// que se lo pasara por parametro.
		Element raiz = doc.getRootElement();
		// cojo el elemento raiz
		// System.out.println(raiz.getAttributeValue ("tipo"));

		// Obtenemos la Lista de todas las Opciones(hijos) posibles de nuestro
		// colores.
		List opciones = raiz.getChildren("opciones");
		// System.out.println("Formada por:"+opciones.size()+" opciones");
		Iterator iter = opciones.iterator();
		ItemDeLista item;
		while (iter.hasNext()) {
			Element e = (Element) iter.next();// obtenemos el primer elemento
			// de opciones
			Element items = e.getChild("item");
			item = new ItemDeLista(items.getAttributeValue("tituloEtiqueta"),
					items.getAttributeValue("tituloOpcion"));
			// System.out.print("Item"+item.getEtiqueta()+ "
			// "+item.getTituloOpcion());
			// Obtenemos los hijos de la Fuente
			Element fuente = e.getChild("fuente");
			Font f = new Font(fuente.getAttributeValue("tipo"), Integer
					.parseInt(fuente.getAttributeValue("estilo")), Integer
					.parseInt(fuente.getAttributeValue("size")));
			// System.out.print("Fuente"+f);
			// Obtenemos los hijos de color
			Element color = e.getChild("color");
			Color fore = new Color(Integer.parseInt(color
					.getAttributeValue("primerPlano")));
			Color back = new Color(Integer.parseInt(color
					.getAttributeValue("segundoPlano")));
			// System.out.print("color"+fore);
			// Construimos todo.
			if (item != null && item.getEtiqueta() != null)
				imapa.put(item, new AtributosPreferenicas(f, back, fore));

		}
		}else{
			setDefectoColores(imapa);
		}

	}

	/**
	 *<p>
	 * Inicializa los colores:
	 * </p>
	 *<ul>
	 *<li>En primer lugar buscamos en nuestro XML, para la carga de colores</li>
	 *<li>En el caso de problemas en el XML Cargamos nuestro colores por
	 * defecto</li>
	 *</ul>
	 *Finalmente inicializamos los colores con el mapa obtenido de variable de
	 * instancia (imapa)
	 * 
	 *Creado : Parras, 12-oct-2009
	 */
	private void initStyles() {

		// System.out.println(imapa.get(new ItemDeLista ("body","")));

		try {
			coloresXml();

		} catch (JDOMException e) {
			// Ponemos los valores por defecto a los colores por fallo del
			// fichero
			setDefectoColores(imapa);
			// e.printStackTrace();
		} catch (IOException e) {
			// Ponemos los valores por defecto a los colores por fallo del
			// fichero
			setDefectoColores(imapa);
			e.printStackTrace();
		} finally {
			// Simpre tenemos que inicializar los colores
			inicializaColores();
		}

	}

	/**
	 * Inicializa colores los colores de nuestra variable imapa
	 * 
	 * Creado : Parras, 12-oct-2009
	 */
	private void inicializaColores() {
		Style style;
		// Inicializar el mapa con los valores
		// Comentario
		style = styleContext.addStyle("comment", null);
		StyleConstants.setFontFamily(style, imapa.get(
				new ItemDeLista("comment", "")).getFuente().getFontName());
		StyleConstants.setFontSize(style, imapa.get(
				new ItemDeLista("comment", "")).getFuente().getSize());
		StyleConstants.setBackground(style, imapa.get(
				new ItemDeLista("comment", "")).getColorBack());
		StyleConstants.setForeground(style, imapa.get(
				new ItemDeLista("comment", "")).getColorFore());
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, true);

		// Palabras Reservadas
		style = styleContext.addStyle("reservedWord", null);
		StyleConstants.setFontFamily(style, imapa.get(
				new ItemDeLista("reservedWord", "")).getFuente().getFontName());
		StyleConstants.setFontSize(style, imapa.get(
				new ItemDeLista("reservedWord", "")).getFuente().getSize());
		StyleConstants.setBackground(style, imapa.get(
				new ItemDeLista("reservedWord", "")).getColorBack());
		StyleConstants.setForeground(style, imapa.get(
				new ItemDeLista("reservedWord", "")).getColorFore());
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		// Texto Normal
		style = styleContext.addStyle("identifier", null);
		StyleConstants.setFontFamily(style, imapa.get(
				new ItemDeLista("identifier", "")).getFuente().getFontName());
		StyleConstants.setFontSize(style, imapa.get(
				new ItemDeLista("identifier", "")).getFuente().getSize());
		StyleConstants.setBackground(style, imapa.get(
				new ItemDeLista("identifier", "")).getColorBack());
		StyleConstants.setForeground(style, imapa.get(
				new ItemDeLista("identifier", "")).getColorFore());
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);
		// Numeros
		style = styleContext.addStyle("literal", null);
		StyleConstants.setFontFamily(style, imapa.get(
				new ItemDeLista("literal", "")).getFuente().getFontName());
		StyleConstants.setFontSize(style, imapa.get(
				new ItemDeLista("literal", "")).getFuente().getSize());
		StyleConstants.setBackground(style, imapa.get(
				new ItemDeLista("literal", "")).getColorBack());
		StyleConstants.setForeground(style, imapa.get(
				new ItemDeLista("literal", "")).getColorFore());
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		// Espacios
		style = styleContext.addStyle("whitespace", null);
		StyleConstants.setFontFamily(style, imapa.get(
				new ItemDeLista("whitespace", "")).getFuente().getFontName());
		StyleConstants.setFontSize(style, imapa.get(
				new ItemDeLista("whitespace", "")).getFuente().getSize());
		StyleConstants.setBackground(style, imapa.get(
				new ItemDeLista("whitespace", "")).getColorBack());
		StyleConstants.setForeground(style, imapa.get(
				new ItemDeLista("whitespace", "")).getColorFore());
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		// Operadores + * /
		style = styleContext.addStyle("operator", null);
		StyleConstants.setFontFamily(style, imapa.get(
				new ItemDeLista("operator", "")).getFuente().getFontName());
		StyleConstants.setFontSize(style, imapa.get(
				new ItemDeLista("operator", "")).getFuente().getSize());
		StyleConstants.setBackground(style, imapa.get(
				new ItemDeLista("operator", "")).getColorBack());
		StyleConstants.setForeground(style, imapa.get(
				new ItemDeLista("operator", "")).getColorFore());
		StyleConstants.setBold(style, true);
		StyleConstants.setItalic(style, false);

		/** ***************NO UTILIZAMOS EN JAVACC************************** */
		// tipos de letras que no son reconocida
		style = styleContext.addStyle("error", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants.setForeground(style, Color.black);
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		style = styleContext.addStyle("separator", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants
				.setForeground(style, new Color(0x000080)/* Color.navy */);
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		// No lo utilizamos porque no hacemos un anlisis semtico
		style = styleContext.addStyle("body", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants.setForeground(style, Color.black);
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		// System.out.print(style);

		style = styleContext.addStyle("tag", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants.setForeground(style, Color.blue);
		StyleConstants.setBold(style, true);
		StyleConstants.setItalic(style, false);

		// System.out.print(styleContext);

		style = styleContext.addStyle("endtag", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants.setForeground(style, Color.blue);
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		style = styleContext.addStyle("reference", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants.setForeground(style, Color.black);
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		style = styleContext.addStyle("name", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants
				.setForeground(style, new Color(0xB03060)/* Color.maroon */);
		StyleConstants.setBold(style, true);
		StyleConstants.setItalic(style, false);

		style = styleContext.addStyle("value", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants
				.setForeground(style, new Color(0xB03060)/* Color.maroon */);
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, true);

		style = styleContext.addStyle("preprocessor", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setBackground(style, Color.white);
		StyleConstants.setForeground(style, new Color(0xA020F0).darker()/*
																		 * Color.
																		 * purple
																		 */);
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);

		style = styleContext.addStyle("unknown", null);
		StyleConstants.setFontFamily(style, "Monospaced");
		StyleConstants.setFontSize(style, 12);
		StyleConstants.setForeground(style, Color.orange);
		StyleConstants.setBold(style, false);
		StyleConstants.setItalic(style, false);
	}

	/**
	 * Obtener el arbol directorio.
	 * 
	 * @return el arbol directorio Creado : Parras, 12-oct-2009
	 */
	public ArbolFicheros getArbolDirectorio() {
		return arbolDirectorio;
	}

	/**
	 * Modificar la propiedad arbol directorio.
	 * 
	 * @param arbolDirectorio
	 *            La propiedad arbol directorio
	 */
	public void setArbolDirectorio(ArbolFicheros arbolDirectorio) {
		this.arbolDirectorio = arbolDirectorio;
	}

	// Proyecto activo en este momento
	/**
	 * Obtener el proyecto activo.
	 * 
	 * @return el proyecto activo Creado : Parras, 12-oct-2009
	 */
	public String getProyectoActivo() {
		return iSProyectoActivo;
	}

	/**
	 * Obtener texto tab activo.
	 * 
	 * @return el nombre del tab activo en este momento
	 */
	public String getTextoTabActivo() {
		return getFicheroTabRun().getName();
	}

	/**
	 * Modificar la propiedad proyecto activo.
	 * 
	 * @param proyectoActivo
	 *            La propiedad proyecto activo
	 */
	public void setProyectoActivo(String proyectoActivo) {
		iSProyectoActivo = proyectoActivo;
	}

	/**
	 * Obtener el ruta proyecto activo.
	 * 
	 * @return el ruta proyecto activo Creado : Parras, 12-oct-2009
	 */
	public File getRutaProyectoActivo() {
		return rutaProyectoActivo;
	}

	/**
	 * Modificar la propiedad ruta proyecto activo.
	 * 
	 * @param rutaProyectoActivo
	 *            La propiedad ruta proyecto activo
	 */
	public void setRutaProyectoActivo(File rutaProyectoActivo) {
		this.rutaProyectoActivo = rutaProyectoActivo;
	}

}
// //////////////////////FIN MODIFICACIONES

