/*
 * 
 * @author Manuel Parras  
 */
package proyecto.herramientas;

import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.PlainDocument;

/**
 *<p>JTextFieldLimit</p>
 *
 *<p>Clase que hereda de PlainDocument, a la cual le aadimos un JTextField y le aplicamos 
 *dicho documento modificado. El documento tiene modificadores para poder usarlo a nuestras 
 *necesidades. Los modificadores aadidos son:  reconocedor numrico y reconocedor de nombre 
 *de ficheros (constantes definidas en la clase).</p>
 *<p>Podemos restringir el nmero de caracteres que podemos insertar en nuestro JTextField, en 
 *el caso que sea -1(JTextFieldLimit.SIN_LIMITE_DE_CARACTERES) no tendr ningn lmite.</p>
 *<p>Un casos de usos es para el ir al nmero de lnea y nuevo Fichero </p>
 *
 *@see javax.swing.JTextField
 *@see javax.swing.text.PlainDocument
 * 
 * @author Parras
 * 
 */
public class JTextFieldLimit extends PlainDocument {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	/**
	 * Si deseamos el JTextField sin ningn limite.
	 */
	public static final int SIN_LIMITE_DE_CARACTERES = -1;
	/**
	 * Reconoce cualquier numero
	 */
	public static final String MODO_NUMERICO = "[0-9]*";
	/**
	 * Reconoce cualquier nombre de fichero vlido.
	 */
	public static final String MODO_RECONOCEDOR_FICHEROS = "[a-zA-Z$_0-9]*";

	/**
	 *Total de caracteres lmite
	 */
	private int ilimite;

	/**
	 * Modo de constantes que tendr asociada nuestra clase.
	 */
	private String isModoReconocedor;

	/**
	 * @param alimite
	 *            limte de palabras mximas que queremos representar en nuestro
	 *            JTextFiedd, si pasamos la costante SIN_LIMITE_DE_CARACTERES no
	 *            tendr limite
	 * 
	 */
	public JTextFieldLimit(int alimite) {
		super();
		this.ilimite = alimite;
		isModoReconocedor = JTextFieldLimit.MODO_NUMERICO;
	}

	/**
	 * @param alimite
	 *            limte de palabras mximas que queremos representar en nuestro
	 *            JTextFiedd, si pasamos la costante SIN_LIMITE_DE_CARACTERES no
	 *            tendr limite
	 * @param asModo
	 *            Modos de constantes definidas en la clase para que actue de
	 *            reconocedor difirente
	 */
	public JTextFieldLimit(int alimite, String asModo) {
		super();
		this.ilimite = alimite;
		isModoReconocedor = asModo;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see javax.swing.text.PlainDocument#insertString(int, java.lang.String,
	 * javax.swing.text.AttributeSet)
	 */
	public void insertString(int offset, String str, AttributeSet attr)
			throws BadLocationException {
		if (str == null)
			return;
		// que el textField tenga una limitacin y ademas obligatorio que sea
		// numrico
		if (((getLength() + str.length()) <= ilimite || ilimite == JTextFieldLimit.SIN_LIMITE_DE_CARACTERES)
				&& str.matches(isModoReconocedor)) {
			super.insertString(offset, str, attr);
		}
	}
}
