/*
 * 
 * @author Manuel Parras  
 */
package proyecto.herramientas;

import java.beans.XMLEncoder;
import java.io.BufferedOutputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;

import proyecto.editor.Editor;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.OperacionesVentanas;

// TODO: Auto-generated Javadoc
/*
 * OpcionesCompilacion.java
 *
 * Created on 2 de diciembre de 2007, 19:47
 */

/**
 * <p>
 * OpcionesCompilacion
 * </p>
 * <p>
 * Panel encargado de representar la opciones sobre JavaCC a la hora de
 * compilar, es decir, cualquier modificacin que se realice en este
 * mantenimiento ser guardado(en un fichero XML) para todas las posteriores
 * compilaciones.
 * </p>
 *<p>
 * En el mantenimiento se ha generado un botn para poder obtener los valores
 * por defecto de JavaCC
 * </p>
 * <p>
 * Se han representado los valores tal cual son referenciados por JavaCC.
 * </p>
 * <p>
 * Opciones con valores Enteros:
 * <p>
 * <ul>
 * <li>LOOKAHEAD (default 1)</li>
 * <li>CHOICE_AMBIGUITY_CHECK (default 2)</li>
 * <li>OR_AMBIGUITY_CHECK (default 1)</li>
 * </ul>
 * Opciones con valores booleanos:
 * <ul>
 * <li>STATIC (default true)</li>
 * <li>DEBUG_PARSER (default false)</li>
 * <li>DEBUG_LOOKAHEAD (default false)</li>
 * <li>DEBUG_TOKEN_MANAGER (default false)</li>
 * <li>OPTIMIZE_TOKEN_MANAGER (default true)</li>
 * <li>ERROR_REPORTING (default true)</li>
 * <li>JAVA_UNICODE_ESCAPE (default false)</li>
 * <li>UNICODE_INPUT (default false)</li>
 * <li>IGNORE_CASE (default false)</li>
 * <li>COMMON_TOKEN_ACTION (default false)</li>
 * <li>USER_TOKEN_MANAGER (default false)</li>
 * <li>USER_CHAR_STREAM (default false)</li>
 * <li>BUILD_PARSER (default true)</li>
 * <li>BUILD_TOKEN_MANAGER (default true)</li>
 * <li>TOKEN_MANAGER_USES_PARSER (default false)</li>
 * <li>SANITY_CHECK (default true)</li>
 * <li>FORCE_LA_CHECK (default false)</li>
 * <li>CACHE_TOKENS (default false)</li>
 * <li>KEEP_LINE_COLUMN (default true)</li>
 * </ul>
 * 
 * @author Parras
 * @see proyecto.herramientas.PreferenciasCompilacion
 */
public class OpcionesCompilacion extends javax.swing.JDialog {
    
    /* Opcioenes con valores Enteros:

    LOOKAHEAD              (default 1)
    CHOICE_AMBIGUITY_CHECK (default 2)
    OR_AMBIGUITY_CHECK  (default 1)

 Opciones con valores booleanos:

    STATIC                 (default true)
    DEBUG_PARSER           (default false)
    DEBUG_LOOKAHEAD        (default false)
    DEBUG_TOKEN_MANAGER    (default false)
    OPTIMIZE_TOKEN_MANAGER (default true)
    ERROR_REPORTING        (default true)
    JAVA_UNICODE_ESCAPE    (default false)
    UNICODE_INPUT          (default false)
    IGNORE_CASE            (default false)
    COMMON_TOKEN_ACTION    (default false)
    USER_TOKEN_MANAGER     (default false)
    USER_CHAR_STREAM       (default false)
    BUILD_PARSER           (default true)
    BUILD_TOKEN_MANAGER    (default true)
    TOKEN_MANAGER_USES_PARSER (default false)
    SANITY_CHECK           (default true)
    FORCE_LA_CHECK         (default false)
    CACHE_TOKENS           (default false)
    KEEP_LINE_COLUMN       (default true)

 string valued options are:

    OUTPUT_DIRECTORY       (default Current Directory)
    JDK_VERSION       (default 1.4)
     */
     
    
    /**  Constant serialVersionUID. */
	private static final long serialVersionUID = 1L;
	
	/** Creates new form OpcionesCompilacion. */
	private Editor iGui;
	
    /**
	 * Constructor opciones compilacion.
	 * 
	 * Creado : Parras, 16-jul-2009
	 * 
	 * @param aGui
	 *             a gui
	 * @param modal
	 *             modal
	 */
    public OpcionesCompilacion(Editor aGui, boolean modal) {
        super(aGui, modal);
        iGui=aGui;
        initComponents();
        
        //Convertimos Nuestro TextField Numerico y de Limite 2
        jTextField1LOOKAHEAD.setDocument(new JTextFieldLimit(2));
        jTextField2CHOICE_AMBIGUITY_CHECK.setDocument(new JTextFieldLimit(2));
        jTextField3OR_AMBIGUITY_CHECK.setDocument(new JTextFieldLimit(2));
        valoresPorDefecto();
        this.pack();
        //this.setSize(549,644);
        OperacionesVentanas.centraVentanaHija(this);
    }
    
    /**
	 * Cargar datos de nuetras ventana
	 * 
	 * 
	 * @param aPreferencias
	 *             a preferencias
	 *             <p> Creado : Parras, 16-jul-2009</p>
	 */
    public void cargarDatos(PreferenciasCompilacion aPreferencias) {
        jCheckBox10USER_TOKEN_MANAGER.setSelected(aPreferencias.isUserTokenManager());
        jCheckBox11USER_CHAR_STREAM.setSelected(aPreferencias.isUserCharStream());
        jCheckBox12BUILD_PARSER.setSelected(aPreferencias.isBuildParser());
        jCheckBox13BUILD_TOKEN_MANAGER.setSelected(aPreferencias.isBuildTokenManager());
        jCheckBox14TOKEN_MANAGER_USES_PARSER.setSelected(aPreferencias.isTokenManagerUsesParser());
        jCheckBox15SANITY_CHECK.setSelected(aPreferencias.isSanityCheck());
        jCheckBox16FORCE_LA_CHECK.setSelected(aPreferencias.isForceLaCheck());
        jCheckBox17CACHE_TOKENS.setSelected(aPreferencias.isCacheTokens());
        jCheckBox18KEEP_LINE_COLUMN.setSelected(aPreferencias.isKeepLineColumn());
        jCheckBox1STATIC.setSelected(aPreferencias.isStatic());
        jCheckBox2DEBUG_PARSER.setSelected(aPreferencias.isDebugParser());
        jCheckBox3DEBUG_LOOKAHEAD.setSelected(aPreferencias.isDebugLookahead());
        jCheckBox4DEBUG_TOKEN_MANAGER.setSelected(aPreferencias.isDebugTokenManager());
        jCheckBox5OPTIMIZE_TOKEN_MANAGER.setSelected(aPreferencias.isOptimizeTokenManager());
        jCheckBox6ERROR_REPORTING.setSelected(aPreferencias.isErrorReporting());
        jCheckBox7JAVA_UNICODE_ESCAPE.setSelected(aPreferencias.isJavaUnicodeEscape());
        jCheckBox8IGNORE_CASE.setSelected(aPreferencias.isIgnoreCase());
        jCheckBox9COMMON_TOKEN_ACTION.setSelected(aPreferencias.isCommonTokenAction());
        jCheckBox19UNICODE_INPUT.setSelected(aPreferencias.isunicodeInput());
        
        //TextField
         jTextField1LOOKAHEAD.setText(String.valueOf(aPreferencias.getLookahed()));
         jTextField2CHOICE_AMBIGUITY_CHECK.setText(String.valueOf(aPreferencias.getChoiceAmbiguityCheck()));
         jTextField3OR_AMBIGUITY_CHECK.setText(String.valueOf(aPreferencias.getOtherAmbiguityCheck()));
    	
    }
    
    /**
	 * This method is called from within  constructor to initialize  form.
	 * WARNING: Do NOT modify this code.  content of this method is always
	 * regenerated by  Form Editor.
	 */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">                          
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        jPanel1 = new javax.swing.JPanel();
        jPanel1Check = new javax.swing.JPanel();
        jCheckBox1STATIC = new javax.swing.JCheckBox();
        jCheckBox2DEBUG_PARSER = new javax.swing.JCheckBox();
        jCheckBox3DEBUG_LOOKAHEAD = new javax.swing.JCheckBox();
        jCheckBox4DEBUG_TOKEN_MANAGER = new javax.swing.JCheckBox();
        jCheckBox5OPTIMIZE_TOKEN_MANAGER = new javax.swing.JCheckBox();
        jCheckBox6ERROR_REPORTING = new javax.swing.JCheckBox();
        jCheckBox7JAVA_UNICODE_ESCAPE = new javax.swing.JCheckBox();
        jCheckBox8IGNORE_CASE = new javax.swing.JCheckBox();
        jCheckBox9COMMON_TOKEN_ACTION = new javax.swing.JCheckBox();
        jCheckBox10USER_TOKEN_MANAGER = new javax.swing.JCheckBox();
        jCheckBox11USER_CHAR_STREAM = new javax.swing.JCheckBox();
        jCheckBox12BUILD_PARSER = new javax.swing.JCheckBox();
        jCheckBox13BUILD_TOKEN_MANAGER = new javax.swing.JCheckBox();
        jCheckBox14TOKEN_MANAGER_USES_PARSER = new javax.swing.JCheckBox();
        jCheckBox15SANITY_CHECK = new javax.swing.JCheckBox();
        jCheckBox16FORCE_LA_CHECK = new javax.swing.JCheckBox();
        jCheckBox17CACHE_TOKENS = new javax.swing.JCheckBox();
        jCheckBox18KEEP_LINE_COLUMN = new javax.swing.JCheckBox();
        jCheckBox19UNICODE_INPUT = new javax.swing.JCheckBox();
        jLabel1STATIC = new javax.swing.JLabel();
        jLabel2DEBUG_PARSER = new javax.swing.JLabel();
        jLabel3DEBUG_LOOKAHEAD = new javax.swing.JLabel();
        jLabel4DEBUG_TOKEN_MANAGER = new javax.swing.JLabel();
        jLabel5OPTIMIZE_TOKEN_MANAGER = new javax.swing.JLabel();
        jLabel6ERROR_REPORTING = new javax.swing.JLabel();
        jLabel7JAVA_UNICODE_ESCAPE = new javax.swing.JLabel();
        jLabel8IGNORE_CASE = new javax.swing.JLabel();
        jLabel9COMMON_TOKEN_ACTION = new javax.swing.JLabel();
        jLabel10USER_TOKEN_MANAGER = new javax.swing.JLabel();
        jLabel11USER_CHAR_STREAM = new javax.swing.JLabel();
        jLabel12BUILD_PARSER = new javax.swing.JLabel();
        jLabel13BUILD_TOKEN_MANAGER = new javax.swing.JLabel();
        jLabel14TOKEN_MANAGER_USES_PARSER = new javax.swing.JLabel();
        jLabel15SANITY_CHECK = new javax.swing.JLabel();
        jLabel16FORCE_LA_CHECK = new javax.swing.JLabel();
        jLabel17CACHE_TOKENS = new javax.swing.JLabel();
        jLabel18KEEP_LINE_COLUMN = new javax.swing.JLabel();
        jLabel19UNICODE_INPUT = new javax.swing.JLabel();
        jPanel2Enteros = new javax.swing.JPanel();
        jTextField2CHOICE_AMBIGUITY_CHECK = new javax.swing.JTextField();
        jTextField3OR_AMBIGUITY_CHECK = new javax.swing.JTextField();
        jTextField1LOOKAHEAD = new javax.swing.JTextField();
        jLabel1LOOKAHEAD = new javax.swing.JLabel();
        jLabel2CHOICE_AMBIGUITY_CHECK = new javax.swing.JLabel();
        jLabel3OR_AMBIGUITY_CHECK = new javax.swing.JLabel();
        jPanelBotonera = new javax.swing.JPanel();
        jButtonAceptar = new javax.swing.JButton();
        jButtonCancelar = new javax.swing.JButton();
        jButtonDefecto = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setTitle("Preferencias de Compilaci\u00f3n");
        jPanel1.setLayout(new java.awt.BorderLayout());

        jPanel1Check.setLayout(new java.awt.GridBagLayout());

        jPanel1Check.setBorder(javax.swing.BorderFactory.createTitledBorder("Valores L\u00f3gicos"));
        jCheckBox1STATIC.setSelected(true);
        jCheckBox1STATIC.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox1STATIC.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox1STATIC, gridBagConstraints);

        jCheckBox2DEBUG_PARSER.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox2DEBUG_PARSER.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox2DEBUG_PARSER, gridBagConstraints);

        jCheckBox3DEBUG_LOOKAHEAD.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox3DEBUG_LOOKAHEAD.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox3DEBUG_LOOKAHEAD, gridBagConstraints);

        jCheckBox4DEBUG_TOKEN_MANAGER.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox4DEBUG_TOKEN_MANAGER.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox4DEBUG_TOKEN_MANAGER, gridBagConstraints);

        jCheckBox5OPTIMIZE_TOKEN_MANAGER.setSelected(true);
        jCheckBox5OPTIMIZE_TOKEN_MANAGER.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox5OPTIMIZE_TOKEN_MANAGER.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox5OPTIMIZE_TOKEN_MANAGER, gridBagConstraints);

        jCheckBox6ERROR_REPORTING.setSelected(true);
        jCheckBox6ERROR_REPORTING.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox6ERROR_REPORTING.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox6ERROR_REPORTING, gridBagConstraints);

        jCheckBox7JAVA_UNICODE_ESCAPE.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox7JAVA_UNICODE_ESCAPE.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox7JAVA_UNICODE_ESCAPE, gridBagConstraints);

        jCheckBox8IGNORE_CASE.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox8IGNORE_CASE.setMargin(new java.awt.Insets(0, 0, 0, 0));
        
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox8IGNORE_CASE, gridBagConstraints);

        jCheckBox9COMMON_TOKEN_ACTION.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox9COMMON_TOKEN_ACTION.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox9COMMON_TOKEN_ACTION, gridBagConstraints);

        jCheckBox10USER_TOKEN_MANAGER.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox10USER_TOKEN_MANAGER.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 9;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox10USER_TOKEN_MANAGER, gridBagConstraints);

        jCheckBox11USER_CHAR_STREAM.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox11USER_CHAR_STREAM.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 10;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox11USER_CHAR_STREAM, gridBagConstraints);

        jCheckBox12BUILD_PARSER.setSelected(true);
        jCheckBox12BUILD_PARSER.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox12BUILD_PARSER.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 11;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox12BUILD_PARSER, gridBagConstraints);

        jCheckBox13BUILD_TOKEN_MANAGER.setSelected(true);
        jCheckBox13BUILD_TOKEN_MANAGER.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox13BUILD_TOKEN_MANAGER.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 12;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox13BUILD_TOKEN_MANAGER, gridBagConstraints);

        jCheckBox14TOKEN_MANAGER_USES_PARSER.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox14TOKEN_MANAGER_USES_PARSER.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 13;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox14TOKEN_MANAGER_USES_PARSER, gridBagConstraints);

        jCheckBox15SANITY_CHECK.setSelected(true);
        jCheckBox15SANITY_CHECK.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox15SANITY_CHECK.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 14;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox15SANITY_CHECK, gridBagConstraints);

        jCheckBox16FORCE_LA_CHECK.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox16FORCE_LA_CHECK.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 15;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox16FORCE_LA_CHECK, gridBagConstraints);

        jCheckBox17CACHE_TOKENS.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox17CACHE_TOKENS.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 16;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox17CACHE_TOKENS, gridBagConstraints);

        jCheckBox18KEEP_LINE_COLUMN.setSelected(true);
        jCheckBox18KEEP_LINE_COLUMN.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox18KEEP_LINE_COLUMN.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 17;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox18KEEP_LINE_COLUMN, gridBagConstraints);

        jCheckBox19UNICODE_INPUT.setBorder(javax.swing.BorderFactory.createEmptyBorder(0, 0, 0, 0));
        jCheckBox19UNICODE_INPUT.setMargin(new java.awt.Insets(0, 0, 0, 0));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 18;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jCheckBox19UNICODE_INPUT, gridBagConstraints);

        jLabel1STATIC.setText("STATIC");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel1STATIC, gridBagConstraints);

        jLabel2DEBUG_PARSER.setText("DEBUG_PARSER");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel2DEBUG_PARSER, gridBagConstraints);

        jLabel3DEBUG_LOOKAHEAD.setText("DEBUG_LOOKAHEAD");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel3DEBUG_LOOKAHEAD, gridBagConstraints);

        jLabel4DEBUG_TOKEN_MANAGER.setText("DEBUG_TOKEN_MANAGER");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 3;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel4DEBUG_TOKEN_MANAGER, gridBagConstraints);

        jLabel5OPTIMIZE_TOKEN_MANAGER.setText("OPTIMIZE_TOKEN_MANAGER");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 4;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel5OPTIMIZE_TOKEN_MANAGER, gridBagConstraints);

        jLabel6ERROR_REPORTING.setText("ERROR_REPORTING");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 5;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel6ERROR_REPORTING, gridBagConstraints);

        jLabel7JAVA_UNICODE_ESCAPE.setText("JAVA_UNICODE_ESCAPE");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 6;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel7JAVA_UNICODE_ESCAPE, gridBagConstraints);

        jLabel8IGNORE_CASE.setText("IGNORE_CASE");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 7;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel8IGNORE_CASE, gridBagConstraints);

        jLabel9COMMON_TOKEN_ACTION.setText("COMMON_TOKEN_ACTION");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 8;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel9COMMON_TOKEN_ACTION, gridBagConstraints);

        jLabel10USER_TOKEN_MANAGER.setText("USER_TOKEN_MANAGER");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 9;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel10USER_TOKEN_MANAGER, gridBagConstraints);

        jLabel11USER_CHAR_STREAM.setText("USER_CHAR_STREAM");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 10;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel11USER_CHAR_STREAM, gridBagConstraints);

        jLabel12BUILD_PARSER.setText("BUILD_PARSER");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 11;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel12BUILD_PARSER, gridBagConstraints);

        jLabel13BUILD_TOKEN_MANAGER.setText("BUILD_TOKEN_MANAGER");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 12;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel13BUILD_TOKEN_MANAGER, gridBagConstraints);

        jLabel14TOKEN_MANAGER_USES_PARSER.setText("TOKEN_MANAGER_USES_PARSER");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 13;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel14TOKEN_MANAGER_USES_PARSER, gridBagConstraints);

        jLabel15SANITY_CHECK.setText("SANITY_CHECK");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 14;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel15SANITY_CHECK, gridBagConstraints);

        jLabel16FORCE_LA_CHECK.setText("FORCE_LA_CHECK");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 15;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel16FORCE_LA_CHECK, gridBagConstraints);

        jLabel17CACHE_TOKENS.setText("CACHE_TOKENS");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 16;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel17CACHE_TOKENS, gridBagConstraints);

        jLabel18KEEP_LINE_COLUMN.setText("KEEP_LINE_COLUMN");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 17;
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel18KEEP_LINE_COLUMN, gridBagConstraints);

        jLabel19UNICODE_INPUT.setText("UNICODE_INPUT");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 18;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel1Check.add(jLabel19UNICODE_INPUT, gridBagConstraints);

        jPanel1.add(jPanel1Check, java.awt.BorderLayout.CENTER);

        jPanel2Enteros.setLayout(new java.awt.GridBagLayout());

        jPanel2Enteros.setBorder(javax.swing.BorderFactory.createTitledBorder(javax.swing.BorderFactory.createTitledBorder("Valores Enteros")));
        jTextField2CHOICE_AMBIGUITY_CHECK.setText("1");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.ipadx = 20;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel2Enteros.add(jTextField2CHOICE_AMBIGUITY_CHECK, gridBagConstraints);

        jTextField3OR_AMBIGUITY_CHECK.setText("2");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.ipadx = 20;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel2Enteros.add(jTextField3OR_AMBIGUITY_CHECK, gridBagConstraints);

        jTextField1LOOKAHEAD.setText("1");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.ipadx = 20;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel2Enteros.add(jTextField1LOOKAHEAD, gridBagConstraints);

        jLabel1LOOKAHEAD.setText("LOOKAHEAD");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel2Enteros.add(jLabel1LOOKAHEAD, gridBagConstraints);

        jLabel2CHOICE_AMBIGUITY_CHECK.setText("CHOICE_AMBIGUITY_CHECK");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel2Enteros.add(jLabel2CHOICE_AMBIGUITY_CHECK, gridBagConstraints);

        jLabel3OR_AMBIGUITY_CHECK.setText("OR_AMBIGUITY_CHECK");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 0.3;
        gridBagConstraints.insets = new java.awt.Insets(3, 3, 3, 3);
        jPanel2Enteros.add(jLabel3OR_AMBIGUITY_CHECK, gridBagConstraints);

        jPanel1.add(jPanel2Enteros, java.awt.BorderLayout.NORTH);

        jButtonAceptar.setMnemonic('A');
        jButtonAceptar.setText("Aceptar");
        jButtonAceptar.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jButtonAceptarActionPerformed(evt);
            }
        });

        jPanelBotonera.add(jButtonAceptar);

        jButtonCancelar.setMnemonic('C');
        jButtonCancelar.setText("Cancelar");
        jButtonCancelar.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jButtonCancelarActionPerformed(evt);
            }
        });

        jPanelBotonera.add(jButtonCancelar);

        jButtonDefecto.setMnemonic('D');
        jButtonDefecto.setText("Valores Por Defecto");
        jButtonDefecto.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                valoresPorDefecto();
            }
        });

        jPanelBotonera.add(jButtonDefecto);

        jPanel1.add(jPanelBotonera, java.awt.BorderLayout.SOUTH);

        getContentPane().add(jPanel1, java.awt.BorderLayout.NORTH);

        pack();
    }// </editor-fold>                        

    /**
	 * <p>Valores por defecto con los que viene javaCC precargado para la compilacin sin argumentos.<p>
	 * <p> Creado : Parras, 16-jul-2009</p>
	 */
    private void valoresPorDefecto() {                                               
        jCheckBox10USER_TOKEN_MANAGER.setSelected(false);
        jCheckBox11USER_CHAR_STREAM.setSelected(false);
        jCheckBox12BUILD_PARSER.setSelected(true);
        jCheckBox13BUILD_TOKEN_MANAGER.setSelected(true);
        jCheckBox14TOKEN_MANAGER_USES_PARSER.setSelected(false);
        jCheckBox15SANITY_CHECK.setSelected(true);
        jCheckBox16FORCE_LA_CHECK.setSelected(false);
        jCheckBox17CACHE_TOKENS.setSelected(false);
        jCheckBox18KEEP_LINE_COLUMN.setSelected(true);
        jCheckBox1STATIC.setSelected(true);
        jCheckBox2DEBUG_PARSER.setSelected(false);
        jCheckBox3DEBUG_LOOKAHEAD.setSelected(false);
        jCheckBox4DEBUG_TOKEN_MANAGER.setSelected(false);
        jCheckBox5OPTIMIZE_TOKEN_MANAGER.setSelected(true);
        jCheckBox6ERROR_REPORTING.setSelected(true);
        jCheckBox7JAVA_UNICODE_ESCAPE.setSelected(false);
        jCheckBox8IGNORE_CASE.setSelected(false);
        jCheckBox9COMMON_TOKEN_ACTION.setSelected(false);
        jCheckBox19UNICODE_INPUT.setSelected(false);
        
        //TextField
         jTextField1LOOKAHEAD.setText("1");
         jTextField2CHOICE_AMBIGUITY_CHECK.setText("2");
         jTextField3OR_AMBIGUITY_CHECK.setText("1");
    }                                              

    /**
	 * Jbutton cancelar action performed. Creado : Parras, 16-jul-2009
	 * 
	 * @param evt
	 *             evt
	 */
    private void jButtonCancelarActionPerformed(java.awt.event.ActionEvent evt) {                                                
       //System.out.print(this.getSize());
        this.dispose();
    }                                               

    /**
	 * Jbutton aceptar action performed.
	 * 
	 * <p>Cuando pulsamos aceptar  nos genera un fichero XML en la ruta indicada en ConstantesEpSilon para el fichero 
	 * compilacion.xml</p>  
	 *  <p> Estamos utilizando XMLEncoder que convierte un objeto java a XML</p>
	 * 
	 * @param evt
	 *             evt
	 *             <p>Creado : Parras, 16-jul-2009<p>
	 *             @see java.beans.XMLEncoder

	 */
    private void jButtonAceptarActionPerformed(java.awt.event.ActionEvent evt) {                                               
        //guardaremos nuestra opciones de compilacin
    	PreferenciasCompilacion lPreferencias = new PreferenciasCompilacion();
    	
    	
    	lPreferencias.setUserTokenManager(jCheckBox10USER_TOKEN_MANAGER.isSelected());
    	lPreferencias.setUserCharStream(jCheckBox11USER_CHAR_STREAM.isSelected());
    	lPreferencias.setBuildParser(jCheckBox12BUILD_PARSER.isSelected());    	
    	lPreferencias.setBuildTokenManager(jCheckBox13BUILD_TOKEN_MANAGER.isSelected());
    	lPreferencias.setTokenManagerUsesParser(jCheckBox14TOKEN_MANAGER_USES_PARSER.isSelected());
    	lPreferencias.setSanityCheck(jCheckBox15SANITY_CHECK.isSelected());
    	lPreferencias.setForceLaCheck(jCheckBox16FORCE_LA_CHECK.isSelected());
    	lPreferencias.setCacheTokens(jCheckBox17CACHE_TOKENS.isSelected());
        lPreferencias.setKeepLineColumn(jCheckBox18KEEP_LINE_COLUMN.isSelected());
        lPreferencias.setStatic(jCheckBox1STATIC.isSelected());
        lPreferencias.setDebugParser(jCheckBox2DEBUG_PARSER.isSelected());
        lPreferencias.setDebugLookahead(jCheckBox3DEBUG_LOOKAHEAD.isSelected());        
        lPreferencias.setDebugTokenManager(jCheckBox4DEBUG_TOKEN_MANAGER.isSelected());
        lPreferencias.setOptimizeTokenManager(jCheckBox5OPTIMIZE_TOKEN_MANAGER.isSelected());        
        lPreferencias.setErrorReporting(jCheckBox6ERROR_REPORTING.isSelected());
        lPreferencias.setJavaUnicodeEscape(jCheckBox7JAVA_UNICODE_ESCAPE.isSelected());
        lPreferencias.setIgnoreCase(jCheckBox8IGNORE_CASE.isSelected());
        lPreferencias.setCommonTokenAction(jCheckBox9COMMON_TOKEN_ACTION.isSelected());
        lPreferencias.setunicodeInput(jCheckBox19UNICODE_INPUT.isSelected());
        
        //TextField
         lPreferencias.setLookahed(Integer.parseInt(jTextField1LOOKAHEAD.getText()));
         lPreferencias.setChoiceAmbiguityCheck(Integer.parseInt(jTextField2CHOICE_AMBIGUITY_CHECK.getText()));
         lPreferencias.setOtherAmbiguityCheck(Integer.parseInt(jTextField3OR_AMBIGUITY_CHECK.getText()));
         
         XMLEncoder e;
		try {
			e = new XMLEncoder(new BufferedOutputStream(new FileOutputStream(Editor.get().getCompilacionXML())));
			e.writeObject(lPreferencias);
	        e.close();
		} catch (FileNotFoundException e1) {
			Mensajes.mensajeDetalles("Error al guardar la configuracin", e1);			
		}
		iGui.setPreferenciasCompilacion(lPreferencias);
        this.dispose();
    }                                              



    
    // Variables declaration - do not modify                     
    /** button aceptar. */
    private javax.swing.JButton jButtonAceptar;
    
    /** button cancelar. */
    private javax.swing.JButton jButtonCancelar;
    
    /** button defecto. */
    private javax.swing.JButton jButtonDefecto;
    
    /** check box10 user_ toke n_ manager. */
    private javax.swing.JCheckBox jCheckBox10USER_TOKEN_MANAGER;
    
    /** check box11 user_ cha r_ stream. */
    private javax.swing.JCheckBox jCheckBox11USER_CHAR_STREAM;
    
    /** check box12 build_ parser. */
    private javax.swing.JCheckBox jCheckBox12BUILD_PARSER;
    
    /** check box13 build_ toke n_ manager. */
    private javax.swing.JCheckBox jCheckBox13BUILD_TOKEN_MANAGER;
    
    /** check box14 token_ manage r_ use s_ parser. */
    private javax.swing.JCheckBox jCheckBox14TOKEN_MANAGER_USES_PARSER;
    
    /** check box15 sanity_ check. */
    private javax.swing.JCheckBox jCheckBox15SANITY_CHECK;
    
    /** check box16 force_l a_ check. */
    private javax.swing.JCheckBox jCheckBox16FORCE_LA_CHECK;
    
    /** check box17 cach e_tokens. */
    private javax.swing.JCheckBox jCheckBox17CACHE_TOKENS;
    
    /** check box18 kee p_lin e_ column. */
    private javax.swing.JCheckBox jCheckBox18KEEP_LINE_COLUMN;
    
    /** check box19 unicode_ input. */
    private javax.swing.JCheckBox jCheckBox19UNICODE_INPUT;
    
    /** check box1 static. */
    private javax.swing.JCheckBox jCheckBox1STATIC;
    
    /** check box2 debu g_parser. */
    private javax.swing.JCheckBox jCheckBox2DEBUG_PARSER;
    
    /** check box3 debu g_lookahead. */
    private javax.swing.JCheckBox jCheckBox3DEBUG_LOOKAHEAD;
    
    /** check box4 debu g_toke n_ manager. */
    private javax.swing.JCheckBox jCheckBox4DEBUG_TOKEN_MANAGER;
    
    /** check box5 optimize_ toke n_ manager. */
    private javax.swing.JCheckBox jCheckBox5OPTIMIZE_TOKEN_MANAGER;
    
    /** check box6 error_ reporting. */
    private javax.swing.JCheckBox jCheckBox6ERROR_REPORTING;
    
    /** check box7 java_ unicod e_ escape. */
    private javax.swing.JCheckBox jCheckBox7JAVA_UNICODE_ESCAPE;
    
    /** check box8ignor e_ case. */
    private javax.swing.JCheckBox jCheckBox8IGNORE_CASE;
    
    /** check box9commo n_ toke n_ action. */
    private javax.swing.JCheckBox jCheckBox9COMMON_TOKEN_ACTION;
    
    /** label10 user_ toke n_ manager. */
    private javax.swing.JLabel jLabel10USER_TOKEN_MANAGER;
    
    /** label11 user_ cha r_ stream. */
    private javax.swing.JLabel jLabel11USER_CHAR_STREAM;
    
    /** label12 build_ parser. */
    private javax.swing.JLabel jLabel12BUILD_PARSER;
    
    /** label13 build_ toke n_ manager. */
    private javax.swing.JLabel jLabel13BUILD_TOKEN_MANAGER;
    
    /** label14 token_ manage r_ use s_ parser. */
    private javax.swing.JLabel jLabel14TOKEN_MANAGER_USES_PARSER;
    
    /** label15 sanity_ check. */
    private javax.swing.JLabel jLabel15SANITY_CHECK;
    
    /** label16 force_ l a_ check. */
    private javax.swing.JLabel jLabel16FORCE_LA_CHECK;
    
    /** label17 cache_ tokens. */
    private javax.swing.JLabel jLabel17CACHE_TOKENS;
    
    /** label18 keep_ lin e_ column. */
    private javax.swing.JLabel jLabel18KEEP_LINE_COLUMN;
    
    /** jlabel19 unicode_ input. */
    private javax.swing.JLabel jLabel19UNICODE_INPUT;
    
    /**  jlabel1 lookahead. */
    private javax.swing.JLabel jLabel1LOOKAHEAD;
    
    /**  jlabel1 static. */
    private javax.swing.JLabel jLabel1STATIC;
    
    /**  jlabel2 choic e_ambiguit y_ check. */
    private javax.swing.JLabel jLabel2CHOICE_AMBIGUITY_CHECK;
    
    /**  jlabel2 debu g_parser. */
    private javax.swing.JLabel jLabel2DEBUG_PARSER;
    
    /**  jlabel3 debu g_lookahead. */
    private javax.swing.JLabel jLabel3DEBUG_LOOKAHEAD;
    
    /**  jlabel3 o r_ ambiguit y_ check. */
    private javax.swing.JLabel jLabel3OR_AMBIGUITY_CHECK;
    
    /**  jlabel4 debu g_ toke n_ manager. */
    private javax.swing.JLabel jLabel4DEBUG_TOKEN_MANAGER;
    
    /**  jlabel5 optimiz e_ toke n_ manager. */
    private javax.swing.JLabel jLabel5OPTIMIZE_TOKEN_MANAGER;
    
    /**  jlabel6 erro r_ reporting. */
    private javax.swing.JLabel jLabel6ERROR_REPORTING;
    
    /**  jlabel7 jav a_ unicod e_ escape. */
    private javax.swing.JLabel jLabel7JAVA_UNICODE_ESCAPE;
    
    /**  jlabel8 ignore_ case. */
    private javax.swing.JLabel jLabel8IGNORE_CASE;
    
    /**  jlabel9 commo n_ toke n_ action. */
    private javax.swing.JLabel jLabel9COMMON_TOKEN_ACTION;
    
    /**  jpanel1. */
    private javax.swing.JPanel jPanel1;
    
    /**  jpanel1 check. */
    private javax.swing.JPanel jPanel1Check;
    
    /**  jpanel2 enteros. */
    private javax.swing.JPanel jPanel2Enteros;
    
    /**  jpanel botonera. */
    private javax.swing.JPanel jPanelBotonera;
    
    /**  jtext field1 lookahead. */
    private javax.swing.JTextField jTextField1LOOKAHEAD;
    
    /**  jtext field2 choice_ ambiguit y_ check. */
    private javax.swing.JTextField jTextField2CHOICE_AMBIGUITY_CHECK;
    
    /**  jtext field3 or_ ambiguit y_ check. */
    private javax.swing.JTextField jTextField3OR_AMBIGUITY_CHECK;
    // End of variables declaration                   
    
}
