/*
 * 
 * @author Manuel Parras  
 */
package proyecto.herramientas;

import java.util.ArrayList;

/**
 * PreferenciasCompilacion.
 * 
 * <p>
 * Es una clase que representa las preferencias que nos ha seleccionado el
 * usuario para la compilacin de JavaCC
 * </p>
 * <p>
 * Existen mtodos en esta clase para poder poner los valores por defecto y
 * poder obtenerner los seleccionado por el usuario
 * </p>
 * Los valores de JavaCC por defecto son lo mencionados:
 * <p>
 * Opciones con valores Enteros:
 * <p>
 * <ul>
 * <li>LOOKAHEAD (default 1)</li>
 * <li>CHOICE_AMBIGUITY_CHECK (default 2)</li>
 * <li>OR_AMBIGUITY_CHECK (default 1)</li>
 * </ul>
 * Opciones con valores booleanos:
 * <ul>
 * <li>STATIC (default true)</li>
 * <li>DEBUG_PARSER (default false)</li>
 * <li>DEBUG_LOOKAHEAD (default false)</li>
 * <li>DEBUG_TOKEN_MANAGER (default false)</li>
 * <li>OPTIMIZE_TOKEN_MANAGER (default true)</li>
 * <li>ERROR_REPORTING (default true)</li>
 * <li>JAVA_UNICODE_ESCAPE (default false)</li>
 * <li>UNICODE_INPUT (default false)</li>
 * <li>IGNORE_CASE (default false)</li>
 * <li>COMMON_TOKEN_ACTION (default false)</li>
 * <li>USER_TOKEN_MANAGER (default false)</li>
 * <li>USER_CHAR_STREAM (default false)</li>
 * <li>BUILD_PARSER (default true)</li>
 * <li>BUILD_TOKEN_MANAGER (default true)</li>
 * <li>TOKEN_MANAGER_USES_PARSER (default false)</li>
 * <li>SANITY_CHECK (default true)</li>
 * <li>FORCE_LA_CHECK (default false)</li>
 * <li>CACHE_TOKENS (default false)</li>
 * <li>KEEP_LINE_COLUMN (default true)</li>
 * </ul>
 * 
 * <p>Creado : Parras, 19-jul-2009</p>
 */
public class PreferenciasCompilacion {

    /**  user token manager. */
    private boolean userTokenManager;
    
    /**  user char stream. */
    private boolean userCharStream;
    
    /**  build parser. */
    private boolean buildParser;
    
    /**  build token manager. */
    private boolean buildTokenManager;
    
    /**  token manager uses parser. */
    private boolean tokenManagerUsesParser;
    
    /**  sanity check. */
    private boolean sanityCheck;
    
    /**  force la check. */
    private boolean forceLaCheck;
    
    /**  cache tokens. */
    private boolean cacheTokens;
    
    /**  keep line column. */
    private boolean keepLineColumn;
    
    /**  unicode input. */
    private boolean unicodeInput;
    
    /**  ibstatic. */
    private boolean ibstatic;
    
    /**  debug parser. */
    private boolean debugParser;
    
    /**  debug lookahead. */
    private boolean debugLookahead;
    
    /**  debug token manager. */
    private boolean debugTokenManager;
    
    /**  optimize token manager. */
    private boolean optimizeTokenManager;
    
    /**  error reporting. */
    private boolean errorReporting;
    
    /**  java unicode escape. */
    private boolean javaUnicodeEscape;
    
    /**  ignore case. */
    private boolean ignoreCase;
    
    /**  common token action. */
    private boolean commonTokenAction;   
    
    /**  lookahed. */
    private int lookahed;
    
    /**  choice ambiguity check. */
    private int choiceAmbiguityCheck;
    
    /**  other ambiguity check. */
    private int otherAmbiguityCheck;
    
    
    
    /**
	 * Constructor preferencias compilacion.
	 * 
	 * <p>Creado : Parras, 19-jul-2009</p>
	 */
    public PreferenciasCompilacion(){
    	 
    }
   
   /**
	 * PreferenciasCompilacion.
	 * 
	 * <p>Construtor que no incicializa la variables de instancia con los valores por defecto,
	 *     en otro caso no le asigana ningn valor</p>
	 * 
	 * @param valoresDefecto
	 *             valores defecto
	 *   <p>Creado : Parras, 19-jul-2009</p>
	 */
    
    public PreferenciasCompilacion(boolean valoresDefecto){
    	
    	if (valoresDefecto){
    		userTokenManager=false;
    	    userCharStream=false;
    	    buildParser=true;
    	    buildTokenManager=true;
    	    tokenManagerUsesParser=false;
    	    sanityCheck=true;
    	    forceLaCheck=false;
    	    cacheTokens=false;
    	    keepLineColumn=true;
    	    unicodeInput=false;
    	    ibstatic=true;
    	    debugParser=false;
    	    debugLookahead=false;
    	    debugTokenManager=false;
    	    optimizeTokenManager=true;
    	    errorReporting=true;
    	    javaUnicodeEscape=false;
    	    ignoreCase=false;
    	    commonTokenAction=false;   
    	    lookahed=1;
    	    choiceAmbiguityCheck=2;
    	    otherAmbiguityCheck=1;
    	}
    	
    }
    
    
	/**
	 * Verificamos si es builds  parser.
	 * 
	 * @return true, Si es builds  parser Creado : Parras, 19-jul-2009
	 */
	public boolean isBuildParser() {
		return buildParser;
	}
	
	/**
	 * Modificar la propiedad builds  parser.
	 * 
	 * @param buildParser
	 *            La propiedad builds  parser
	 */
	public void setBuildParser(boolean buildParser) {
		this.buildParser = buildParser;
	}
	
	/**
	 * Verificamos si es builds  token manager.
	 * 
	 * @return true, Si es builds  token manager Creado : Parras, 19-jul-2009
	 */
	public boolean isBuildTokenManager() {
		return buildTokenManager;
	}
	
	/**
	 * Modificar la propiedad builds  token manager.
	 * 
	 * @param buildTokenManager
	 *            La propiedad builds  token manager
	 */
	public void setBuildTokenManager(boolean buildTokenManager) {
		this.buildTokenManager = buildTokenManager;
	}
	
	/**
	 * Verificamos si es cache tokens.
	 * 
	 * @return true, Si es cache tokens Creado : Parras, 19-jul-2009
	 */
	public boolean isCacheTokens() {
		return cacheTokens;
	}
	
	/**
	 * Modificar la propiedad cache tokens.
	 * 
	 * @param cacheTokens
	 *            La propiedad cache tokens
	 */
	public void setCacheTokens(boolean cacheTokens) {
		this.cacheTokens = cacheTokens;
	}
	
	/**
	 * Obtener el choice ambiguity check.
	 * 
	 * @return el choice ambiguity check Creado : Parras, 19-jul-2009
	 */
	public int getChoiceAmbiguityCheck() {
		return choiceAmbiguityCheck;
	}
	
	/**
	 * Modificar la propiedad choice ambiguity check.
	 * 
	 * @param choiceAmbiguityCheck
	 *            La propiedad choice ambiguity check
	 */
	public void setChoiceAmbiguityCheck(int choiceAmbiguityCheck) {
		this.choiceAmbiguityCheck = choiceAmbiguityCheck;
	}
	
	/**
	 * Verificamos si es common token action.
	 * 
	 * @return true, Si es common token action Creado : Parras, 19-jul-2009
	 */
	public boolean isCommonTokenAction() {
		return commonTokenAction;
	}
	
	/**
	 * Modificar la propiedad common token action.
	 * 
	 * @param commonTokenAction
	 *            La propiedad common token action
	 */
	public void setCommonTokenAction(boolean commonTokenAction) {
		this.commonTokenAction = commonTokenAction;
	}
	
	/**
	 * Verificamos si es debug lookahead.
	 * 
	 * @return true, Si es debug lookahead Creado : Parras, 19-jul-2009
	 */
	public boolean isDebugLookahead() {
		return debugLookahead;
	}
	
	/**
	 * Modificar la propiedad debug lookahead.
	 * 
	 * @param debugLookahead
	 *            La propiedad debug lookahead
	 */
	public void setDebugLookahead(boolean debugLookahead) {
		this.debugLookahead = debugLookahead;
	}
	
	/**
	 * Verificamos si es debug parser.
	 * 
	 * @return true, Si es debug parser Creado : Parras, 19-jul-2009
	 */
	public boolean isDebugParser() {
		return debugParser;
	}
	
	/**
	 * Modificar la propiedad debug parser.
	 * 
	 * @param debugParser
	 *            La propiedad debug parser
	 */
	public void setDebugParser(boolean debugParser) {
		this.debugParser = debugParser;
	}
	
	/**
	 * Verificamos si es debug token manager.
	 * 
	 * @return true, Si es debug token manager Creado : Parras, 19-jul-2009
	 */
	public boolean isDebugTokenManager() {
		return debugTokenManager;
	}
	
	/**
	 * Modificar la propiedad debug token manager.
	 * 
	 * @param debugTokenManager
	 *            La propiedad debug token manager
	 */
	public void setDebugTokenManager(boolean debugTokenManager) {
		this.debugTokenManager = debugTokenManager;
	}
	
	/**
	 * Verificamos si es error reporting.
	 * 
	 * @return true, Si es error reporting Creado : Parras, 19-jul-2009
	 */
	public boolean isErrorReporting() {
		return errorReporting;
	}
	
	/**
	 * Modificar la propiedad error reporting.
	 * 
	 * @param errorReporting
	 *            La propiedad error reporting
	 */
	public void setErrorReporting(boolean errorReporting) {
		this.errorReporting = errorReporting;
	}
	
	/**
	 * Verificamos si es force la check.
	 * 
	 * @return true, Si es force la check Creado : Parras, 19-jul-2009
	 */
	public boolean isForceLaCheck() {
		return forceLaCheck;
	}
	
	/**
	 * Modificar la propiedad force la check.
	 * 
	 * @param forceLaCheck
	 *            La propiedad force la check
	 */
	public void setForceLaCheck(boolean forceLaCheck) {
		this.forceLaCheck = forceLaCheck;
	}
	
	/**
	 * Verificamos si es static.
	 * 
	 * @return true, Si es static Creado : Parras, 19-jul-2009
	 */
	public boolean isStatic() {
		return ibstatic;
	}
	
	/**
	 * Modificar la propiedad static.
	 * 
	 * @param ibstatic
	 *            La propiedad static
	 */
	public void setStatic(boolean ibstatic) {
		this.ibstatic = ibstatic;
	}
	
	/**
	 * Verificamos si es ignore case.
	 * 
	 * @return true, Si es ignore case Creado : Parras, 19-jul-2009
	 */
	public boolean isIgnoreCase() {
		return ignoreCase;
	}
	
	/**
	 * Modificar la propiedad ignore case.
	 * 
	 * @param ignoreCase
	 *            La propiedad ignore case
	 */
	public void setIgnoreCase(boolean ignoreCase) {
		this.ignoreCase = ignoreCase;
	}
	
	/**
	 * Verificamos si es java unicode escape.
	 * 
	 * @return true, Si es java unicode escape Creado : Parras, 19-jul-2009
	 */
	public boolean isJavaUnicodeEscape() {
		return javaUnicodeEscape;
	}
	
	/**
	 * Modificar la propiedad java unicode escape.
	 * 
	 * @param javaUnicodeEscape
	 *            La propiedad java unicode escape
	 */
	public void setJavaUnicodeEscape(boolean javaUnicodeEscape) {
		this.javaUnicodeEscape = javaUnicodeEscape;
	}
	
	/**
	 * Verificamos si es keep line column.
	 * 
	 * @return true, Si es keep line column Creado : Parras, 19-jul-2009
	 */
	public boolean isKeepLineColumn() {
		return keepLineColumn;
	}
	
	/**
	 * Modificar la propiedad keep line column.
	 * 
	 * @param keepLineColumn
	 *            La propiedad keep line column
	 */
	public void setKeepLineColumn(boolean keepLineColumn) {
		this.keepLineColumn = keepLineColumn;
	}
	
	/**
	 * Obtener el lookahed.
	 * 
	 * @return el lookahed Creado : Parras, 19-jul-2009
	 */
	public int getLookahed() {
		return lookahed;
	}
	
	/**
	 * Modificar la propiedad lookahed.
	 * 
	 * @param lookahed
	 *            La propiedad lookahed
	 */
	public void setLookahed(int lookahed) {
		this.lookahed = lookahed;
	}
	
	/**
	 * Verificamos si es optimize token manager.
	 * 
	 * @return true, Si es optimize token manager Creado : Parras, 19-jul-2009
	 */
	public boolean isOptimizeTokenManager() {
		return optimizeTokenManager;
	}
	
	/**
	 * Modificar la propiedad optimize token manager.
	 * 
	 * @param optimizeTokenManager
	 *            La propiedad optimize token manager
	 */
	public void setOptimizeTokenManager(boolean optimizeTokenManager) {
		this.optimizeTokenManager = optimizeTokenManager;
	}
	
	/**
	 * Obtener el other ambiguity check.
	 * 
	 * @return el other ambiguity check Creado : Parras, 19-jul-2009
	 */
	public int getOtherAmbiguityCheck() {
		return otherAmbiguityCheck;
	}
	
	/**
	 * Modificar la propiedad other ambiguity check.
	 * 
	 * @param otherAmbiguityCheck
	 *            La propiedad other ambiguity check
	 */
	public void setOtherAmbiguityCheck(int otherAmbiguityCheck) {
		this.otherAmbiguityCheck = otherAmbiguityCheck;
	}
	
	/**
	 * Verificamos si es sanity check.
	 * 
	 * @return true, Si es sanity check Creado : Parras, 19-jul-2009
	 */
	public boolean isSanityCheck() {
		return sanityCheck;
	}
	
	/**
	 * Modificar la propiedad sanity check.
	 * 
	 * @param sanityCheck
	 *            La propiedad sanity check
	 */
	public void setSanityCheck(boolean sanityCheck) {
		this.sanityCheck = sanityCheck;
	}
	
	/**
	 * Verificamos si es token manager uses parser.
	 * 
	 * @return true, Si es token manager uses parser Creado : Parras,
	 *         19-jul-2009
	 */
	public boolean isTokenManagerUsesParser() {
		return tokenManagerUsesParser;
	}
	
	/**
	 * Modificar la propiedad token manager uses parser.
	 * 
	 * @param tokenManagerUsesParser
	 *            La propiedad token manager uses parser
	 */
	public void setTokenManagerUsesParser(boolean tokenManagerUsesParser) {
		this.tokenManagerUsesParser = tokenManagerUsesParser;
	}
	
	/**
	 * Verificamos si es unicode input.
	 * 
	 * @return true, Si es unicode input Creado : Parras, 19-jul-2009
	 */
	public boolean isunicodeInput() {
		return unicodeInput;
	}
	
	/**
	 * Modificar la propiedad unicode input.
	 * 
	 * @param unicodeInput
	 *            La propiedad unicode input
	 */
	public void setunicodeInput(boolean unicodeInput) {
		this.unicodeInput = unicodeInput;
	}
	
	/**
	 * Verificamos si es user char stream.
	 * 
	 * @return true, Si es user char stream Creado : Parras, 19-jul-2009
	 */
	public boolean isUserCharStream() {
		return userCharStream;
	}
	
	/**
	 * Modificar la propiedad user char stream.
	 * 
	 * @param userCharStream
	 *            La propiedad user char stream
	 */
	public void setUserCharStream(boolean userCharStream) {
		this.userCharStream = userCharStream;
	}
	
	/**
	 * Verificamos si es user token manager.
	 * 
	 * @return true, Si es user token manager Creado : Parras, 19-jul-2009
	 */
	public boolean isUserTokenManager() {
		return userTokenManager;
	}
	
	/**
	 * Modificar la propiedad user token manager.
	 * 
	 * @param userTokenManager
	 *            La propiedad user token manager
	 */
	public void setUserTokenManager(boolean userTokenManager) {
		this.userTokenManager = userTokenManager;
	}
	
	/**
	 * getPropiedadesCompilacion
	 * 
	 * Metodo que nos devuelve el ArrayList<String> de String con las
	 * propiedades de compilacin
	 * 
	 * </p>
	 * <p>
	 * Opciones con valores Enteros:
	 * <p>
	 * <ul>
	 * <li>LOOKAHEAD (default 1)</li>
	 * <li>CHOICE_AMBIGUITY_CHECK (default 2)</li>
	 * <li>OR_AMBIGUITY_CHECK (default 1)</li>
	 * </ul>
	 * Opciones con valores booleanos:
	 * <ul>
	 * <li>STATIC (default true)</li>
	 * <li>DEBUG_PARSER (default false)</li>
	 * <li>DEBUG_LOOKAHEAD (default false)</li>
	 * <li>DEBUG_TOKEN_MANAGER (default false)</li>
	 * <li>OPTIMIZE_TOKEN_MANAGER (default true)</li>
	 * <li>ERROR_REPORTING (default true)</li>
	 * <li>JAVA_UNICODE_ESCAPE (default false)</li>
	 * <li>UNICODE_INPUT (default false)</li>
	 * <li>IGNORE_CASE (default false)</li>
	 * <li>COMMON_TOKEN_ACTION (default false)</li>
	 * <li>USER_TOKEN_MANAGER (default false)</li>
	 * <li>USER_CHAR_STREAM (default false)</li>
	 * <li>BUILD_PARSER (default true)</li>
	 * <li>BUILD_TOKEN_MANAGER (default true)</li>
	 * <li>TOKEN_MANAGER_USES_PARSER (default false)</li>
	 * <li>SANITY_CHECK (default true)</li>
	 * <li>FORCE_LA_CHECK (default false)</li>
	 * <li>CACHE_TOKENS (default false)</li>
	 * <li>KEEP_LINE_COLUMN (default true)</li>
	 * </ul>
	 * -debug_parser mygrammar.jj
	 * 
	 * @return propiedades compilacion
	 */
	public ArrayList<String> getPropiedadesCompilacion() {
		ArrayList<String> lpropiedades = new ArrayList <String>();
		
		if (userTokenManager)
			lpropiedades.add("-USER_TOKEN_MANAGER="+userTokenManager);
	    
		if (userCharStream)
			lpropiedades.add("-USER_CHAR_STREAM="+userCharStream);
		
		if (!buildParser)
			lpropiedades.add("-BUILD_PARSER="+buildParser);
		
		if (!buildTokenManager)
			lpropiedades.add("-BUILD_TOKEN_MANAGER="+buildTokenManager);
		
		if (tokenManagerUsesParser)
			lpropiedades.add("-TOKEN_MANAGER_USES_PARSER="+tokenManagerUsesParser);
		
	    
		if (!sanityCheck)
			lpropiedades.add("-SANITY_CHECK="+sanityCheck);
		
		if (forceLaCheck)
			lpropiedades.add("-FORCE_LA_CHECK="+forceLaCheck);
		
		
	    
		if (cacheTokens)
			lpropiedades.add("-CACHE_TOKENS="+cacheTokens);
		
		
		if (!keepLineColumn)
			lpropiedades.add("-KEEP_LINE_COLUMN="+keepLineColumn);	
		
		if (unicodeInput)
			lpropiedades.add("-UNICODE_INPUT="+unicodeInput);		
	    
		if (!ibstatic)
			lpropiedades.add("-STATIC="+ibstatic);		
	    
		if (debugParser)
			lpropiedades.add("-DEBUG_PARSER="+ibstatic);
		
		
		if (debugLookahead)
			lpropiedades.add("-DEBUG_LOOKAHEAD="+debugLookahead);
		
	    
		if (debugTokenManager)
			lpropiedades.add("-DEBUG_TOKEN_MANAGER="+debugTokenManager);
		
	    
	    
	    if (!optimizeTokenManager)
			lpropiedades.add("-OPTIMIZE_TOKEN_MANAGER="+optimizeTokenManager);
		

	    if (!errorReporting)
			lpropiedades.add("-ERROR_REPORTING="+errorReporting);
		
	  
	    
	    
	    if (javaUnicodeEscape)
			lpropiedades.add("-JAVA_UNICODE_ESCAPE="+javaUnicodeEscape);
		
	    
	    
	    if (ignoreCase)
			lpropiedades.add("-IGNORE_CASE="+ignoreCase);
		
	    
	    
	    if (commonTokenAction)
			lpropiedades.add("-COMMON_TOKEN_ACTION="+commonTokenAction);
		
	    
	    
	    if (lookahed!=1)
			lpropiedades.add("-LOOKAHEAD:"+lookahed);
		
	    if (choiceAmbiguityCheck!=2)
			lpropiedades.add("-CHOICE_AMBIGUITY_CHECK:"+choiceAmbiguityCheck);
	    
	    if (otherAmbiguityCheck!=1)
			lpropiedades.add("-OTHER_AMBIGUITY_CHECK:"+otherAmbiguityCheck);
	   
		
		return lpropiedades;
	}
}
