package proyecto.imagenes;


import java.awt.Image;
import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;

import javax.swing.Icon;
import javax.swing.ImageIcon;

import org.apache.log4j.Logger;



/**
 * IconFactory
 * <p>
 * Es la clase que nos coordina la bsqueda de nuestro source de imgenes en el
 * proyecto, ya que en el paquete donde cuelga esta clase tenemos ubicadas todas
 * las iconos y imgenes que engloban a nuestro proyecto.
 * </p>
 * <p>
 * En el caso que no pasemos el nombre de un String no vlido el mtodo nos
 * devolver la imagen por defecto para no producir un error y nos dir que no
 * existe esa imagen en el log.
 * </p>
 * <p><b>Nota:<b>Los nombre de los iconos van en minscula</p>
 * 
 * @author Parras
 * 
 */
public final class IconFactory{

	
	/** The Constant objLogger. */
	private static final Logger objLogger = Logger.getLogger(IconFactory.class);
	
  /**
    * Devuelve una imagen en la ruta relativa al proyecto proyecto/imagenes/+name.
    * @param aNombreImagen El nombre de la imagen (por ejemplo "myfile.gif"  "images/myfile.gif").
    * @return La imagen. Si la imagen no se encuentra devuelve una imagen vaca.
    */
  public static final Icon getImage( String aNombreImagen )
  {
    try
    {
      return new ImageIcon( IconFactory.class.getResource( aNombreImagen.toLowerCase()));
    }
    catch( Throwable e )
    {
	  
      try
      {
    	  if ( objLogger.isDebugEnabled() )
              objLogger.debug("IMAGEN NO ENCONTADA "+ aNombreImagen);
    	  
		return new ImageIcon( IconFactory.class.getResource( "defaultimage.gif") );
      }
      catch( Exception e2 )
      {
    	  if ( objLogger.isDebugEnabled() )
              objLogger.debug("IMAGEN DEFECTO NO ENCONTRADA");
    	  
        return null;
      }
    }
  }

  /**
   * Devuelve una imagen en la ruta relativa al proyecto proyecto/imagenes/+name. Si no existe la ruta del classPath
   * @param aNombreImagen El nombre de la imagen (por ejemplo "myfile.gif").
   * @return File  ruta completa de la imagen.
   */
 public static final File getImagenRuta( String aNombreImagen )
 {
	File lRutaImagen = null;
	 URL lUrl = IconFactory.class.getResource( aNombreImagen.toLowerCase());
	 if (lUrl != null)
		  lRutaImagen = new File (lUrl.getFile());
	else
		  lRutaImagen =   new File (".");
	 
		return lRutaImagen;
	
 }
 
}