/*
 * 
 * @author Manuel Parras  
 */


package proyecto.impresion;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.util.Map;
import java.util.Properties;
import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;

import net.sf.jasperreports.engine.JRDataSource;
import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JRExporterParameter;
import net.sf.jasperreports.engine.JRParameter;
import net.sf.jasperreports.engine.JasperExportManager;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.JasperPrintManager;
import net.sf.jasperreports.engine.JasperReport;
import net.sf.jasperreports.engine.export.JRRtfExporter;
import net.sf.jasperreports.view.JRViewer;
import proyecto.paneles.DatosExportar;


/**
 * Clase que modela los informes.
 * @author Parras
 *
 */
public class EpSilonInforme extends javax.swing.JPanel{

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = -6146558688551604175L;
	
	/**  report. */
	private Informe report  ;
	
	/** isinforme. */
	private String isInforme;
	
	/**  parametros. */
	private Map parametros;
	
	/** The rb. */
	protected ResourceBundle rb;

	/**
	 * Constructor eEpSilonInforme.
	 * 
	 * Creado : Parras, 26-ago-2009
	 */
	public EpSilonInforme(){
		//this.setLayout(new java.awt.BorderLayout());
		try{
			this.setLayout(new java.awt.BorderLayout());
			//this.cambiaLookAndFeel(javax.swing.UIManager.getCrossPlatformLookAndFeelClassName());
			report = new Informe();
			this.add(report, java.awt.BorderLayout.CENTER);
		} catch (Exception e){
			System.out.println(e);
		}
	}

	/**
	 * Modificar la propiedad toolbar visible.
	 * 
	 * @param visible
	 *            La propiedad toolbar visible
	 */
	public void setToolbarVisible(boolean visible){
		if (report != null)
			report.setToolbarVisible(visible);
	}
	
	/**
	 * Verificamos si es toolbar visible.
	 * 
	 * @return true, Si es toolbar visible Creado : Parras, 26-ago-2009
	 */
	public boolean isToolbarVisible(){
		return report.isToolbarVisible();
	}

	/**
	 * Modificar la propiedad resouce bundle.
	 * 
	 * @param traducciones
	 *            La propiedad resouce bundle
	 */
	public void setResouceBundle(ResourceBundle traducciones){
		this.rb = traducciones;
	}

	/**
	 * Modificar la propiedad informe.
	 * 
	 * @param asInforme
	 *            La propiedad informe
	 */
	public void setInforme(String asInforme) {
		this.isInforme = asInforme;
	}
	
	/**
	 * Obtener el informe.
	 * 
	 * @return el informe Creado : Parras, 26-ago-2009
	 */
	public String getInforme(){
		return isInforme;
	}

	/**
	 * Modificar la propiedad de los parametros.
	 * 
	 * @param param
	 *            La propiedad parametros
	 */
	public void setParametros(Map param){
		this.parametros = param;
	}

	/**
	 * Agrega Datasources para realizar subreports. cada valor del array de
	 * String (nombre del parametro) se corresponde con el mismo valor del array
	 * datosSubreports y los agrega como parametros.
	 * 
	 * @param param
	 *            the param
	 * @param datosSubreports
	 *            the datos subreports
	 */
	public void setParametrosSubreport(String[] param, Object[] datosSubreports){
		JRDataSource datasource;
		for(int i=0;i<param.length;i++){
			datasource = new DataSource((Object[])datosSubreports[i]);
			this.parametros.put(param[i],datasource);
		}
	}	

	/**
	 * Carga el informe con el array de datos que le llega teniendo en cuenta
	 * que los campos del mismo deben ser iguales que los metodos getter sin el
	 * prefijo get por ejemplo: getNombre -> el campo debe ser = Nombre.
	 * 
	 * @param datos
	 *            the datos
	 */
	public void cargaDatos(Object datos[]) {
		JRDataSource datasource = new DataSource(datos);
		this.cargaDatos(datos,datasource);
	}


	/**
	 * Carga el informe con el array de datos que le llega teniendo en cuenta
	 * que la relacion entre los campos del mismo y los del objeto de datos se
	 * saca del segundo parametro. En el properties la clave es el nombre del
	 * campo y el valor el metodo getter
	 * 
	 * @param datos
	 *            the datos
	 * @param relacion
	 *            the relacion
	 */
	public void cargaDatos(Object datos[],Properties relacion) {
		JRDataSource datasource = new RelacionDatasource(datos,relacion);
		this.cargaDatos(datos,datasource);
	}


	/**
	 * Carga datos. Creado : Parras, 26-ago-2009
	 * 
	 * @param datos
	 *            the datos
	 * @param datasource
	 *            the datasource
	 */
	private void cargaDatos(Object datos[],JRDataSource datasource) {
		if (isInforme != null) {
			if (report != null)
				this.remove(report);
			try{
				String lsLookEsiap =  javax.swing.UIManager.getLookAndFeel().getClass().getName();
				this.cambiaLookAndFeel(javax.swing.UIManager.getCrossPlatformLookAndFeelClassName());

				java.io.InputStream is = EpSilonInforme.class.getResourceAsStream(isInforme );
				JasperReport jasperReport = (JasperReport)net.sf.jasperreports.engine.util.JRLoader.loadObject(is);
				if (rb == null){ 
					java.io.InputStream stream = EpSilonInforme.class.getResourceAsStream("/proyecto/informe/informe.properties");
					rb = new PropertyResourceBundle(stream);
				}

				parametros.put(JRParameter.REPORT_RESOURCE_BUNDLE,rb);
				JasperPrint print = net.sf.jasperreports.engine.JasperFillManager.fillReport(jasperReport, parametros, datasource);
				report = new Informe(print);


				this.add(report, java.awt.BorderLayout.CENTER);
				this.updateUI();
				this.cambiaLookAndFeel(lsLookEsiap);
			} catch (Exception e){
				System.out.println(e);
			}
		}
	}

	/**
	 * Cambia look and feel. Creado : Parras, 26-ago-2009
	 * 
	 * @param asLookAndFeel
	 *            the as look and feel
	 */
	protected void cambiaLookAndFeel(String asLookAndFeel){
		try {
			javax.swing.UIManager.setLookAndFeel(asLookAndFeel);
		}
		catch (Throwable le) {
			System.out.println(le);
		}
	}

	/**
	 * Imprime. Creado : Parras, 26-ago-2009
	 */
	public void imprime(){
		report.imprime();
	}

	/**
	 * Imprime. Creado : Parras, 26-ago-2009
	 * 
	 * @param aDatos
	 *            the a datos
	 */
	public void imprime(DatosExportar aDatos){
		report.imprime(aDatos);
	}

	/**
	 * Obtener el numero paginas.
	 * 
	 * @return el numero paginas Creado : Parras, 26-ago-2009
	 */
	public int getNumeroPaginas(){
		if (report!=null){
			return report.getJasperPrint().getPages().size();
		}else{
			return 0;
		}
	}
}



class Informe extends JRViewer{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	//La referencia que guarda el padre
	//es privada. La creamos para tener
	//acceso al informe
	private JasperPrint print;
	/** Creates a new instance of NFCReport */
	public Informe() throws JRException{
		this(null);
		ActionListener[] laListeners = this.btnPrint.getActionListeners();
		if (laListeners!=null){
			for (int i=0;i<laListeners.length;i++){
				btnPrint.removeActionListener(laListeners[i]);
			}
		}
		btnPrint.addActionListener(new java.awt.event.ActionListener(){
			public void actionPerformed(ActionEvent evt){
				imprime();
			}
		});


	}


	public Informe(JasperPrint print) throws JRException{
		super(print);
		this.print = print;
		ActionListener[] laListeners = this.btnPrint.getActionListeners();
		if (laListeners!=null){
			for (int i=0;i<laListeners.length;i++){
				btnPrint.removeActionListener(laListeners[i]);
			}
		}
		btnPrint.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent evt){
				imprime();
			}
		});


	}

	public JasperPrint getJasperPrint(){
		return print;
	}

	public void setToolbarVisible(boolean visible){
		this.tlbToolBar.setVisible(visible);
	}
	public boolean isToolbarVisible(){
		return this.tlbToolBar.isVisible();
	}

	public void imprime(){
		Thread thread =
			new Thread(
					new Runnable() {
						public void run() {
							try {
								boolean ibMostrarDialogoImpresion=false;
								String os= System.getProperty("os.name");
								if (os != null){
									if ( os.startsWith("Windows")){
										ibMostrarDialogoImpresion=true;
									}
								}

								JasperPrintManager.printReport(print, ibMostrarDialogoImpresion); 
								//JasperPrintManager.(print);
//								JasperExportManager.exportReportToPdfFile(print, "C:\\pruebasEpsilon\\pruebaEpsilon.pdf");
//								JasperExportManager.exportReportToHtmlFile(print, "C:\\pruebasEpsilon\\pruebaEpsilon.html");
//								JasperExportManager.exportReportToXmlFile(print, "C:\\pruebasEpsilon\\pruebaEpsilon.xml",true);

//								JRRtfExporter exporter = new JRRtfExporter();
//								exporter.setParameter(JRExporterParameter.JASPER_PRINT, print);
//								exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME, "C:\\pruebasEpsilon\\pruebaEpsilon.rtf");
//								exporter.exportReport();


							}
							catch (Exception ex) {
								ex.printStackTrace();
								javax.swing.JOptionPane.showMessageDialog(null, java.util.ResourceBundle.getBundle("net/sf/jasperreports/view/viewer").getString("error.printing"));
							}
						}
					}
			);

		thread.start();
	}

	public void imprime(DatosExportar aDatos){
		ThreadImpresion thread =new ThreadImpresion(aDatos);	

		thread.start();
	}

	class ThreadImpresion extends Thread{

		DatosExportar iDatosExportar;
		public  ThreadImpresion(DatosExportar aDatos){
			iDatosExportar=aDatos;
		}
		@Override
		public void run() {          
			try {
				boolean lbMostrarDialogoImpresion=false;
				String os= System.getProperty("os.name");
				if (os != null){
					if ( os.startsWith("Windows")){
						lbMostrarDialogoImpresion=true;
					}
				}				    					
				//JasperPrintManager.printReport(print, ibMostrarDialogoImpresion); 
				//JasperPrintManager.(print);
				
				//hay que montar la ruta de esta forma 
				//"C:\\pruebasEpsilon\\pruebaEpsilon.xml"

				if (iDatosExportar.isPDF())
					JasperExportManager.exportReportToPdfFile(print, iDatosExportar.getRutaExportar().toString()+ File.separator +iDatosExportar.getNombreExportar()+".pdf");

				if (iDatosExportar.isHTML())
					JasperExportManager.exportReportToHtmlFile(print,iDatosExportar.getRutaExportar().toString() + File.separator +iDatosExportar.getNombreExportar()+".html");

				if (iDatosExportar.isXML())
					JasperExportManager.exportReportToXmlFile(print, iDatosExportar.getRutaExportar().toString()+ File.separator +iDatosExportar.getNombreExportar()+".xml",true);

				if (iDatosExportar.isRTF()){
					JRRtfExporter exporter = new JRRtfExporter();
					exporter.setParameter(JRExporterParameter.JASPER_PRINT, print);
					exporter.setParameter(JRExporterParameter.OUTPUT_FILE_NAME, iDatosExportar.getRutaExportar().toString()+  File.separator +iDatosExportar.getNombreExportar()+".rtf");
					exporter.exportReport();
				}


			}
			catch (Exception ex) {
				ex.printStackTrace();
				javax.swing.JOptionPane.showMessageDialog(null, java.util.ResourceBundle.getBundle("net/sf/jasperreports/view/viewer").getString("error.printing"));
			}
		}

	}

//	private void btnPrintActionPerformed(java.awt.event.ActionEvent evt)
//	{

//	this.imprime();
//	}


}

class DataSource implements net.sf.jasperreports.engine.JRDataSource  {

	int row = -1;

	Object datos[];

	/** Creates a new instance of JRCVSDataSource */
	public DataSource(Object datos[]) {

		this.datos = datos;
	}

	public Object getFieldValue(net.sf.jasperreports.engine.JRField jRField) throws net.sf.jasperreports.engine.JRException {

		if  ((datos == null) ||(datos[row] == null))
			return null;

		//Buscamos por reflexion el dato que nos ha llegado
		String field = jRField.getName();
		//Buscamos en el objeto de datos la columna que corresponde

		String  lsMetodo = new StringBuffer("get").append(field).toString();

		java.lang.Class lc = datos[row].getClass();
		java.lang.reflect.Method lm = null;
		try{
			lm = lc.getMethod(lsMetodo,null);
			return lm.invoke(datos[row],null);
		} catch (Throwable lth){
			//Si el getMethod falla pasamos la primera letra a mayuscula
			//por si el report se ha dise�ado con el JavaBean Datasource
			try{

				lsMetodo = new StringBuffer("get").append(Character.toUpperCase(field.charAt(0)))
				.append(field.substring(1, field.length())).toString() ;
				lm = lc.getMethod(lsMetodo,null);
				return lm.invoke(datos[row],null);
			} catch (Throwable lth2){
				System.out.println(lth);
				return null;
			}
		}
	}

	public boolean next() throws net.sf.jasperreports.engine.JRException {
		if  ( (datos != null) && (row < datos.length -1)){
			row ++;
			return true;
		}else
			return false;
	}
}

class RelacionDatasource extends DataSource{
	java.util.Properties relacion;
	public RelacionDatasource(Object datos[], Properties relacion){
		super(datos);
		this.relacion = relacion;
	}

	public Object getFieldValue(net.sf.jasperreports.engine.JRField jRField) throws net.sf.jasperreports.engine.JRException {

		if  ((datos == null) ||(datos[row] == null))
			return null;

		//Buscamos por reflexion el dato que nos ha llegado
		String field = jRField.getName();
		//Buscamos en el objeto de datos la columna que corresponde

		String getter = (String)relacion.get(field);

		java.lang.Class lc = datos[row].getClass();
		java.lang.reflect.Method lm = null;
		try{
			lm = lc.getMethod(getter,null);
			return lm.invoke(datos[row],null);
		} catch (Throwable lth){
			//Si el getMethod falla pasamos la primera letra a mayuscula
			//por si el report se ha dise�ado con el JavaBean Datasource
			System.out.println(lth);
			return null;
		}
	}

}

