/*
 * 
 * @author Manuel Parras  
 */

package proyecto.paneles;

import java.io.File;

/**
 * Clase DatosExportar.
 * 
 * Clase DatosExportar. Es la clase encargada de generar un objeto con los datos
 * que vamos a exportar.<br>
 * Actualmente vamos a exportar en los siguientes tipos:
 * <ul>
 * <li>RTF: Rich Text Format o RTF</li>
 * <li>HTML: HyperText Markup Language</li>
 * <li>PDF: Portable Document Format</li>
 * <li>XML: Extensible Markup Language</li>
 * </ul>
 * 
 * Debemos elegir el directorio en el que vamos a exportar. Para aadir una
 * nuevo formato dependemos de la herramienta iReport.
 * 
 * 
 * @author mparras
 */
public class DatosExportar {

/** Propiedad que indica si se va a importar rtf. */
private boolean ibRTF=false;

/** Propiedad que indica si se va a importar xml. */
private boolean ibXML=false;

/** Propiedad que indica si se va a importar html. */
private boolean ibHTML=false;

/** Propiedad que indica si se va a importar pdf. */
private boolean ibPDF=false;

/** Propiedad que indica la ruta donde exportar. */
private File iFRutaExportar;

/** Nombre de fichero al que vamos a exportar exportar. */
private String iSNombreExportar;
//ibRTF ibPDF ibXML ibHTML

   /**
 * Instantiates a new datos exportar.
 */
public DatosExportar(){
       
   }
   
  
   
   /**
	 * Constructor datos exportar.
	 * 
	 * Creado : Parras, 06-abr-2009
	 * 
	 * @param aRTF
	 *            the a rtf
	 * @param aPDF
	 *            the a pdf
	 * @param aXML
	 *            the a xml
	 * @param aHTML
	 *            the a html
	 * @param aFRutaExportar
	 *            the a f ruta exportar
	 */
   public DatosExportar(boolean aRTF,boolean aPDF,boolean aXML,boolean aHTML,File aFRutaExportar){
    
       ibRTF=aRTF;
       ibPDF=aPDF;
       ibXML=aXML;
       ibHTML=aHTML;
       iFRutaExportar=aFRutaExportar;
   }
    
    
    /**
	 * Verificamos si es rTF.
	 * 
	 * @return true, Si es rTF
	 */
    public boolean isRTF() {
        return ibRTF;
    }

    
    /**
	 * Modificar la propiedad rTF.
	 * 
	 * @param abRTF
	 *            La propiedad rTF
	 */
    public void setRTF(boolean abRTF) {
        this.ibRTF = abRTF;
    }

    /**
	 * Verificamos si es xML.
	 * 
	 * @return true, Si es xML
	 */
    public boolean isXML() {
        return ibXML;
    }


    /**
	 * Modificar la propiedad xML.
	 * 
	 * @param abXML
	 *            La propiedad xML
	 */
    public void setXML(boolean abXML) {
        this.ibXML = abXML;
    }

    
    /**
	 * Verificamos si es hTML.
	 * 
	 * @return true, Si es hTML
	 */
    public boolean isHTML() {
        return ibHTML;
    }

    
    /**
	 * Modificar la propiedad hTML.
	 * 
	 * @param abHTML
	 *            La propiedad hTML
	 */
    public void setHTML(boolean abHTML) {
        this.ibHTML = abHTML;
    }

    
    /**
	 * Verificamos si es pDF.
	 * 
	 * @return true, Si es pDF
	 */
    public boolean isPDF() {
        return ibPDF;
    }

    
    /**
	 * Modifica la propiedad a exportar a pdf.
	 * 
	 * @param abPDF
	 *            the ab pdf
	 */
    public void setPDF(boolean abPDF) {
        this.ibPDF = abPDF;
    }

    
    /**
	 * Obtener el ruta a exportar.
	 * 
	 * @return el ruta exportar
	 */
    public File getRutaExportar() {
        return iFRutaExportar;
    }

  
    /**
	 * Modificar la propiedad ruta exportar.
	 * 
	 * @param aFRutaExportar
	 *            La propiedad ruta exportar
	 */
    public void setRutaExportar(File aFRutaExportar) {
        this.iFRutaExportar = aFRutaExportar;
    }
    
    
    /**
	 * Verificamos si es valido.
	 * 
	 * @return true, Si es valido
	 */
    public boolean isValido(){
        return (iFRutaExportar!=null) && (ibRTF || ibPDF || ibXML || ibHTML);
    }

	
	/**
	 * Obtener el nombre a exportar.
	 * 
	 * @return el nombre exportar
	 */
	public String getNombreExportar() {
		return iSNombreExportar;
	}
	
	/**
	 * Es el nombre con el que saldr nuestro ficheros a la hora de ser
	 * Exportadas.
	 * 
	 * @param aSNombreExportar
	 *            the a s nombre exportar
	 */
	public void setNombreExportar(String aSNombreExportar) {
		iSNombreExportar = aSNombreExportar;
	}
	
	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	public String toString(){
		return " RTF:"+ibRTF + " PDF:"+ibPDF+ " XML:"+ ibXML + " HTML:"+ibHTML;
	}
	
}
