/*
 * 
 * @author Manuel Parras  
 */

package proyecto.paneles;


import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.io.File;
import javax.swing.JFileChooser;
import org.apache.log4j.Logger;
import proyecto.imagenes.IconFactory;
import proyecto.utilidades.OperacionesVentanas;

/**
 * ExportacionesPanel
 * 
 * <p>
 * Este panel es el encargado de exportar el fichero fuente seleccionado, es
 * decir, el que est activo en ese momento en nuestro tab de la aplicacin. El
 * formato ser el que tiene en nuestro entorno, es decir con su sangrado y
 * coloreado.</p>
 * <p> El fichero podr ser exportado a los siguientes formatos : </p>
 * <ul>
 * <li>RTF: Rich Text Format o RTF</li>
 * <li>HTML: HyperText Markup Language</li>
 * <li>PDF: Portable Document Format</li>
 * <li>XML: Extensible Markup Language</li>
 * </ul>
 * <p> Las opciones de exportar sern seleccionados por el usuario, la cuales, sern
 * marcadas en los checks que se muestran en el panel. Por lo menos necesita una
 * seleccin para que se habilite el procedimiento(validaciones()).</p>
 * <p> La exportacin requiere un path donde volcar los fichero exportados, para
 * ello tan solo debemos examinar y se no abrir en JFileChooser en modo
 * directorio.</p>
 * <p> Esta clase nos genera un objeto del tipo DatosExportar el cual se le pasar
 * al report para la Exportacin, toda la comunicacin la realiza mtodo
 * exportar(DatosExportar).</p>
 * 
 * @see proyecto.editor.PanelEdicion#exportar
 * @see proyecto.paneles.DatosExportar
 * @see javax.swing.JFileChooser 
 * @author mparras
 */
public class ExportacionesPanel extends java.awt.Dialog implements
		MouseListener {

	/**
	 * 
	 */
	private static final long serialVersionUID = 40607922550317935L;

	/** The Constant objLogger. */
	private static final Logger objLogger = Logger
			.getLogger(ExportacionesPanel.class);

	/**
	 * <p>
	 * El directorio seleccionado donde se procedera a la exportacin.<p/
	 * <p>
	 * Esta direccin es el path del directorio, el nombre del fichero vendr
	 * definido por el tab activo
	 * </p>
	 */
	private File iFDirectorioSeleccionado;

	/** @see proyecto.paneles.DatosExportar */
	private DatosExportar iDatosExportar;

	/**
	 * 
	 * Constructor de ExportacionesPanel.
	 * <p>
	 * Activa los listeners de la ventana y le da un size a la ventana
	 * </p>
	 * 
	 * @param parent
	 *            Ventana padre
	 * @param modal
	 */
	public ExportacionesPanel(java.awt.Frame parent, boolean modal) {
		super(parent, modal);
		initComponents();
		jAceptar.setEnabled(false);
		this.pack();
		this.setSize(650, 409);
		OperacionesVentanas.centraVentanaHija(this);

		jExaminar.addMouseListener(this);
		jCheckBoxHTML.addMouseListener(this);
		jCheckBoxPDF.addMouseListener(this);
		jCheckBoxRTF.addMouseListener(this);
		jCheckBoxXML.addMouseListener(this);

	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// <editor-fold defaultstate="collapsed"
	// desc="Generated Code">//GEN-BEGIN:initComponents
	private void initComponents() {
		java.awt.GridBagConstraints gridBagConstraints;

		jPanel1 = new javax.swing.JPanel();
		jPanelCheck = new javax.swing.JPanel();
		jCheckBoxPDF = new javax.swing.JCheckBox();
		jCheckBoxRTF = new javax.swing.JCheckBox();
		jCheckBoxHTML = new javax.swing.JCheckBox();
		jCheckBoxXML = new javax.swing.JCheckBox();
		jLabelHTML = new javax.swing.JLabel();
		jLabelPDF = new javax.swing.JLabel();
		jLabelRTF = new javax.swing.JLabel();
		jLabelXML = new javax.swing.JLabel();
		jTextField1 = new javax.swing.JTextField();
		jExaminar = new javax.swing.JButton();
		jPanelBotonera = new javax.swing.JPanel();
		jAceptar = new javax.swing.JButton();
		jCancelar = new javax.swing.JButton();

		setTitle("Exportaciones");
		addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent evt) {
				closeDialog(evt);
			}
		});

		jPanel1.setMinimumSize(new java.awt.Dimension(215, 224));
		jPanel1.setPreferredSize(new java.awt.Dimension(215, 224));
		jPanel1.setLayout(new java.awt.GridBagLayout());

		jPanelCheck.setBorder(javax.swing.BorderFactory
				.createTitledBorder("Opciones"));
		jPanelCheck.setLayout(new java.awt.GridBagLayout());

		jCheckBoxPDF.setToolTipText("Exportacin a PDF");
		jCheckBoxPDF.setBorder(javax.swing.BorderFactory.createEmptyBorder(0,
				0, 0, 0));
		jCheckBoxPDF.setMargin(new java.awt.Insets(0, 0, 0, 0));
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 0;
		//gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
		jPanelCheck.add(jCheckBoxPDF, gridBagConstraints);

		jCheckBoxRTF.setToolTipText("Exportacin a RTF");
		jCheckBoxRTF.setBorder(javax.swing.BorderFactory.createEmptyBorder(0,
				0, 0, 0));
		jCheckBoxRTF.setMargin(new java.awt.Insets(0, 0, 0, 0));
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 3;
		gridBagConstraints.gridy = 0;
		//gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
		jPanelCheck.add(jCheckBoxRTF, gridBagConstraints);

		jCheckBoxHTML.setToolTipText("Exportacin a HTML");
		jCheckBoxHTML.setBorder(javax.swing.BorderFactory.createEmptyBorder(0,
				0, 0, 0));
		jCheckBoxHTML.setMargin(new java.awt.Insets(0, 0, 0, 0));
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 1;
		//gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
		jPanelCheck.add(jCheckBoxHTML, gridBagConstraints);

		jCheckBoxXML.setToolTipText("Exportacin a XML");
		jCheckBoxXML.setBorder(javax.swing.BorderFactory.createEmptyBorder(0,
				0, 0, 0));
		jCheckBoxXML.setMargin(new java.awt.Insets(0, 0, 0, 0));
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 3;
		gridBagConstraints.gridy = 1;
		//gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
		jPanelCheck.add(jCheckBoxXML, gridBagConstraints);

		jLabelHTML.setIcon(IconFactory.getImage("html.png"));
		jLabelHTML.setText("HTML");
		jLabelHTML.setToolTipText("Exportacin a HTML");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 4);
		jPanelCheck.add(jLabelHTML, gridBagConstraints);

		jLabelPDF.setIcon(IconFactory.getImage("pdf.png"));
		jLabelPDF.setText("PDF");
		jLabelPDF.setToolTipText("Exportacin a PDF");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 4);
		jPanelCheck.add(jLabelPDF, gridBagConstraints);

		jLabelRTF.setIcon(IconFactory.getImage("rtf.png"));
		jLabelRTF.setText("RTF");
		jLabelRTF.setToolTipText("Exportacin a RTF");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 2;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 4);
		jPanelCheck.add(jLabelRTF, gridBagConstraints);

		jLabelXML.setIcon(IconFactory.getImage("xml.png"));
		jLabelXML.setText("XML");
		jLabelXML.setToolTipText("Exportacin a XML");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 2;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 4);
		jPanelCheck.add(jLabelXML, gridBagConstraints);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.gridwidth = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.weightx = 1.0;
		gridBagConstraints.weighty = 1.0;
		gridBagConstraints.insets = new java.awt.Insets(3, 2, 3, 4);
		jPanel1.add(jPanelCheck, gridBagConstraints);

		jTextField1.setEditable(false);
		jTextField1.setToolTipText("Ruta a exportar");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.weightx = 1.0;
		gridBagConstraints.insets = new java.awt.Insets(3, 2, 3, 4);
		jPanel1.add(jTextField1, gridBagConstraints);

		jExaminar.setMnemonic('E');
		jExaminar.setText("Examinar");
		jExaminar.setToolTipText("Seleccionar el directorio a exportar");
		jExaminar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jExaminarActionPerformed(evt);
			}
		});
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(3, 2, 3, 4);
		jPanel1.add(jExaminar, gridBagConstraints);

		jAceptar.setMnemonic('A');
		jAceptar.setText("Aceptar");
		jAceptar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jAceptarActionPerformed(evt);
			}
		});
		jPanelBotonera.add(jAceptar);

		jCancelar.setMnemonic('C');
		jCancelar.setText("Cancelar");
		jCancelar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jCancelarActionPerformed(evt);
			}
		});
		jPanelBotonera.add(jCancelar);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.gridwidth = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.weightx = 1.0;
		gridBagConstraints.insets = new java.awt.Insets(3, 2, 3, 4);
		jPanel1.add(jPanelBotonera, gridBagConstraints);

		add(jPanel1, java.awt.BorderLayout.CENTER);

		pack();
	}// </editor-fold>//GEN-END:initComponents

	/**
	 * Elimnina nuestra ventana, no verifica si ha cambios
	 * 
	 * @param evt
	 *            evento recibido del botn cancelar
	 */
	private void jCancelarActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jCancelarActionPerformed

		dispose();
		System.out.print("Exportaciones Panel " + this.getSize());
	}// GEN-LAST:event_jCancelarActionPerformed

	/**
	 * <p>
	 * Metodo que abre el file chooser para seleccionar el directorio donde
	 * vamos a mandar los datos seleccionados al exportar
	 * </p>
	 * 
	 * @param evt
	 *            evento recibido del botn Examinar
	 */
	private void jExaminarActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jExaminarActionPerformed
		// Botn Examinar abrir� nuestro FileChooser
		JFileChooser fileChooser;
		if (iFDirectorioSeleccionado == null)
			fileChooser = new JFileChooser(".");
		else
			fileChooser = new JFileChooser(iFDirectorioSeleccionado);

		fileChooser.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		int estado = fileChooser.showOpenDialog(null);
		if (estado == JFileChooser.APPROVE_OPTION) {
			iFDirectorioSeleccionado = fileChooser.getSelectedFile();
			if (!iFDirectorioSeleccionado.exists()){
				iFDirectorioSeleccionado.mkdirs();
				if (objLogger.isDebugEnabled())
					objLogger.debug("Directorio para Exportacin no existe=> Se Crea: " + iFDirectorioSeleccionado );
			}
			
			jTextField1.setText(iFDirectorioSeleccionado.toString());
			jTextField1.setToolTipText(iFDirectorioSeleccionado.toString());
		} else {
			jTextField1.setText("");
			jTextField1.setToolTipText("");
		}

		if (validaciones())
			jAceptar.setEnabled(true);
		else
			jAceptar.setEnabled(false);

	}// GEN-LAST:event_jExaminarActionPerformed

	/**
	 * Nos dice si esta selecionada una opcion a exportar
	 */
	private boolean validaciones() {
		return !jTextField1.getText().equals("")
				&& (jCheckBoxHTML.isSelected() || jCheckBoxPDF.isSelected()
						|| jCheckBoxRTF.isSelected() || jCheckBoxXML
						.isSelected());
	}

	/** Closes the dialog */
	private void closeDialog(java.awt.event.WindowEvent evt) {// GEN-FIRST:event_closeDialog
		setVisible(false);
		dispose();
	}// GEN-LAST:event_closeDialog

	private void jAceptarActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jAceptarActionPerformed
		// Nuestra variable de retorno

		setDatosExportar(new DatosExportar(jCheckBoxRTF.isSelected(),
				jCheckBoxPDF.isSelected(), jCheckBoxXML.isSelected(),
				jCheckBoxHTML.isSelected(), iFDirectorioSeleccionado));
		if (objLogger.isDebugEnabled())
			objLogger
					.debug("Datos A Exportar " + getDatosExportar().toString());

		dispose();
	}// GEN-LAST:event_jAceptarActionPerformed

	public void mouseClicked(MouseEvent e) {
		if (validaciones())
			jAceptar.setEnabled(true);
		else
			jAceptar.setEnabled(false);

	}

	public DatosExportar getDatosExportar() {
		return iDatosExportar;
	}

	/**
	 * Modificar la propiedad datos exportar.
	 * 
	 * @param iDatosExportar
	 *            La propiedad datos exportar
	 */
	public void setDatosExportar(DatosExportar iDatosExportar) {
		this.iDatosExportar = iDatosExportar;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseListener#mousePressed(java.awt.event.MouseEvent)
	 */
	public void mousePressed(MouseEvent e) {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.MouseListener#mouseReleased(java.awt.event.MouseEvent)
	 */
	public void mouseReleased(MouseEvent e) {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseListener#mouseEntered(java.awt.event.MouseEvent)
	 */
	public void mouseEntered(MouseEvent e) {
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseListener#mouseExited(java.awt.event.MouseEvent)
	 */
	public void mouseExited(MouseEvent e) {
	}

	/**
	 * The main method.
	 * 
	 * @param args
	 *            the command line arguments
	 */
	public static void main(String args[]) {
		java.awt.EventQueue.invokeLater(new Runnable() {
			public void run() {
				new ExportacionesPanel(new java.awt.Frame(), true)
						.setVisible(true);
			}
		});
	}

	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** Opciones que genera la ventana */

	private javax.swing.JButton jAceptar;
	private javax.swing.JButton jCancelar;
	private javax.swing.JCheckBox jCheckBoxHTML;
	private javax.swing.JCheckBox jCheckBoxPDF;
	private javax.swing.JCheckBox jCheckBoxRTF;
	private javax.swing.JCheckBox jCheckBoxXML;
	private javax.swing.JButton jExaminar;
	private javax.swing.JLabel jLabelHTML;
	private javax.swing.JLabel jLabelXML;
	private javax.swing.JLabel jLabelPDF;
	private javax.swing.JLabel jLabelRTF;
	private javax.swing.JPanel jPanel1;
	private javax.swing.JPanel jPanelBotonera;
	private javax.swing.JPanel jPanelCheck;
	private javax.swing.JTextField jTextField1;
	// End of variables declaration//GEN-END:variables

}
