/*
 * 
 * @author Manuel Parras  
 */

package proyecto.paneles;

import java.awt.Component;
import java.awt.Dimension;
import java.io.File;
import java.util.ArrayList;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;
import javax.swing.event.CaretEvent;
import javax.swing.event.CaretListener;
import proyecto.arbol.PaqueteActivos;
import proyecto.imagenes.IconFactory;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.OperacionesVentanas;
import proyecto.herramientas.JTextFieldLimit;

/**
 * NuevoVentana
 * <p>
 * Esta ventana es la encargada de generar nuevos ficheros (java o JavaCC) y
 * carpetas en nuestro proyecto. Para hacer esto tangible debemos rellenar todos
 * los campos que nos muestra en el diseo de la ventana. Los campos a rellanar
 * son:
 * </p>
 * <ul>
 * <li>Nombre: Nombre de fichero (este fichero ser vlido por nuestro
 * JTextFieldLimit)</li>
 * <li>Paquete: Debemos seleccionar un paquete donde colgaremos nuestro fichero
 * o Carpeta en nuestro proyecto.</li>
 * <li>Tipos de ficheros: Los fichero que se permite crear en nuestra ventana
 * son:
 * <ul>
 * <li>Fichero JavaCC: Crea un fichero con la extensin .jj.</li>
 * <li>Fichero Java: Crea un fichero con la extensin .java.</li>
 * <li>Carpeta: Crea una carpeta</li>
 * </ul>
 * </ul>
 * <p>
 * Esta opcin de nuevo la vamos hacer accesible desde la barra de
 * herramientas de la aplicacin y desde el men de archivo.
 * </p>
 * <p>
 * Una vez rellenado todos los campos, al aceptar se estudiarn problemas como
 * mismo nombre fichero o problemas de escritura en nuestro mquina local.
 * </p>
 * 
 * <p>Creado : Parras, 13-sep-2009</p>
 * @see proyecto.arbol.PaqueteActivos
 * @see proyecto.paneles.SeleccionPaqueteDialogo
 * @see proyecto.herramientas.JTextFieldLimit
 * @see javax.swing.JDialog
 */
public class NuevoVentana extends javax.swing.JDialog {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	/** The Constant ELEMENTO_VACIO. */
	private static final int ELEMENTO_VACIO = -1;

	/** The Constant JAVACC_EXTENSION. */
	private static final int JAVACC_EXTENSION = 1;

	/** The Constant JAVA_EXTENSION. */
	private static final int JAVA_EXTENSION = 2;

	/** The Constant CARPETA_EXTENSION. */
	private static final int CARPETA_EXTENSION = 3;

	/**
	 * @see proyecto.arbol.PaqueteActivos
	 */
	PaqueteActivos[] iPaquetes;

	/**
	 * Nodo seleccionado en la ventana.
	 * 
	 * @see proyecto.arbol.PaqueteActivos
	 */
	private PaqueteActivos ipaqueteNodoSelecionado;

	/**
	 * Si se desea crear un nuevo paquete en el proyecto.
	 * 
	 * @see proyecto.arbol.PaqueteActivos
	 */
	private PaqueteActivos iPaqueteNuevo;

	/**
	 * Constructor nuevo ventana.
	 * 
	 * Creado : Parras, 13-sep-2009
	 * 
	 * @param parent
	 *            frame padre
	 * @param modal
	 *            modal
	 * @param aPaquetes
	 *            Lista de paquetes en nuestro proyecto
	 * 
	 *@see proyecto.arbol.PaqueteActivos
	 */
	public NuevoVentana(java.awt.Frame parent, boolean modal,
			ArrayList<PaqueteActivos> aPaquetes) {
		super(parent, modal);
		initComponents();
		//habilitamos al jTextField para el uso de un documento reconocedor de ficheros
		jTextFieldFieldNombreFichero.setDocument(new JTextFieldLimit(JTextFieldLimit.SIN_LIMITE_DE_CARACTERES,JTextFieldLimit.MODO_RECONOCEDOR_FICHEROS));
		iPaquetes = (aPaquetes == null) ? null : (PaqueteActivos[]) aPaquetes
				.toArray(new PaqueteActivos[aPaquetes.size()]);
		// System.out.print("NuevaVenta: "+iPaquetes);
		this.pack();
		this.setMinimumSize(new Dimension(455, 236));
		this.setResizable(false);
		OperacionesVentanas.centraVentanaHija(this);
		// jTextFieldRutaCompleta.setVisible(false);
	}

	/*
	 * Metodo que nos devuelve las extensiones permitidas por EPSIOLON
	 */

	/**
	 * Obtener el tipo extension.
	 * 
	 * @param aiExtension
	 *            the ai extension
	 * 
	 * @return el tipo extension
	 *         <p>
	 *         Creado : Parras, 13-sep-2009
	 *         </p>
	 */
	public static String getTipoExtension(int aiExtension) {
		String lsExtension = "";

		if (JAVA_EXTENSION == aiExtension)
			lsExtension = ".java";
		if (JAVACC_EXTENSION == aiExtension)
			lsExtension = ".jj";
		if (CARPETA_EXTENSION == aiExtension)
			lsExtension = "";
		System.out.print("la Extension que se de salida es: " + lsExtension
				+ " " + aiExtension);

		return lsExtension;
	}

	/**
	 * Inits the components.
	 * <p>
	 * Creado : Parras, 13-sep-2009
	 * </p>
	 */
	private void initComponents() {
		java.awt.GridBagConstraints gridBagConstraints;

		jPanel1 = new javax.swing.JPanel();
		jPanelBotonera = new javax.swing.JPanel();
		jButtonAceptar = new javax.swing.JButton();
		jButtonCancelar = new javax.swing.JButton();
		jPanelOpciones = new javax.swing.JPanel();
		jLabelNombre = new javax.swing.JLabel();
		jButtonExaminar = new javax.swing.JButton();
		jComboBoxListaTipos = new javax.swing.JComboBox();
		jComboBoxListaTipos.setRenderer(new DesplegableRenderer());
		jLabel1Tipo = new javax.swing.JLabel();
		jTextFieldRutaCompleta = new javax.swing.JTextField();
		jTextFieldFieldNombreFichero = new javax.swing.JTextField();
		jPaneRelleno = new javax.swing.JPanel();
		jLabel1 = new javax.swing.JLabel();

		setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		setTitle("Nuevo");
		setModal(true);
		jPanel1.setLayout(new java.awt.BorderLayout());

		jButtonAceptar.setText("Aceptar");
		jButtonAceptar.setToolTipText("Aceptar");
		jButtonAceptar.setMnemonic('A');
		jButtonAceptar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonAceptarActionPerformed(evt);
			}
		});

		jPanelBotonera.add(jButtonAceptar);

		jButtonCancelar.setText("Cancelar");
		jButtonCancelar.setToolTipText("Cancelar");
		jButtonCancelar.setMnemonic('C');
		jButtonCancelar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonCancelarActionPerformed(evt);
			}
		});

		jPanelBotonera.add(jButtonCancelar);

		jPanel1.add(jPanelBotonera, java.awt.BorderLayout.SOUTH);

		jPanelOpciones.setLayout(new java.awt.GridBagLayout());

		jLabelNombre.setText("Nombre:");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanelOpciones.add(jLabelNombre, gridBagConstraints);

		jButtonExaminar.setText("Examirar...");
		jButtonExaminar.setMnemonic('E');
		jButtonExaminar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonExaminarActionPerformed(evt);
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 2;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.insets = new java.awt.Insets(2, 0, 2, 5);
		jPanelOpciones.add(jButtonExaminar, gridBagConstraints);

		jComboBoxListaTipos.setModel(new javax.swing.DefaultComboBoxModel(
				new Object[] { ELEMENTO_VACIO, JAVACC_EXTENSION,
						JAVA_EXTENSION, CARPETA_EXTENSION }));
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(6, 2, 2, 2);
		jPanelOpciones.add(jComboBoxListaTipos, gridBagConstraints);

		jLabel1Tipo.setText("Tipo:");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(6, 2, 2, 2);
		jPanelOpciones.add(jLabel1Tipo, gridBagConstraints);

		jTextFieldRutaCompleta.setEditable(false);
		jTextFieldRutaCompleta.setForeground(new java.awt.Color(51, 0, 255));
		jTextFieldRutaCompleta.setEnabled(false);
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.gridwidth = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 5);
		jPanelOpciones.add(jTextFieldRutaCompleta, gridBagConstraints);	
		jTextFieldFieldNombreFichero.addCaretListener(new CaretListener(){

			@Override
			public void caretUpdate(CaretEvent e) {
				
				jTextFieldRutaCompleta.setToolTipText(construirFile());
				
			}
			
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.weightx = 1.0;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanelOpciones.add(jTextFieldFieldNombreFichero, gridBagConstraints);

		jPanel1.add(jPanelOpciones, java.awt.BorderLayout.CENTER);

		jPaneRelleno.setLayout(new java.awt.BorderLayout());

		jPaneRelleno.setBackground(new java.awt.Color(0, 83, 166));
		jPaneRelleno.setMinimumSize(new java.awt.Dimension(100, 100));
		jPaneRelleno.setPreferredSize(new java.awt.Dimension(233, 80));
		jLabel1.setIcon(IconFactory.getImage("file_manager.png"));
		jPaneRelleno.add(jLabel1, java.awt.BorderLayout.WEST);

		jPanel1.add(jPaneRelleno, java.awt.BorderLayout.NORTH);

		getContentPane().add(jPanel1, java.awt.BorderLayout.CENTER);

		pack();
	}// </editor-fold></editor-fold>

	

	/**
	 * Construir file con los datos que apercen en nuestra ventana.Nos construye
	 * la ruta del fichero
	 * 
	 * @param evt
	 *            el evento puede ser nulo, entonces no concatenamos la palabra
	 *            que ha pulsado
	 * @return the string
	 * 
	 *        <p>
	 *         Creado : Parras, 13-sep-2009
	 *         </p>
	 */	
	private String construirFile() {
		StringBuffer texto = new StringBuffer();
		if (ipaqueteNodoSelecionado != null)
			texto.append(ipaqueteNodoSelecionado.toString() + "\\");	
		
		texto.append(jTextFieldFieldNombreFichero.getText());
		

		jTextFieldRutaCompleta.setText(texto.toString());
		if (jComboBoxListaTipos.getSelectedIndex() != 0) {// hemos seleccionado
			texto.append(getTipoExtension(jComboBoxListaTipos
					.getSelectedIndex()));
		}
		return texto.toString();
	}

	/**
	 * jbutton aceptar action performed. Creado : Parras, 13-sep-2009
	 * 
	 * @param evt
	 *            evt
	 *            <p>
	 *            Creado : Parras, 13-sep-2009
	 *            </p>
	 */
	private void jButtonAceptarActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jButtonAceptarActionPerformed
		// Este Debe actulizar nuestro arbol y abrrir una pestaa si corresponde
		// a un fichero
		// debemos validar que todo es correcto
		File lFicheroNuevo = null;

		if (validaciones()) {

			lFicheroNuevo = new File(construirFile());
			if (lFicheroNuevo.exists())
				Mensajes.mensajeAtencion("El elemento Existe en el proyecto ");
			else {
				iPaqueteNuevo = new PaqueteActivos(ipaqueteNodoSelecionado
						.getNodo(), lFicheroNuevo);
				this.dispose();
			}

		}

	}// GEN-LAST:event_jButtonAceptarActionPerformed

	/**
	 * Validaciones.
	 * 
	 * @return true, si es correcto
	 *         <p>
	 *         Creado : Parras, 13-sep-2009
	 *         </p>
	 */
	private boolean validaciones() {

		System.out.print("\nHacer Validad NuevaVenana");

		// jTextFieldFieldNombreFichero;
		// jTextFieldRutaCompleta;
		if (jTextFieldFieldNombreFichero.getText().equals("")) {
			Mensajes.mensajeError("Debemos introducir un Nombre. ");
			return false;
		}

		if (ipaqueteNodoSelecionado == null) {
			Mensajes.mensajeError("Debemos introducir una carpeta fuente.  ");
			return false;
		}

		System.out.print(jComboBoxListaTipos.getSelectedIndex());

		if (jComboBoxListaTipos.getSelectedIndex() == 0) {
			Mensajes.mensajeError("Debemos seleccionar el tipo a crear.  ");
			return false;
		}

		return true;
	}

	/**
	 * Jbutton examinar action performed. Creado : Parras, 13-sep-2009
	 * 
	 * @param evt
	 *            evento
	 *            <p>
	 *            Creado : Parras, 13-sep-2009
	 *            </p>
	 * @see proyecto.paneles.SeleccionPaqueteDialogo
	 */
	private void jButtonExaminarActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jButtonExaminarActionPerformed
		// Este boton llamar a nuestro JList con nuestro paquetes.
		jTextFieldRutaCompleta.setVisible(false);
		SeleccionPaqueteDialogo paquete = new SeleccionPaqueteDialogo(this,
				true, iPaquetes);
		paquete.setVisible(true);
		ipaqueteNodoSelecionado = paquete.getPaqueteSelecionado();
		if (ipaqueteNodoSelecionado != null) {
			jTextFieldRutaCompleta.setVisible(true);
			jTextFieldRutaCompleta.setText(paquete.getPaqueteSelecionado()
					+ "\\" + jTextFieldFieldNombreFichero.getText());
		}

	}// GEN-LAST:event_jButtonExaminarActionPerformed

	/**
	 * Jbutton cancelar action performed.
	 * 
	 * @param evt
	 *            evt
	 *            <p>
	 *            Creado : Parras, 13-sep-2009
	 *            </p>
	 * 
	 */
	private void jButtonCancelarActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jButtonCancelarActionPerformed
		// Boton que cancela y cierra nuestra ventana
		this.dispose();
		System.out.println(this.getSize());
	}// GEN-LAST:event_jButtonCancelarActionPerformed

	/**
	 * Obtener el paquete nuevo.
	 * 
	 * @return el paquete nuevo Creado : Parras, 13-sep-2009
	 */
	public PaqueteActivos getPaqueteNuevo() {
		return iPaqueteNuevo;
	}

	/**
	 * Modificar la propiedad paquete nuevo.
	 * 
	 * @param paqueteNuevo
	 *            La propiedad paquete nuevo
	 */
	public void setPaqueteNuevo(PaqueteActivos paqueteNuevo) {
		iPaqueteNuevo = paqueteNuevo;
	}

	/**
	 * The main method.
	 * 
	 * @param args
	 *            the command line arguments
	 */
	public static void main(String args[]) {
		java.awt.EventQueue.invokeLater(new Runnable() {
			public void run() {
			}
		});
	}

	/**
	 * The Class DesplegableRenderer.
	 */
	private class DesplegableRenderer extends JLabel implements
			ListCellRenderer {

		/**
		 * 
		 */
		private static final long serialVersionUID = 1L;

		/**
		 * Constructor desplegable renderer.
		 * 
		 * Creado : Parras, 13-sep-2009
		 */
		public DesplegableRenderer() {

		}

		// MTODOS DE TRATAMIENTO

		// -------------------------------------------------------------------------

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * javax.swing.ListCellRenderer#getListCellRendererComponent(javax.swing
		 * .JList, java.lang.Object, int, boolean, boolean)
		 */
		public Component getListCellRendererComponent(

		JList list,

		Object value,

		int index,

		boolean isSelected,

		boolean cellHasFocus) {

			// System.out.print ("\n"+value);
			// "", "Fichero JavaCC", "Fichero Java", "Carpeta"
			if (value.equals(JAVA_EXTENSION)) {// aqui tenemos un fichero
				this.setIcon(IconFactory.getImage("arbolFicherojava.png"));
				this.setText("Fichero Java");

			} else if (value.equals(JAVACC_EXTENSION)) {
				this.setIcon(IconFactory.getImage("arbolFicherojj.png"));
				this.setText("Fichero JavaCC");

			} else if (value.equals(CARPETA_EXTENSION)) {// Es un directorio
				this.setIcon(IconFactory.getImage("arbolCarpeta.png"));
				this.setText("Carpeta");
			} else {// ELEMENTO_VACIO
				this.setIcon(null);
				this.setText("");
			}

			return this;

		}

	}// FIN RENDERER

	// Variables declaration - do not modify
	/** button aceptar. */
	private javax.swing.JButton jButtonAceptar;

	/** button cancelar. */
	private javax.swing.JButton jButtonCancelar;

	/** button examinar. */
	private javax.swing.JButton jButtonExaminar;

	/** combo box lista tipos. */
	private javax.swing.JComboBox jComboBoxListaTipos;

	/** label1. */
	private javax.swing.JLabel jLabel1;

	/** label1 tipo. */
	private javax.swing.JLabel jLabel1Tipo;

	/** label nombre. */
	private javax.swing.JLabel jLabelNombre;

	/** pane relleno. */
	private javax.swing.JPanel jPaneRelleno;

	/** panel1. */
	private javax.swing.JPanel jPanel1;

	/** panel botonera. */
	private javax.swing.JPanel jPanelBotonera;

	/** panel opciones. */
	private javax.swing.JPanel jPanelOpciones;

	/** text field field nombre fichero. */
	private javax.swing.JTextField jTextFieldFieldNombreFichero;

	/** text field ruta completa. */
	private javax.swing.JTextField jTextFieldRutaCompleta;
	// End of variables declaration

}
