/*
 * 
 * @author Manuel Parras  
 */

package proyecto.paneles;


import java.awt.Component;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.io.File;


import javax.swing.DefaultListModel;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;
import java.io.FileFilter;
import java.util.ArrayList;
import java.util.Arrays;

import proyecto.arbol.PaqueteActivos;
import proyecto.configuracion.ConstantesEpSilon;
import proyecto.editor.Editor;
import proyecto.imagenes.IconFactory;
import proyecto.utilidades.OperacionesVentanas;


/**
 * SeleccionPaqueteDialogo
 * <p> Esta ventana la vamos adoptar en dos usos una pero bsicamente con la misma
 * funcionalidad seleccionar un directorio. Los usos son los siguientes:
 * </p>
 * <ul>
 * <li>Seleccionar Paquete Activos: En este formato de ventana se usa cuando la
 * llamamos desde la ventana de nuevo (NuevoVentana).
 * <li>Cargar proyecto activos: Cuando vamos a seleccionar unos de los proyectos
 * que tenemos en nuestro workspace. Le pasamos directamente un array con la
 * lista de Files; lugar donde se ubican los proyecto (siempre dentro de la
 * carpeta de workpSpace).</li>
 * </ul>
 * <p>
 * Dependiendo del uso que le vayamos a dar usaremos un constructor o el otro.
 * 
 * @see proyecto.paneles.NuevoVentana
 * @see proyecto.editor.ControlVentEditor
 * @see proyecto.arbol.PaqueteActivos
 * @see javax.swing.JDialog
 * @author Parras
 */
public class SeleccionPaqueteDialogo extends javax.swing.JDialog {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 206045939584249440L;

	/** Creates new form SeleccionPaqueteDialogo. */
	PaqueteActivos[] iPaquetesActivos;

	/**
	 * The paquete selecionado.
	 * 
	 * @see proyecto.arbol.PaqueteActivos
	 * */
	PaqueteActivos iPaqueteSelecionado;

	/** proyecto files. */
	File[] iProyectoFile;

	/** The proyecto selecionado. */
	File iProyectoSelecionado;

	/**
	 * Modo Para cargar las carpetas que existe en un determinado proyecto.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 * @param aPaquetes
	 *            the a paquetes
	 */
	public SeleccionPaqueteDialogo(java.awt.Dialog parent, boolean modal,
			PaqueteActivos[] aPaquetes) {
		super(parent, modal);
		iPaquetesActivos = aPaquetes;
		initComponents();
		jButtonAceptar.setEnabled(false);
		jButtonAceptar.setMnemonic('A');
		jButtonCancelar.setMnemonic('C');
		OperacionesVentanas.centraVentanaHija(this);
		setTitle("Selecci\u00f3n de carpeta fuente");
	}

	/**
	 * Para cargar los posibles directorios que existen en un workspace.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 * @param aProyectoFile
	 *            the a proyecto file
	 */
	public SeleccionPaqueteDialogo(Frame parent, boolean modal,
			File[] aProyectoFile) {
		super(parent, modal);

		iProyectoFile = aProyectoFile;
		initComponents();		
		jButtonAceptar.setEnabled(false);
		jButtonAceptar.setMnemonic('A');
		jButtonCancelar.setMnemonic('C');
		jButtonExaminar.setVisible(true);
		OperacionesVentanas.centraVentanaHija(this);
		setTitle("Seleccionar Proyeto");
		this.pack();
		
	}

	public SeleccionPaqueteDialogo(SeleccionPaqueteDialogo parent,
			boolean modal, File[] aProyectoFile) {
		super(parent, modal);

		iProyectoFile = aProyectoFile;
		initComponents();		
		jButtonAceptar.setEnabled(false);
		jButtonAceptar.setMnemonic('A');
		jButtonCancelar.setMnemonic('C');
		jButtonExaminar.setVisible(false);
		OperacionesVentanas.centraVentanaHija(this);
		setTitle("Cargar Proyeto");
		this.pack();
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// <editor-fold defaultstate="collapsed"
	// desc=" Generated Code ">//GEN-BEGIN:initComponents
	private void initComponents() {
		java.awt.GridBagConstraints gridBagConstraints;

		jPanel2 = new javax.swing.JPanel();
		jScrollPane1 = new javax.swing.JScrollPane();
		jListListaPaquetes = new javax.swing.JList();
		PanelBotonera = new javax.swing.JPanel();
		jButtonAceptar = new javax.swing.JButton();
		jButtonExaminar = new javax.swing.JButton(); 
		jButtonCancelar = new javax.swing.JButton();
		jLabel1 = new javax.swing.JLabel();

		setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		jPanel2.setLayout(new java.awt.GridBagLayout());

		if (iPaquetesActivos != null) {
			jListListaPaquetes.setModel(new DefaultListModel() {
				/**
				 * 
				 */
				private static final long serialVersionUID = 299743174566491596L;
				PaqueteActivos[] paquetes = iPaquetesActivos;

				// { "Item 1", "Item 2", "Item 3", "Item 4", "Item 5" };
				public int getSize() {
					return paquetes.length;
				}

				public Object getElementAt(int i) {
					return paquetes[i];
				}
			});
		}

		if (iProyectoFile != null) {
			jListListaPaquetes.setModel(cargarModelo(iProyectoFile));
//			jListListaPaquetes.setModel(new DefaultListModel() {
//				/**
//				 * 
//				 */
//				private static final long serialVersionUID = 299743174566491596L;
//				File[] paquetes = iProyectoFile;
//
//				// { "Item 1", "Item 2", "Item 3", "Item 4", "Item 5" };
//				public int getSize() {
//					return paquetes.length;
//				}
//
//				public Object getElementAt(int i) {
//					return paquetes[i];
//				}				
//				
//			});
		}
		jListListaPaquetes.setCellRenderer(new RenderJlistPaquete());
		jListListaPaquetes
				.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
		jListListaPaquetes
				.addListSelectionListener(new javax.swing.event.ListSelectionListener() {
					public void valueChanged(
							javax.swing.event.ListSelectionEvent evt) {
						jListListaPaquetesValueChanged(evt);
					}
				});

		jScrollPane1.setViewportView(jListListaPaquetes);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.weightx = 1.0;
		gridBagConstraints.weighty = 1.0;
		gridBagConstraints.insets = new java.awt.Insets(2, 4, 2, 4);
		jPanel2.add(jScrollPane1, gridBagConstraints);

		jButtonAceptar.setText("Aceptar");
		jButtonAceptar.setToolTipText("Aceptar");
		jButtonAceptar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonAceptarActionPerformed(evt);
			}
		});

		PanelBotonera.add(jButtonAceptar);

		jButtonCancelar.setText("Cancelar");
		jButtonCancelar.setToolTipText("Cancelar");
		jButtonCancelar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonCancelarActionPerformed(evt);
			}
		});

		PanelBotonera.add(jButtonCancelar);
		
		jButtonExaminar.setText("Examinar");
		jButtonExaminar.setMnemonic('E');
		jButtonExaminar.setToolTipText("Examinar WorkSpace");
		jButtonExaminar.setVisible(false);
		jButtonExaminar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonExaminarActionPerformed(evt);
			}
		});
		
		PanelBotonera.add(jButtonExaminar);

		

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 4, 2, 4);
		jPanel2.add(PanelBotonera, gridBagConstraints);

		jLabel1.setText("Elegir una carpeta fuente:");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 4, 2, 4);
		jPanel2.add(jLabel1, gridBagConstraints);

		getContentPane().add(jPanel2, java.awt.BorderLayout.CENTER);

		pack();
	}// </editor-fold>//GEN-END:initComponents

	
	/**
	 * Carga el modelo de la lista
	 * 
	 * @param proyectoFile
	 * @return
	 */
	private DefaultListModel cargarModelo(File[] proyectoFile) {
	
		
		DefaultListModel model = new DefaultListModel();
		if (proyectoFile !=null ){
		Arrays.sort(proyectoFile);
		 for (File lFichero : proyectoFile) {  
			 model.addElement(lFichero);  
		 }  
		}
		return model;
	}

	/**
	 * Accin de Examinar
	 * @param evt
	 */
	protected void jButtonExaminarActionPerformed(ActionEvent evt) {
		SeleccionNProyectosDialogo proyecto = new SeleccionNProyectosDialogo(this,true,cargarDirectorio(Editor.get().getWorkspace()));
		proyecto.setVisible(true);
		if (proyecto.getProyectoSelecionado() !=null)
			insertarNuevoProyecto(proyecto.getProyectoSelecionado());		
	}
	
	
	/**
	 * Amplia nuestro variable de instacia iProyectoFile con un posible nuevo proyecto
	 * @param aProyecto
	 */
	public void insertarNuevoProyecto(File aProyecto){
		
		ArrayList<File> ilproyectos = new ArrayList<File>(Arrays.asList(iProyectoFile));
		ilproyectos.add(aProyecto);		
		iProyectoFile = ((ilproyectos == null) ? null : ilproyectos.toArray(new File[ilproyectos.size()]));
		this.getJListListaPaquetes().setModel(cargarModelo(iProyectoFile));
		
	}	
	

	/**
	 * Filtra de nuestro workSpace los proyecto que ya tenemos
	 * @param aWorkSpace
	 * @return
	 */
	private File[] cargarDirectorio(File aWorkSpace){
		
		return aWorkSpace.listFiles(new MiFiltroProyecto(iProyectoFile));
	}

	/**
	 * Jlist lista paquetes value changed. Creado : Parras, 27-sep-2009
	 * 
	 * @param evt
	 *            the evt
	 */
	private void jListListaPaquetesValueChanged(
			javax.swing.event.ListSelectionEvent evt) {// GEN-FIRST:event_jListListaPaquetesValueChanged
		// Aqui guardaremos en nuestra variable la opcin y visualizamos aceptar
		jButtonAceptar.setEnabled(true);

	}// GEN-LAST:event_jListListaPaquetesValueChanged

	/**
	 * J button cancelar action performed. Creado : Parras, 27-sep-2009
	 * 
	 * @param evt
	 *            the evt
	 */
	private void jButtonCancelarActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jButtonCancelarActionPerformed
	// Boton que cancela y cierra nuestra ventana
		this.dispose();
	}// GEN-LAST:event_jButtonCancelarActionPerformed

	/**
	 *  button aceptar action performed. Creado : Parras, 27-sep-2009
	 * 
	 * @param evt
	 *            the evt
	 */
	private void jButtonAceptarActionPerformed(java.awt.event.ActionEvent evt) {// GEN-FIRST:event_jButtonAceptarActionPerformed
		// Este Debe darnos nuestra ruta completa
		if (jListListaPaquetes.getSelectedValue() instanceof PaqueteActivos) {
			iPaqueteSelecionado = (PaqueteActivos) jListListaPaquetes
					.getSelectedValue();
		}

		if (jListListaPaquetes.getSelectedValue() instanceof File) {
			iProyectoSelecionado = (File) jListListaPaquetes.getSelectedValue();
		}

		this.dispose();
	}
	
	
	/**
	 * Clase que nos devuelve solo los proyecto que no tenemos insertados
	 * 
	 * @author Parras
	 */
	 class MiFiltroProyecto implements FileFilter{
		
		/** The is extension. */
		ArrayList<File> iaProyectos;
		
		/**
		 * Guarda nuestro proyectos para verificar si existe un nuevo File.
		 * 
		 * @param aProyecto
		 *            Proyectos cargados en nuestro sistema
		 */
		MiFiltroProyecto (File[] aProyecto) {
			if (aProyecto != null)			
				iaProyectos = new ArrayList<File>(Arrays.asList(aProyecto));
			else
				iaProyectos = new ArrayList<File>();
				
		}

		/* (non-Javadoc)
		 * @see java.io.FileFilter#accept(java.io.File)
		 */
		public boolean accept(File pathname) {
			if (iaProyectos == null || pathname == null)
				return false;
				
			return !iaProyectos.contains(pathname) 
			&& pathname.isDirectory() && !pathname.getName().equals(ConstantesEpSilon.DIRECTORIO_METADATOS) ;
		}
	}
	
	  

	/**
	 * Obtener el paquete selecionado.
	 * 
	 * @return el paquete selecionado Creado : Parras, 27-sep-2009
	 */
	public PaqueteActivos getPaqueteSelecionado() {
		return iPaqueteSelecionado;
	}

	/**
	 * Modificar la propiedad paquete selecionado.
	 * 
	 * @param paqueteSelecionado
	 *            La propiedad paquete selecionado
	 */
	public void setPaqueteSelecionado(PaqueteActivos paqueteSelecionado) {
		iPaqueteSelecionado = paqueteSelecionado;
	}

	/**
	 * Devuelve el proyecto seleccionado.
	 * 
	 * @return File
	 */
	public File getProyectoSelecionado() {
		return iProyectoSelecionado;
	}

	/**
	 * Obtenermos La Lsita de PProyectos
	 * @return
	 */
	public javax.swing.JList getJListListaPaquetes() {
		return jListListaPaquetes;
	}


	/**
	 * The main method.
	 * 
	 * @param args
	 *            the command line arguments
	 */
	public static void main(String args[]) {
		java.awt.EventQueue.invokeLater(new Runnable() {
			public void run() {
				new SeleccionPaqueteDialogo(new javax.swing.JDialog(), true,
						null).setVisible(true);
			}
		});
	}

	/**
	 * RendereJlist. Aade al JList un reder con un icono de carpeta, para una
	 * grata visualizacin de los paquetes del proyecto.
	 * 
	 * @see javax.swing.List
	 */
	private class RenderJlistPaquete extends JLabel implements ListCellRenderer {

		/** The Constant serialVersionUID. */
		private static final long serialVersionUID = 1L;

		/*
		 * (non-Javadoc)
		 * 
		 * @see
		 * javax.swing.ListCellRenderer#getListCellRendererComponent(javax.swing
		 * .JList, java.lang.Object, int, boolean, boolean)
		 */
		public Component getListCellRendererComponent(JList arg0, Object arg1,
				int arg2, boolean arg3, boolean arg4) {
			// TODO Apndice de mtodo generado automticamente
			// System.out.print(arg1);

			if (arg1 instanceof PaqueteActivos) {
				PaqueteActivos paquete = (PaqueteActivos) arg1;
				this.setIcon(IconFactory.getImage("carpeta.gif"));
				this.setText(paquete.toString().substring(
						Editor.get().getWorkspace().toString().length()));

			}

			if (arg1 instanceof File) {
				File paquete = (File) arg1;
				this.setIcon(IconFactory.getImage("carpeta.gif"));
				this.setText(paquete.getName());
			}

			return this;
		}

	}
	


	// Variables declaration - do not modify//GEN-BEGIN:variables
	/** Panel botonera. */
	private javax.swing.JPanel PanelBotonera;
	
	/** button aceptar. */
	private javax.swing.JButton jButtonExaminar;

	/** button aceptar. */
	private javax.swing.JButton jButtonAceptar;

	/** button cancelar. */
	private javax.swing.JButton jButtonCancelar;

	/** label1. */
	private javax.swing.JLabel jLabel1;

	/** list lista paquetes. */
	private javax.swing.JList jListListaPaquetes;

	/** panel2. */
	private javax.swing.JPanel jPanel2;

	/** scroll pane1. */
	private javax.swing.JScrollPane jScrollPane1;
	// End of variables declaration//GEN-END:variables

	
}
