/*
 * 
 * @author Manuel Parras  
 */

package proyecto.paneles;

import java.awt.Dimension;
import java.io.File;

import proyecto.editor.Editor;
import proyecto.imagenes.IconFactory;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.OperacionesFicheros;
import proyecto.utilidades.OperacionesVentanas;

// TODO: Auto-generated Javadoc
/**
 * VentanaEliminarProyecto
 * 
 * Esta ventana modal nos informar cuando el usuario vaya a eliminar el
 * proyecto precaragado en el rbol de la aplicacin. Nos mostrar dos opciones
 * excluyentes (JRadioButton) sobre el borrado del proyecto, son las siguientes:
 * <ul>
 * <li>No suprimir contenido: deja el proyecto con los fuentes pero lo elimina
 * desde nuestro workSpace.xml</li>
 * <li>suprimir el proyecto: elimina el proyecto con los fuentes y lo suprime
 * desde nuestro workSpace.xml</li>
 * </ul>
 * <p>
 * Refresca el rbol y la barra de estado de la aplicacin dejndola si ningn
 * proyecto.
 * </p>
 * 
 * @see proyecto.editor.Editor#setBorrarProyecto(String)
 * @see proyecto.editor.PanelEdicion#anularArbol()
 * @see proyecto.editor.PanelEdicion#getbarraEstado()
 * @see javax.swing.JDialog
 * @see javax.swing. JRadioButton
 */
public class VentanaEliminarProyecto extends javax.swing.JDialog {

	/**
	 * 
	 */
	private static final long serialVersionUID = -1L;

	/** The is proyecto. */
	private String isProyecto = Editor.get().getPanel().getProyectoActivo();

	/** The is work space. */
	private String isWorkSpace = Editor.get().getWorkspace().toString();

	/**
	 * Creates new form VentanaEliminarProyecto.
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
	public VentanaEliminarProyecto(java.awt.Frame parent, boolean modal) {
		super(parent, modal);
		initComponents();
		OperacionesVentanas.centraVentana(this);
		jRadioButton2NoSup.setSelected(true);
		this.pack();
		this.setMinimumSize(new Dimension(476, 182));
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// <editor-fold defaultstate="collapsed" desc=" Generated Code ">
	private void initComponents() {
		java.awt.GridBagConstraints gridBagConstraints;

		grupoBotones = new javax.swing.ButtonGroup();
		jPanel1 = new javax.swing.JPanel();
		jPanel2 = new javax.swing.JPanel();
		jBAceptar = new javax.swing.JButton();
		jBCancelar = new javax.swing.JButton();
		jRadioButtonSup = new javax.swing.JRadioButton();
		jRadioButton2NoSup = new javax.swing.JRadioButton();
		jLabelPregunta = new javax.swing.JLabel();
		jLabelIcono = new javax.swing.JLabel();

		setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		setTitle("Confirmaci\u00f3n supresi\u00f3n del proyecto");
		jPanel1.setLayout(new java.awt.GridBagLayout());

		jBAceptar.setMnemonic('A');
		jBAceptar.setText("Aceptar");
		jBAceptar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jBAceptarActionPerformed(evt);
			}
		});

		jPanel2.add(jBAceptar);

		jBCancelar.setMnemonic('C');
		jBCancelar.setText("Cancelar");
		jBCancelar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jBCancelarActionPerformed(evt);
			}
		});

		jPanel2.add(jBCancelar);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 3;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
		gridBagConstraints.insets = new java.awt.Insets(2, 0, 2, 2);
		jPanel1.add(jPanel2, gridBagConstraints);

		grupoBotones.add(jRadioButtonSup);
		jRadioButtonSup.setMnemonic('S');
		jRadioButtonSup.setSelected(true);
		jRadioButtonSup.setText("Suprimir tambi\u00e9n el contenido bajo '"
				+ isWorkSpace + File.separator+isProyecto + "'");
		jRadioButtonSup.setBorder(javax.swing.BorderFactory.createEmptyBorder(
				0, 0, 0, 0));
		jRadioButtonSup.setMargin(new java.awt.Insets(0, 0, 0, 0));
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jRadioButtonSup, gridBagConstraints);

		grupoBotones.add(jRadioButton2NoSup);
		jRadioButton2NoSup.setMnemonic('n');
		jRadioButton2NoSup.setText("No suprimir contenido");
		jRadioButton2NoSup.setBorder(javax.swing.BorderFactory
				.createEmptyBorder(0, 0, 0, 0));
		jRadioButton2NoSup.setMargin(new java.awt.Insets(0, 0, 0, 0));
		jRadioButton2NoSup
				.addActionListener(new java.awt.event.ActionListener() {
					public void actionPerformed(java.awt.event.ActionEvent evt) {

					}
				});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jRadioButton2NoSup, gridBagConstraints);

		jLabelPregunta
				.setText("\u00bfEst\u00e1 seguro de que desea suprimir el proyecto '"
						+ isProyecto + "'?");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jLabelPregunta, gridBagConstraints);

		jLabelIcono.setIcon(IconFactory.getImage("pregunta.gif"));
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		jPanel1.add(jLabelIcono, gridBagConstraints);

		getContentPane().add(jPanel1, java.awt.BorderLayout.CENTER);

		pack();
	}// </editor-fold>

	/**
	 * cancelar action performed.
	 * <p>
	 * Eliminamos al instacia de la ventana
	 * </p>
	 * 
	 * @param evt
	 *            the evt
	 *            <p>
	 *            Creado : Parras, 28-sep-2009
	 *            </p>
	 */
	private void jBCancelarActionPerformed(java.awt.event.ActionEvent evt) {
		System.out.print("Tamao Ventana eliminar : " + this.getSize());
		this.dispose();

	}

	/**
	 * aceptar action performed.
	 * <p>
	 * Verificacin del estado de los Radio Buttn para realizar al accin
	 * correspondiente a cada uno.
	 * </p>
	 * 
	 * @param evt
	 *            the evt
	 *            <p>
	 *            Creado : Parras, 28-sep-2009
	 *            </p>
	 */
	private void jBAceptarActionPerformed(java.awt.event.ActionEvent evt) {
		if (jRadioButton2NoSup.isSelected()) {// Debemos borrar solo el proyecto
												// de nuestro workspace
			// borrado logico
			if (Editor.get().setBorrarProyecto(isProyecto)) {
				Editor.get().getPanel().anularArbol();
				Editor.get().getPanel().getbarraEstado().setVisible(false);
			} else
				Mensajes
						.mensajeError("No se ha sido posible borrar el proyecto");

		} else {
			// Borrado Fisico
			if (Editor.get().setBorrarProyecto(isProyecto)
					&& OperacionesFicheros.deleteDirectorio(new File(
							isWorkSpace + File.separator + isProyecto))) {
				// Inicializar arbol con nulo
				Editor.get().getPanel().anularArbol();
				Editor.get().getPanel().getbarraEstado().setVisible(false);
			} else
				Mensajes
						.mensajeError("No se ha sido posible borrar el proyecto");
		}
		this.dispose();
	}

	/**
	 * The main method.
	 * 
	 * @param args
	 *            the command line arguments
	 *            <p>
	 *            Creado : Parras, 28-sep-2009
	 *            </p>
	 */
	public static void main(String args[]) {
		java.awt.EventQueue.invokeLater(new Runnable() {
			public void run() {
				new VentanaEliminarProyecto(new javax.swing.JFrame(), true)
						.setVisible(true);
			}
		});
	}

	// Variables declaration - do not modify
	/** The grupo botones. */
	private javax.swing.ButtonGroup grupoBotones;

	/** aceptar. */
	private javax.swing.JButton jBAceptar;

	/** cancelar. */
	private javax.swing.JButton jBCancelar;

	/** label icono. */
	private javax.swing.JLabel jLabelIcono;

	/** label pregunta. */
	private javax.swing.JLabel jLabelPregunta;

	/** panel1. */
	private javax.swing.JPanel jPanel1;

	/** panel2. */
	private javax.swing.JPanel jPanel2;

	/** radio button2 no sup. */
	private javax.swing.JRadioButton jRadioButton2NoSup;

	/** radio button sup. */
	private javax.swing.JRadioButton jRadioButtonSup;
	// End of variables declaration

}
