/*
 * 
 * @author Manuel Parras  
 */
package proyecto.preferencias;

import java.awt.Color;
import java.awt.Font;

/**
 * AtributosPreferenicas. <br>
 * Este objeto es el encargado de contener los atributos
 * que determinan las palabras en nuestro editor (ejemplo: palabras reservadas,
 * comentarios .etc...), es decir, todas palabras o cadena de nuestro editor
 * llevara asociado un atributo.<br>
 * Cada atributo est compuesto de 3 caractersticas:
 *  <ul>
 * <li>
 * Fuente: Es el objeto fuente de java que contiene todos los atributos
 * referente a la fuente (tipo de letra, tamao, .etc).
 * </li>
 * <li>
 * Color Foreground: es el color que representa la palabra
 * </li>
 * <li>
 * Color BackGround: el color que se pinta detrs de la palabra
 * </li>
 * </ul> <br>
 * Gracias a esta clase tendremos cada letra implementada con un atributo que la
 * hace especial dependiendo la cadena que forme.
 * 
 * @author Parras
 */
public class AtributosPreferenicas {

	/** La fuente del atributo. */
	private Font fuente;
    
    /** El color trasero del atributo. */
    private Color colorBack;
    
    /**El color principal del atributo */
    private Color colorFore;
   
    
    /**
	 * Crear una nueva instacia de AtributosPrefe.
	 * 
	 * @param aFuente
	 *            the a fuente
	 * @param aColorBack
	 *            Color trasero
	 * @param aColorFore
	 *            Color Principal
	 */
    public AtributosPreferenicas(Font aFuente,Color aColorBack,Color aColorFore) {
        fuente=aFuente;
        colorBack=aColorBack;
        colorFore= aColorFore;
        //System.out.print("\nAtributosPreferenicas "+colorBack.toString() + colorFore.toString());
    }

    /**
	 * Obtener la fuente fuente.
	 * 
	 * @return el fuente Creado : Parras, 01-jun-2009
	 */
    public Font getFuente() {
        return fuente;
    }

    /**
	 * Modificar la propiedad de la fuente.
	 * 
	 * @param fuente
	 *            Objto fuente
	 */
    public void setFuente(Font fuente) {
        this.fuente = fuente;
    }

    /**
	 * Obtener el color de atrs.
	 * 
	 * @return el color trasero <br>
	 * Creado : Parras, 01-jun-2009
	 */
    public Color getColorBack() {
        return colorBack;
    }

    /**
	 * Modificar la propiedad color de atrs.
	 * 
	 * @param colorBack
	 *            La propiedad trasero
	 */
    public void setColorBack(Color colorBack) {
        this.colorBack = colorBack;
    }

    /**
	 * Obtener el color principal.
	 * 
	 * @return el color fore <br>
	 * Creado : Parras, 01-jun-2009
	 */
    public Color getColorFore() {
        return colorFore;
    }

    /**
	 * Modificar la propiedad color principal.
	 * 
	 * @param colorFore
	 *            La propiedad color fore
	 */
    public void setColorFore(Color colorFore) {
        this.colorFore = colorFore;
    }
    
    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    public String toString(){
    	
    	StringBuffer f =new StringBuffer(); 
    		
    	     f.append("\n\t\t<fuente " + "tipo=\""+this.fuente.getName()+"\"")
    		 .append(" size=\""+fuente.getSize()+"\"")
    		 .append(" estilo=\""+fuente.getStyle()+"\">"+"</fuente>")
    		 .append("\n\t\t<color primerPlano=\""+ colorFore.getRGB()+"\"")
    		 .append(" segundoPlano=\""+ colorBack.getRGB()+"\">"+"</color>") ;
    		
    		return f.toString();
    	       
    	 
    }
    
}
