

/*
 * 
 * @author Manuel Parras  
 */
// ---------------------------------------------------------------------------
package proyecto.preferencias;


// Importaciones
// ---------------------------------------------------------------------------
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GraphicsEnvironment;
import java.awt.Point;
import java.awt.Window;
import java.awt.event.KeyEvent;
import java.util.StringTokenizer;
import javax.swing.DefaultListModel;
import javax.swing.JList;




/**
 * SeleccionarFuente <br>
 * 
 * El cuadro de dilogo Selector de fuente se utiliza para seleccionar fuentes
 * que se van a aplicar a un tipo de palabra reservada. En nuestra GUI tenemos
 * lo necesario para la seleccin de la fuente como se puede observar en los
 * tres paneles que lo forma nuestra GUI:
 * <ul>
 * <li>Fuente: Est compuesto por todos las fuentes que tenemos registradas en
 * nuestro sistema operativo</li>
 * <li>Estilo: Caracterstica que posee una fuente tipogrfica, que la hace
 * destacar de alguna manera. Los tpicos estilos de fuente son:
 * <ul>
 * <li>Negrita (bold o strong).</li>
 * <li>Cursiva (tambin llamada itlica, bastardilla o aldina).</li>
 * <li>Regular (tambin llamada Normal o Romana).</li>
 * </ul>
 * </li>
 * <li>Tamao: Esta propiedad se usa para modificar el tamao de la fuente
 * mostrada</li>
 * </ul>
 * En nuestra GUI existe un panel auxiliar llamado Ejemplo y sirve para hacer
 * una visin global de la fuente seleccionada.
 * 
 * 
 * <br>
 * @author Manuel Parras.
 * @see java.awt.Font
 */

 public class SeleccionarFuente extends javax.swing.JDialog { 
	 
  /** The style list. */
  String[] styleList = new String[] { "Normal","Negrita","Cursiva" };
  
  /** The size list. */
  String[] sizeList = new String[]  { "2","4","6","8","10","12","14","16","18","20","22","24","30","36","48","72" };
  
  /** The current font. */
  String currentFont = null;
  
  /** The current style. */
  int currentStyle = -1;
  
  /** The current size. */
  int currentSize = -1;  
  
  /** The ok. */
  public boolean ok = false;
 
 /* ------------------------------------------------------------- */  
 
 
  /**
	 * Constructor seleccionar fuente.
	 * 
	 * Creado : Parras, 03-jun-2009
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 */
 private SeleccionarFuente(java.awt.Window parent,boolean modal) {  
   
	setModal(modal);
    initComponents();
    setListValues(jFontList,GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames());
    setListValues(jStyleList,styleList);
    setListValues(jSizeList,sizeList);
    setCurrentFont(jSample.getFont());
    pack();
  }  
  
 //private SeleccionarFuente(java.awt.Frame parent,boolean modal,Font font) {  
  /**
	 * Constructor seleccionar fuente.
	 * 
	 * Creado : Parras, 03-jun-2009
	 * 
	 * @param parent
	 *            the parent
	 * @param modal
	 *            the modal
	 * @param font
	 *            the font
	 */
 private SeleccionarFuente(java.awt.Window parent,boolean modal,Font font) {  
	this(parent,modal);
    setCurrentFont(font);
  }  
  
/* ------------------------------------------------------------- */  
  
 /**
 * Modifica la propiedad list values. Creado : Parras, 03-jun-2009
 * 
 * @param list
 *            the list
 * @param values
 *            the values
 */
private void setListValues(JList list,String[] values) {   
	 
	 if (list.getModel() instanceof DefaultListModel) {     
		 DefaultListModel model = (DefaultListModel)      list.getModel();
      model.removeAllElements();
      for (int j=0;j < values.length;j++) {       
		  model.addElement(values[j]);
      }    
	 }  
 }  
 
/* ------------------------------------------------------------- */  
 
 /**
 * Modifica la propiedad sample font. Creado : Parras, 03-jun-2009
 */
private void setSampleFont() {   
	 
	 if (currentFont != null && currentStyle >= 0 && currentSize > 0) {
		 jSample.setFont(new Font      (currentFont,currentStyle,currentSize));
    } 
 }  
 
 /**
	 * Style to string.
	 * 
	 * @param style
	 *            the style
	 * 
	 * @return the string Creado : Parras, 03-jun-2009
	 */
 private String styleToString(int style) {    
	 String str = "";
    if ((style&Font.BOLD) == Font.BOLD) {    
		if (str.length() > 0) {
			str += ",";
      }  
		str += "Negrita";
    }    
	 if ((style&Font.ITALIC) == Font.ITALIC) {  
		 if (str.length() > 0) { 
			 str += ",";
      }      str += "Cursiva";
    }   
	 if (str.length() <= 0 && (style&Font.PLAIN) == Font.PLAIN) {      
		 str = "Normal";
    }    
	 return str;
  }  

/* ------------------------------------------------------------- */  
  
 /**
 * Obtener el current font.
 * 
 * @return el current font Creado : Parras, 03-jun-2009
 */
public Font getCurrentFont() {   
	 return jSample.getFont();
  } 
 
/* ------------------------------------------------------------- */  
  
 /**
 * Modificar la propiedad current font.
 * 
 * @param font
 *            La propiedad current font
 */
public void setCurrentFont(Font font) {  
	 
	 if (font==null) {      
		 font = jSample.getFont();
    }    
	jFont.setText(font.getName());
    jFontActionPerformed(null);
    jStyle.setText(styleToString(font.getStyle()));
    jStyleActionPerformed(null);
    jSize.setText(Integer.toString(font.getSize()));
    jSizeActionPerformed(null);
  } 
  
 /* ------------------------------------------------------------- */  
  
 //public static Font showDialog(Frame parent,String title,Font font) {
  /**
	 * Show dialog.
	 * 
	 * @param parent
	 *            the parent
	 * @param title
	 *            the title
	 * @param font
	 *            the font
	 * 
	 * @return the font Creado : Parras, 03-jun-2009
	 */
 public static Font showDialog(Window parent,String title,Font font) {
	 
	SeleccionarFuente dialog = new SeleccionarFuente(parent,true,font);
    Point p1 = parent.getLocation();
    Dimension d1 = parent.getSize();
    Dimension d2 = dialog.getSize();
    int x = p1.x+(d1.width-d2.width)/2;
    int y = p1.y+(d1.height-d2.height)/2;
    if (x < 0) { x = 0;}    
	if (y < 0) { y = 0;}  
	if (title!=null) { 
		dialog.setTitle(title);
    }    
	dialog.setLocation(x,y);
	

    dialog.setVisible(true);
	
    Font newfont = null;
    if (dialog.ok) {   
		newfont = dialog.getCurrentFont();
    }    dialog.dispose();
    return newfont;	
  } 
  
  
  /**
	 * Nuevo construtor sin ttulo asociado.
	 * 
	 * @param parent
	 *            the parent
	 * @param font
	 *            the font
	 * 
	 * @return the font
	 */
 //public static Font showDialog(Frame parent, Font font) {
  public static Font showDialog(Window parent, Font font) {
	 
	SeleccionarFuente dialog = new SeleccionarFuente(parent,true,font);
    Point p1 = parent.getLocation();
    Dimension d1 = parent.getSize();
    Dimension d2 = dialog.getSize();
    int x = p1.x+(d1.width-d2.width)/2;
    int y = p1.y+(d1.height-d2.height)/2;
    if (x < 0) { x = 0;}    
	if (y < 0) { y = 0;}  
  
	dialog.setLocation(x,y);
	
	
	
    dialog.setVisible(true);
	
    Font newfont = null;
    if (dialog.ok) {   
		newfont = dialog.getCurrentFont();
    }    dialog.dispose();
    return newfont;	
  }    
  
 /**
	 * This method is called from within the constructor to * initialize the
	 * form. * WARNING: Do NOT modify this code. The content of this method is *
	 * always regenerated by the FormEditor.
	 */  
  
 private void initComponents() {   
	 
	jPanel3 = new javax.swing.JPanel();
    jFont = new javax.swing.JTextField();
    jScrollPane1 = new javax.swing.JScrollPane();
    jFontList = new javax.swing.JList();
    jPanel4 = new javax.swing.JPanel();
    jStyle = new javax.swing.JTextField();
    jScrollPane2 = new javax.swing.JScrollPane();
    jStyleList = new javax.swing.JList();
    jPanel5 = new javax.swing.JPanel();
    jSize = new javax.swing.JTextField();
    jScrollPane3 = new javax.swing.JScrollPane();
    jSizeList = new javax.swing.JList();
    jPanel1 = new javax.swing.JPanel();
    jScrollPane4 = new javax.swing.JScrollPane();
    jSample = new javax.swing.JTextArea();
    jButtons = new javax.swing.JPanel();
    jOk = new javax.swing.JButton();
    jCancel = new javax.swing.JButton();
    jLabel6 = new javax.swing.JLabel();
    getContentPane().setLayout(new java.awt.GridBagLayout());
    java.awt.GridBagConstraints gridBagConstraints1;
	
    
	setTitle("Selector De Fuentes");
	
    addWindowListener(new java.awt.event.WindowAdapter() {        
 		public void windowClosing(java.awt.event.WindowEvent evt) {     
			closeDialog(evt);
        }      
		}    
	);
    jPanel3.setLayout(new java.awt.GridBagLayout());
    java.awt.GridBagConstraints gridBagConstraints2;
	
    //jPanel3.setBorder(new javax.swing.border.TitledBorder(new javax.swing.border.EtchedBorder(), " Font "));
	jPanel3.setBorder(new javax.swing.border.TitledBorder(new javax.swing.border.EtchedBorder(), "Fuente"));
	
    jFont.setColumns(24);
    jFont.addActionListener(new java.awt.event.ActionListener() {      
 		public void actionPerformed(java.awt.event.ActionEvent evt) {   
			jFontActionPerformed(evt);
        }     
	}   );
    gridBagConstraints2 = new java.awt.GridBagConstraints();
    gridBagConstraints2.gridwidth = 0;
    gridBagConstraints2.fill =    java.awt.GridBagConstraints.HORIZONTAL;
    gridBagConstraints2.insets = new java.awt.Insets(0, 3, 0, 3);
    gridBagConstraints2.anchor = java.awt.GridBagConstraints.NORTHWEST;
    gridBagConstraints2.weightx = 1.0;
    jPanel3.add(jFont, gridBagConstraints2);
    jFontList.setModel(new DefaultListModel());
    jFontList.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
    jFontList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {      
 		public void valueChanged(javax.swing.event.ListSelectionEvent evt) {          
			jFontListValueChanged(evt);
        }      
	}    
		);
    jScrollPane1.setViewportView(jFontList);
    gridBagConstraints2 = new java.awt.GridBagConstraints();
    gridBagConstraints2.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints2.insets = new java.awt.Insets(3, 3, 3, 3);
    gridBagConstraints2.anchor = java.awt.GridBagConstraints.NORTHWEST;
    gridBagConstraints2.weightx = 1.0;
    gridBagConstraints2.weighty = 1.0;
    jPanel3.add(jScrollPane1, gridBagConstraints2);
    gridBagConstraints1 = new java.awt.GridBagConstraints();
    gridBagConstraints1.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints1.insets = new java.awt.Insets(5, 5, 0, 0);
    gridBagConstraints1.weightx = 0.5;
    gridBagConstraints1.weighty = 1.0;
    getContentPane().add(jPanel3, gridBagConstraints1);
    jPanel4.setLayout(new java.awt.GridBagLayout());
    java.awt.GridBagConstraints gridBagConstraints3;
	
    //jPanel4.setBorder(new javax.swing.border.TitledBorder(new javax.swing.border.EtchedBorder(), " Style "));
	jPanel4.setBorder(new javax.swing.border.TitledBorder(new javax.swing.border.EtchedBorder(),"Estilo"));

	
    jStyle.setColumns(18);
    jStyle.addActionListener(new java.awt.event.ActionListener() {      
		 public void actionPerformed(java.awt.event.ActionEvent evt) {      
			 jStyleActionPerformed(evt);
        }      }    
		);
    gridBagConstraints3 = new java.awt.GridBagConstraints();
    gridBagConstraints3.gridwidth = 0;
    gridBagConstraints3.fill =    java.awt.GridBagConstraints.HORIZONTAL;
    gridBagConstraints3.insets = new java.awt.Insets(0, 3, 0, 3);
    gridBagConstraints3.anchor = java.awt.GridBagConstraints.NORTHWEST;
    gridBagConstraints3.weightx = 1.0;
    jPanel4.add(jStyle, gridBagConstraints3);
    jStyleList.setModel(new DefaultListModel());
    jStyleList.setVisibleRowCount(4);
    jStyleList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {        
 		public void valueChanged(javax.swing.event.ListSelectionEvent evt) {          
			jStyleListValueChanged(evt);
        }      }    
	);
    jScrollPane2.setViewportView(jStyleList);
    gridBagConstraints3 = new java.awt.GridBagConstraints();
    gridBagConstraints3.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints3.insets = new java.awt.Insets(3, 3, 3, 3);
    gridBagConstraints3.anchor = java.awt.GridBagConstraints.NORTHWEST;
    gridBagConstraints3.weightx = 0.5;
    gridBagConstraints3.weighty = 1.0;
    jPanel4.add(jScrollPane2, gridBagConstraints3);
    gridBagConstraints1 = new java.awt.GridBagConstraints();
    gridBagConstraints1.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints1.insets = new java.awt.Insets(5, 5, 0, 0);
    gridBagConstraints1.weightx = 0.375;
    gridBagConstraints1.weighty = 1.0;
    getContentPane().add(jPanel4, gridBagConstraints1);
    jPanel5.setLayout(new java.awt.GridBagLayout());
    java.awt.GridBagConstraints gridBagConstraints4;
	
    //jPanel5.setBorder(new javax.swing.border.TitledBorder(new javax.swing.border.EtchedBorder(), " Size "));
	jPanel5.setBorder(new javax.swing.border.TitledBorder(new javax.swing.border.EtchedBorder(), "Tamao"));
	
    jSize.setColumns(6);
    jSize.addActionListener(new    java.awt.event.ActionListener() {      
 public void actionPerformed(java.awt.event.ActionEvent evt) {          jSizeActionPerformed(evt);
        }      }    );
    gridBagConstraints4 = new java.awt.GridBagConstraints();
    gridBagConstraints4.gridwidth = 0;
    gridBagConstraints4.fill = java.awt.GridBagConstraints.HORIZONTAL;
    gridBagConstraints4.insets = new java.awt.Insets(0, 3, 0, 3);
    gridBagConstraints4.anchor = java.awt.GridBagConstraints.NORTHWEST;
    gridBagConstraints4.weightx = 1.0;
    jPanel5.add(jSize, gridBagConstraints4);
    jSizeList.setModel(new DefaultListModel());
    jSizeList.setVisibleRowCount(4);
    jSizeList.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
    jSizeList.addListSelectionListener(new javax.swing.event.ListSelectionListener() {        
 public void valueChanged(javax.swing.event.ListSelectionEvent evt) {          jSizeListValueChanged(evt);
        }      }    );
    jScrollPane3.setViewportView(jSizeList);
    gridBagConstraints4 = new java.awt.GridBagConstraints();
    gridBagConstraints4.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints4.insets = new java.awt.Insets(3, 3, 3, 3);
    gridBagConstraints4.anchor = java.awt.GridBagConstraints.NORTHWEST;
    gridBagConstraints4.weightx = 0.25;
    gridBagConstraints4.weighty = 1.0;
    jPanel5.add(jScrollPane3, gridBagConstraints4);
    gridBagConstraints1 = new java.awt.GridBagConstraints();
    gridBagConstraints1.gridwidth = 0;
    gridBagConstraints1.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints1.insets = new java.awt.Insets(5, 5, 0, 5);
    gridBagConstraints1.weightx = 0.125;
    gridBagConstraints1.weighty = 1.0;
    getContentPane().add(jPanel5, gridBagConstraints1);
    jPanel1.setLayout(new java.awt.GridBagLayout());
    java.awt.GridBagConstraints gridBagConstraints5;
	
    //jPanel1.setBorder(new javax.swing.border.TitledBorder(new javax.swing.border.EtchedBorder(), " Sample "));
	jPanel1.setBorder(new javax.swing.border.TitledBorder(new javax.swing.border.EtchedBorder(), "Ejemplo"));
	
    jSample.setWrapStyleWord(true);
    jSample.setLineWrap(true);
    jSample.setColumns(20);
    jSample.setRows(3);
	
    //jSample.setText("The quick brown fox jumped over the lazy dog.");
	jSample.setText("Prueba de la Fuente");
	
    jScrollPane4.setViewportView(jSample);
    gridBagConstraints5 = new java.awt.GridBagConstraints();
    gridBagConstraints5.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints5.insets = new java.awt.Insets(0, 3, 3, 3);
    gridBagConstraints5.weightx = 1.0;
    gridBagConstraints5.weighty = 1.0;
    jPanel1.add(jScrollPane4, gridBagConstraints5);
    gridBagConstraints1 = new java.awt.GridBagConstraints();
    gridBagConstraints1.gridwidth = 0;
    gridBagConstraints1.fill = java.awt.GridBagConstraints.BOTH;
    gridBagConstraints1.insets = new java.awt.Insets(0, 5, 0, 5);
    gridBagConstraints1.anchor = java.awt.GridBagConstraints.NORTHWEST;
    gridBagConstraints1.weightx = 1.0;
    getContentPane().add(jPanel1, gridBagConstraints1);
	
    jButtons.setLayout(new java.awt.GridBagLayout());
	
    java.awt.GridBagConstraints gridBagConstraints6;
    //jOk.setMnemonic(KeyEvent.VK_O);
	jOk.setMnemonic(KeyEvent.VK_ACCEPT);	
    //jOk.setText("OK");
	jOk.setText("Aceptar");
		
    jOk.setRequestFocusEnabled(false);
    jOk.addActionListener(new java.awt.event.ActionListener() {        
	public void actionPerformed(java.awt.event.ActionEvent evt) {          jOkActionPerformed(evt);
        }      }    );
		
    gridBagConstraints6 = new java.awt.GridBagConstraints();
    gridBagConstraints6.insets = new java.awt.Insets(5, 5, 5, 0);
    gridBagConstraints6.anchor = java.awt.GridBagConstraints.WEST;
    jButtons.add(jOk, gridBagConstraints6);
	
    jCancel.setMnemonic(KeyEvent.VK_C);	
    //jCancel.setText("Cancel");
	jCancel.setText("Cancelar");
		
    jCancel.setRequestFocusEnabled(false);
    jCancel.addActionListener(new    java.awt.event.ActionListener() {      
 	public void actionPerformed(java.awt.event.ActionEvent evt) {          jCancelActionPerformed(evt);
        }      }    );
    gridBagConstraints6 = new java.awt.GridBagConstraints();
    gridBagConstraints6.gridwidth = 0;
    gridBagConstraints6.insets = new java.awt.Insets(5, 5, 5, 5);
    gridBagConstraints6.anchor = java.awt.GridBagConstraints.WEST;
    gridBagConstraints6.weightx = 1.0;
    jButtons.add(jCancel, gridBagConstraints6);
	
    gridBagConstraints6 = new java.awt.GridBagConstraints();
    gridBagConstraints6.weightx = 1.0;
    jButtons.add(jLabel6, gridBagConstraints6);
	
    gridBagConstraints1 = new java.awt.GridBagConstraints();
    gridBagConstraints1.gridwidth = 0;
    gridBagConstraints1.anchor = java.awt.GridBagConstraints.SOUTHWEST;
    gridBagConstraints1.weightx = 1.0;
	
    getContentPane().add(jButtons, gridBagConstraints1);
	
  }  
  
 /**
	 * J cancel action performed. Creado : Parras, 03-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 */
 private void jCancelActionPerformed(java.awt.event.ActionEvent evt) {    
 	// Add your handling code here:    
	 setVisible(false);
  }  
  
 /**
	 * J ok action performed. Creado : Parras, 03-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 */
 private void jOkActionPerformed (java.awt.event.ActionEvent evt) {    
 	// Add your handling code here:    
	ok = true;
    setVisible(false);
  }  
  
 /**
	 * J size action performed. Creado : Parras, 03-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 */
 private void jSizeActionPerformed (java.awt.event.ActionEvent evt) {    
 	// Add your handling code here:    
	int size = 0;
    try {      
		size = Integer.parseInt(jSize.getText());
    }catch (Exception e) {}    
	if (size > 0) {     
	  currentSize = size;
      setSampleFont();
    }  
 }  
 
 /**
	 * J style action performed. Creado : Parras, 03-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 */
 private void jStyleActionPerformed (java.awt.event.ActionEvent evt) {    
 	// Add your handling code here:   
	StringTokenizer st = new StringTokenizer(jStyle.getText(),",");
    int style = 0;
    while (st.hasMoreTokens()) { 
		String str = st.nextToken().trim();
      	if (str.equalsIgnoreCase("Normal")) { 
			style |= Font.PLAIN;
 		} else if (str.equalsIgnoreCase("Negrita")) {
			style |= Font.BOLD;
 		} else if (str.equalsIgnoreCase("Cursiva")) {
			style |= Font.ITALIC;
 		}    
	}
	if (style >= 0) {      
	  currentStyle = style;
      setSampleFont();
    }  
 }  
 
 /**
	 * J font action performed. Creado : Parras, 03-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 */
 private void jFontActionPerformed (java.awt.event.ActionEvent evt) {    
 	// Add your handling code here:    
	DefaultListModel model = (DefaultListModel) jFontList.getModel();
    if (model.indexOf(jFont.getText()) >= 0) {
		currentFont = jFont.getText();
      	setSampleFont();
    } 
 } 
 
 /**
	 * J style list value changed. Creado : Parras, 03-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 */
 private void jStyleListValueChanged(javax.swing.event.ListSelectionEvent evt) {    
 	// Add your handling code here:   
	String str = new String();
    Object[] values = jStyleList.getSelectedValues();
    if (values.length > 0) {      
	  int j;
      for (j=0;j < values.length;j++) {        
	  	String s = (String) values[j];
        if (s.equalsIgnoreCase("Normal")) { 
			str = "Normal";
  			break;
        }        
		if (str.length() > 0) {
			str += ",";
 		} 
		str += (String) values[j];
      }    
	}    
	else { 
		str = styleToString(currentStyle);
 	} 
	jStyle.setText(str);
    jStyleActionPerformed(null);
  }  
  
 /**
	 * J size list value changed. Creado : Parras, 03-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 */
 private void jSizeListValueChanged(javax.swing.event.ListSelectionEvent evt) {    
 	// Add your handling code here:    
	 String str = (String) jSizeList.getSelectedValue();
    if (str==null || str.length() <= 0) { 
		str = Integer.toString(currentSize);
 	}
	jSize.setText(str);
    jSizeActionPerformed(null);
  }
  
 /**
	 * J font list value changed. Creado : Parras, 03-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 */
 private void jFontListValueChanged(javax.swing.event.ListSelectionEvent evt) {    
 	// Add your handling code here:   
	 String str = (String) jFontList.getSelectedValue();
    if (str==null || str.length() <= 0) {
		str = currentFont;
 	}
	 jFont.setText(str);
     jFontActionPerformed(null);
  }  
 
  
/**
 * Closes the dialog.
 * 
 * @param evt
 *            the evt
 */  
  
 private void closeDialog(java.awt.event.WindowEvent evt) {   
	 setVisible (false);
 }  
  
  
 // Variables declaration - do not modify  
 /** The j panel3. */
 private javax.swing.JPanel jPanel3;  
 
 /** The j font. */
 private javax.swing.JTextField jFont;  
 
 /** The j scroll pane1. */
 private javax.swing.JScrollPane jScrollPane1;  
 
 /** The j font list. */
 private javax.swing.JList jFontList;  
 
 /** The j panel4. */
 private javax.swing.JPanel jPanel4;  
 
 /** The j style. */
 private javax.swing.JTextField jStyle;  
 
 /** The j scroll pane2. */
 private javax.swing.JScrollPane jScrollPane2;  
 
 /** The j style list. */
 private javax.swing.JList jStyleList;  
 
 /** The j panel5. */
 private javax.swing.JPanel jPanel5;  
 
 /** The j size. */
 private javax.swing.JTextField jSize;  
 
 /** The j scroll pane3. */
 private javax.swing.JScrollPane jScrollPane3;  
 
 /** The j size list. */
 private javax.swing.JList jSizeList;  
 
 /** The j panel1. */
 private javax.swing.JPanel jPanel1;  
 
 /** The j scroll pane4. */
 private javax.swing.JScrollPane jScrollPane4;  
 
 /** The j sample. */
 private javax.swing.JTextArea jSample;  
 
 /** The j buttons. */
 private javax.swing.JPanel jButtons;  
 
 /** The j ok. */
 private javax.swing.JButton jOk;  
 
 /** The j cancel. */
 private javax.swing.JButton jCancel;  
 
 /** The j label6. */
 private javax.swing.JLabel jLabel6;
 
 // End of variables declaration 
 
 
//******************* MTODO MAIN PARA PRUEBAS
 
	/**
	 * MAIN.
	 * 
	 * @param args
	 *            Parametros de la linea de comandos
	 */
	public static void main(String args[]) {

		javax.swing.JFrame frame = new javax.swing.JFrame("Prueba Selector de fuentes");
		
	    frame.setSize(715,525);
        frame.setVisible(true);
		Font f = SeleccionarFuente.showDialog(frame,"Selector de Fuentes",new Font("Dialog", 0, 12));		
		if (f != null){
			System.out.println(f);
		}
		else{
			System.out.println("No se seleccion ninguna fuente");
		}
		
	}
      
}
