/*
 * 
 * @author Manuel Parras  
 */

package proyecto.preferencias;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.io.File;
import java.io.IOException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Set;

import javax.swing.JColorChooser;
import javax.swing.ListSelectionModel;

import proyecto.editor.Editor;
import proyecto.editor.EpSilonExcepciones;
import proyecto.imagenes.IconFactory;
import proyecto.utilidades.Mensajes;
import proyecto.utilidades.OperacionesFicheros;

/**
 * VentanaPreferencias.
 * 
 *<p> Esta ventana modal encargada de gestionar los colores y fuentes que tendr
 * nuestro editor (forma que se visualizar el cdigo fuente). El funcionamiento
 * es sencillo, consiste en: seleccionar un elemento de la lista (palabras
 * reservadas) y asignarle una fuente y un color en los botones que estn
 * contiguos. Los botones estn definidos de la siguiente forma:</p>
 * <ul>
 * <li>Seleccin de fuente: Pulsamos el botn y nos abre el seleccionador de
 * fuente (ver referencias en el mtodo)</li>
 * <li>Botn de ForeGround: Selecciona el color que va a tener la fuente. Abre
 * el JfileChooser para capturar la preferencias de los colores.</li>
 * <li>Botn de BackGround: Selecciona el color que va a tener el fondo de la
 * fuente. Abre el JfileChooser para capturar la preferencias de los colores.</li>
 * </ul>
 *<p> Los atributos se definen mediante un mapa con ItemDeLista y
 * AtributosPreferenicas, existe un botn en la ventana para capturar los
 * valores definidos por defecto. Los valores definidos por el usuario se
 * guardarn localmente en un fichero para poder hacer referencia siempre a
 * ellos cuando carguemos la aplicacin. Los colores se guarda en la parte de
 * configuracin de nuestra aplicacin definido en la ruta
 * /workspace/.metadata/configColores.xml</p>
 * 
 *@see proyecto.preferencias.SeleccionarFuente
 *@see proyecto.preferencias.ItemDeLista
 *@see proyecto.preferencias.AtributosPreferenicas
 *@see javax.swing.JFileChooser
 *@see java.awt.Font
 *@see javax.swing.JDialog
 */
public class VentanaPreferencias extends javax.swing.JDialog implements
		MouseListener {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 6373773511150086108L;
	// private Map<ItemDeLista,AtributosPreferenicas> imapa=new
	// HashMap<ItemDeLista,AtributosPreferenicas>();
	/**
	 * imapaAux Variable que nos sirve para ir capturando las nuevas
	 * modificaciones que nos valla haciendo el usuario en nuestra ventana de
	 * preferencias, ya que si el usuario deseara anular los cambios podemos
	 * referenciar los antiguos atributos.
	 * 
	 * @see java.util.HashMap
	 **/
	private Map<ItemDeLista, AtributosPreferenicas> imapaAux = new HashMap<ItemDeLista, AtributosPreferenicas>();

	/** hay cambios en la ventana. */
	private boolean hayCambios;

	/**
	 * valorAnterior valor anteriror, a la modificacin del usuario.
	 * 
	 * @see proyecto.preferencias.ItemDeLista
	 */
	private ItemDeLista valorAnterior = new ItemDeLista("", "");

	/** Color principal. */
	Color colorFore = null;

	/** Colo trasero */
	private Color colorBack = null;

	/** la fuente */
	private Font fuente = null;

	/**
	 * Ventana principa
	 * 
	 * @see proyecto.editor.Editor
	 * */
	private Editor gui;

	/**
	 * Constructor VentanaPreferencias.
	 * 
	 * @param parent
	 *            Ventana padre
	 * @param modal
	 *            Modal
	 * @param aMapa
	 *            de valores <item,atributos>
	 * @see proyecto.preferencias.ItemDeLista
	 * @see proyecto.preferencias.AtributosPreferenicas
	 */
	public VentanaPreferencias(java.awt.Frame parent, boolean modal,
			Map<ItemDeLista, AtributosPreferenicas> aMapa) {
		super(parent, modal);
		gui = (Editor) parent;
		initComponents();
		//
		this.pack();
		this.setMinimumSize(new Dimension(539, 329));
		// Solo podemos seleccionar un item a la vez
		this.jList1.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		this.jList1.addMouseListener(this);
		setDeshabilitarBotones();
		hayCambios = false;
		Rectangle bounds = parent.getBounds();
		Dimension size = getSize();
		setLocation(
				(int) (bounds.getX() + (bounds.getWidth() - size.getWidth()) / 2),
				(int) (bounds.getY() + (bounds.getHeight() - size.getHeight()) / 2));
		// setDefault();
		// imapa.putAll(aMapa);
		imapaAux.putAll(aMapa);
		this.jButtonAceptar.setMnemonic('A');
		this.jButtonPorDefecto.setMnemonic('D');
		this.jButtonFuente.setMnemonic('F');

	}

	/**
	 * Modifica bloquea los botoenes de la ventana. <br>
	 * <p>
	 * Creado : Parras, 06-jun-2009
	 * </p>
	 */
	public void setDeshabilitarBotones() {
		this.jButtonAceptar.setEnabled(false);
		this.jButtonPorDefecto.setEnabled(false);
		this.jButtonBackGround.setEnabled(false);
		this.jButtonForeGround.setEnabled(false);
		this.jButtonFuente.setEnabled(false);
	}

	/**
	 * Modifica habilita los botones de la ventana.
	 * <p>
	 * Creado : Parras, 06-jun-2009
	 * </p>
	 */
	public void setHabilitarBotones() {
		this.jButtonAceptar.setEnabled(true);
		this.jButtonPorDefecto.setEnabled(true);
		this.jButtonBackGround.setEnabled(true);
		this.jButtonForeGround.setEnabled(true);
		this.jButtonFuente.setEnabled(true);
	}

	/**
	 * This method is called from within the constructor to initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is always
	 * regenerated by the Form Editor.
	 */
	// <editor-fold defaultstate="collapsed" desc=" Generated Code ">
	private void initComponents() {
		java.awt.GridBagConstraints gridBagConstraints;

		jPanel2 = new javax.swing.JPanel();
		jPanel1 = new javax.swing.JPanel();
		jLabelFuente = new javax.swing.JLabel();
		jButtonBackGround = new javax.swing.JButton();
		jLabelBackGround = new javax.swing.JLabel();
		jLabelForeGround = new javax.swing.JLabel();
		jButtonForeGround = new javax.swing.JButton();
		jButtonFuente = new javax.swing.JButton();
		jLabelTextoFuente = new javax.swing.JLabel();
		jPanelColorForeGround = new javax.swing.JPanel();
		jPanelColorBackGround = new javax.swing.JPanel();
		jScrollPane1 = new javax.swing.JScrollPane();
		jList1 = new javax.swing.JList();
		jPanelBotonera = new javax.swing.JPanel();
		jButtonAceptar = new javax.swing.JButton();
		jButtonCancelar = new javax.swing.JButton();
		jButtonPorDefecto = new javax.swing.JButton();
		jPaneRelleno = new javax.swing.JPanel();
		jLabel1 = new javax.swing.JLabel();

		setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
		setTitle("Preferencias");
		setModal(true);
		jPanel2.setLayout(new java.awt.GridBagLayout());

		jPanel1.setLayout(new java.awt.GridBagLayout());

		jLabelFuente.setText("Fuente:");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.ipadx = 10;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jLabelFuente, gridBagConstraints);

		jButtonBackGround.setText("...");
		jButtonBackGround
				.addActionListener(new java.awt.event.ActionListener() {
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						jButtonBackGroundActionPerformed(evt);
					}
				});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 2;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.ipadx = -25;
		gridBagConstraints.ipady = -10;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 0, 2, 2);
		jPanel1.add(jButtonBackGround, gridBagConstraints);

		jLabelBackGround.setText("Segundo Plano:");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jLabelBackGround, gridBagConstraints);

		jLabelForeGround.setText("Primer Plano:");
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jLabelForeGround, gridBagConstraints);

		jButtonForeGround.setText("...");
		jButtonForeGround
				.addActionListener(new java.awt.event.ActionListener() {
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						jButtonForeGroundActionPerformed(evt);
					}
				});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 2;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.ipadx = -25;
		gridBagConstraints.ipady = -10;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 0, 2, 2);
		jPanel1.add(jButtonForeGround, gridBagConstraints);

		jButtonFuente.setText("...");
		jButtonFuente.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonFuenteActionPerformed(evt);
			}
		});

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 2;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.ipadx = -25;
		gridBagConstraints.ipady = -10;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.SOUTH;
		gridBagConstraints.insets = new java.awt.Insets(2, 0, 2, 3);
		jPanel1.add(jButtonFuente, gridBagConstraints);

		jLabelTextoFuente.setFont(new java.awt.Font("Microsoft Sans Serif", 0,
				10));
		jLabelTextoFuente.setBorder(javax.swing.BorderFactory
				.createEtchedBorder());
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
		gridBagConstraints.ipadx = 30;
		gridBagConstraints.ipady = 20;
		gridBagConstraints.anchor = java.awt.GridBagConstraints.NORTH;
		gridBagConstraints.weightx = 0.3;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jLabelTextoFuente, gridBagConstraints);

		jPanelColorForeGround.setBorder(javax.swing.BorderFactory
				.createEtchedBorder());
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.ipadx = 30;
		gridBagConstraints.ipady = 10;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jPanelColorForeGround, gridBagConstraints);

		jPanelColorBackGround.setBorder(javax.swing.BorderFactory
				.createEtchedBorder());
		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.ipadx = 30;
		gridBagConstraints.ipady = 10;
		gridBagConstraints.insets = new java.awt.Insets(2, 2, 2, 2);
		jPanel1.add(jPanelColorBackGround, gridBagConstraints);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 1;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		jPanel2.add(jPanel1, gridBagConstraints);
		jList1.setModel(new javax.swing.AbstractListModel() {
			ItemDeLista[] opciones = { new ItemDeLista("identifier", "Texto"),
					new ItemDeLista("reservedWord", "Palabras Reservadas"),
					new ItemDeLista("literal", "Literal"),
					new ItemDeLista("whitespace", "Separadores"),
					new ItemDeLista("operator", "Operadores"),
					new ItemDeLista("comment", "Comentarios") };

			public int getSize() {
				return opciones.length;
			}

			public Object getElementAt(int i) {
				return opciones[i];
			}
		});
		jScrollPane1.setViewportView(jList1);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 0;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		// gridBagConstraints.ipadx = 40;
		gridBagConstraints.ipadx = 100;
		gridBagConstraints.ipady = 15;
		gridBagConstraints.weighty = 1.0;
		gridBagConstraints.insets = new java.awt.Insets(12, 9, 12, 5);
		jPanel2.add(jScrollPane1, gridBagConstraints);

		jButtonAceptar.setText("Aceptar");
		jButtonAceptar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonAceptarActionPerformed(evt);
			}
		});

		jPanelBotonera.add(jButtonAceptar);

		jButtonCancelar.setText("Cancelar");
		jButtonCancelar.addActionListener(new java.awt.event.ActionListener() {
			public void actionPerformed(java.awt.event.ActionEvent evt) {
				jButtonCancelarActionPerformed(evt);
			}
		});

		jPanelBotonera.add(jButtonCancelar);

		jButtonPorDefecto.setText("Por Defecto");
		jButtonPorDefecto
				.addActionListener(new java.awt.event.ActionListener() {
					public void actionPerformed(java.awt.event.ActionEvent evt) {
						jButtonPorDefectoActionPerformed(evt);
					}
				});
		jPanelBotonera.add(jButtonPorDefecto);

		gridBagConstraints = new java.awt.GridBagConstraints();
		gridBagConstraints.gridx = 0;
		gridBagConstraints.gridy = 1;
		gridBagConstraints.gridwidth = 2;
		gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
		gridBagConstraints.weightx = 0.3;
		gridBagConstraints.weighty = 0.3;
		gridBagConstraints.insets = new java.awt.Insets(4, 3, 2, 10);
		jPanel2.add(jPanelBotonera, gridBagConstraints);

		getContentPane().add(jPanel2, java.awt.BorderLayout.CENTER);

		jPaneRelleno.setLayout(new java.awt.BorderLayout());

		jPaneRelleno.setBackground(new java.awt.Color(0, 83, 166));
		jPaneRelleno.setMinimumSize(new java.awt.Dimension(100, 100));
		jPaneRelleno.setPreferredSize(new java.awt.Dimension(233, 80));
		jLabel1.setIcon(IconFactory.getImage("paleta.gif"));
		jPaneRelleno.add(jLabel1, java.awt.BorderLayout.WEST);

		getContentPane().add(jPaneRelleno, java.awt.BorderLayout.NORTH);

		pack();
	}// </editor-fold>

	/**
	 * Accio botn por defecto <br>
	 * Creado : Parras, 06-jun-2009
	 * 
	 * @param evt
	 *            the evt
	 *            <p>
	 *            Creado : Parras, 06-jun-2009
	 *            </p>
	 */
	private void jButtonPorDefectoActionPerformed(ActionEvent evt) {
		gui.getPanel().setDefectoColores(imapaAux);
		setAsignarColores((ItemDeLista) this.jList1.getSelectedValue());

	}

	/**
	 * Accin botn backGround
	 * 
	 * 
	 * @param evt
	 *            the evt
	 *            <p>
	 *            Creado : Parras, 06-jun-2009
	 *            </p>
	 */
	private void jButtonBackGroundActionPerformed(java.awt.event.ActionEvent evt) {

		colorBack = JColorChooser.showDialog(VentanaPreferencias.this,
				"Seleccione un color", colorBack);
		if (colorBack != null) {
			jPanelColorBackGround.setBackground(colorBack);
			hayCambios = true;
		}

	}

	/**
	 * Accin boton foreGround
	 * 
	 * 
	 * @param evt
	 *            the evt
	 *            <p>
	 *            Creado : Parras, 06-jun-2009
	 *            </p>
	 */
	private void jButtonForeGroundActionPerformed(java.awt.event.ActionEvent evt) {

		colorFore = JColorChooser.showDialog(VentanaPreferencias.this,
				"Seleccione un color", colorFore);
		if (colorFore != null) {
			jPanelColorForeGround.setBackground(colorFore);
			hayCambios = true;
		}
	}

	/**
	 * Accin boton Cancelar opciones
	 * 
	 * 
	 * @param evt
	 *            the evt
	 * 
	 *            <p>
	 *            Creado : Parras, 06-jun-2009
	 *            </p>
	 */
	private void jButtonCancelarActionPerformed(java.awt.event.ActionEvent evt) {
		Rectangle tamano = this.getBounds();
		System.out.println("\nRectangulo de la ventana es: " + tamano);
		this.dispose();
	}

	/**
	 * Accin botn Aceptar opciones seleccionadas
	 * 
	 * Guarda nuestra configuaracin en nustro fichero XML.
	 * /workpsace/.metadata/configColores.xml
	 * 
	 * @param evt
	 *            the evt
	 *            <p>
	 *            Creado : Parras, 06-jun-2009
	 *            </p>
	 */
	private void jButtonAceptarActionPerformed(java.awt.event.ActionEvent evt) {
		// Preparamos el mapa para guardarlo en nuestro fichero
		ItemDeLista tipo;
		AtributosPreferenicas atrib;

		// Por el caso Base, cuando solo hacemos una seleccion
		// no volvemos a pasar por el mouseClick para coger los datos pendientes
		if (fuente != null)
			imapaAux.get(valorAnterior).setFuente(fuente);
		if (colorFore != null)
			imapaAux.get(valorAnterior).setColorFore(colorFore);

		if (colorBack != null)
			imapaAux.get(valorAnterior).setColorBack(colorBack);
		// Fin del tratamiento de guardado de datos pendientes
		// Empezamos con el guardado en xml de los valores obtenidos

		Set<ItemDeLista> claves = imapaAux.keySet();
		Iterator iter = claves.iterator();
		StringBuffer textoOpciones = new StringBuffer();
		textoOpciones.append("\n<colores tipo=\"EpSilon Colores\">");
		while (iter.hasNext()) {
			tipo = (ItemDeLista) iter.next(); // aqui tenemos la clave
			// System.out.println("EL TIPO : "+tipo.getEtiqueta() + tipo);
			atrib = imapaAux.get(tipo);

			// textoOpciones.append("\n\t"+"<opciones-"+tipo.getEtiqueta()+">")
			textoOpciones.append("\n\t" + "<opciones>").append(
					"\n\t\t<item tituloOpcion=\"" + tipo
							+ "\" tituloEtiqueta=\"" + tipo.getEtiqueta()
							+ "\">" + "</item>")
			// .append("\n\t\t<tituloEtiqueta>"+tipo.getEtiqueta()
					// +"</tituloEtiqueta>")
					.append(atrib.toString())// Colores fuente
					// .append("\n\t"+"</opciones-"+tipo.getEtiqueta()+">");
					.append("\n\t" + "</opciones>");
		}
		textoOpciones.append("\n</colores>");
		try {

			File configuracion = new File(Editor.get().getPrefColoresXML());
			// System.out.print("Ruta Fichero Colores"+configuracion);

			OperacionesFicheros.guardarFichero(configuracion, textoOpciones
					.toString());
		} catch (EpSilonExcepciones e) {
			Mensajes.mensajeError("ERROR, Al guardar Fichero de configuracin");

		} catch (IOException e) {
			Mensajes.mensajeError("ERROR, Al guardar Fichero de configuracin");
		}
		// System.out.print(textoOpciones);
		this.dispose();
	}

	/**
	 * Accin botn seleccionar fuente
	 * 
	 * 
	 * 
	 * @param evt
	 *            the evt
	 *            <p>
	 *            Creado : Parras, 06-jun-2009
	 *            </p>
	 */
	private void jButtonFuenteActionPerformed(java.awt.event.ActionEvent evt) {
		fuente = SeleccionarFuente.showDialog(this, "Selector de Fuentes",
				new Font("Dialog", 0, 12));
		if (fuente != null) {
			jLabelTextoFuente.setText(setFormateoFuente(fuente));
			hayCambios = true;
		}
		// System.out.println(fuente);
	}

	/**
	 * Modifica la propiedad del formateo fuente.
	 * 
	 * @param f
	 *            Fuente a modificar
	 * 
	 * @return the string <br>
	 *         Creado : Parras, 06-jun-2009 java.awt.Font
	 */
	private String setFormateoFuente(Font f) {
		String estilo = "";
		if (f.isBold())
			estilo = "Negrita";

		if (f.isItalic())
			estilo = "Cursiva";
		if (f.isPlain())
			estilo = "Normal";

		return f.getName() + "+" + estilo + "+" + String.valueOf(f.getSize());
	}

	/*
	 * public void setDefault(){
	 * 
	 * //{ "Texto","Palabras Reservadas", "Identificadores", "Separadores",
	 * "Operadores", "Comentarios" };
	 * 
	 * 
	 * //Preparamamos los atributos
	 * 
	 * // new ItemDeLista("texto", "Texto"), // new ItemDeLista("reservada",
	 * "Palabras Reservadas"), // new ItemDeLista("identificador",
	 * "Identificadores"), // new ItemDeLista("separador", "Separadores"), //
	 * new ItemDeLista("operador", "Operadores"), // new
	 * ItemDeLista("comentario", "Comentarios")
	 * 
	 * 
	 * //Body
	 * 
	 * imapa.put(new ItemDeLista("texto", "Texto"), new AtributosPreferenicas
	 * (new Font("Monospaced",0,12), Color.white,Color.black)); //Aadir al Mapa
	 * 
	 * //Tag //Aadir al Mapa imapa.put(new ItemDeLista("tag", "Etiquetas"),new
	 * AtributosPreferenicas (new Font("Monospaced",0,12),
	 * Color.white,Color.black));
	 * 
	 * 
	 * //endtag //Aadir al Mapa //imapa.put("Tag",new AtributosPreferenicas
	 * (new Font("Monospaced",0,12), Color.white,Color.blue));
	 * 
	 * //reference //imapa.put("reference",new AtributosPreferenicas (new
	 * Font("Monospaced",0,12), Color.white,Color.black));
	 * 
	 * // Tag //Aadir al Mapa //imapa.put("name",new AtributosPreferenicas (new
	 * Font("Monospaced",0,12), Color.white,new Color(0xB03060)));
	 * 
	 * // reservedWord //Aadir al Mapa imapa.put(new ItemDeLista("reservada",
	 * "Palabras Reservadas"),new AtributosPreferenicas (new
	 * Font("Monospaced",0,12), Color.white,Color.blue));
	 * 
	 * // identifier
	 * 
	 * //Aadir al Mapa imapa.put( new ItemDeLista("identificador",
	 * "Identificadores"),new AtributosPreferenicas (new
	 * Font("Monospaced",0,12), Color.white,Color.black));
	 * 
	 * 
	 * 
	 * 
	 * 
	 * }
	 */

	// Metodos
	/**
	 * Guarda los colores seleccionadoes en nustro mapa
	 * 
	 * @param valor
	 *            ItemDeLista
	 *            <p>
	 *            Creado : Parras, 06-jun-2009
	 *            </p>
	 *@see proyecto.preferencias.ItemDeLista
	 */
	private void setAsignarColores(ItemDeLista valor) {
		AtributosPreferenicas asignarcolores = imapaAux.get(valor);

		if (asignarcolores != null) {

			jLabelTextoFuente.setText(setFormateoFuente(asignarcolores
					.getFuente()));
			jPanelColorBackGround.setBackground(asignarcolores.getColorBack());
			jPanelColorForeGround.setBackground(asignarcolores.getColorFore());
			// System.out.print("\n setAsignarColores  " +
			// asignarcolores.getColorFore().toString()+asignarcolores.getColorBack());

		} else {
			System.out.print("Nulo para este texo " + valor);
		}

	}

	/**
	 * Modificar la propiedad guardar colores.
	 * 
	 * @param valorAnterior2
	 *            La propiedad guardar colores
	 *@see proyecto.preferencias.ItemDeLista
	 *@see proyecto.preferencias.ItemDeLista
	 */
	public void setGuardarColores(ItemDeLista valorAnterior2) {
		AtributosPreferenicas atributo = imapaAux.get(valorAnterior2);

		// System.out.print("\nAtributo Que Eliminamos "+atributo);
		if (colorBack == null)
			colorBack = atributo.getColorBack();

		if (colorFore == null)
			colorFore = atributo.getColorFore();

		if (fuente == null)
			fuente = atributo.getFuente();

		imapaAux.get(valorAnterior2).setFuente(fuente);
		imapaAux.get(valorAnterior2).setColorBack(colorBack);
		imapaAux.get(valorAnterior2).setColorFore(colorFore);
		// atributo=imapaAux.put(valor, new AtributosPreferenicas(new
		// Font(fuente.getName(),fuente.getStyle(),fuente.getSize()),colorBack,colorFore));

		// Volvemos a poner los valores a nulo
		fuente = null;
		colorBack = null;
		colorFore = null;

	}

	/**
	 * Obtener el imapa de los baroles modificados.
	 * 
	 * @return el imapa Creado : Parras, 06-jun-2009 *@see
	 *         proyecto.preferencias.ItemDeLista
	 *@see proyecto.preferencias.AtributosPreferenicas
	 */
	public Map<ItemDeLista, AtributosPreferenicas> getImapa() {
		return imapaAux;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseListener#mouseClicked(java.awt.event.MouseEvent)
	 */
	public void mouseClicked(MouseEvent arg0) {
		// Recogemos lo colores y lo guardamos en el mapa auxiliar
		setHabilitarBotones();
		ItemDeLista valor = (ItemDeLista) this.jList1.getSelectedValue();
		setAsignarColores(valor);

		if (hayCambios) {
			// Hay cambios guardamos los datos
			setGuardarColores(valorAnterior);
		} else {
			valorAnterior = valor;
		}
		// hemos Terminado y tiene que estar a falso para otras modificaciones
		hayCambios = false;

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseListener#mouseEntered(java.awt.event.MouseEvent)
	 */
	public void mouseEntered(MouseEvent arg0) {

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseListener#mouseExited(java.awt.event.MouseEvent)
	 */
	public void mouseExited(MouseEvent arg0) {
		// TODO Apndice de mtodo generado automticamente

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseListener#mousePressed(java.awt.event.MouseEvent)
	 */
	public void mousePressed(MouseEvent arg0) {
		// TODO Apndice de mtodo generado automticamente

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.MouseListener#mouseReleased(java.awt.event.MouseEvent)
	 */
	public void mouseReleased(MouseEvent arg0) {
		// TODO Apndice de mtodo generado automticamente

	}

	// Variables declaration - do not modify
	/** Tbutton aceptar. */
	private javax.swing.JButton jButtonAceptar;

	/** Tbutton por defecto. */
	private javax.swing.JButton jButtonPorDefecto;

	/** Tbutton back ground. */
	private javax.swing.JButton jButtonBackGround;

	/** Tbutton cancelar. */
	private javax.swing.JButton jButtonCancelar;

	/** Tbutton fore ground. */
	private javax.swing.JButton jButtonForeGround;

	/** Tbutton fuente. */
	private javax.swing.JButton jButtonFuente;

	/** Tlabel1. */
	private javax.swing.JLabel jLabel1;

	/** Tlabel back ground. */
	private javax.swing.JLabel jLabelBackGround;

	/** Tlabel fore ground. */
	private javax.swing.JLabel jLabelForeGround;

	/** Tlabel fuente. */
	private javax.swing.JLabel jLabelFuente;

	/** Tlabel texto fuente. */
	private javax.swing.JLabel jLabelTextoFuente;

	/** Tlist1. */
	private javax.swing.JList jList1;

	/** pane relleno. */
	private javax.swing.JPanel jPaneRelleno;

	/** panel1. */
	private javax.swing.JPanel jPanel1;

	/** panel2. */
	private javax.swing.JPanel jPanel2;

	/** panel botonera. */
	private javax.swing.JPanel jPanelBotonera;

	/** color back ground. */
	private javax.swing.JPanel jPanelColorBackGround;

	/** panel color fore ground. */
	private javax.swing.JPanel jPanelColorForeGround;

	/** scroll pane1. */
	private javax.swing.JScrollPane jScrollPane1;
	// End of variables declaration

}
