/*
 * 
 * @author Manuel Parras  
 */
package proyecto.utilidades;


import java.awt.Color;
import java.awt.Font;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import proyecto.editor.PanelEdicion;

/**
 * BarraEstado
 * <p>
 * La barra de estado es la encargada de dar informacin al usuario sobre
 * eventos ocurridos en la aplicacin en la zona del editor. Est compuesta en
 * dos partes:
 * </p>
 * <ul>
 * <li>Posicin: Indica la posicin del cursor (lnea y columna) en cada
 * momento. Esta referido al documento con el que estamos trabajando en este
 * preciso momento (tiene que tener el foco). La posicin tiene un evento
 * asociado al darle doble click consiste en: abrir la ventana para ir al nmero
 * de lnea en nuestro fichero.</li>
 * <li>Observaciones: Indica acciones que se realiza en el editor (abrir un
 * archivo, guardar archivo .etc...). Las observaciones se eliminarn cuando
 * exista un movimiento de la posicin.</li>
 * </ul>
 * <p>
 * La barra de estado solo debe estar visible en nuestra aplicacin cuando
 * exista un fichero abierto. En otro caso estar no visible.
 * </p>
 * <p>
 * Creado : Parras, 12-oct-2009
 * </p>
 * 
 * @see proyecto.editor.PanelEdicion
 * @see proyecto.editor.PanelEdicion#getVentanaIrA()
 */
public class BarraEstado extends javax.swing.JPanel implements MouseListener {
    
    /** Constante serialVersionUID. */
	private static final long serialVersionUID = -8438914597314944760L;
	
	/** Constante color de barra estado . */
	private static final Color COLOR_BARRA_ESTADO=Color.BLUE;//new java.awt.Color(255, 0, 0);
    
    /**Constante fuente de barra de estado FUENTE_BARRA_ESTADO. */
    private static final Font  FUENTE_BARRA_ESTADO=new Font("Courier", 1, 12);
	
	/** @see proyecto.editor.PanelEdicion */
	private PanelEdicion iPanelEdicion;
	
    /**
	 * Constructor barra estado, crea los componentes y listener.
	 * 
	 * @param aPanel
	 *             panel
	 * <p> Creado : Parras, 12-oct-2009</p>            
	 */
    public BarraEstado(PanelEdicion aPanel) {
        this.iPanelEdicion = aPanel;
    	initComponents();
      textAreacursor.addMouseListener(this); 
            
    }

    /**
	 * Obtener el text areacursor.
	 * <p>Posicin en la que se encuentra nuentro curso en cada momento</p>
	 * @return el text areacursor
	 * <p>Creado : Parras, 12-oct-2009</p>
	 */
    public String getTextAreacursor() {
        return textAreacursor.getText();
    }

    /**
	 * Modificar la propiedad text areacursor.
	 * 
	 * @param aTCursor
	 *            La propiedad text areacursor
	 *  <p>Creado : Parras, 12-oct-2009</p>
	 */
    public void setTextAreacursor(String aTCursor) {
        textAreacursor.setText(aTCursor);
    }

    /**
	 * Obtener el text area opciones.
	 * 
	 * @return el text area opciones
	 * <p>Creado : Parras, 12-oct-2009</p> 
	 */
    public String getTextAreaOpciones() {
        return textAreaOpciones.getText();
    }

    /**
	 * Modificar la propiedad text area opciones.
	 * 
	 * @param aTpciones
	 *            La propiedad text area opciones
	 *  <p>Creado : Parras, 12-oct-2009</p>
	 */
    public void setTextAreaOpciones(String aTpciones) {
        this.textAreaOpciones.setText(aTpciones) ;
    }
    
    
    
   
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">                          
    /**
	 * Inits the components. Creado : Parras, 12-oct-2009
	 */
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        textAreaOpciones = new javax.swing.JTextArea();
        textAreacursor = new javax.swing.JTextArea();

        setLayout(new java.awt.GridBagLayout());

        setMaximumSize(new java.awt.Dimension(4, 24));
        setPreferredSize(new java.awt.Dimension(4, 24));
        textAreaOpciones.setColumns(20);
        textAreaOpciones.setEditable(false);        
        textAreaOpciones.setFont(FUENTE_BARRA_ESTADO);
        textAreaOpciones.setForeground(COLOR_BARRA_ESTADO);
        textAreaOpciones.setRows(5);
        //textAreaOpciones.setFocusable(false);
        textAreaOpciones.setMaximumSize(new java.awt.Dimension(10, 18));
        textAreaOpciones.setMinimumSize(new java.awt.Dimension(10, 18));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.ipady = 5;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(0, 2, 4, 0);
        add(textAreaOpciones, gridBagConstraints);

        textAreacursor.setColumns(20);
        textAreacursor.setEditable(false);
        textAreacursor.setFont(new java.awt.Font("Courier", 1, 12));
        textAreacursor.setRows(5);
        textAreacursor.setCaretColor(new java.awt.Color(224, 223, 227));
        textAreacursor.setFocusable(false);
        textAreacursor.setMaximumSize(new java.awt.Dimension(10, 18));
        textAreacursor.setMinimumSize(new java.awt.Dimension(10, 18));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.ipady = 5;
        gridBagConstraints.weightx = 0.1;
        gridBagConstraints.insets = new java.awt.Insets(0, 0, 4, 0);
        add(textAreacursor, gridBagConstraints);

    }// </editor-fold>                        
    
    
    // Variables declaration - do not modify                     
    /** text area opciones. */
    private javax.swing.JTextArea textAreaOpciones;
    
    /** text areacursor. */
    private javax.swing.JTextArea textAreacursor;
    // End of variables declaration                   

    
    //Metodos que tenemos que implementar para el MouseListener
	/**
     * @see proyecto.editor.PanelEdicion#getVentanaIrA()
     * @see java.awt.event.MouseListener#mouseClicked(java.awt.event.MouseEvent)
     *  
     */
    public void mouseClicked(MouseEvent e) {
		   if (e.getClickCount()==2){
               //System.out.println("Por Definir Doble Clik en TextoAreaCursor");
			   iPanelEdicion.getVentanaIrA();
            }
		
	}

	/* (non-Javadoc)
	 * @see java.awt.event.MouseListener#mouseEntered(java.awt.event.MouseEvent)
	 */
	public void mouseEntered(MouseEvent e) {
		
		
	}

	/* (non-Javadoc)
	 * @see java.awt.event.MouseListener#mouseExited(java.awt.event.MouseEvent)
	 */
	public void mouseExited(MouseEvent e) {
		
		
	}

	/* (non-Javadoc)
	 * @see java.awt.event.MouseListener#mousePressed(java.awt.event.MouseEvent)
	 */
	public void mousePressed(MouseEvent e) {
		
		
	}

	/* (non-Javadoc)
	 * @see java.awt.event.MouseListener#mouseReleased(java.awt.event.MouseEvent)
	 */
	public void mouseReleased(MouseEvent e) {
		
		
	}
    
}
