/*
 * 
 * @author Manuel Parras  
 */
package proyecto.utilidades;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import javax.swing.JOptionPane;

/**
 * 
 * Mensajes.
 * 
 * <p>
 * Clase que gestiona los eventos de mensajes de nuestra aplicacin. Cualquier
 * tipo de mensaje que necesitamos (Informacin, Error, Informacin con detalle
 * ..etc.) seralizado desde esta clase.<p>
 * @see  javax.swing.JOptionPane
 */
public class Mensajes {

    /** Tipo usado para mostrar los botones SI,NO. */
    public final static int SI_NO =1;
    
    /** Tipo usado para mostrar los botones SI,NO y CANCELAR. */
    public final static int SI_NO_CANCELAR = 2;
    
    /** Tipo usado para mostrar los botones ACEPTAR y CANCELAR. */
    public final static int ACEPTAR_CANCELAR = 3;
    
    /** Tipo usado para mostrar segn el botn ACEPTAR. */
    public final static int ACEPTAR = 4;
    
    /** Tipo usado para mostrar los botones REINTENTAR y CANCELAR. */
    public final static int REINTENTAR_CANCELAR = 5;
    
    /** Tipo usado para mostrar los botones ABORTAR,REINTENTAR y IGNORAR. */
    public final static int ABORTAR_REINTENTAR_IGNORAR = 6;
    
    /** Tipo usado para mostrar los botones ACEPTAR y DETALLES. */
    public final static int ACEPTAR_DETALLES = 7;


    //el final en este caso sirve para que no se pueda redimensionar
    //el array, pero si se puede cambiar su valor

    /** Contiene el texto para los botones SI,NO. */
    protected final static String[] SI_NO_TXT = new String[2];
    
    /** Contiene el texto para los botones SI,NO y CANCELAR. */
    protected final static String[] SI_NO_CANCELAR_TXT = new String[3];
    
    /** Contiene el texto para los botones ACEPTAR y CANCELAR. */
    protected final static String[] ACEPTAR_CANCELAR_TXT = new String[2];
    
    /** Contiene el texto para el botn ACEPTAR. */
    protected final static String[] ACEPTAR_TXT = new String[1];
    
    /** Contiene el texto para los botones REINTENTAR y CANCELAR. */
    protected final static String[] REINTENTAR_CANCELAR_TXT = new String[2];
    
    /** Contiene el texto para los botones ABORTAR, REINTENTAR y IGNORAR. */
    protected final static String[] ABORTAR_REINTENTAR_IGNORAR_TXT = new String[3];
	
	/** Contiene el texto para los botones ACEPTAR y DETALLES. */
	protected final static String[] ACEPTAR_DETALLES_TXT = new String[2];


	/** Texto para el ttulo del mensaje Error. */
    protected final static String[] TITULO_ERROR = new String[1];

	/** Texto para el ttulo del mensaje Informacin. */
	protected final static String[] TITULO_INFORMACION = new String[1];

	/** Texto para el ttulo del mensaje Pregunta. */
	protected final static String[] TITULO_PREGUNTA = new String[1];

	/** Texto para el ttulo del mensaje Atencin. */
	protected final static String[] TITULO_ATENCION = new String[1];

	/** Texto para el mensaje de abandonar la aplicacin (error FATAL). */
	protected final static String[] MENSAJE_SALIR_APLICACION = new String[4];


	/** Tipo usado para mostrar un icono de ERROR. */
    public final static int STOP = 0;

    /** Tipo usado para mostrar un icono de INFORMACION. */
    public final static int INFORMACION = 1;

    /** Tipo usado para mostrar un icono de ALERTA . */
    public final static int ALERTA = 2;

    /** Tipo usado para mostrar un icono de PREGUNTA. */
    public final static int PREGUNTA = 3;

    /** Tipo usado para no mostrar icono. */
    public final static int SIMPLE = -1;

    /** Indica si estan cargadas las var. estticas de la clase. */
    protected static boolean variableCargada = false;

    // Este metodo carga las las constantes estaticas con los valores que tendran los distintos botones
    // la primera vez que se muestre un mensaje, y un array de string  con los textos de los botones
    // para el mensaje
    /**
	 * Cargar constantes.
	 * 
	 * @param aiBoton
	 *            the ai boton
	 * 
	 * @return the string[] Creado : Parras, 12-oct-2009
	 */
    protected static String[] cargarConstantes(int aiBoton) {
        String lsBoton[] = new String[3];//solo para 3 botones

        if ( !variableCargada ) {
            String lsFicheroIdioma = new String();
            lsFicheroIdioma = (new Mensajes()).getClass().getName();
            lsFicheroIdioma = lsFicheroIdioma.replace('.',  java.io.File.separatorChar);

            try{
                ResourceBundle  lrecurso = ResourceBundle.getBundle(lsFicheroIdioma);
                SI_NO_TXT[0] = lrecurso.getString("      SI      ");
                SI_NO_TXT[1] = lrecurso.getString("NO");
                SI_NO_CANCELAR_TXT[0] = lrecurso.getString("SI");
                SI_NO_CANCELAR_TXT[1] = lrecurso.getString("NO");
                SI_NO_CANCELAR_TXT[2] = lrecurso.getString("CANCELAR");
                ACEPTAR_CANCELAR_TXT[0] = lrecurso.getString("ACEPTAR");
                ACEPTAR_CANCELAR_TXT[1] = lrecurso.getString("CANCELAR");
                ACEPTAR_TXT[0] = lrecurso.getString("ACEPTAR");
                REINTENTAR_CANCELAR_TXT[0] = lrecurso.getString("REINTENTAR");
                REINTENTAR_CANCELAR_TXT[1] = lrecurso.getString("CANCELAR");
                ABORTAR_REINTENTAR_IGNORAR_TXT[0] = lrecurso.getString("ABORTAR");
                ABORTAR_REINTENTAR_IGNORAR_TXT[1] = lrecurso.getString("REINTENTAR");
                ABORTAR_REINTENTAR_IGNORAR_TXT[2] = lrecurso.getString("IGNORAR");
				ACEPTAR_DETALLES_TXT[0] = lrecurso.getString("ACEPTAR");
				ACEPTAR_DETALLES_TXT[1] = lrecurso.getString("DETALLES");

				TITULO_ERROR[0] = lrecurso.getString("TITULO_ERROR");
				TITULO_INFORMACION[0] = lrecurso.getString("TITULO_INFORMACION");
				TITULO_PREGUNTA[0] = lrecurso.getString("TITULO_PREGUNTA");
				TITULO_ATENCION[0] = lrecurso.getString("TITULO_ATENCION");
				MENSAJE_SALIR_APLICACION[0] = lrecurso.getString("ERROR_GRAVE");
				MENSAJE_SALIR_APLICACION[1] = lrecurso.getString("FUNCIONAMIENTO_INCORRECTO");
				MENSAJE_SALIR_APLICACION[2] = lrecurso.getString("RECOMENDAR_SALIR");
				MENSAJE_SALIR_APLICACION[3] = lrecurso.getString("FINALIZAR_APLICACION");

            }
            catch (MissingResourceException mre) {//no encuentra el fichero de propiedades, o alguna
                //de las etiquetas, se cargan todas por defecto
                //Log.av("Fichero de traduccin " + isFicheroIdioma + " incompleto. Se usarn etiquetas por defecto.");
				//System.out.println("Fichero de traduccin " + isFicheroIdioma + " incompleto. Se usarn etiquetas por defecto.");
                SI_NO_TXT[0] = "      Si      ";
                SI_NO_TXT[1] = "      No      ";
                SI_NO_CANCELAR_TXT[0] = "      Si      ";
                SI_NO_CANCELAR_TXT[1] = "      No      ";
                SI_NO_CANCELAR_TXT[2] = "   Cancelar   ";
                ACEPTAR_CANCELAR_TXT[0] = "    Aceptar   ";
                ACEPTAR_CANCELAR_TXT[1] = "   Cancelar   ";
                ACEPTAR_TXT[0] = "    Aceptar   ";
                REINTENTAR_CANCELAR_TXT[0] = "  Reintentar  ";
                REINTENTAR_CANCELAR_TXT[1] = "   Cancelar   ";
                ABORTAR_REINTENTAR_IGNORAR_TXT[0] = "   Abortar    ";
                ABORTAR_REINTENTAR_IGNORAR_TXT[1] = "  Reintentar  ";
                ABORTAR_REINTENTAR_IGNORAR_TXT[2] = "   Ignorar    ";
				ACEPTAR_DETALLES_TXT[0] = "    Aceptar   ";
				ACEPTAR_DETALLES_TXT[1] = " Detalles >>  ";

				TITULO_ERROR[0] = "Error";
				TITULO_INFORMACION[0] = "Informacin";
				TITULO_PREGUNTA[0] = "Pregunta";
                TITULO_ATENCION[0] = "Atencin";
				MENSAJE_SALIR_APLICACION[0] = "Se ha producido un error grave.";
				MENSAJE_SALIR_APLICACION[1] = "Es posible que la aplicacin deje de funcionar correctamente.";
				MENSAJE_SALIR_APLICACION[2] = "Se recomienda finalizar la aplicacin.";
				MENSAJE_SALIR_APLICACION[3] = "Desea finalizar la aplicacin?";

            }
            variableCargada = true;
        }
        // Si ya esta cargado

        switch (aiBoton ){
            case SI_NO:
                lsBoton = SI_NO_TXT;
                break;
            case SI_NO_CANCELAR:
                lsBoton = SI_NO_CANCELAR_TXT;
                break;
            case ACEPTAR_CANCELAR:
                lsBoton = ACEPTAR_CANCELAR_TXT;
                break;
            case ACEPTAR:
                lsBoton = ACEPTAR_TXT;
                break;
            case REINTENTAR_CANCELAR:
                lsBoton = REINTENTAR_CANCELAR_TXT;
                break;
            case ABORTAR_REINTENTAR_IGNORAR:
                lsBoton = ABORTAR_REINTENTAR_IGNORAR_TXT;
                break;
			case ACEPTAR_DETALLES:
                lsBoton = ACEPTAR_DETALLES_TXT;
                break;
            default ://si hay algun error pongo el boton aceptar
                lsBoton = ACEPTAR_TXT;
                break;
        }
        return lsBoton;

        //para que no aparezca el icono de la taza de cafe ->
	//asigno  un icono  al frame que utiliza el joptionpane cuando es
        //nulo el primer argumento,

        //String lsPathIcono = lrecurso.getString("PATH_ICONO");
	//Frame lfFrame = JOptionPane.getRootFrame();
        //lfFrame.setIconImage(java.awt.Toolkit.getDefaultToolkit().getImage(lsPathIcono));

    }



    /**
	 * Muestra un mensaje con un icono de INFORMACION y un botn ACEPTAR.
	 * 
	 * @param asTitulo
	 *            the as titulo
	 * @param asMensaje
	 *            the as mensaje
	 * 
	 * @return Un tipo int indicando la opcin elegida por el usuario
	 */

    public static int muestraMensaje(String asTitulo, String asMensaje){
        return muestraMensaje(asTitulo , asMensaje , INFORMACION , ACEPTAR );
    }


    /**
	 * Muestra un mensaje con un botn ACEPTAR.
	 * 
	 * @param asTitulo
	 *            the as titulo
	 * @param asMensaje
	 *            the as mensaje
	 * @param aiIcono
	 *            the ai icono
	 * 
	 * @return Un tipo int indicando la opcin elegida por el usuario
	 */
    public static int muestraMensaje(String asTitulo, String asMensaje , int aiIcono){
        return muestraMensaje(asTitulo , asMensaje , aiIcono , ACEPTAR );
    }
    
    /**
	 * Muestra la ventana con un input para introducir datos.
	 * 
	 * @param asTitulo
	 *            the as titulo
	 * @param asMensaje
	 *            the as mensaje
	 * @param aiIcono
	 *            the ai icono
	 * 
	 * @return Devuelve la cadena de caracteres escrita por el usuario
	 */
    public static String entradaMensaje (String asTitulo, String asMensaje , int aiIcono){
    	 return JOptionPane.showInputDialog(null, asMensaje, asTitulo, aiIcono);
    }
    
    

    /**
	 * Muestra un mensaje especificando todos los parmetros.
	 * 
	 * @param asTitulo
	 *            the as titulo
	 * @param asMensaje
	 *            the as mensaje
	 * @param aiIcono
	 *            the ai icono
	 * @param aiBoton
	 *            the ai boton
	 * 
	 * @return Un tipo int indicando la opcin elegida por el usuario
	 */
    public static int muestraMensaje (String asTitulo, String asMensaje, int aiIcono, int aiBoton ){
		int valor = 0;
		try{
			if (!javax.swing.SwingUtilities.isEventDispatchThread()){
				MuestraMensaje muestra = new MuestraMensaje(asTitulo,asMensaje,aiIcono,aiBoton);
				javax.swing.SwingUtilities.invokeLater(muestra);
				valor = muestra.getValor();
                        } else {
                            // modificado
                            // Si segn hay un botn se pone como componente por defecto (valor inicial)
                            // Si no, no se pone ningn componente por defecto
                            if (Mensajes.cargarConstantes(aiBoton).length==1){
                                valor = JOptionPane.showOptionDialog(null , asMensaje ,asTitulo ,JOptionPane.DEFAULT_OPTION ,
                                                                                               aiIcono , null , Mensajes.cargarConstantes(aiBoton) , Mensajes.cargarConstantes(aiBoton)[0]);
                            } else {
                                valor = JOptionPane.showOptionDialog(null , asMensaje ,asTitulo ,JOptionPane.DEFAULT_OPTION ,
        						                                   aiIcono , null , Mensajes.cargarConstantes(aiBoton) ,null);
                            }
                        }
              // final modificado

                } catch (Throwable lth){
			
		}

		return valor;

//        return appThread
    }


    
    
  /**
	 * Muestra un mensaje especificando todos los parámetros.
	 * 
	 * 
	 * @param asTitulo
	 * @param asMensaje
	 * @param aiIcono
	 * @param aiBoton
	 * @param aiBotonDefecto
	 *            Boton por defecto en el mensaje
	 *            SI_NO_CANCELAR,ACEPTAR_CANCELAR, ACEPTAR,REINTENTAR_CANCELAR,
	 *            ABORTAR_REINTENTAR_IGNORAR
	 * 
	 * @return Un tipo int indicando la opción elegida por el usuario
	 */
	public static int muestraMensaje(String asTitulo, String asMensaje,
			int aiIcono, int aiBoton, int aiBotonDefecto) {
		int valor = 0;

		try {
			if (!javax.swing.SwingUtilities.isEventDispatchThread()) {
				MuestraMensaje muestra = new MuestraMensaje(asTitulo,
						asMensaje, aiIcono, aiBoton);
				javax.swing.SwingUtilities.invokeLater(muestra);
				valor = muestra.getValor();
                        } else {
                                if (aiBoton >= aiBotonDefecto && aiBotonDefecto >= 0)
                                {
                                    valor = JOptionPane.showOptionDialog(null , asMensaje ,asTitulo ,JOptionPane.DEFAULT_OPTION ,
                                    			                                   aiIcono , null , Mensajes.cargarConstantes(aiBoton) , Mensajes.cargarConstantes(aiBoton)[aiBotonDefecto]);       
                                    //System.out.println("el boton por defecto si vale");
                                }else{
                                    valor = JOptionPane.showOptionDialog(null , asMensaje ,asTitulo ,JOptionPane.DEFAULT_OPTION ,
                                    			                                   aiIcono , null , Mensajes.cargarConstantes(aiBoton) , Mensajes.cargarConstantes(aiBoton)[0]);       
                                    //System.out.println("el boton por defecto no vale");
                                }
                        }    
              

                } catch (Throwable lth){
			
		}

		return valor;


    }



/**
 * Muestra un mensaje con el ttulo "Error" y con el icono de "Stop".
 * 
 * @param asMensaje
 *            Mensaje a mostrar
 * 
 * @return El botn seleccionado
 */
	public static int mensajeError (String asMensaje){
		cargarConstantes(1); // Sin esta lnea no se cargan los ttulos (arreglar esto!!)
		return muestraMensaje(TITULO_ERROR[0], asMensaje, STOP);
    }

/**
 * Muestra un mensaje con el ttulo "Informacin" y con el icono de "i".
 * 
 * @param asMensaje
 *            Mensaje a mostrar
 * 
 * @return El botn seleccionado (en este caso solo existe Aceptar)
 */
	public static int mensajeInfo (String asMensaje){
		cargarConstantes(1);
		return muestraMensaje(TITULO_INFORMACION[0], asMensaje, INFORMACION);
    }

 

/**
 * Muestra un mensaje con el ttulo "Pregunta" y con el icono de "?".
 * 
 * @param asMensaje
 *            Mensaje a mostrar
 * @param aiBoton
 *            Los botones que se quieren mostrar (ver constantes)
 * 
 * @return El botn seleccionado
 */
	public static int mensajePregunta (String asMensaje, int aiBoton){
		cargarConstantes(1);
		return muestraMensaje(TITULO_PREGUNTA[0], asMensaje, PREGUNTA, aiBoton);
                // crear un nuevo  metodo  que se le pasa el boton por defecto.
                
                
    }
    
    
//    
/**
 * Muestra un mensaje con el ttulo "Pregunta" y con el icono de "?".
 * 
 * @param asMensaje
 *            Mensaje a mostrar
 * @param aiBoton
 *            Los botones que se quieren mostrar (ver constantes)
 * @param aiBotonDefecto
 *            indica el botn que tiene el foco por defecto
 * 
 * @return El botn seleccionado
 */
	public static int mensajePregunta (String asMensaje, int aiBoton,int aiBotonDefecto){
                cargarConstantes(1);
		return muestraMensaje(TITULO_PREGUNTA[0], asMensaje, PREGUNTA, aiBoton,aiBotonDefecto);
                // crear un nuevo  metodo  que se le pasa el boton por defecto.
                
                
    }    
    
//     
    

/**
 * Muestra un mensaje con el ttulo "Atencin" y con el icono de "!".
 * 
 * @param asMensaje
 *            Mensaje a mostrar
 * 
 * @return El botn seleccionado (en este caso solo existe Aceptar)
 */
	public static int mensajeAtencion (String asMensaje){
        cargarConstantes(1);
		return muestraMensaje(TITULO_ATENCION[0], asMensaje, ALERTA);
    }

/**
 * Muestra un mensaje con el ttulo "Error" y con el icono de "Stop" y dos
 * botones: "Aceptar" y "Detalles". En el primer caso no se hace nada. En el
 * segundo se abre una segunda ventana que muestra el mensaje devuelvo por la
 * excepcin pasada como argumento
 * 
 * IMPORTANTE: En caso de que la excepcin sea de tipo FATAL, se cierra la
 * aplicacin automticamente
 * 
 * @param asMensaje
 *            Mensaje a mostrar
 * @param athExcepcion
 *            La excepcion cuyo mensaje se quiere mostrar
 * 
 * @return El botn seleccionado
 */
	public static int mensajeDetalles (String asMensaje, Throwable athExcepcion)
	{
		int liRtn = -1;

//		if (!Thread.currentThread().getName().equals("main"))
//		{
//			Thread.currentThread().interrupt();
//		}
//		else
//		{
		  

			cargarConstantes(1);
			liRtn = muestraMensaje(TITULO_ERROR[0], asMensaje, STOP, ACEPTAR_DETALLES);

			// Si se pulsnDetalles, mostramos la ventana correspondiente
			if (liRtn == 1)
			{
				liRtn = muestraMensaje(ACEPTAR_DETALLES_TXT[1], athExcepcion.getMessage(), STOP);
							athExcepcion.printStackTrace();
			}
//		}
		return liRtn;
    }

	
    /**
	 * Muestra un mensaje con el ttulo "Error" y con el icono de "Stop" y dos
	 * botones: "Aceptar" y "Detalles". En el primer caso no se hace nada. En el
	 * segundo se abre una segunda ventana que muestra el mensaje devuelvo por
	 * la excepcin pasada como argumento este metodo pone por defecto el botn
	 * que se quiera
	 * 
	 * IMPORTANTE: En caso de que la excepcin sea de tipo FATAL, se cierra la
	 * aplicacin automticamente
	 * 
	 * @param asMensaje
	 *            Mensaje a mostrar
	 * @param athExcepcion
	 *            La excepcion cuyo mensaje se quiere mostrar
	 * @param aiBotonDefecto
	 *            indica el boton por defecto del mensaje.
	 * 
	 * @return El botn seleccionado
	 */
	public static int mensajeDetalles (String asMensaje, Throwable athExcepcion,int aiBotonDefecto)
	{
		int liRtn = -1;

//		if (!Thread.currentThread().getName().equals("main"))
//		{
//			Thread.currentThread().interrupt();
//		}
//		else
//		{
		 

			cargarConstantes(1);
			liRtn = muestraMensaje(TITULO_ERROR[0], asMensaje, STOP, ACEPTAR_DETALLES,aiBotonDefecto);

			// Si se pulsn Detalles, mostramos la ventana correspondiente
			if (liRtn == 1)
			{
				liRtn = muestraMensaje(ACEPTAR_DETALLES_TXT[1], athExcepcion.getMessage(), STOP);
							athExcepcion.printStackTrace();
			}
//		}
		return liRtn;
    }
    







	// MAIN DE PRUEBAS
/**
	 * Main para pruebas.
	 * 
	 * @param args
	 *            Argumentos de entrada
	 */
	public static void main (String args[])
	{
		try{

			Locale currentLocale;
			currentLocale = new Locale("en", "GB");
			Locale.setDefault(currentLocale);


			mensajeError("String asMensaje");
			mensajeInfo("String asMensaje");
			mensajePregunta("String asMensaje", Mensajes.ABORTAR_REINTENTAR_IGNORAR);
			mensajeAtencion("String asMensaje");
			String[] la = new String[5];
			la[0] = " Dar de alta al paciente";
			la[1] = " Descartar los cambios";
			la[2] = " Salir de la aplicacin";
			la[3] = " Imprimir el resultado";
			la[4] = " Dar de baja al paciente";
			//			int li = op.muestraVentana(la, "<HTML>Se han encontrado distintas posibilidades<BR>de seleccin.", "Indique quin desea hacer:", "Seleccione paciente");
	



		}
		catch (Exception e)
		{
			mensajeDetalles("Se ha producido una excepcin", e);
			e.printStackTrace();
			System.exit(0);
		}
	}

 }

final class MuestraMensaje implements Runnable{
	 String titulo;
	 String mensaje;
	 int icono;
	 int boton;
     int valor;
     
	 public MuestraMensaje(String asTitulo, String asMensaje, int aiIcono, int aiBoton){
		this.titulo = asTitulo;
		this.mensaje = asMensaje;
		this.icono = aiIcono;
		this.boton = aiBoton;
	 }
	 public void run() {
		// Si segn hay un botn se pone como componente por defecto (valor inicial)
        // Si no, no se pone ningn componente por defecto
        if (boton==0)
            valor = JOptionPane.showOptionDialog(null , mensaje ,titulo ,JOptionPane.DEFAULT_OPTION ,
				                                   icono , null , Mensajes.cargarConstantes(boton) , Mensajes.cargarConstantes(boton)[0]);       
        else
            valor = JOptionPane.showOptionDialog(null , mensaje ,titulo ,JOptionPane.DEFAULT_OPTION ,
		                                           icono , null , Mensajes.cargarConstantes(boton) , null);       
           //System.out.println("pasa por aki");     
	 }
     
	 public int getValor(){
		return valor;
	 }
}

