/*
 * 
 * @author Manuel Parras  
 */
package proyecto.utilidades;

import java.awt.Component;
import java.awt.Event;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;
import javax.swing.KeyStroke;

import proyecto.editor.JavaTextPane;
import proyecto.editor.PanelEdicion;
import proyecto.imagenes.IconFactory;

/**
 ** MenuPopup.java
 * 
 * Esta clase es la encargada de pintarnos nuestro men contextual cuando
 * pulsemos con el botn derecho del ratn sobre una pestaa que contiene un
 * componente de texto.<br>
 * La opciones que no despliegan son :
 * <ul>
 * <li>tem Deshacer: Nos deshace las acciones realizadas con anterioridad en
 * nuestro cdigo.
 * 
 * <li>tem Rehacer: Podemos rehacer las acciones que acabamos de deshacer en
 * nuestro cdigo.
 * 
 * <li>tem Copiar: Cuando nos referimos a copiar queremos decir que vamos a
 * situar el contenido de texto en portapapeles.
 * 
 * <li>tem Cortar: Cuando hablamos de cortar queremos decir quitar algo de un
 * lugar para llevarlo a otro lugar.
 * 
 * <li>tem Pegar: Si seleccionamos esta opcin la cantidad de texto que
 * tengamos en el Portapapeles se introducir en nuestro componente de texto.
 * 
 * <li>tem Seleccionar todo: Nos marca todo el texto que existe dentro de
 * nuestro componente.
 * 
 * <li>tem Formatear cdigo: Esta opcin solo est definida para los fichero
 * que tenga extensin .java y consistir en sangrar nuestro cdigo fuente.
 * </ul>
 * Si deseamos ampliar con alguna opcin ms nuestro men contextual, debemos
 * definir el JMenuItem y en el mtodo getPopupMenu() se crear y se dir la
 * accin que debe realizar.<br>
 * Si necesitamos algn regla de negocio para la visibilidad del tem se realiza
 * en el mtodo isVisible().
 * 
 *@author mparras
 */
public class MenuPopup extends MouseAdapter {

	private JMenuItem itemMenuEditar_Deshacer, itemMenuEditar_Rehacer,
			itemMenuEditar_Copiar, itemMenuEditar_Pegar;
	private JMenuItem itemMenuEditar_Cortar, itemMenuEditar_Todo,
			itemMenuEditar_Supr, itemMenuEditar_FormatearCodigo;

	private JPopupMenu cachedMenu = null;
	private JavaTextPane iTexto;
	private PanelEdicion iPanel;

	public MenuPopup() {

	}

	/**
	 * Instacia un nuevo menu popup.
	 * 
	 * @param aTexto
	 *            the a texto
	 * @param aPanel
	 *            the a panel
	 */
	public MenuPopup(JavaTextPane aTexto, PanelEdicion aPanel) {
		iTexto = aTexto;
		iPanel = aPanel;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseAdapter#mousePressed(java.awt.event.MouseEvent)
	 */
	public void mousePressed(MouseEvent ev) {

		activarPopup(ev);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseAdapter#mouseReleased(java.awt.event.MouseEvent)
	 */
	public void mouseReleased(MouseEvent ev) {

		activarPopup(ev);

	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.awt.event.MouseAdapter#mouseClicked(java.awt.event.MouseEvent)
	 */
	public void mouseClicked(MouseEvent ev) {

		activarPopup(ev);

	}

	/**
	 *
	 *
	 * activarPopup Activa el menu Pop-up en la cordaneda que nos venga en el
	 * evento
	 * 
	 * @param ev  MouseEvent
	 */
	private void activarPopup(MouseEvent ev) {

		if (ev.isPopupTrigger()) {

			JPopupMenu menu = getPopupMenu();

			menu.pack();

			isVisible();

			menu.show((Component) ev.getSource(), ev.getX(), ev.getY());

		}

	}

	/**
	 * visible Constrola la visibilidades de los componentes aadidos al PopUp
	 * 
	 */
	private void isVisible() {
		if (OperacionesFicheros.getExtension(iPanel.getFicheroTabRun()).equals(
				"jj"))
			itemMenuEditar_FormatearCodigo.setVisible(false);
		else
			itemMenuEditar_FormatearCodigo.setVisible(true);

	}

	/**
	 * instaciamos nuestras variables que contendrn nuestro JPopupMenu y las acciones que realizarn
	 * 
	 * @return JPopupMenu  Devuelve nuestro menu contextual
	 */
	private JPopupMenu getPopupMenu() {
		JPopupMenu menu = cachedMenu;
		if (menu == null) {
			menu = new JPopupMenu();

			// ITEM Deshacer ctrl+Z
			// itemMenuEditar_Deshacer = new JMenuItem("Deshacer Teclado");
			itemMenuEditar_Deshacer = new JMenuItem("Deshacer Teclado",
					IconFactory.getImage("deshacer.gif"));
			itemMenuEditar_Deshacer.setAccelerator(KeyStroke.getKeyStroke(
					KeyEvent.VK_Z, ActionEvent.CTRL_MASK));
			itemMenuEditar_Deshacer.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					iTexto.deshacer();
				}
			});

			menu.add(itemMenuEditar_Deshacer);
			// ITEM Reshacer ctrl+Y
			// itemMenuEditar_Rehacer = new JMenuItem("Rehacer");
			itemMenuEditar_Rehacer = new JMenuItem("Rehacer", IconFactory
					.getImage("rehacer.gif"));
			itemMenuEditar_Rehacer.setAccelerator(KeyStroke.getKeyStroke(
					KeyEvent.VK_Y, ActionEvent.CTRL_MASK));
			itemMenuEditar_Rehacer.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					iTexto.rehacer();
				}
			});

			menu.add(itemMenuEditar_Rehacer);

			menu.addSeparator();

			// ITEM COPIAR ctrl+C
			itemMenuEditar_Copiar = new JMenuItem("Copiar", IconFactory
					.getImage("copiar.gif"));
			itemMenuEditar_Copiar.setAccelerator(KeyStroke.getKeyStroke(
					KeyEvent.VK_C, ActionEvent.CTRL_MASK));
			itemMenuEditar_Copiar.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					iTexto.copiar();
				}
			});
			menu.add(itemMenuEditar_Copiar);

			// ITEM Pegar ctrl+V
			itemMenuEditar_Pegar = new JMenuItem("Pegar", IconFactory
					.getImage("pegar.gif"));
			itemMenuEditar_Pegar.setAccelerator(KeyStroke.getKeyStroke(
					KeyEvent.VK_P, ActionEvent.CTRL_MASK));
			itemMenuEditar_Pegar.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					iTexto.pegar();
				}
			});

			menu.add(itemMenuEditar_Pegar);

			// ITEM Cortar ctrl+x
			itemMenuEditar_Cortar = new JMenuItem("Cortar", IconFactory
					.getImage("cortar.gif"));
			itemMenuEditar_Cortar.setAccelerator(KeyStroke.getKeyStroke(
					KeyEvent.VK_X, ActionEvent.CTRL_MASK));
			itemMenuEditar_Cortar.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					iTexto.cortar();
				}
			});

			menu.add(itemMenuEditar_Cortar);

			menu.addSeparator();

			// ITEM Suprimir SUPR
			itemMenuEditar_Supr = new JMenuItem("Suprimir", IconFactory
					.getImage("suprimir.gif"));
			itemMenuEditar_Supr.setMnemonic('l');
			itemMenuEditar_Supr.setDisplayedMnemonicIndex(2);
			itemMenuEditar_Supr.setAccelerator(KeyStroke.getKeyStroke(
					KeyEvent.VK_DELETE, 0));
			itemMenuEditar_Supr.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					iTexto.suprimir();
				}
			});

			menu.add(itemMenuEditar_Supr);

			// ITEM Seleciona Todo ctr+A
			itemMenuEditar_Todo = new JMenuItem("Selecionar todo ");
			itemMenuEditar_Todo.setAccelerator(KeyStroke.getKeyStroke(
					KeyEvent.VK_A, ActionEvent.CTRL_MASK));
			itemMenuEditar_Todo.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					iTexto.selecionarTodo();
				}
			});
			menu.add(itemMenuEditar_Todo);

			menu.addSeparator();

			// ITEM Reformatear Cdigo
			itemMenuEditar_FormatearCodigo = new JMenuItem("Sangrado Correcto");
			itemMenuEditar_FormatearCodigo.setMnemonic('D');
			itemMenuEditar_FormatearCodigo.setDisplayedMnemonicIndex(6);
			itemMenuEditar_FormatearCodigo.setAccelerator(KeyStroke
					.getKeyStroke(KeyEvent.VK_D, Event.CTRL_MASK
							| Event.SHIFT_MASK));
			itemMenuEditar_FormatearCodigo
					.addActionListener(new ActionListener() {
						public void actionPerformed(ActionEvent e) {
							iTexto.formatearCodigo();
						}
					});

			menu.add(itemMenuEditar_FormatearCodigo);

		}

		return menu;

	}

}
