/*
 * 
 * @author Manuel Parras  
 */
package proyecto.utilidades;


import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.IOException;

import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;

import proyecto.editor.Editor;
import proyecto.editor.EpSilonExcepciones;
import proyecto.editor.PanelEdicion;


/** 
 * MenuPopupConsola.java
 * 
 * Esta clase es la encargada de pintarnos nuestro men contextual cuando
 * pulsemos con el botn derecho del ratn sobre el texto superior de una pestaa de la consola.<br>
 * La opciones que no despliegan son :
 * <ul> 
 * <li>tem Cerrar TAB: Cierra la tab marcada. 
 * <li>tem Cerrar Todas la TABs: Elimina todas las tab del sistema abiertas.
 *
 * </ul>
 * <p>Cuando cerrarmos los item tab verifica si existen cambios.</p>
 * Si deseamos ampliar con alguna opcin ms nuestro men contextual, debemos
 * definir el JMenuItem y en el mtodo getPopupMenu() se crear y se dir la
 * accin que debe realizar.<br>
 * Si necesitamos algn regla de negocio para la visibilidad del tem se realiza
 * en el mtodo isVisible().
 * 
 * @see proyecto.editor.PanelEdicion#cerrarVentanas(boolean)
 *@author mparras
 */
public class MenuPopupTab extends MouseAdapter {

	/** item cerrar todas tab. */
	private JMenuItem itemCerrarTab,itemCerrarTodasTab;




	/** CacheMenu*/
	private JPopupMenu cachedMenu = null;
	
	/** i panel. */
	private PanelEdicion iPanel;

	/**
	 * Constructor menu popup tab.
	 * 
	 * Creado : Parras, 12-oct-2009
	 * 
	 * @param aPanel
	 *            the a panel
	 */
	public MenuPopupTab (PanelEdicion aPanel) {
		iPanel=aPanel;
	}







	/* (non-Javadoc)
	 * @see java.awt.event.MouseAdapter#mousePressed(java.awt.event.MouseEvent)
	 */
	public void mousePressed(MouseEvent ev) {
		if (iPanel.ventanaActiva()>=0){

			activarPopup(ev);
		}


	}


	/* (non-Javadoc)
	 * @see java.awt.event.MouseAdapter#mouseReleased(java.awt.event.MouseEvent)
	 */
	public void mouseReleased(MouseEvent ev) {
		if (iPanel.ventanaActiva()>=0){
			activarPopup(ev);
		}

	}



	/* (non-Javadoc)
	 * @see java.awt.event.MouseAdapter#mouseClicked(java.awt.event.MouseEvent)
	 */
	public void mouseClicked(MouseEvent ev) {
		if (iPanel.ventanaActiva()>=0){
			if (ev.getClickCount()==1){//cambiomos el Texto del Frame

				Editor.get().updateCaption(iPanel.getTextoTabActivo());

			}
			activarPopup(ev);
		}

	}

	/**
	 * Activar popup. Creado : Parras, 12-oct-2009
	 * 
	 * @param ev
	 *            the ev
	 */
	private void activarPopup(MouseEvent ev) {


		if (ev.isPopupTrigger() ){


			JPopupMenu menu = getPopupMenu();


			menu.pack();
			menu.show((Component)ev.getSource(), ev.getX(), ev.getY());


		}


	}

	/**
	 * Obtener el popup menu.
	 * 
	 * @return el popup menu Creado : Parras, 12-oct-2009
	 * @see proyecto.editor.PanelEdicion#cerrarVentanas(boolean)
	 */
	private JPopupMenu getPopupMenu() {
		JPopupMenu menu = cachedMenu;
		if (menu == null) {
			menu = new JPopupMenu();            


			itemCerrarTab = new JMenuItem("Cerrar");
			itemCerrarTab.addActionListener (
					new ActionListener () {
						public void actionPerformed (ActionEvent e) {
							try {
								iPanel.cerrarVentanas(true);
							} catch (EpSilonExcepciones e1) {
								iPanel.setTextoBarraEstado("Error, al Cerrar la pestaa");
							} catch (IOException e1) {
								// TODO Bloque catch generado automticamente
								iPanel.setTextoBarraEstado("Error, al Cerrar la pestaa");
							}
						}
					});


			menu.add(itemCerrarTab);

			itemCerrarTodasTab = new JMenuItem("Cerrar todos");
			itemCerrarTodasTab.addActionListener (
					new ActionListener () {
						public void actionPerformed (ActionEvent e) {
							try {
								iPanel.cerrarVentanas(false);
							} catch (EpSilonExcepciones e1) {
								iPanel.setTextoBarraEstado("Error, al Cerrar la pestaa");
							} catch (IOException e1) {
								
								iPanel.setTextoBarraEstado("Error, al Cerrar la pestaa");
							}
						}
					}
			);

			menu.add(itemCerrarTodasTab);






		}

		return menu;

	}



}

