/*
 * 
 * @author Manuel Parras  
 */
package proyecto.utilidades;

import javax.swing.text.Element;
import javax.swing.text.JTextComponent;


 

/**
 * OperacionesTextPane.
 * <p>Clase con mtodos estaticos para operaciones  bsicas con Componentes de texto, por ejemplo: 
 * <ul>  
 * <li> Columna Cursor: getColumnaCursor</li>
 * <li> LineDel  Cursor: getLineDelCaret</li>
 * <li> ect..</li>
 * </ul>
 * </p>
 * @see javax.swing.text.JTextComponent
 * @author mparras
 * 
 */
public class OperacionesTextPane
{
	
	/**
	 * Devuelve la columna y la posicion que esta el cursor.
	 * 
	 * @param component
	 *            the component
	 * 
	 * @return the columna cursor
	 */	
	public static int getColumnaCursor(JTextComponent component)
	{
		int posicionCursor = component.getCaretPosition();
		
		//Es un mapa de lineas y cada elemento es una linea del texto
		Element raiz = component.getDocument().getDefaultRootElement();//Consigue el elemento de la raz por defecto para el modelo del documento.
		int linea = raiz.getElementIndex( posicionCursor );
		int lineaInicio = raiz.getElement( linea ).getStartOffset();
		//No puede estar en la Columna 0 por eso siempre le sumamos 1
 
		return posicionCursor - lineaInicio + 1;

	}
 
	/**
	 * Devuelve la linea actual del cursor.
	 * 
	 * @param component
	 *            the component
	 * 
	 * @return the line del caret
	 */
	public static int getLineDelCaret(JTextComponent component)
	{
		int posicionCursor = component.getCaretPosition();
		Element raiz = component.getDocument().getDefaultRootElement();
 
		return raiz.getElementIndex( posicionCursor ) + 1;
	}
 
	/**
	 * Devuelve el numero totales de lineas que tiene el texto.
	 * 
	 * @param component
	 *            the component
	 * 
	 * @return the lineas
	 */
	public static int getLineas(JTextComponent component)
	{
		Element raiz = component.getDocument().getDefaultRootElement();
		return raiz.getElementCount();
	}
 

	
	/**
	 * Posicionona el cursor en la linea indicada al principio.
	 * 
	 * @param component
	 *            the component
	 * @param linea
	 *            the linea
	 */  
	public static void irALinea(JTextComponent component, int linea)
	{
		Element raiz = component.getDocument().getDefaultRootElement();
		linea = Math.max(linea, 1);//Por si tiene solo 1 linea siempre nos dara 1, si no nuestra linea
		linea = Math.min(linea, raiz.getElementCount());//por si es el numero total de lineas
		// Le restamos -1 porque getElement cuenta de la posicion 0
		component.setCaretPosition( raiz.getElement( linea - 1 ).getStartOffset() );
	}
	
	

	/**
	 * Pasado un entero nos devuelve su valor en hexadecimal.
	 * 
	 * @param n
	 *            the n
	 * 
	 * @return String
	 */
	public static String rgb_a_hex(int n){
	    int aux=(int)(Math.floor(n/16));
	    int aux2=n%16;
	    return ""+(aux==10?"a":((aux==11?"b":(aux==12?"c":(aux==13?"d":(aux==14?"e":(aux==15?"f":""+aux))))))) +
	    (aux2==10?"a":((aux2==11?"b":(aux2==12?"c":(aux2==13?"d":(aux2==14?"e":(aux2==15?"f":""+aux2)))))));
	  }
	
	
 
}

