/*
 * 
 * @author Manuel Parras  
 */
package proyecto.utilidades;

import java.awt.Dimension;
import java.awt.Window;

/**
 * OperacionesVentanas. 
 * 
 * <p>Clase con mtodos estaticos para operaciones  bsicas con ventanas, por ejemplo:
 * 
 * <ul>  
 * <li> centrar Ventana: centraVentana</li>
 * <li>centrar VentanaHija : centraVentanaHija
 * <li> ect..</li>
 * </ul>
 * </p>
 * 
 * @author mparras
 */
public class OperacionesVentanas {
	
	/**
	 * Centra ventana. Creado : Parras, 13-oct-2009
	 * 
	 * @param ventana
	 *            the ventana
	 */
	public static void centraVentana(Window ventana){
		  java.awt.Dimension ldim = ventana.getToolkit().getScreenSize();
		  ventana.setLocation(ldim.width/2 - ventana.getWidth()/2, ldim.height/2 - ventana.getHeight()/2);
		 }
		 
 		/**
		 * Centra una ventana con respecto a su ventana padre.
		 * 
		 * @param ventana
		 *            the ventana
		 */
		 public static void centraVentanaHija(Window ventana){
		  Window lw = ventana.getOwner();
		  if (lw != null){
		   ventana.setLocation( lw.getX() + (lw.getWidth()/2 - ventana.getWidth()/2)
		     , lw.getY() + (lw.getHeight()/2 - ventana.getHeight()/2)  );
		  } else {
		   centraVentana(ventana);
		  }
		  
		 }
		 
		 /**
		 * Asigna el tamao y centra la ventana.
		 * 
		 * @param iContenedor
		 *            the i contenedor
		 * @param iDimension
		 *            the i dimension
		 */
		 public static void posicionVentana(Window iContenedor, Dimension iDimension)
		 {
		  java.awt.Dimension dim = iContenedor.getToolkit().getScreenSize();
		   
		  int liAnchoW = (int)iDimension.getWidth();
		  int liAltoH = (int)iDimension.getHeight();
		  
		  //setSize(liAnchoW, liAltoH);
		  //setLocation(dim.width/2 - liAnchoW/2, dim.height/2 - liAltoH/2);
		  iContenedor.setBounds(dim.width/2 - liAnchoW/2, dim.height/2 - liAltoH/2, liAnchoW, liAltoH);
		  
		 }
		 
		 
		 /**
		 * Posicion ventana hija. Creado : Parras, 13-oct-2009
		 * 
		 * @param iContenedor
		 *            the i contenedor
		 * @param iDimension
		 *            the i dimension
		 */
 		public static void posicionVentanaHija(Window iContenedor, Dimension iDimension)
		 {
		  Window lw = iContenedor.getOwner();
		  if (lw != null){
		   
		   java.awt.Dimension dim = iContenedor.getToolkit().getScreenSize();
		 
		   int liAnchoW = (int)iDimension.getWidth();
		   int liAltoH = (int)iDimension.getHeight();
		  
		   //setSize(liAnchoW, liAltoH);
		   //setLocation(dim.width/2 - liAnchoW/2, dim.height/2 - liAltoH/2);
		   iContenedor.setBounds(lw.getX() + (dim.width/2 - liAnchoW/2), lw.getY() + (dim.height/2 - liAltoH/2), liAnchoW, liAltoH);
		  }
		  else
		  {
		   posicionVentana(iContenedor, iDimension);
		  }
		   
		 }
		 
		 /**
		 * Centra la ventana en horizontal, pero la posicion vertical hay que
		 * proporcionarla.
		 * 
		 * @param iContenedor
		 *            the i contenedor
		 * @param aiAncho
		 *            the ai ancho
		 * @param aiAlto
		 *            the ai alto
		 * @param aiY
		 *            the ai y
		 */
		 public static void posicionVentanaH(Window iContenedor, int aiAncho, int aiAlto, int aiY)
		 {
		  java.awt.Dimension dim = iContenedor.getToolkit().getScreenSize();
		   
		  int liAnchoW = aiAncho;
		  int liAltoH = aiAlto;
		  
		  //setSize(liAnchoW, liAltoH);
		  //setLocation(dim.width/2 - liAnchoW/2, dim.height/2 - liAltoH/2);
		  iContenedor.setBounds(dim.width/2 - liAnchoW/2, aiY, liAnchoW, liAltoH);
		  
		 }

}
